@@ -28,13 +28,19 @@
 
 #include "e-util/e-config.h"
 
+#define EAB_TYPE_CONFIG (eab_config_get_type ())
+#define EAB_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), EAB_TYPE_CONFIG, EABConfig))
+
 G_BEGIN_DECLS
 
 typedef struct _EABConfig EABConfig;
 typedef struct _EABConfigClass EABConfigClass;
+typedef struct _EABConfigPrivate EABConfigPrivate;
 
 struct _EABConfig {
 	EConfig config;
+
+	EABConfigPrivate *priv;
 };
 
 struct _EABConfigClass {
