@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -61,8 +61,8 @@ action_list_folders_init (ActionContext * p_actctx)
 			EBook *book;
 			EBookQuery *query;
 			GList *contacts;
-			char *uri;
-			const char *name;
+			gchar *uri;
+			const gchar *name;
 
 			book = e_book_new (s, NULL);
 			if (!book
@@ -79,7 +79,9 @@ action_list_folders_init (ActionContext * p_actctx)
 			name = e_source_peek_name (s);
 
 			if (outputfile)
-				fprintf (outputfile, "\"%s\",\"%s\",%d\n", uri, name, g_list_length (contacts));
+				fprintf (
+					outputfile, "\"%s\",\"%s\",%d\n",
+					uri, name, g_list_length (contacts));
 			else
 				printf ("\"%s\",\"%s\",%d\n", uri, name, g_list_length (contacts));
 
