@@ -60,10 +60,6 @@
 #include "e-util/e-alert-dialog.h"
 #include "e-util/e-ui-manager.h"
 
-#define COMP_EDITOR_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), TYPE_COMP_EDITOR, CompEditorPrivate))
-
 #define d(x)
 
 /* Private part of the CompEditor structure */
@@ -462,7 +458,8 @@ save_comp (CompEditor *editor)
 	priv->comp = clone;
 
 	e_cal_component_get_uid (priv->comp, &orig_uid);
-	/* make a copy of it, because call of e_cal_create_object rewrites the internal uid */
+	/* Make a copy of it, because call of e_cal_create_object()
+	 * rewrites the internal uid. */
 	orig_uid_copy = g_strdup (orig_uid);
 
 	/* send timezones */
@@ -471,8 +468,8 @@ save_comp (CompEditor *editor)
 
 	/* Attachments*/
 
-	e_cal_component_set_attachment_list (priv->comp,
-					     get_attachment_list (editor));
+	e_cal_component_set_attachment_list (
+		priv->comp, get_attachment_list (editor));
 	icalcomp = e_cal_component_get_icalcomponent (priv->comp);
 	/* send the component to the server */
 	if (!cal_comp_is_on_server (priv->comp, priv->client)) {
@@ -492,12 +489,11 @@ save_comp (CompEditor *editor)
 		}
 		result = e_cal_modify_object (priv->client, icalcomp, priv->mod, &error);
 
-		if (result && priv->mod == CALOBJ_MOD_THIS) {
-			/* FIXME do we really need to do this ? */
-			if ((flags & COMP_EDITOR_DELEGATE) ||
+		if (priv->mod == CALOBJ_MOD_THIS) {
+			if (result && ((flags & COMP_EDITOR_DELEGATE) ||
 				!e_cal_component_has_organizer (clone) ||
 				itip_organizer_is_user (clone, priv->client) ||
-				itip_sentby_is_user (clone, priv->client))
+				itip_sentby_is_user (clone, priv->client)))
 				e_cal_component_commit_sequence (clone);
 			else
 				e_cal_component_abort_sequence (clone);
@@ -632,11 +628,15 @@ save_comp_with_send (CompEditor *editor)
 					editor, E_CAL_COMPONENT_METHOD_REQUEST,
 					strip_alarms);
 		} else {
-			if (!comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_REQUEST, strip_alarms))
+			if (!comp_editor_send_comp (
+				editor, E_CAL_COMPONENT_METHOD_REQUEST,
+				strip_alarms))
 				return FALSE;
 
 			if (delegate)
-				return comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_REPLY, strip_alarms);
+				return comp_editor_send_comp (
+					editor, E_CAL_COMPONENT_METHOD_REPLY,
+					strip_alarms);
 		}
 	}
 
@@ -882,7 +882,8 @@ action_save_cb (GtkAction *action,
 		return;
 
 	if (!text.value)
-		if (!send_component_prompt_subject ((GtkWindow *) editor, priv->client, priv->comp))
+		if (!send_component_prompt_subject (
+			(GtkWindow *) editor, priv->client, priv->comp))
 			return;
 
 	if (save_comp_with_send (editor)) {
@@ -1444,7 +1445,7 @@ comp_editor_dispose (GObject *object)
 {
 	CompEditorPrivate *priv;
 
-	priv = COMP_EDITOR_GET_PRIVATE (object);
+	priv = COMP_EDITOR (object)->priv;
 
 	if (priv->shell != NULL) {
 		g_object_remove_weak_pointer (
@@ -1508,7 +1509,7 @@ comp_editor_finalize (GObject *object)
 {
 	CompEditorPrivate *priv;
 
-	priv = COMP_EDITOR_GET_PRIVATE (object);
+	priv = COMP_EDITOR (object)->priv;
 
 	g_free (priv->summary);
 
@@ -1609,7 +1610,7 @@ comp_editor_drag_motion (GtkWidget *widget,
 	CompEditorPrivate *priv;
 	EAttachmentView *view;
 
-	priv = COMP_EDITOR_GET_PRIVATE (widget);
+	priv = COMP_EDITOR (widget)->priv;
 	view = E_ATTACHMENT_VIEW (priv->attachment_view);
 
 	return e_attachment_view_drag_motion (view, context, x, y, time);
@@ -1627,7 +1628,7 @@ comp_editor_drag_data_received (GtkWidget *widget,
 	CompEditorPrivate *priv;
 	EAttachmentView *view;
 
-	priv = COMP_EDITOR_GET_PRIVATE (widget);
+	priv = COMP_EDITOR (widget)->priv;
 	view = E_ATTACHMENT_VIEW (priv->attachment_view);
 
 	/* Forward the data to the attachment view.  Note that calling
@@ -1836,7 +1837,8 @@ comp_editor_init (CompEditor *editor)
 	express_mode = e_shell_get_express_mode (shell);
 	meego_mode = e_shell_get_meego_mode (shell);
 
-	editor->priv = priv = COMP_EDITOR_GET_PRIVATE (editor);
+	editor->priv = priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		editor, TYPE_COMP_EDITOR, CompEditorPrivate);
 
 	g_object_weak_ref (
 		G_OBJECT (editor), (GWeakNotify)
@@ -1969,6 +1971,10 @@ comp_editor_init (CompEditor *editor)
 	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
 	gtk_widget_show (widget);
 
+	gtk_style_context_add_class (
+		gtk_widget_get_style_context (widget),
+		GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
+
 	widget = e_attachment_paned_new ();
 	gtk_container_set_border_width (GTK_CONTAINER (widget), 6);
 	gtk_box_pack_start (GTK_BOX (container), widget, TRUE, TRUE, 0);
@@ -2091,7 +2097,8 @@ prompt_and_save_changes (CompEditor *editor, gboolean send)
 			return FALSE;
 
 		if (!text.value)
-			if (!send_component_prompt_subject ((GtkWindow *) editor, priv->client, priv->comp))
+			if (!send_component_prompt_subject (
+				(GtkWindow *) editor, priv->client, priv->comp))
 				return FALSE;
 
 		if (e_cal_component_is_instance (priv->comp))
@@ -3198,11 +3205,11 @@ comp_editor_get_comp (CompEditor *editor)
 
 /**
  * comp_editor_get_current_comp
+ * @editor: a #CompEditor
+ * @correct: Set this no non-%NULL if you are interested to know if all
+ * pages reported success when filling component.
  *
- * @param editor
- * @param correct Set this no non-NULL if you are interested to know if
- *                all pages reported success when filling component.
- * @return Newly allocated component, should be unref-ed by g_object_unref.
+ * Returns: Newly allocated component, should be unref-ed by g_object_unref().
  **/
 ECalComponent *
 comp_editor_get_current_comp (CompEditor *editor, gboolean *correct)
