@@ -42,6 +42,7 @@
 #include "misc/e-buffer-tagger.h"
 
 #include "e-util/e-util.h"
+#include "e-util/e-account-utils.h"
 #include "e-util/e-categories-config.h"
 #include "e-util/e-dialog-utils.h"
 #include "e-util/e-dialog-widgets.h"
@@ -63,8 +64,6 @@ struct _MemoPagePrivate {
 
 	GtkWidget *memo_content;
 
-	EAccountList *accounts;
-
 	/* Generic informative messages placeholder */
 	GtkWidget *info_hbox;
 	GtkWidget *info_icon;
@@ -93,7 +92,8 @@ struct _MemoPagePrivate {
 
 	GtkWidget *source_selector;
 
-	GList *address_strings;
+	gchar **address_strings;
+	gchar *fallback_address;
 
 	ENameSelector *name_selector;
 };
@@ -106,6 +106,56 @@ static void memo_page_select_organizer (MemoPage *mpage, const gchar *backend_ad
 
 G_DEFINE_TYPE (MemoPage, memo_page, TYPE_COMP_EDITOR_PAGE)
 
+static gboolean
+get_current_identity (MemoPage *page,
+                      gchar **name,
+                      gchar **mailto)
+{
+	EAccountList *account_list;
+	EIterator *iterator;
+	GtkWidget *entry;
+	const gchar *text;
+	gboolean match = FALSE;
+
+	entry = gtk_bin_get_child (GTK_BIN (page->priv->org_combo));
+	text = gtk_entry_get_text (GTK_ENTRY (entry));
+
+	if (text == NULL || *text == '\0')
+		return FALSE;
+
+	account_list = e_get_account_list ();
+	iterator = e_list_get_iterator (E_LIST (account_list));
+
+	while (!match && e_iterator_is_valid (iterator)) {
+		EAccount *account;
+		const gchar *id_name;
+		const gchar *id_address;
+		gchar *identity;
+
+		/* XXX EIterator misuses const. */
+		account = (EAccount *) e_iterator_get (iterator);
+
+		id_name = account->id->name;
+		id_address = account->id->address;
+
+		identity = g_strdup_printf ("%s <%s>", id_name, id_address);
+		match = (g_ascii_strcasecmp (text, identity) == 0);
+		g_free (identity);
+
+		if (match && name != NULL)
+			*name = g_strdup (id_name);
+
+		if (match && mailto != NULL)
+			*mailto = g_strdup_printf ("MAILTO:%s", id_address);
+
+		e_iterator_next (iterator);
+	}
+
+	g_object_unref (iterator);
+
+	return match;
+}
+
 /* Fills the widgets with default values */
 static void
 clear_widgets (MemoPage *mpage)
@@ -138,8 +188,8 @@ memo_page_dispose (GObject *object)
 
 	priv = MEMO_PAGE (object)->priv;
 
-	g_list_foreach (priv->address_strings, (GFunc) g_free, NULL);
-	g_list_free (priv->address_strings);
+	g_strfreev (priv->address_strings);
+	g_free (priv->fallback_address);
 
 	/* Chain up to parent's dispose() method. */
 	G_OBJECT_CLASS (memo_page_parent_class)->dispose (object);
@@ -552,35 +602,6 @@ fill_comp_with_recipients (ENameSelector *name_selector, ECalComponent *comp)
 		return FALSE;
 }
 
-static EAccount *
-get_current_account (MemoPage *page)
-{
-	MemoPagePrivate *priv = page->priv;
-	EIterator *it;
-	const gchar *str;
-
-	str = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (priv->org_combo))));
-	if (!str)
-		return NULL;
-
-	for (it = e_list_get_iterator ((EList *)priv->accounts); e_iterator_is_valid (it); e_iterator_next (it)) {
-		EAccount *a = (EAccount *)e_iterator_get (it);
-		gchar *full = g_strdup_printf("%s <%s>", a->id->name, a->id->address);
-
-		if (!g_ascii_strcasecmp (full, str)) {
-			g_free (full);
-			g_object_unref (it);
-
-			return a;
-		}
-
-		g_free (full);
-	}
-	g_object_unref (it);
-
-	return NULL;
-}
-
 /* fill_component handler for the memo page */
 static gboolean
 memo_page_fill_component (CompEditorPage *page,
@@ -698,36 +719,39 @@ memo_page_fill_component (CompEditorPage *page,
 	if ((flags & COMP_EDITOR_IS_SHARED) && (flags & COMP_EDITOR_NEW_ITEM) && fill_comp_with_recipients (priv->name_selector, comp)) {
 		ECalComponentOrganizer organizer = {NULL, NULL, NULL, NULL};
 
-		EAccount *a;
-		gchar *backend_addr = NULL, *org_addr = NULL, *sentby = NULL;
+		gchar *backend_addr = NULL;
+		gchar *backend_mailto = NULL;
+		gchar *name;
+		gchar *mailto;
 
 		e_cal_get_cal_address (client, &backend_addr, NULL);
 
 		/* Find the identity for the organizer or sentby field */
-		a = get_current_account (mpage);
-
-		/* Sanity Check */
-		if (a == NULL) {
-			e_notice (priv->main, GTK_MESSAGE_ERROR,
-					_("The organizer selected no longer has an account."));
+		if (!get_current_identity (mpage, &name, &mailto)) {
+			e_notice (
+				priv->main, GTK_MESSAGE_ERROR,
+				_("An organizer is required."));
 			return FALSE;
 		}
 
-		if (a->id->address == NULL || strlen (a->id->address) == 0) {
-			e_notice (priv->main, GTK_MESSAGE_ERROR,
-					_("An organizer is required."));
-			return FALSE;
+		/* Prefer the backend addres if we have one. */
+		if (backend_addr != NULL && *backend_addr != '\0') {
+			backend_mailto = g_strdup_printf (
+				"MAILTO:%s", backend_addr);
+			if (g_ascii_strcasecmp (backend_mailto, mailto) == 0) {
+				g_free (backend_mailto);
+				backend_mailto = NULL;
+			}
 		}
 
-		if (!(backend_addr && *backend_addr) || !g_ascii_strcasecmp (backend_addr, a->id->address)) {
-			org_addr = g_strdup_printf ("MAILTO:%s", a->id->address);
-			organizer.value = org_addr;
-			organizer.cn = a->id->name;
+		if (backend_mailto == NULL) {
+			organizer.cn = name;
+			organizer.value = mailto;
+			name = mailto = NULL;
 		} else {
-			org_addr = g_strdup_printf ("MAILTO:%s", backend_addr);
-			sentby = g_strdup_printf ("MAILTO:%s", a->id->address);
-			organizer.value = org_addr;
-			organizer.sentby = sentby;
+			organizer.value = backend_mailto;
+			organizer.sentby = mailto;
+			backend_mailto = mailto = NULL;
 		}
 
 		e_cal_component_set_organizer (comp, &organizer);
@@ -736,8 +760,9 @@ memo_page_fill_component (CompEditorPage *page,
 			comp_editor_set_needs_send (editor, TRUE);
 
 		g_free (backend_addr);
-		g_free (org_addr);
-		g_free (sentby);
+		g_free (backend_mailto);
+		g_free (name);
+		g_free (mailto);
 	}
 
 	return TRUE;
@@ -1072,18 +1097,12 @@ memo_page_select_organizer (MemoPage *mpage, const gchar *backend_address)
 	MemoPagePrivate *priv;
 	CompEditor *editor;
 	CompEditorFlags flags;
-	GList *l;
 	ECal *client;
-	EAccount *def_account;
-	gchar *def_address = NULL;
 	const gchar *default_address;
 	gboolean subscribed_cal = FALSE;
 	ESource *source = NULL;
 	const gchar *user_addr = NULL;
-
-	def_account = itip_addresses_get_default ();
-	if (def_account && def_account->enabled)
-		def_address = g_strdup_printf("%s <%s>", def_account->id->name, def_account->id->address);
+	gint ii;
 
 	priv = mpage->priv;
 	editor = comp_editor_page_get_editor (COMP_EDITOR_PAGE (mpage));
@@ -1100,26 +1119,24 @@ memo_page_select_organizer (MemoPage *mpage, const gchar *backend_address)
 	else
 		user_addr = (backend_address && *backend_address) ? backend_address : NULL;
 
-	default_address = NULL;
-	if (user_addr)
-		for (l = priv->address_strings; l != NULL; l = l->next)
-			if (g_strrstr ((gchar *) l->data, user_addr) != NULL) {
-				default_address = (const gchar *) l->data;
+	default_address = priv->fallback_address;
+
+	if (user_addr) {
+		for (ii = 0; priv->address_strings[ii] != NULL; ii++) {
+			if (g_strrstr (priv->address_strings[ii], user_addr) != NULL) {
+				default_address = priv->address_strings[ii];
 				break;
 			}
+		}
+	}
 
-	if (!default_address && def_account)
-		default_address = def_address;
-
-	if (default_address) {
+	if (default_address != NULL) {
 		if (flags & COMP_EDITOR_NEW_ITEM) {
 			gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (priv->org_combo))), default_address);
 			gtk_widget_set_sensitive (priv->org_combo, !subscribed_cal);
 		}
 	} else
 		g_warning ("No potential organizers!");
-
-	g_free (def_address);
 }
 
 /**
@@ -1134,11 +1151,11 @@ memo_page_select_organizer (MemoPage *mpage, const gchar *backend_address)
 MemoPage *
 memo_page_construct (MemoPage *mpage)
 {
-	MemoPagePrivate *priv = mpage->priv;
+	MemoPagePrivate *priv;
 	CompEditor *editor;
 	CompEditorFlags flags;
-	EIterator *it;
-	EAccount *a;
+
+	priv = mpage->priv;
 
 	editor = comp_editor_page_get_editor (COMP_EDITOR_PAGE (mpage));
 	flags = comp_editor_get_flags (editor);
@@ -1153,35 +1170,18 @@ memo_page_construct (MemoPage *mpage)
 	}
 
 	if (flags & COMP_EDITOR_IS_SHARED) {
-		priv->accounts = itip_addresses_get ();
-		for (it = e_list_get_iterator ((EList *)priv->accounts);
-				e_iterator_is_valid (it);
-				e_iterator_next (it)) {
-			gchar *full = NULL;
+		GtkTreeModel *model;
+		gint ii;
 
-			a = (EAccount *)e_iterator_get (it);
+		model = gtk_combo_box_get_model (GTK_COMBO_BOX (priv->org_combo));
+		priv->address_strings = itip_get_user_identities ();
+		priv->fallback_address = itip_get_fallback_identity ();
 
-			/* skip disabled accounts */
-			if (!a->enabled)
-				continue;
+		for (ii = 0; priv->address_strings[ii] != NULL; ii++)
+			e_dialog_append_list_store_text (
+				model, 0, priv->address_strings[ii]);
 
-			full = g_strdup_printf("%s <%s>", a->id->name, a->id->address);
-
-			priv->address_strings = g_list_append (priv->address_strings, full);
-		}
-
-		g_object_unref (it);
-
-		if (priv->address_strings) {
-			GList *l;
-			GtkTreeModel *model = gtk_combo_box_get_model (GTK_COMBO_BOX (priv->org_combo));
-
-			for (l = priv->address_strings; l; l = l->next)
-				e_dialog_append_list_store_text (model, 0, l->data);
-
-			gtk_combo_box_set_active (GTK_COMBO_BOX (priv->org_combo), 0);
-		} else
-			g_warning ("No potential organizers!");
+		gtk_combo_box_set_active (GTK_COMBO_BOX (priv->org_combo), 0);
 
 		gtk_widget_show (priv->org_label);
 		gtk_widget_show (priv->org_combo);
