@@ -35,7 +35,7 @@
  * Implements dialog for allowing user to select a destination source.
  */
 ESource *
-select_source_dialog (GtkWindow *parent, ECalSourceType obj_type)
+select_source_dialog (GtkWindow *parent, ECalSourceType obj_type, ESource *except_source)
 {
 	GtkWidget *dialog;
 	ESourceList *source_list;
@@ -48,7 +48,7 @@ select_source_dialog (GtkWindow *parent, ECalSourceType obj_type)
 		gconf_key = "/apps/evolution/calendar/sources";
 	else if (obj_type == E_CAL_SOURCE_TYPE_TODO)
 		gconf_key = "/apps/evolution/tasks/sources";
-        else if (obj_type == E_CAL_SOURCE_TYPE_JOURNAL)
+	else if (obj_type == E_CAL_SOURCE_TYPE_JOURNAL)
                 gconf_key = "/apps/evolution/memos/sources";
 	else
 		return NULL;
@@ -63,12 +63,15 @@ select_source_dialog (GtkWindow *parent, ECalSourceType obj_type)
 		icon_name = "x-office-calendar";
 	else if (obj_type == E_CAL_SOURCE_TYPE_TODO)
 		icon_name = "stock_todo";
-        else if (obj_type == E_CAL_SOURCE_TYPE_JOURNAL)
+	else if (obj_type == E_CAL_SOURCE_TYPE_JOURNAL)
                 icon_name = "stock_journal";
 
 	if (icon_name)
 		gtk_window_set_icon_name (GTK_WINDOW (dialog), icon_name);
 
+	if (except_source)
+		g_object_set_data (G_OBJECT (dialog), "except-source", except_source);
+
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
 		selected_source = e_source_selector_dialog_peek_primary_selection (E_SOURCE_SELECTOR_DIALOG (dialog));
 		if (selected_source) {
