@@ -222,66 +222,54 @@ static void
 task_editor_show_categories (CompEditor *editor,
                              gboolean visible)
 {
-	TaskEditorPrivate *priv;
+	TaskEditor *task_editor = TASK_EDITOR (editor);
 
-	priv = TASK_EDITOR_GET_PRIVATE (editor);
-
-	task_page_set_show_categories (priv->task_page, visible);
+	task_page_set_show_categories (task_editor->priv->task_page, visible);
 }
 
 static void
 task_editor_show_role (CompEditor *editor,
                        gboolean visible)
 {
-	TaskEditorPrivate *priv;
+	TaskEditor *task_editor = TASK_EDITOR (editor);
 
-	priv = TASK_EDITOR_GET_PRIVATE (editor);
-
-	task_page_set_view_role (priv->task_page, visible);
+	task_page_set_view_role (task_editor->priv->task_page, visible);
 }
 
 static void
 task_editor_show_rsvp (CompEditor *editor,
                        gboolean visible)
 {
-	TaskEditorPrivate *priv;
+	TaskEditor *task_editor = TASK_EDITOR (editor);
 
-	priv = TASK_EDITOR_GET_PRIVATE (editor);
-
-	task_page_set_view_rsvp (priv->task_page, visible);
+	task_page_set_view_rsvp (task_editor->priv->task_page, visible);
 }
 
 static void
 task_editor_show_status (CompEditor *editor,
                          gboolean visible)
 {
-	TaskEditorPrivate *priv;
+	TaskEditor *task_editor = TASK_EDITOR (editor);
 
-	priv = TASK_EDITOR_GET_PRIVATE (editor);
-
-	task_page_set_view_status (priv->task_page, visible);
+	task_page_set_view_status (task_editor->priv->task_page, visible);
 }
 
 static void
 task_editor_show_time_zone (CompEditor *editor,
                             gboolean visible)
 {
-	TaskEditorPrivate *priv;
+	TaskEditor *task_editor = TASK_EDITOR (editor);
 
-	priv = TASK_EDITOR_GET_PRIVATE (editor);
-
-	task_page_set_show_timezone (priv->task_page, visible);
+	task_page_set_show_timezone (task_editor->priv->task_page, visible);
 }
 
 static void
 task_editor_show_type (CompEditor *editor,
                        gboolean visible)
 {
-	TaskEditorPrivate *priv;
+	TaskEditor *task_editor = TASK_EDITOR (editor);
 
-	priv = TASK_EDITOR_GET_PRIVATE (editor);
-
-	task_page_set_view_type (priv->task_page, visible);
+	task_page_set_view_type (task_editor->priv->task_page, visible);
 }
 
 static void
@@ -418,37 +406,28 @@ task_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 			ECalComponentAttendee *ca = l->data;
 			EMeetingAttendee *ia;
 
-			ia = E_MEETING_ATTENDEE (e_meeting_attendee_new_from_e_cal_component_attendee (ca));
+			ia = E_MEETING_ATTENDEE (
+				e_meeting_attendee_new_from_e_cal_component_attendee (ca));
 			/* If we aren't the organizer or the attendee is just
 			 * delegating, don't allow editing. */
 			if (!comp_editor_get_user_org (editor) ||
 				e_meeting_attendee_is_set_delto (ia))
 				e_meeting_attendee_set_edit_level (
 					ia,  E_MEETING_ATTENDEE_EDIT_NONE);
-			task_page_add_attendee (priv->task_page, ia);
+			comp_editor_page_add_attendee (
+				COMP_EDITOR_PAGE (priv->task_page), ia);
 
 			g_object_unref (ia);
 		}
 
 		/* If we aren't the organizer we can still change our own status */
 		if (!comp_editor_get_user_org (editor)) {
-			EAccountList *accounts;
-			EAccount *account;
-			EIterator *it;
+			EMeetingAttendee *ia;
 
-			accounts = itip_addresses_get ();
-			for (it = e_list_get_iterator ((EList *)accounts);
-				e_iterator_is_valid (it);
-				e_iterator_next (it)) {
-				EMeetingAttendee *ia;
+			ia = e_meeting_store_find_self (priv->model, &row);
 
-				account = (EAccount*)e_iterator_get (it);
-
-				ia = e_meeting_store_find_attendee (priv->model, account->id->address, &row);
-				if (ia != NULL)
-					e_meeting_attendee_set_edit_level (ia, E_MEETING_ATTENDEE_EDIT_STATUS);
-			}
-			g_object_unref (it);
+			if (ia != NULL)
+				e_meeting_attendee_set_edit_level (ia, E_MEETING_ATTENDEE_EDIT_STATUS);
 		} else if (e_cal_get_organizer_must_attend (client)) {
 			EMeetingAttendee *ia;
 
