@@ -80,7 +80,7 @@ void		task_page_show_options		(TaskPage *page);
 void		task_page_hide_options		(TaskPage *page);
 void		task_page_set_assignment	(TaskPage *page,
 						 gboolean set);
-void		task_page_send_options_clicked_cb(TaskPage *tpage);
+void		task_page_send_options_clicked_cb (TaskPage *tpage);
 void		task_page_set_view_role		(TaskPage *page,
 						 gboolean state);
 void		task_page_set_view_status	(TaskPage *page,
@@ -96,8 +96,6 @@ void		task_page_set_show_categories	(TaskPage *page,
 void		task_page_set_info_string	(TaskPage *tpage,
 						 const gchar *icon,
 						 const gchar *msg);
-void		task_page_add_attendee		(TaskPage *tpage,
-						 EMeetingAttendee *attendee);
 
 G_END_DECLS
 
