@@ -34,10 +34,6 @@
 #include <e-util/e-util.h>
 #include <e-util/e-categories-config.h>
 
-#define E_CAL_COMPONENT_PREVIEW_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_CAL_COMPONENT_PREVIEW, ECalComponentPreviewPrivate))
-
 struct _ECalComponentPreviewPrivate {
 	/* information about currently showing component in a preview;
 	   if it didn't change then the preview is not updated */
@@ -134,8 +130,8 @@ timet_to_str_with_zone (ECalComponentDateTime *dt,
 {
 	struct icaltimetype itt;
 	icaltimezone *zone;
-        struct tm tm;
-        gchar buf[256];
+	struct tm tm;
+	gchar buf[256];
 
 	if (dt->tzid) {
 		/* If we can't find the zone, we'll guess its "local" */
@@ -150,9 +146,9 @@ timet_to_str_with_zone (ECalComponentDateTime *dt,
 	itt = *dt->value;
 	if (zone)
 		icaltimezone_convert_time (&itt, zone, default_zone);
-        tm = icaltimetype_to_tm (&itt);
+	tm = icaltimetype_to_tm (&itt);
 
-        e_time_format_date_and_time (
+	e_time_format_date_and_time (
 		&tm, use_24_hour_format,
 		FALSE, FALSE, buf, sizeof (buf));
 
@@ -404,7 +400,9 @@ cal_component_preview_class_init (ECalComponentPreviewClass *class)
 static void
 cal_component_preview_init (ECalComponentPreview *preview)
 {
-	preview->priv = E_CAL_COMPONENT_PREVIEW_GET_PRIVATE (preview);
+	preview->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		preview, E_TYPE_CAL_COMPONENT_PREVIEW,
+		ECalComponentPreviewPrivate);
 }
 
 GType
