@@ -24,7 +24,7 @@
 #define E_MEETING_TIME_SELECTOR_H
 
 #include <gtk/gtk.h>
-#include <libgnomecanvas/gnome-canvas.h>
+#include <libgnomecanvas/libgnomecanvas.h>
 #include <text/e-text.h>
 #include <table/e-table-model.h>
 #include <table/e-table.h>
@@ -174,18 +174,14 @@ struct _EMeetingTimeSelector {
 	GdkColor bg_color;
 	GdkColor all_attendees_bg_color;
 	GdkColor meeting_time_bg_color;
-	GdkColor stipple_bg_color;
 	GdkColor attendee_list_bg_color;
 	GdkColor grid_color;
 	GdkColor grid_shadow_color;
 	GdkColor grid_unused_color;
 	GdkColor busy_colors[E_MEETING_FREE_BUSY_LAST];
 
-	/* The stipple used for attendees with no data. */
-	GdkPixmap *stipple;
-
-	/* GC for drawing the color key. */
-	GdkGC *color_key_gc;
+        /* The pattern used for attendees with no data. */
+        cairo_pattern_t *no_info_pattern;
 
 	/* Width of the hours strings (e.g. "1:00") in the current font. */
 	gint hour_widths[24];
