@@ -39,13 +39,6 @@
 
 #include <text/e-text.h>
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
-#define E_WEEK_VIEW_EVENT_ITEM_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_WEEK_VIEW_EVENT_ITEM, EWeekViewEventItemPrivate))
-
 struct _EWeekViewEventItemPrivate {
 	/* The event index in the EWeekView events array. */
 	gint event_num;
@@ -63,7 +56,7 @@ enum {
 static gpointer parent_class;
 
 static gboolean
-can_draw_in_region (GdkRegion *draw_region,
+can_draw_in_region (cairo_region_t *draw_region,
                     gint x,
                     gint y,
                     gint width,
@@ -78,8 +71,8 @@ can_draw_in_region (GdkRegion *draw_region,
 	rect.width = width;
 	rect.height = height;
 
-	return gdk_region_rect_in (draw_region, &rect) !=
-		GDK_OVERLAP_RECTANGLE_OUT;
+	return cairo_region_contains_rectangle (draw_region, &rect) !=
+		CAIRO_REGION_OVERLAP_OUT;
 }
 
 static ECalendarViewPosition
@@ -304,7 +297,7 @@ week_view_draw_time (EWeekView *week_view,
 	PangoLayout *layout;
 	PangoFontDescription *small_font_desc;
 
-        cairo_save (cr);
+	cairo_save (cr);
 
 	model = e_calendar_view_get_model (E_CALENDAR_VIEW (week_view));
 
@@ -329,16 +322,16 @@ week_view_draw_time (EWeekView *week_view,
 		/* Draw the hour. */
 		if (hour_to_display < 10) {
 			pango_layout_set_text (layout, buffer + 1, 1);
-                        cairo_move_to (cr,
-                                       time_x + week_view->digit_width,
-                                       time_y_normal_font);
-                        pango_cairo_show_layout (cr, layout);
+			cairo_move_to (cr,
+				       time_x + week_view->digit_width,
+				       time_y_normal_font);
+			pango_cairo_show_layout (cr, layout);
 		} else {
 			pango_layout_set_text (layout, buffer, 2);
-                        cairo_move_to (cr,
-                                       time_x,
-                                       time_y_normal_font);
-                        pango_cairo_show_layout (cr, layout);
+			cairo_move_to (cr,
+				       time_x,
+				       time_y_normal_font);
+			pango_cairo_show_layout (cr, layout);
 		}
 
 		time_x += week_view->digit_width * 2;
@@ -346,10 +339,10 @@ week_view_draw_time (EWeekView *week_view,
 		/* Draw the start minute, in the small font. */
 		pango_layout_set_font_description (layout, week_view->small_font_desc);
 		pango_layout_set_text (layout, buffer + 3, 2);
-                cairo_move_to (cr,
-                               time_x,
-                               time_y_small_font);
-                pango_cairo_show_layout (cr, layout);
+		cairo_move_to (cr,
+			       time_x,
+			       time_y_small_font);
+		pango_cairo_show_layout (cr, layout);
 
 		pango_layout_set_font_description (layout, style->font_desc);
 
@@ -359,10 +352,10 @@ week_view_draw_time (EWeekView *week_view,
 		if (!e_cal_model_get_use_24_hour_format (model)) {
 			pango_layout_set_text (layout, suffix, -1);
 
-                        cairo_move_to (cr,
-                                       time_x,
-                                       time_y_normal_font);
-                        pango_cairo_show_layout (cr, layout);
+			cairo_move_to (cr,
+				       time_x,
+				       time_y_normal_font);
+			pango_cairo_show_layout (cr, layout);
 		}
 	} else {
 		/* Draw the start time in one go. */
@@ -370,32 +363,32 @@ week_view_draw_time (EWeekView *week_view,
 			    hour_to_display, minute, suffix);
 		if (hour_to_display < 10) {
 			pango_layout_set_text (layout, buffer + 1, -1);
-                        cairo_move_to (cr,
-                                       time_x + week_view->digit_width,
-                                       time_y_normal_font);
-                        pango_cairo_show_layout (cr, layout);
+			cairo_move_to (cr,
+				       time_x + week_view->digit_width,
+				       time_y_normal_font);
+			pango_cairo_show_layout (cr, layout);
 		} else {
 			pango_layout_set_text (layout, buffer, -1);
-                        cairo_move_to (cr,
-                                       time_x,
-                                       time_y_normal_font);
-                        pango_cairo_show_layout (cr, layout);
+			cairo_move_to (cr,
+				       time_x,
+				       time_y_normal_font);
+			pango_cairo_show_layout (cr, layout);
 		}
 
 	}
 	g_object_unref (layout);
 
-        cairo_restore (cr);
+	cairo_restore (cr);
 }
 
 static void
 week_view_event_item_draw_icons (EWeekViewEventItem *event_item,
-                                 GdkDrawable *drawable,
+                                 cairo_t *cr,
                                  gint icon_x,
                                  gint icon_y,
                                  gint x2,
                                  gboolean right_align,
-                                 GdkRegion *draw_region)
+                                 cairo_region_t *draw_region)
 {
 	EWeekView *week_view;
 	EWeekViewEvent *event;
@@ -407,7 +400,6 @@ week_view_event_item_draw_icons (EWeekViewEventItem *event_item,
 	gboolean draw_timezone_icon = FALSE, draw_attach_icon = FALSE;
 	gboolean draw_meeting_icon = FALSE;
 	GSList *categories_pixbufs = NULL, *pixbufs;
-	cairo_t *cr;
 
 	canvas = GNOME_CANVAS_ITEM (event_item)->canvas;
 	parent = gtk_widget_get_parent (GTK_WIDGET (canvas));
@@ -426,8 +418,6 @@ week_view_event_item_draw_icons (EWeekViewEventItem *event_item,
 	e_cal_component_set_icalcomponent (
 		comp, icalcomponent_new_clone (event->comp_data->icalcomp));
 
-	cr = gdk_cairo_create (drawable);
-
 	if (e_cal_component_has_alarms (comp)) {
 		draw_reminder_icon = TRUE;
 		num_icons++;
@@ -505,7 +495,6 @@ week_view_event_item_draw_icons (EWeekViewEventItem *event_item,
 	g_slist_foreach (categories_pixbufs, (GFunc)g_object_unref, NULL);
 	g_slist_free (categories_pixbufs);
 
-	cairo_destroy (cr);
 	g_object_unref (comp);
 }
 
@@ -513,13 +502,13 @@ week_view_event_item_draw_icons (EWeekViewEventItem *event_item,
    the days visible on screen. */
 static void
 week_view_event_item_draw_triangle (EWeekViewEventItem *event_item,
-                                    GdkDrawable *drawable,
+                                    cairo_t *cr,
                                     GdkColor bg_color,
                                     gint x,
                                     gint y,
                                     gint w,
                                     gint h,
-                                    GdkRegion *draw_region)
+                                    cairo_region_t *draw_region)
 {
 	ECalModel *model;
 	EWeekView *week_view;
@@ -529,7 +518,6 @@ week_view_event_item_draw_triangle (EWeekViewEventItem *event_item,
 	GdkPoint points[3];
 	const gchar *color_spec;
 	gint c1, c2;
-	cairo_t *cr;
 
 	if (!can_draw_in_region (draw_region, x, y, w, h))
 		return;
@@ -547,8 +535,6 @@ week_view_event_item_draw_triangle (EWeekViewEventItem *event_item,
 	if (!is_comp_data_valid (event))
 		return;
 
-	cr = gdk_cairo_create (drawable);
-
 	points[0].x = x;
 	points[0].y = y;
 	points[1].x = x + w;
@@ -562,20 +548,7 @@ week_view_event_item_draw_triangle (EWeekViewEventItem *event_item,
 		e_cal_model_get_color_for_component (model, event->comp_data);
 
 	if (gdk_color_parse (color_spec, &bg_color)) {
-		GdkColormap *colormap;
-
-		colormap = gtk_widget_get_colormap (GTK_WIDGET (week_view));
-		if (gdk_colormap_alloc_color (colormap, &bg_color, TRUE, TRUE)) {
-			gdk_cairo_set_source_color (cr, &bg_color);
-		} else {
-			EWeekViewColors wvc;
-			GdkColor *color;
-
-			wvc = E_WEEK_VIEW_COLOR_EVENT_BACKGROUND;
-			color = &week_view->colors[wvc];
-
-			gdk_cairo_set_source_color (cr, color);
-		}
+		gdk_cairo_set_source_color (cr, &bg_color);
 	} else {
 		EWeekViewColors wvc;
 		GdkColor *color;
@@ -610,8 +583,6 @@ week_view_event_item_draw_triangle (EWeekViewEventItem *event_item,
 	cairo_move_to (cr, x, y + h - 1);
 	cairo_line_to (cr, x + w, c2);
 	cairo_restore (cr);
-
-	cairo_destroy (cr);
 }
 
 static void
@@ -706,7 +677,7 @@ week_view_event_item_update (GnomeCanvasItem *item,
 
 static void
 week_view_event_item_draw (GnomeCanvasItem *canvas_item,
-                           GdkDrawable *drawable,
+                           cairo_t *cr,
                            gint x,
                            gint y,
                            gint width,
@@ -726,12 +697,11 @@ week_view_event_item_draw (GnomeCanvasItem *canvas_item,
 	gboolean draw_start, draw_end;
 	gboolean draw_start_triangle = FALSE, draw_end_triangle = FALSE;
 	GdkColor bg_color;
-	cairo_t *cr;
 	cairo_pattern_t *pat;
 	guint16 red, green, blue;
 	gdouble radius, cx0, cy0, rect_height, rect_width;
 	gdouble cc = 65535.0;
-	GdkRegion *draw_region;
+	cairo_region_t *draw_region;
 	GdkRectangle rect;
 	const gchar *color_spec;
 
@@ -780,15 +750,16 @@ week_view_event_item_draw (GnomeCanvasItem *canvas_item,
 	rect.y = 0;
 	rect.width = width;
 	rect.height = height;
-	draw_region = gdk_region_rectangle (&rect);
+	if (rect.width > 0 && rect.height > 0)
+		draw_region = cairo_region_create_rectangle (&rect);
+	else
+		draw_region = cairo_region_create ();
 
 	if (!can_draw_in_region (draw_region, x1, y1, x2 - x1, y2 - y1)) {
-		gdk_region_destroy (draw_region);
+		cairo_region_destroy (draw_region);
 		return;
 	}
 
-	cr = gdk_cairo_create (drawable);
-
 	icon_y = y1 + E_WEEK_VIEW_EVENT_BORDER_HEIGHT + E_WEEK_VIEW_ICON_Y_PAD;
 
 	/* Get the start & end times in 24-hour format. */
@@ -804,7 +775,8 @@ week_view_event_item_draw (GnomeCanvasItem *canvas_item,
 
 	time_width = e_week_view_get_time_string_width (week_view);
 
-	one_day_event = e_week_view_is_one_day_event (week_view, event_item->priv->event_num);
+	one_day_event = e_week_view_is_one_day_event (
+		week_view, event_item->priv->event_num);
 
 	model = e_calendar_view_get_model (E_CALENDAR_VIEW (week_view));
 
@@ -812,13 +784,8 @@ week_view_event_item_draw (GnomeCanvasItem *canvas_item,
 		e_cal_model_get_color_for_component (model, event->comp_data);
 
 	bg_color = week_view->colors[E_WEEK_VIEW_COLOR_EVENT_BACKGROUND];
-	if (gdk_color_parse (color_spec, &bg_color)) {
-		GdkColormap *colormap;
-
-		colormap = gtk_widget_get_colormap (GTK_WIDGET (week_view));
-		if (!gdk_colormap_alloc_color (colormap, &bg_color, TRUE, TRUE)) {
-			bg_color = week_view->colors[E_WEEK_VIEW_COLOR_EVENT_BACKGROUND];
-		}
+	if (!gdk_color_parse (color_spec, &bg_color)) {
+		bg_color = week_view->colors[E_WEEK_VIEW_COLOR_EVENT_BACKGROUND];
 	}
 
 	red = bg_color.red;
@@ -918,7 +885,7 @@ week_view_event_item_draw (GnomeCanvasItem *canvas_item,
 
 		/* Draw the icons. */
 		week_view_event_item_draw_icons (
-			event_item, drawable, icon_x,
+			event_item, cr, icon_x,
 			icon_y, x2, FALSE, draw_region);
 
 	} else {
@@ -987,7 +954,7 @@ week_view_event_item_draw (GnomeCanvasItem *canvas_item,
 
 		if (draw_start_triangle) {
 			week_view_event_item_draw_triangle (
-				event_item, drawable, bg_color,
+				event_item, cr, bg_color,
 				x1 + E_WEEK_VIEW_EVENT_L_PAD + 2,
 				y1, -3, y2 - y1 + 1, draw_region);
 		} else if (can_draw_in_region (draw_region, rect_x, y1, 1, y2 - y1)) {
@@ -1008,7 +975,7 @@ week_view_event_item_draw (GnomeCanvasItem *canvas_item,
 
 		if (draw_end_triangle) {
 			week_view_event_item_draw_triangle (
-				event_item, drawable, bg_color,
+				event_item, cr, bg_color,
 				x2 - E_WEEK_VIEW_EVENT_R_PAD - 2,
 				y1, 3, y2 - y1 + 1, draw_region);
 		} else if (can_draw_in_region (draw_region, rect_x2, y2, 1, 1)) {
@@ -1047,20 +1014,20 @@ week_view_event_item_draw (GnomeCanvasItem *canvas_item,
 				+ E_WEEK_VIEW_EVENT_BORDER_WIDTH
 				+ E_WEEK_VIEW_EVENT_EDGE_X_PAD;
 
-                        cairo_save (cr);
+			cairo_save (cr);
 
-                        cairo_rectangle (cr,
-                                         x1, y1,
+			cairo_rectangle (cr,
+					 x1, y1,
 					 x2 - x1 - E_WEEK_VIEW_EVENT_R_PAD
 					  - E_WEEK_VIEW_EVENT_BORDER_WIDTH + 1,
 					 y2 - y1 + 1);
-                        cairo_clip (cr);
+			cairo_clip (cr);
 
 			week_view_draw_time (
 				week_view, cr, time_x,
 				time_y, start_hour, start_minute);
 
-                        cairo_restore (cr);
+			cairo_restore (cr);
 
 			/* We don't want the end time to be drawn over the
 			   start time, so we increase the minimum position. */
@@ -1098,13 +1065,12 @@ week_view_event_item_draw (GnomeCanvasItem *canvas_item,
 			|| week_view->editing_span_num != event_item->priv->span_num)) {
 			icon_x = span->text_item->x1 - E_WEEK_VIEW_ICON_R_PAD - x;
 			week_view_event_item_draw_icons (
-				event_item, drawable, icon_x,
+				event_item, cr, icon_x,
 				icon_y, max_icon_x, TRUE, draw_region);
 		}
 	}
-	cairo_destroy (cr);
 
-	gdk_region_destroy (draw_region);
+	cairo_region_destroy (draw_region);
 }
 
 static GnomeCanvasItem *
@@ -1188,7 +1154,9 @@ week_view_event_item_class_init (EWeekViewEventItemClass *class)
 static void
 week_view_event_item_init (EWeekViewEventItem *event_item)
 {
-	event_item->priv = E_WEEK_VIEW_EVENT_ITEM_GET_PRIVATE (event_item);
+	event_item->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		event_item, E_TYPE_WEEK_VIEW_EVENT_ITEM,
+		EWeekViewEventItemPrivate);
 
 	event_item->priv->event_num = -1;
 	event_item->priv->span_num = -1;
