@@ -31,7 +31,6 @@
 #include <gtk/gtk.h>
 #include <misc/e-calendar.h>
 #include <libecal/e-cal.h>
-#include <shell/e-shell-settings.h>
 
 #include "e-cal-model.h"
 
@@ -113,10 +112,8 @@ struct _GnomeCalendarClass {
 };
 
 GType		gnome_calendar_get_type		(void);
-GtkWidget *	gnome_calendar_new		(EShellSettings *shell_settings);
+GtkWidget *	gnome_calendar_new		(void);
 void		gnome_calendar_dispose          (GnomeCalendar *gcal);
-EShellSettings *gnome_calendar_get_shell_settings
-						(GnomeCalendar *gcal);
 ECalendar *	gnome_calendar_get_date_navigator
 						(GnomeCalendar *gcal);
 void		gnome_calendar_set_date_navigator
@@ -138,7 +135,7 @@ void		gnome_calendar_next		(GnomeCalendar *gcal);
 void		gnome_calendar_previous		(GnomeCalendar *gcal);
 void		gnome_calendar_goto		(GnomeCalendar *gcal,
 						 time_t new_time);
-void		gnome_calendar_update_view_times(GnomeCalendar *gcal,
+void		gnome_calendar_update_view_times (GnomeCalendar *gcal,
 						 time_t start_time);
 void		gnome_calendar_dayjump		(GnomeCalendar *gcal,
 						 time_t time);
@@ -152,7 +149,7 @@ void		gnome_calendar_display_view	(GnomeCalendar *gcal,
 						 GnomeCalendarViewType view_type);
 
 struct _ECalendarView *
-		gnome_calendar_get_calendar_view(GnomeCalendar *gcal,
+		gnome_calendar_get_calendar_view (GnomeCalendar *gcal,
 						 GnomeCalendarViewType view_type);
 
 gboolean	gnome_calendar_get_range_selected
