@@ -28,6 +28,7 @@
 #include <libedataserver/e-time-utils.h>
 #include <gtk/gtk.h>
 #include <libical/ical.h>
+#include <e-util/e-account-utils.h>
 #include <e-util/e-dialog-utils.h>
 #include <libecal/e-cal-time-util.h>
 #include <libecal/e-cal-util.h>
@@ -60,28 +61,111 @@ static icalproperty_method itip_methods_enum[] = {
     ICAL_METHOD_DECLINECOUNTER,
 };
 
-static EAccountList *accounts = NULL;
-
-EAccountList *
-itip_addresses_get (void)
+/**
+ * itip_get_user_identities:
+ *
+ * Returns a %NULL-terminated array of name + address strings based on
+ * registered mail identities.  Free the returned array with g_strfreev().
+ *
+ * Returns: an %NULL-terminated array of mail identity strings
+ **/
+gchar **
+itip_get_user_identities (void)
 {
-	if (accounts == NULL) {
-		GConfClient *gconf_client = gconf_client_get_default ();
-		accounts = e_account_list_new (gconf_client);
-		g_object_unref (gconf_client);
+	EAccountList *account_list;
+	EIterator *iterator;
+	gchar **identities;
+	gint length, ii = 0;
+
+	account_list = e_get_account_list ();
+	length = e_list_length (E_LIST (account_list));
+	iterator = e_list_get_iterator (E_LIST (account_list));
+
+	identities = g_new0 (gchar *, length + 1);
+
+	while (e_iterator_is_valid (iterator)) {
+		EAccount *account;
+
+		/* XXX EIterator misuses const. */
+		account = (EAccount *) e_iterator_get (iterator);
+
+		if (account->enabled)
+			identities[ii++] = g_strdup_printf (
+				"%s <%s>",
+				account->id->name,
+				account->id->address);
+
+		e_iterator_next (iterator);
 	}
 
-	return accounts;
+	g_object_unref (iterator);
+
+	return identities;
 }
 
-EAccount *
-itip_addresses_get_default (void)
+/**
+ * itip_get_fallback_identity:
+ *
+ * Returns a name + address string taken from the default mail identity,
+ * but only if the corresponding account is enabled.  If the account is
+ * disabled, the function returns %NULL.  This is meant to be used as a
+ * fallback identity for organizers.  Free the returned string with
+ * g_free().
+ *
+ * Returns: a fallback mail identity, or %NULL
+ **/
+gchar *
+itip_get_fallback_identity (void)
 {
-	return (EAccount *)e_account_list_get_default (itip_addresses_get ());
+	EAccount *account;
+	gchar *identity = NULL;
+
+	account = e_get_default_account ();
+	if (account != NULL && account->enabled)
+		identity = g_strdup_printf (
+			"%s <%s>",
+			account->id->name,
+			account->id->address);
+
+	return identity;
+}
+
+/**
+ * itip_address_is_user:
+ * @address: an email address
+ *
+ * Looks for a registered mail identity with a matching email address.
+ *
+ * Returns: %TRUE if a match was found, %FALSE if not
+ **/
+gboolean
+itip_address_is_user (const gchar *address)
+{
+	EAccountList *account_list;
+	EAccount *account;
+
+	g_return_val_if_fail (address != NULL, FALSE);
+
+	account_list = e_get_account_list ();
+
+	/* XXX EAccountList misuses const. */
+	account = (EAccount *) e_account_list_find (
+		account_list, E_ACCOUNT_FIND_ID_ADDRESS, address);
+
+	return (account != NULL);
 }
 
 gboolean
-itip_organizer_is_user_ex (ECalComponent *comp, ECal *client, gboolean skip_cap_test)
+itip_organizer_is_user (ECalComponent *comp,
+                        ECal *client)
+{
+	return itip_organizer_is_user_ex (comp, client, FALSE);
+}
+
+gboolean
+itip_organizer_is_user_ex (ECalComponent *comp,
+                           ECal *client,
+                           gboolean skip_cap_test)
 {
 	ECalComponentOrganizer organizer;
 	const gchar *strip;
@@ -112,22 +196,15 @@ itip_organizer_is_user_ex (ECalComponent *comp, ECal *client, gboolean skip_cap_
 			return FALSE;
 		}
 
-		user_org = e_account_list_find (
-			itip_addresses_get (),
-			E_ACCOUNT_FIND_ID_ADDRESS, strip) != NULL;
+		user_org = itip_address_is_user (strip);
 	}
 
 	return user_org;
 }
 
 gboolean
-itip_organizer_is_user (ECalComponent *comp, ECal *client)
-{
-	return itip_organizer_is_user_ex (comp, client, FALSE);
-}
-
-gboolean
-itip_sentby_is_user (ECalComponent *comp, ECal *client)
+itip_sentby_is_user (ECalComponent *comp,
+                     ECal *client)
 {
 	ECalComponentOrganizer organizer;
 	const gchar *strip;
@@ -141,16 +218,15 @@ itip_sentby_is_user (ECalComponent *comp, ECal *client)
 	e_cal_component_get_organizer (comp, &organizer);
 	if (organizer.sentby != NULL) {
 		strip = itip_strip_mailto (organizer.sentby);
-		user_sentby = e_account_list_find (
-			itip_addresses_get (),
-			E_ACCOUNT_FIND_ID_ADDRESS, strip) != NULL;
+		user_sentby = itip_address_is_user (strip);
 	}
 
 	return user_sentby;
 }
 
 static ECalComponentAttendee *
-get_attendee (GSList *attendees, gchar *address)
+get_attendee (GSList *attendees,
+              gchar *address)
 {
 	GSList *l;
 
@@ -169,7 +245,8 @@ get_attendee (GSList *attendees, gchar *address)
 }
 
 static ECalComponentAttendee *
-get_attendee_if_attendee_sentby_is_user (GSList *attendees, gchar *address)
+get_attendee_if_attendee_sentby_is_user (GSList *attendees,
+                                         gchar *address)
 {
 	GSList *l;
 
@@ -199,7 +276,8 @@ html_new_lines_for (const gchar *string)
 }
 
 gchar *
-itip_get_comp_attendee (ECalComponent *comp, ECal *client)
+itip_get_comp_attendee (ECalComponent *comp,
+                        ECal *client)
 {
 	GSList *attendees;
 	EAccountList *al;
@@ -209,7 +287,7 @@ itip_get_comp_attendee (ECalComponent *comp, ECal *client)
 	gchar *address = NULL;
 
 	e_cal_component_get_attendee_list (comp, &attendees);
-	al = itip_addresses_get ();
+	al = e_get_account_list ();
 
 	if (client)
 		e_cal_get_cal_address (client, &address, NULL);
@@ -255,8 +333,9 @@ itip_get_comp_attendee (ECalComponent *comp, ECal *client)
 			return user_email;
 		}
 
-		/* If the account was not found in the attendees list, then let's
-		check the 'sentby' fields of the attendees if we can find the account */
+		/* If the account was not found in the attendees list, then
+		 * let's check the 'sentby' fields of the attendees if we can
+		 * find the account. */
 		attendee = get_attendee_if_attendee_sentby_is_user (attendees, a->id->address);
 		if (attendee) {
 			gchar *user_email = g_strdup (itip_strip_mailto (attendee->sentby));
@@ -266,10 +345,11 @@ itip_get_comp_attendee (ECalComponent *comp, ECal *client)
 		}
 	}
 
-	/* We could not find the attendee in the component, so just give the default
-	account address if the email address is not set in the backend */
+	/* We could not find the attendee in the component, so just give
+	 * the default account address if the email address is not set in
+	 * the backend. */
 	/* FIXME do we have a better way ? */
-	a = itip_addresses_get_default ();
+	a = e_get_default_account ();
 	address = g_strdup ((a != NULL) ? a->id->address : "");
 
 	e_cal_component_free_attendee_list (attendees);
@@ -377,7 +457,8 @@ comp_toplevel_with_zones (ECalComponentItipMethod method,
 }
 
 static gboolean
-users_has_attendee (GList *users, const gchar *address)
+users_has_attendee (GList *users,
+                    const gchar *address)
 {
 	GList *l;
 
@@ -390,7 +471,8 @@ users_has_attendee (GList *users, const gchar *address)
 }
 
 static gchar *
-comp_from (ECalComponentItipMethod method, ECalComponent *comp)
+comp_from (ECalComponentItipMethod method,
+           ECalComponent *comp)
 {
 	ECalComponentOrganizer organizer;
 	ECalComponentAttendee *attendee;
@@ -639,7 +721,8 @@ comp_to_list (ECalComponentItipMethod method,
 }
 
 static gchar *
-comp_subject (ECalComponentItipMethod method, ECalComponent *comp)
+comp_subject (ECalComponentItipMethod method,
+              ECalComponent *comp)
 {
 	ECalComponentText caltext;
 	const gchar *description, *prefix = NULL;
@@ -781,12 +864,19 @@ comp_subject (ECalComponentItipMethod method, ECalComponent *comp)
 }
 
 static gchar *
-comp_content_type (ECalComponent *comp, ECalComponentItipMethod method)
+comp_content_type (ECalComponent *comp,
+                   ECalComponentItipMethod method)
 {
+	const gchar *name;
+
+	if (e_cal_component_get_vtype (comp) == E_CAL_COMPONENT_FREEBUSY)
+		name = "freebusy.ifb";
+	else
+		name = "calendar.ics";
+
 	return g_strdup_printf (
 		"text/calendar; name=\"%s\"; charset=utf-8; METHOD=%s",
-		e_cal_component_get_vtype (comp) == E_CAL_COMPONENT_FREEBUSY ?
-		"freebusy.ifb" : "calendar.ics", itip_methods[method]);
+		name, itip_methods[method]);
 }
 
 static const gchar *
@@ -918,21 +1008,19 @@ comp_limit_attendees (ECalComponent *comp)
 		attendee_text = g_strdup (itip_strip_mailto (attendee));
 		g_free (attendee);
 		attendee_text = g_strstrip (attendee_text);
-		found = match = e_account_list_find (
-			itip_addresses_get (),
-			E_ACCOUNT_FIND_ID_ADDRESS,
-			attendee_text) != NULL;
+		found = match = itip_address_is_user (attendee_text);
 
 		if (!found) {
 			param = icalproperty_get_first_parameter (prop, ICAL_SENTBY_PARAMETER);
 			if (param) {
-				attendee_sentby = icalparameter_get_sentby (param);
-				attendee_sentby_text = g_strdup (itip_strip_mailto (attendee_sentby));
-				attendee_sentby_text = g_strstrip (attendee_sentby_text);
-				found = match = e_account_list_find (
-					itip_addresses_get (),
-					E_ACCOUNT_FIND_ID_ADDRESS,
-					attendee_sentby_text) != NULL;
+				attendee_sentby =
+					icalparameter_get_sentby (param);
+				attendee_sentby =
+					itip_strip_mailto (attendee_sentby);
+				attendee_sentby_text =
+					g_strstrip (g_strdup (attendee_sentby));
+				found = match = itip_address_is_user (
+					attendee_sentby_text);
 			}
 		}
 
@@ -963,7 +1051,7 @@ comp_sentby (ECalComponent *comp, ECal *client)
 
 	e_cal_component_get_organizer (comp, &organizer);
 	if (!organizer.value) {
-		EAccount *a = itip_addresses_get_default ();
+		EAccount *a = e_get_default_account ();
 
 		organizer.value = g_strdup_printf ("MAILTO:%s", a->id->address);
 		organizer.sentby = NULL;
@@ -991,7 +1079,7 @@ comp_sentby (ECalComponent *comp, ECal *client)
 	}
 
 	if (!itip_organizer_is_user (comp, client) && !itip_sentby_is_user (comp, client)) {
-		EAccount *a = itip_addresses_get_default ();
+		EAccount *a = e_get_default_account ();
 
 		organizer.value = g_strdup (organizer.value);
 		organizer.sentby = g_strdup_printf ("MAILTO:%s", a->id->address);
@@ -1262,7 +1350,8 @@ append_cal_attachments (EMsgComposer *composer,
 			attachment, mime_attach->encoded_data,
 			mime_attach->length, mime_attach->content_type);
 		if (mime_attach->content_id)
-			camel_mime_part_set_content_id (attachment, mime_attach->content_id);
+			camel_mime_part_set_content_id (
+				attachment, mime_attach->content_id);
 		if (mime_attach->filename != NULL)
 			camel_mime_part_set_filename (
 				attachment, mime_attach->filename);
@@ -1290,7 +1379,8 @@ append_cal_attachments (EMsgComposer *composer,
 }
 
 static EAccount *
-find_enabled_account (EAccountList *accounts, const gchar *id_address)
+find_enabled_account (EAccountList *accounts,
+                      const gchar *id_address)
 {
 	EIterator *it;
 	EAccount *account = NULL;
@@ -1487,7 +1577,7 @@ itip_send_comp (ECalComponentItipMethod method,
 
 	retval = TRUE;
 
- cleanup:
+cleanup:
 	if (comp != NULL)
 		g_object_unref (comp);
 	if (top_level != NULL)
@@ -1676,8 +1766,10 @@ reply_to_calendar_comp (ECalComponentItipMethod method,
 }
 
 gboolean
-itip_publish_begin (ECalComponent *pub_comp, ECal *client,
-		    gboolean cloned, ECalComponent **clone)
+itip_publish_begin (ECalComponent *pub_comp,
+                    ECal *client,
+                    gboolean cloned,
+                    ECalComponent **clone)
 {
 	icalcomponent *icomp =NULL, *icomp_clone = NULL;
 	icalproperty *prop;
@@ -1814,14 +1906,14 @@ comp_fb_normalize (icalcomponent *icomp)
 	}
 
 	return iclone;
-	/* this will never be reached */
-	g_object_unref (iclone);
-	return NULL;
 }
 
 gboolean
-itip_publish_comp (ECal *client, gchar *uri, gchar *username,
-		   gchar *password, ECalComponent **pub_comp)
+itip_publish_comp (ECal *client,
+                   gchar *uri,
+                   gchar *username,
+                   gchar *password,
+                   ECalComponent **pub_comp)
 {
 	icalcomponent *toplevel = NULL, *icalcomp = NULL;
 	icalcomponent *icomp = NULL;
@@ -1888,7 +1980,8 @@ itip_publish_comp (ECal *client, gchar *uri, gchar *username,
 }
 
 static gboolean
-check_time (const struct icaltimetype tmval, gboolean can_null_time)
+check_time (const struct icaltimetype tmval,
+            gboolean can_null_time)
 {
 	if (icaltime_is_null_time (tmval))
 		return can_null_time;
@@ -1906,22 +1999,8 @@ check_time (const struct icaltimetype tmval, gboolean can_null_time)
 gboolean
 is_icalcomp_valid (icalcomponent *icalcomp)
 {
-	if (!icalcomp || !icalcomponent_is_valid (icalcomp))
-		return FALSE;
-
-	switch (icalcomponent_isa (icalcomp)) {
-	case ICAL_VEVENT_COMPONENT:
-		return	check_time (icalcomponent_get_dtstart (icalcomp), FALSE) &&
-			check_time (icalcomponent_get_dtend (icalcomp), TRUE);
-	case ICAL_VTODO_COMPONENT:
-		return	check_time (icalcomponent_get_dtstart (icalcomp), TRUE) &&
-			check_time (icalcomponent_get_due (icalcomp), TRUE);
-	case ICAL_VJOURNAL_COMPONENT:
-		return	check_time (icalcomponent_get_dtstart (icalcomp), TRUE) &&
-			check_time (icalcomponent_get_dtend (icalcomp), TRUE);
-	default:
-		break;
-	}
-
-	return TRUE;
+	return  icalcomp &&
+		icalcomponent_is_valid (icalcomp) &&
+		check_time (icalcomponent_get_dtstart (icalcomp), FALSE) &&
+		check_time (icalcomponent_get_dtend (icalcomp), TRUE);
 }
