@@ -84,7 +84,7 @@
 #include <stdio.h>
 #include <gdk/gdkprivate.h>
 #include <gtk/gtk.h>
-#include <cairo/cairo-gobject.h>
+#include <cairo-gobject.h>
 #include "gailcanvas.h"
 #include "gnome-canvas.h"
 #include "gnome-canvas-i18n.h"
@@ -677,7 +677,7 @@ gnome_canvas_item_raise (GnomeCanvasItem *item, gint positions)
 
 	parent = GNOME_CANVAS_GROUP (item->parent);
 	link = g_list_find (parent->item_list, item);
-	g_assert (link != NULL);
+	g_return_if_fail (link != NULL);
 
 	for (before = link; positions && before; positions--)
 		before = before->next;
@@ -714,7 +714,7 @@ gnome_canvas_item_lower (GnomeCanvasItem *item, gint positions)
 
 	parent = GNOME_CANVAS_GROUP (item->parent);
 	link = g_list_find (parent->item_list, item);
-	g_assert (link != NULL);
+	g_return_if_fail (link != NULL);
 
 	if (link->prev)
 		for (before = link->prev; positions && before; positions--)
@@ -747,7 +747,7 @@ gnome_canvas_item_raise_to_top (GnomeCanvasItem *item)
 
 	parent = GNOME_CANVAS_GROUP (item->parent);
 	link = g_list_find (parent->item_list, item);
-	g_assert (link != NULL);
+	g_return_if_fail (link != NULL);
 
 	if (put_item_after (link, parent->item_list_end)) {
 		redraw_if_visible (item);
@@ -774,7 +774,7 @@ gnome_canvas_item_lower_to_bottom (GnomeCanvasItem *item)
 
 	parent = GNOME_CANVAS_GROUP (item->parent);
 	link = g_list_find (parent->item_list, item);
-	g_assert (link != NULL);
+	g_return_if_fail (link != NULL);
 
 	if (put_item_after (link, NULL)) {
 		redraw_if_visible (item);
@@ -1373,7 +1373,7 @@ gnome_canvas_group_update (GnomeCanvasItem *item,
 	GnomeCanvasGroup *group;
 	GList *list;
 	GnomeCanvasItem *i;
-	double x1, y1, x2, y2;
+	gdouble x1, y1, x2, y2;
 
 	group = GNOME_CANVAS_GROUP (item);
 
@@ -1729,7 +1729,6 @@ gnome_canvas_paint_rect (GnomeCanvas *canvas,
                          gint y1)
 {
 	GtkWidget *widget;
-	GdkWindow *bin_window;
 	GtkAllocation allocation;
 	GtkScrollable *scrollable;
 	GtkAdjustment *hadjustment;
@@ -1744,7 +1743,6 @@ gnome_canvas_paint_rect (GnomeCanvas *canvas,
 
 	widget = GTK_WIDGET (canvas);
 	gtk_widget_get_allocation (widget, &allocation);
-	bin_window = gtk_layout_get_bin_window (GTK_LAYOUT (canvas));
 
 	scrollable = GTK_SCROLLABLE (canvas);
 	hadjustment = gtk_scrollable_get_hadjustment (scrollable);
@@ -1998,8 +1996,8 @@ gnome_canvas_dispose (GObject *object)
 
 	shutdown_transients (canvas);
 
-	if (G_OBJECT_CLASS (canvas_parent_class)->dispose)
-		G_OBJECT_CLASS (canvas_parent_class)->dispose (object);
+	/* Chain up to parent's dispose() method. */
+	G_OBJECT_CLASS (canvas_parent_class)->dispose (object);
 }
 
 /**
@@ -2252,48 +2250,50 @@ gnome_canvas_draw (GtkWidget *widget,
 {
 	GnomeCanvas *canvas = GNOME_CANVAS (widget);
 	cairo_rectangle_int_t rect;
+	GtkLayout *layout;
+	GtkAdjustment *hadjustment;
+	GtkAdjustment *vadjustment;
+	gdouble hadjustment_value;
+	gdouble vadjustment_value;
+
+	layout = GTK_LAYOUT (canvas);
+	hadjustment = gtk_scrollable_get_hadjustment (GTK_SCROLLABLE (layout));
+	vadjustment = gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (layout));
+
+	hadjustment_value = gtk_adjustment_get_value (hadjustment);
+	vadjustment_value = gtk_adjustment_get_value (vadjustment);
 
 	gdk_cairo_get_clip_rectangle (cr, &rect);
 
 	if (canvas->need_update) {
-		gnome_canvas_request_redraw (canvas,
-					     rect.x, rect.y,
-					     rect.x + rect.width,
-					     rect.y + rect.height);
-	} else {
-		GtkLayout *layout;
-		GtkAdjustment *hadjustment;
-		GtkAdjustment *vadjustment;
-		gdouble hadjustment_value;
-		gdouble vadjustment_value;
+		cairo_matrix_t w2c;
 
-		layout = GTK_LAYOUT (canvas);
-		hadjustment = gtk_scrollable_get_hadjustment (GTK_SCROLLABLE (layout));
-		vadjustment = gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (layout));
+		/* We start updating root with w2c matrix */
+		gnome_canvas_w2c_matrix (canvas, &w2c);
 
-		hadjustment_value = gtk_adjustment_get_value (hadjustment);
-		vadjustment_value = gtk_adjustment_get_value (vadjustment);
+		gnome_canvas_item_invoke_update (canvas->root, &w2c, 0);
 
-		cairo_save (cr);
-		cairo_translate (cr,
-				 -canvas->zoom_xofs + rect.x,
-				 -canvas->zoom_yofs + rect.y);
-
-		rect.x += hadjustment_value;
-		rect.y += vadjustment_value;
-
-                /* No pending updates, draw exposed area immediately */
-		gnome_canvas_paint_rect (canvas, cr,
-					 rect.x, rect.y,
-					 rect.x + rect.width,
-					 rect.y + rect.height);
-		cairo_restore (cr);
-
-                /* And call expose on parent container class */
-		GTK_WIDGET_CLASS (canvas_parent_class)->
-			draw (widget, cr);
+		canvas->need_update = FALSE;
 	}
 
+	cairo_save (cr);
+	cairo_translate (cr,
+			 -canvas->zoom_xofs + rect.x,
+			 -canvas->zoom_yofs + rect.y);
+
+	rect.x += hadjustment_value;
+	rect.y += vadjustment_value;
+
+	/* No pending updates, draw exposed area immediately */
+	gnome_canvas_paint_rect (canvas, cr,
+				 rect.x, rect.y,
+				 rect.x + rect.width,
+				 rect.y + rect.height);
+	cairo_restore (cr);
+
+	/* And call expose on parent container class */
+	GTK_WIDGET_CLASS (canvas_parent_class)->draw (widget, cr);
+
 	return FALSE;
 }
 
@@ -2546,7 +2546,8 @@ pick_current_item (GnomeCanvas *canvas, GdkEvent *event)
 		canvas->in_repick = FALSE;
 	}
 
-	/* new_current_item may have been set to NULL during the call to emit_event() above */
+	/* new_current_item may have been set to NULL during the
+	 * call to emit_event() above */
 
 	if ((canvas->new_current_item != canvas->current_item) && button_down) {
 		canvas->left_grabbed_item = TRUE;
@@ -2644,7 +2645,7 @@ gnome_canvas_button (GtkWidget *widget, GdkEventButton *event)
 		break;
 
 	default:
-		g_assert_not_reached ();
+		g_warn_if_reached ();
 	}
 
 	return retval;
@@ -2697,7 +2698,7 @@ gnome_canvas_key (GtkWidget *widget, GdkEventKey *event)
 			if (widget_class->key_release_event)
 				return (* widget_class->key_release_event) (widget, event);
 		} else
-			g_assert_not_reached ();
+			g_warn_if_reached ();
 
 		return FALSE;
 	} else
@@ -2843,7 +2844,7 @@ idle_handler (gpointer data)
 static void
 add_idle (GnomeCanvas *canvas)
 {
-	g_assert (canvas->need_update);
+	g_return_if_fail (canvas->need_update);
 
 	if (!canvas->idle_id)
 		canvas->idle_id = g_idle_add_full (CANVAS_IDLE_PRIORITY,
@@ -2907,8 +2908,8 @@ gnome_canvas_set_scroll_region (GnomeCanvas *canvas,
 	vadjustment_value = gtk_adjustment_get_value (vadjustment);
 
 	/*
-	 * Set the new scrolling region.  If possible, do not move the visible contents of the
-	 * canvas.
+	 * Set the new scrolling region.  If possible, do not move the
+	 * visible contents of the canvas.
 	 */
 
 	gnome_canvas_c2w (canvas,
@@ -3226,7 +3227,7 @@ void
 gnome_canvas_c2w (GnomeCanvas *canvas, gint cx, gint cy, gdouble *wx, gdouble *wy)
 {
 	cairo_matrix_t c2w;
-	double x, y;
+	gdouble x, y;
 
 	g_return_if_fail (GNOME_IS_CANVAS (canvas));
 
