@@ -23,6 +23,8 @@
 
 #include <glib/gi18n.h>
 
+#include "e-mail-folder-utils.h"
+
 #define CHECK_LOCAL_FOLDER_TYPE(type) \
 	((type) < G_N_ELEMENTS (default_local_folders))
 
@@ -41,77 +43,87 @@ static struct {
 };
 
 static CamelStore *local_store;
+static gboolean mail_local_initialized = FALSE;
 
 void
 e_mail_local_init (EMailSession *session,
                    const gchar *data_dir)
 {
-	static gboolean initialized = FALSE;
 	CamelService *service;
 	CamelURL *url;
 	gchar *temp;
 	gint ii;
-	GError *local_error = NULL;
+	GError *error = NULL;
+
+	if (mail_local_initialized)
+		return;
 
-	g_return_if_fail (!initialized);
 	g_return_if_fail (E_IS_MAIL_SESSION (session));
 	g_return_if_fail (data_dir != NULL);
 
+	mail_local_initialized = TRUE;
+
 	url = camel_url_new ("maildir:", NULL);
 	temp = g_build_filename (data_dir, "local", NULL);
 	camel_url_set_path (url, temp);
+	camel_url_set_param (url, "need-summary-check", "no");
 	g_free (temp);
 
 	temp = camel_url_to_string (url, 0);
-	service = camel_session_get_service (
-		CAMEL_SESSION (session), temp,
-		CAMEL_PROVIDER_STORE, &local_error);
+	service = camel_session_add_service (
+		CAMEL_SESSION (session), "local", temp,
+		CAMEL_PROVIDER_STORE, &error);
 	g_free (temp);
 
-	if (local_error != NULL)
+	if (error != NULL)
 		goto fail;
 
 	/* Populate the rest of the default_local_folders array. */
 	for (ii = 0; ii < G_N_ELEMENTS (default_local_folders); ii++) {
 		const gchar *display_name;
-		gchar *folder_uri;
 
 		display_name = default_local_folders[ii].display_name;
 
-		/* XXX Should this URI be account relative? */
-		camel_url_set_fragment (url, display_name);
-		folder_uri = camel_url_to_string (url, 0);
+		default_local_folders[ii].folder_uri =
+			e_mail_folder_uri_build (
+			CAMEL_STORE (service), display_name);
 
 		/* FIXME camel_store_get_folder() may block. */
-		default_local_folders[ii].folder_uri = folder_uri;
 		if (!strcmp (display_name, "Inbox"))
-			default_local_folders[ii].folder = camel_store_get_inbox_folder_sync (
-				CAMEL_STORE (service), NULL, NULL);
+			default_local_folders[ii].folder =
+				camel_store_get_inbox_folder_sync (
+				CAMEL_STORE (service), NULL, &error);
 		else
-			default_local_folders[ii].folder = camel_store_get_folder_sync (
+			default_local_folders[ii].folder =
+				camel_store_get_folder_sync (
 				CAMEL_STORE (service), display_name,
-				CAMEL_STORE_FOLDER_CREATE, NULL, NULL);
+				CAMEL_STORE_FOLDER_CREATE, NULL, &error);
+
+		if (error != NULL) {
+			g_critical ("%s", error->message);
+			g_clear_error (&error);
+		}
 	}
 
 	camel_url_free (url);
 
-	g_object_ref (service);
-	local_store = CAMEL_STORE (service);
+	local_store = g_object_ref (service);
 
 	return;
 
 fail:
-	g_warning (
+	g_critical (
 		"Could not initialize local store/folder: %s",
-		local_error->message);
+		error->message);
 
-	g_error_free (local_error);
+	g_error_free (error);
 	camel_url_free (url);
 }
 
 CamelFolder *
 e_mail_local_get_folder (EMailLocalFolder type)
 {
+	g_return_val_if_fail (mail_local_initialized, NULL);
 	g_return_val_if_fail (CHECK_LOCAL_FOLDER_TYPE (type), NULL);
 
 	return default_local_folders[type].folder;
@@ -120,6 +132,7 @@ e_mail_local_get_folder (EMailLocalFolder type)
 const gchar *
 e_mail_local_get_folder_uri (EMailLocalFolder type)
 {
+	g_return_val_if_fail (mail_local_initialized, NULL);
 	g_return_val_if_fail (CHECK_LOCAL_FOLDER_TYPE (type), NULL);
 
 	return default_local_folders[type].folder_uri;
@@ -128,6 +141,7 @@ e_mail_local_get_folder_uri (EMailLocalFolder type)
 CamelStore *
 e_mail_local_get_store (void)
 {
+	g_return_val_if_fail (mail_local_initialized, NULL);
 	g_return_val_if_fail (CAMEL_IS_STORE (local_store), NULL);
 
 	return local_store;
