@@ -59,7 +59,6 @@
 #include "shell/e-shell.h"
 #include "shell/e-shell-migrate.h"
 
-#include "e-mail-local.h"
 #include "e-mail-store.h"
 #include "e-mail-backend.h"
 #include "em-utils.h"
@@ -97,8 +96,6 @@ GType em_migrate_session_get_type (void);
 
 G_DEFINE_TYPE (EMMigrateSession, em_migrate_session, CAMEL_TYPE_SESSION)
 
-static CamelSession *em_migrate_session_new (const gchar *path);
-
 static void
 em_migrate_session_class_init (EMMigrateSessionClass *class)
 {
@@ -109,15 +106,12 @@ em_migrate_session_init (EMMigrateSession *session)
 {
 }
 
-static CamelSession *
-em_migrate_session_new (const gchar *path)
+static EMMigrateSession *
+em_migrate_session_new (const gchar *user_data_dir)
 {
-	CamelSession *session;
-
-	session = g_object_new (EM_TYPE_MIGRATE_SESSION, NULL);
-	camel_session_construct (session, path);
-
-	return session;
+	return g_object_new (
+		EM_TYPE_MIGRATE_SESSION,
+		"user-data-dir", user_data_dir, NULL);
 }
 
 static GtkWidget *window;
@@ -616,7 +610,9 @@ setup_local_store (EShellBackend *shell_backend,
 	camel_url_set_path (url, tmp);
 	g_free (tmp);
 	tmp = camel_url_to_string (url, 0);
-	store = (CamelStore *)camel_session_get_service (CAMEL_SESSION (session), tmp, CAMEL_PROVIDER_STORE, NULL);
+	store = (CamelStore *) camel_session_add_service (
+		CAMEL_SESSION (session), "local", tmp,
+		CAMEL_PROVIDER_STORE, NULL);
 	g_free (tmp);
 
 	return store;
@@ -654,6 +650,7 @@ migrate_to_db (EShellBackend *shell_backend)
 	gint i=0, len;
 	CamelStore *store = NULL;
 	CamelFolderInfo *info;
+	CamelURL *url;
 	const gchar *data_dir;
 
 	if (!(accounts = e_get_account_list ()))
@@ -669,7 +666,7 @@ migrate_to_db (EShellBackend *shell_backend)
 	iter = e_list_get_iterator ((EList *) accounts);
 	len = e_list_length ((EList *) accounts);
 
-	session = (EMMigrateSession *) em_migrate_session_new (data_dir);
+	session = em_migrate_session_new (data_dir);
 	camel_session_set_online ((CamelSession *) session, FALSE);
 	em_migrate_setup_progress_dialog (
 		_("Migrating Folders"),
@@ -679,6 +676,8 @@ migrate_to_db (EShellBackend *shell_backend)
 
 	em_migrate_set_progress ( (double)i/(len+1));
 	store = setup_local_store (shell_backend, session);
+	url = camel_service_get_camel_url (CAMEL_SERVICE (store));
+
 	info = camel_store_get_folder_info_sync (
 		store, NULL,
 		CAMEL_STORE_FOLDER_INFO_RECURSIVE |
@@ -688,7 +687,7 @@ migrate_to_db (EShellBackend *shell_backend)
 	if (info) {
 		struct migrate_folders_to_db_structure migrate_dbs;
 
-		if (g_str_has_suffix (((CamelService *)store)->url->path, ".evolution/mail/local"))
+		if (g_str_has_suffix (url->path, ".evolution/mail/local"))
 			migrate_dbs.is_local_store = TRUE;
 		else
 			migrate_dbs.is_local_store = FALSE;
@@ -697,7 +696,9 @@ migrate_to_db (EShellBackend *shell_backend)
 		migrate_dbs.store = store;
 		migrate_dbs.done = FALSE;
 
-		g_thread_create ((GThreadFunc) migrate_folders_to_db_thread, &migrate_dbs, TRUE, NULL);
+		g_thread_create (
+			(GThreadFunc) migrate_folders_to_db_thread,
+			&migrate_dbs, TRUE, NULL);
 		while (!migrate_dbs.done)
 			g_main_context_iteration (NULL, TRUE);
 	}
@@ -707,20 +708,16 @@ migrate_to_db (EShellBackend *shell_backend)
 	while (e_iterator_is_valid (iter)) {
 		EAccount *account = (EAccount *) e_iterator_get (iter);
 		EAccountService *service;
-		const gchar *name;
 
 		service = account->source;
-		name = account->name;
 		em_migrate_set_progress ( (double)i/(len+1));
 		if (account->enabled
-		    && service->url != NULL
-		    && service->url[0]
-		    && strncmp(service->url, "mbox:", 5) != 0) {
+		    && service->url != NULL && service->url[0]
+		    && strncmp (service->url, "mbox:", 5) != 0) {
 
-			e_mail_store_add_by_uri (
-				mail_session, service->url, name);
+			store = e_mail_store_add_by_account (
+				mail_session, account);
 
-			store = (CamelStore *) camel_session_get_service (CAMEL_SESSION (session), service->url, CAMEL_PROVIDER_STORE, NULL);
 			info = camel_store_get_folder_info_sync (
 				store, NULL,
 				CAMEL_STORE_FOLDER_INFO_RECURSIVE |
@@ -797,20 +794,10 @@ sanitize_maildir_folder_name (gchar *folder_name)
 }
 
 static void
-copy_folder	(EShellBackend *shell_backend, 
-	      	 CamelStore *mbox_store, 
-		 CamelStore *maildir_store, 
-		 const gchar *mbox_fname, 
-		 const gchar *maildir_fname)
+copy_folder (CamelStore *mbox_store, CamelStore *maildir_store, const gchar *mbox_fname, const gchar *maildir_fname)
 {
 	CamelFolder *fromfolder, *tofolder;
-	EMailSession *mail_session;
-	GPtrArray *uids, *single_uid;
-	GError *error = NULL;
-	gboolean use_fallback = FALSE;
-	guint i;
-
-	mail_session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
+	GPtrArray *uids;
 
 	fromfolder = camel_store_get_folder_sync (
 		mbox_store, mbox_fname, 0, NULL, NULL);
@@ -830,67 +817,18 @@ copy_folder	(EShellBackend *shell_backend,
 	}
 
 	uids = camel_folder_get_uids (fromfolder);
-	single_uid = g_ptr_array_new ();
-
-	/* import mails one by one to detect summary-mismatch errors */
-	for (i = 0; i < uids->len; i++) {
-		gpointer uid = g_ptr_array_index (uids, i);
-	
-		g_ptr_array_add (single_uid, uid);
-		camel_folder_transfer_messages_to_sync (
-				fromfolder, single_uid, tofolder,
-				FALSE, NULL,
-				NULL, &error);
-		g_ptr_array_remove_index (single_uid, 0);
-		if (error) {
-			g_warning ("Error migrating folder %s: %s \n", mbox_fname, error->message);
-		
-			g_clear_error (&error);
-			/* delete the maildir folder */
-			camel_store_delete_folder_sync (maildir_store, maildir_fname, NULL, NULL);
-			if (error)
-				g_warning ("Error deleting maildir folder %s: %s \n", maildir_fname, error->message);
-
-			use_fallback = TRUE;
-			break;
-		}
-	}
+	camel_folder_transfer_messages_to_sync (
+			fromfolder, uids, tofolder,
+			FALSE, NULL,
+			NULL, NULL);
 	camel_folder_free_uids (fromfolder, uids);
-	g_ptr_array_free (single_uid, TRUE);
-
-	/* fallback, import the mbox file directly. All the flags will be lost in this method */
-	if (use_fallback) {
-		const gchar *to_uri;
-		CamelService *mbox_service;
-		gchar *mbox_file_name;
-		
-		g_message ("Using the fallback method to migrate \n");
-		to_uri = camel_folder_get_uri (tofolder);
-		
-		/* build the filename ourselves as there is no way i see to get the filename from the store */
-		mbox_service = (CamelService *) mbox_store;
-		mbox_file_name = g_build_filename (mbox_service->url->path, mbox_fname, NULL);
-
-		g_clear_error (&error);
-		em_utils_import_mbox (mail_session, to_uri, mbox_file_name, NULL, &error);
-		
-		g_free (mbox_file_name);
-	}
-
-	if (error)
-		g_warning ("Error migrating folder %s: %s \n", mbox_fname, error->message);
 
 	g_object_unref (fromfolder);
 	g_object_unref (tofolder);
-	g_clear_error (&error);
 }
 
 static void
-copy_folders	(EShellBackend *shell_backend,
-		 CamelStore *mbox_store,
-		 CamelStore *maildir_store,
-		 CamelFolderInfo *fi,
-		 EMMigrateSession *session)
+copy_folders (CamelStore *mbox_store, CamelStore *maildir_store, CamelFolderInfo *fi, EMMigrateSession *session)
 {
 	if (fi) {
 		if (!g_str_has_prefix (fi->full_name, ".#evolution")) {
@@ -898,20 +836,19 @@ copy_folders	(EShellBackend *shell_backend,
 
 			/* sanitize folder names and copy folders */
 			maildir_folder_name = sanitize_maildir_folder_name (fi->full_name);
-			copy_folder (shell_backend, mbox_store, maildir_store, fi->full_name, maildir_folder_name);
+			copy_folder (mbox_store, maildir_store, fi->full_name, maildir_folder_name);
 			g_free (maildir_folder_name);
 		}
 
 		if (fi->child)
-			copy_folders (shell_backend, mbox_store, maildir_store, fi->child, session);
+			copy_folders (mbox_store, maildir_store, fi->child, session);
 
-		copy_folders (shell_backend, mbox_store, maildir_store, fi->next, session);
+		copy_folders (mbox_store, maildir_store, fi->next, session);
 	}
 }
 
 struct MigrateStore {
 	EMMigrateSession *session;
-	EShellBackend *shell_backend;
 	CamelStore *mbox_store;
 	CamelStore *maildir_store;
 	gboolean complete;
@@ -932,14 +869,15 @@ migrate_stores (struct MigrateStore *ms)
 		NULL, NULL);
 
 	/* FIXME progres dialog */
-	copy_folders (ms->shell_backend, mbox_store, maildir_store, mbox_fi, ms->session);
+	copy_folders (mbox_store, maildir_store, mbox_fi, ms->session);
 	ms->complete = TRUE;
 
 	return;
 }
 
 static gboolean
-migrate_mbox_to_maildir (EShellBackend *shell_backend, EMMigrateSession *session)
+migrate_mbox_to_maildir (EShellBackend *shell_backend,
+                         EMMigrateSession *session)
 {
 	CamelService *mbox_service, *maildir_service;
 	CamelStore *mbox_store, *maildir_store;
@@ -955,8 +893,8 @@ migrate_mbox_to_maildir (EShellBackend *shell_backend, EMMigrateSession *session
 	g_free (temp);
 
 	temp = camel_url_to_string (url, 0);
-	mbox_service = camel_session_get_service (
-		CAMEL_SESSION (session), temp,
+	mbox_service = camel_session_add_service (
+		CAMEL_SESSION (session), "local_mbox", temp,
 		CAMEL_PROVIDER_STORE, NULL);
 	g_free (temp);
 	camel_url_free (url);
@@ -968,8 +906,8 @@ migrate_mbox_to_maildir (EShellBackend *shell_backend, EMMigrateSession *session
 	g_free (temp);
 
 	temp = camel_url_to_string (url, 0);
-	maildir_service = camel_session_get_service (
-		CAMEL_SESSION (session), temp,
+	maildir_service = camel_session_add_service (
+		CAMEL_SESSION (session), "local", temp,
 		CAMEL_PROVIDER_STORE, NULL);
 	g_free (temp);
 	camel_url_free (url);
@@ -980,16 +918,12 @@ migrate_mbox_to_maildir (EShellBackend *shell_backend, EMMigrateSession *session
 	ms.mbox_store = mbox_store;
 	ms.maildir_store = maildir_store;
 	ms.session = session;
-	ms.shell_backend = shell_backend;
 	ms.complete = FALSE;
 
 	g_thread_create ((GThreadFunc) migrate_stores, &ms, TRUE, NULL);
 	while (!ms.complete)
 		g_main_context_iteration (NULL, TRUE);
 
-	g_object_unref (mbox_store);
-	g_object_unref (maildir_store);
-
 	return TRUE;
 }
 
@@ -1017,7 +951,8 @@ exit:
 }
 
 static gboolean
-create_mbox_account (EShellBackend *shell_backend, EMMigrateSession *session)
+create_mbox_account (EShellBackend *shell_backend,
+                     EMMigrateSession *session)
 {
 	EMailBackend *mail_backend;
 	EMailSession *mail_session;
@@ -1037,6 +972,9 @@ create_mbox_account (EShellBackend *shell_backend, EMMigrateSession *session)
 	account = e_account_new ();
 	account->enabled = TRUE;
 
+	g_free (account->uid);
+	account->uid = g_strdup ("local_mbox");
+
 	url = camel_url_new ("mbox:", NULL);
 	temp = g_build_filename (data_dir, "local_mbox", NULL);
 	camel_url_set_path (url, temp);
@@ -1075,7 +1013,7 @@ create_mbox_account (EShellBackend *shell_backend, EMMigrateSession *session)
 	g_free (folder_uri);
 
 	e_account_list_add (accounts, account);
-	e_mail_store_add_by_uri (mail_session, uri, name);
+	e_mail_store_add_by_account (mail_session, account);
 	e_account_list_save (accounts);
 
 exit:
@@ -1087,80 +1025,6 @@ exit:
 	return TRUE;
 }
 
-static void
-change_sent_and_drafts_local_folders (EShellBackend *shell_backend)
-{
-	EAccountList *accounts;
-	EIterator *iter;
-	const gchar *data_dir;
-	gboolean changed = FALSE;
-	CamelURL *url;
-	gchar *tmp_uri, *drafts_uri, *sent_uri, *old_drafts_uri, *old_sent_uri;
-
-	accounts = e_get_account_list ();
-	if (!accounts)
-		return;
-
-	data_dir = e_shell_backend_get_data_dir (shell_backend);
-
-	tmp_uri = g_strconcat ("mbox:", data_dir, "/", "local", NULL);
-	url = camel_url_new (tmp_uri, NULL);
-	g_free (tmp_uri);
-
-	g_return_if_fail (url != NULL);
-
-	camel_url_set_fragment (url, "Drafts");
-	drafts_uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
-
-	camel_url_set_fragment (url, "Sent");
-	sent_uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
-
-	camel_url_free (url);
-
-	tmp_uri = g_strconcat ("mbox:", g_get_home_dir (), "/.evolution/mail/local", NULL);
-	url = camel_url_new (tmp_uri, NULL);
-	g_free (tmp_uri);
-
-	g_return_if_fail (url != NULL);
-
-	camel_url_set_fragment (url, "Drafts");
-	old_drafts_uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
-
-	camel_url_set_fragment (url, "Sent");
-	old_sent_uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
-
-	camel_url_free (url);
-
-	for (iter = e_list_get_iterator ((EList *) accounts); e_iterator_is_valid (iter); e_iterator_next (iter)) {
-		EAccount *account = (EAccount *) e_iterator_get (iter);
-		const gchar *uri;
-
-		if (!account)
-			continue;
-
-		uri = e_account_get_string (account, E_ACCOUNT_DRAFTS_FOLDER_URI);
-		if (g_strcmp0 (uri, drafts_uri) == 0 || g_strcmp0 (uri, old_drafts_uri) == 0) {
-			changed = TRUE;
-			e_account_set_string (account, E_ACCOUNT_DRAFTS_FOLDER_URI, e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_DRAFTS));
-		}
-
-		uri = e_account_get_string (account, E_ACCOUNT_SENT_FOLDER_URI);
-		if (g_strcmp0 (uri, sent_uri) == 0 || g_strcmp0 (uri, old_sent_uri) == 0 ) {
-			changed = TRUE;
-			e_account_set_string (account, E_ACCOUNT_SENT_FOLDER_URI, e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_SENT));
-		}
-	}
-
-	g_object_unref (iter);
-	g_free (old_drafts_uri);
-	g_free (drafts_uri);
-	g_free (old_sent_uri);
-	g_free (sent_uri);
-
-	if (changed)
-		e_account_list_save (accounts);
-}
-
 static gboolean
 migrate_local_store (EShellBackend *shell_backend)
 {
@@ -1186,12 +1050,11 @@ migrate_local_store (EShellBackend *shell_backend)
 	if (!g_file_test (local_store, G_FILE_TEST_EXISTS))
 		g_mkdir_with_parents (local_store, 0700);
 
-	session = (EMMigrateSession *) em_migrate_session_new (data_dir);
+	session = em_migrate_session_new (data_dir);
 	camel_session_set_online (CAMEL_SESSION (session), FALSE);
 
 	migrate_mbox_to_maildir (shell_backend, session);
 	create_mbox_account (shell_backend, session);
-	change_sent_and_drafts_local_folders (shell_backend);
 
 	g_object_unref (session);
 
