@@ -32,6 +32,7 @@
 #include "mail/em-folder-tree.h"
 #include "e-mail-notebook-view.h"
 #include "e-mail-folder-pane.h"
+#include "e-mail-folder-utils.h"
 #include "e-mail-message-pane.h"
 
 #include <shell/e-shell-window-actions.h>
@@ -45,10 +46,6 @@
 #include "e-mail-tab-picker.h"
 #endif
 
-#define E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_MAIL_NOTEBOOK_VIEW, EMailNotebookViewPrivate))
-
 struct _EMailNotebookViewPrivate {
 	GtkNotebook *book;
 	EMailView *current_view;
@@ -126,21 +123,26 @@ mnv_page_changed (GtkNotebook *book,
 	EShellSidebar *shell_sidebar;
 	EMFolderTree *folder_tree;
 	EMailView *mview;
-	const gchar *uri;
+	CamelFolder *folder;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_NOTEBOOK_VIEW (view)->priv;
 
 	shell_view = e_mail_view_get_shell_view (view);
 	shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
 
 	page = gtk_notebook_get_nth_page (book, page_num);
-	uri = e_mail_reader_get_folder_uri (E_MAIL_READER (page));
+	folder = e_mail_reader_get_folder (E_MAIL_READER (page));
 	mview = E_MAIL_VIEW (page);
 
 	g_object_get (shell_sidebar, "folder-tree", &folder_tree, NULL);
 
-	if (uri && E_IS_MAIL_FOLDER_PANE (mview))
-		em_folder_tree_set_selected (folder_tree, uri, FALSE);
+	if (folder != NULL && E_IS_MAIL_FOLDER_PANE (mview)) {
+		gchar *folder_uri;
+
+		folder_uri = e_mail_folder_uri_from_folder (folder);
+		em_folder_tree_set_selected (folder_tree, folder_uri, FALSE);
+		g_free (folder_uri);
+	}
 
 	if (mview != priv->current_view) {
 		e_mail_view_set_previous_view (mview, priv->current_view);
@@ -189,7 +191,7 @@ chooser_clicked_cb (EMailTabPicker *picker,
 
 	gboolean preview_mode;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (view);
+	priv = view->priv;
 	preview_mode = !e_mail_tab_picker_get_preview_mode (priv->tab_picker);
 
 	e_mail_tab_picker_set_preview_mode (priv->tab_picker , preview_mode);
@@ -265,12 +267,19 @@ mnv_tab_closed_cb (ClutterTimeline *timeline,
 		struct _tab_data *data)
 {
 	EMailView *page = g_object_get_data ((GObject *)data->tab, "page");
-	const gchar *folder_uri = e_mail_reader_get_folder_uri (E_MAIL_READER (page));
 	EMailView *prev;
 	gint num;
 
-	if (E_IS_MAIL_FOLDER_PANE (page))
+	if (E_IS_MAIL_FOLDER_PANE (page)) {
+		CamelFolder *folder;
+		gchar *folder_uri;
+
+		folder = e_mail_reader_get_folder (E_MAIL_READER (page));
+		folder_uri = e_mail_folder_uri_from_folder (folder);
 		g_hash_table_remove (data->view->priv->views, folder_uri);
+		g_free (folder_uri);
+	}
+
 	prev = e_mail_view_get_previous_view (page);
 	if (prev) {
 		num = emnv_get_page_num (data->view, (GtkWidget *)prev);
@@ -336,15 +345,21 @@ tab_remove_gtk_cb (GtkWidget *button,
 		   EMailNotebookView *view)
 {
 	EMailView *page = g_object_get_data ((GObject *)button, "page");
-	const gchar *folder_uri = e_mail_reader_get_folder_uri (E_MAIL_READER (page));
 	EMailView *prev;
 	gint num;
 
 	if (gtk_notebook_get_n_pages (view->priv->book) == 1)
 		return;
 
-	if (E_IS_MAIL_FOLDER_PANE (page))
+	if (E_IS_MAIL_FOLDER_PANE (page)) {
+		CamelFolder *folder;
+		gchar *folder_uri;
+
+		folder = e_mail_reader_get_folder (E_MAIL_READER (page));
+		folder_uri = e_mail_folder_uri_from_folder (folder);
 		g_hash_table_remove (view->priv->views, folder_uri);
+		g_free (folder_uri);
+	}
 
 	prev = e_mail_view_get_previous_view (page);
 	if (prev) {
@@ -581,7 +596,7 @@ mail_notebook_view_set_property (GObject *object,
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (object);
+	priv = E_MAIL_NOTEBOOK_VIEW (object)->priv;
 
 	switch (property_id) {
 		case PROP_FORWARD_STYLE:
@@ -614,7 +629,7 @@ mail_notebook_view_get_property (GObject *object,
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (object);
+	priv = E_MAIL_NOTEBOOK_VIEW (object)->priv;
 
 	switch (property_id) {
 		case PROP_FORWARD_STYLE:
@@ -648,7 +663,7 @@ mail_notebook_view_set_search_strings (EMailView *view,
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_NOTEBOOK_VIEW (view)->priv;
 
 	e_mail_view_set_search_strings (priv->current_view, search_strings);
 }
@@ -658,7 +673,7 @@ mail_notebook_view_get_view_instance (EMailView *view)
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_NOTEBOOK_VIEW (view)->priv;
 
 	if (priv->current_view == NULL)
 		return NULL;
@@ -671,7 +686,7 @@ mail_notebook_view_update_view_instance (EMailView *view)
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_NOTEBOOK_VIEW (view)->priv;
 
 	if (priv->current_view == NULL)
 		return;
@@ -685,7 +700,7 @@ mail_notebook_view_set_orientation (EMailView *view,
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_NOTEBOOK_VIEW (view)->priv;
 
 	if (priv->current_view == NULL)
 		return;
@@ -698,7 +713,7 @@ mail_notebook_view_get_orientation (EMailView *view)
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_NOTEBOOK_VIEW (view)->priv;
 
 	if (priv->current_view == NULL)
 		return GTK_ORIENTATION_VERTICAL;
@@ -711,7 +726,7 @@ mail_notebook_view_get_show_deleted (EMailView *view)
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_NOTEBOOK_VIEW (view)->priv;
 
 	if (priv->current_view == NULL)
 		return FALSE;
@@ -725,7 +740,7 @@ mail_notebook_view_set_show_deleted (EMailView *view,
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_NOTEBOOK_VIEW (view)->priv;
 
 	if (priv->current_view == NULL)
 		return;
@@ -738,7 +753,7 @@ mail_notebook_view_get_preview_visible (EMailView *view)
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_NOTEBOOK_VIEW (view)->priv;
 
 	if (priv->current_view == NULL)
 		return FALSE;
@@ -752,7 +767,7 @@ mail_notebook_view_set_preview_visible (EMailView *view,
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_NOTEBOOK_VIEW (view)->priv;
 
 	if (priv->current_view == NULL)
 		return;
@@ -807,7 +822,7 @@ mail_notebook_view_get_formatter (EMailReader *reader)
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (reader);
+	priv = E_MAIL_NOTEBOOK_VIEW (reader)->priv;
 
 	if (priv->current_view == NULL)
 		return NULL;
@@ -820,7 +835,7 @@ mail_notebook_view_get_hide_deleted (EMailReader *reader)
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (reader);
+	priv = E_MAIL_NOTEBOOK_VIEW (reader)->priv;
 
 	if (priv->current_view == NULL)
 		return FALSE;
@@ -835,7 +850,7 @@ mail_notebook_view_get_message_list (EMailReader *reader)
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (reader);
+	priv = E_MAIL_NOTEBOOK_VIEW (reader)->priv;
 
 	if (priv->current_view == NULL)
 		return NULL;
@@ -850,7 +865,7 @@ mail_notebook_view_get_popup_menu (EMailReader *reader)
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (reader);
+	priv = E_MAIL_NOTEBOOK_VIEW (reader)->priv;
 
 	if (priv->current_view == NULL)
 		return NULL;
@@ -894,7 +909,6 @@ mail_netbook_view_open_mail (EMailView *view,
 {
 	EMailNotebookViewPrivate *priv;
 	EShellView *shell_view;
-	const gchar *folder_uri;
 	CamelFolder *folder;
 	EMailView *pane;
 	gint page;
@@ -908,7 +922,7 @@ mail_netbook_view_open_mail (EMailView *view,
 	GtkWidget *mlist;
 #endif
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (nview);
+	priv = nview->priv;
 
 #if HAVE_CLUTTER
 	e_mail_tab_set_active (
@@ -926,7 +940,6 @@ mail_netbook_view_open_mail (EMailView *view,
 	gtk_widget_show (GTK_WIDGET (pane));
 
 	folder = e_mail_reader_get_folder (E_MAIL_READER (view));
-	folder_uri = e_mail_reader_get_folder_uri (E_MAIL_READER (view));
 
 	info = camel_folder_get_message_info (folder, uid);
 
@@ -985,7 +998,7 @@ mail_netbook_view_open_mail (EMailView *view,
 		E_MAIL_READER (pane), "folder-loaded",
 		G_CALLBACK (reconnect_folder_loaded_event), nview);
 	e_mail_reader_set_folder (
-		E_MAIL_READER (pane), folder, folder_uri);
+		E_MAIL_READER (pane), folder);
 	e_mail_reader_set_group_by_threads (
 		E_MAIL_READER (pane),
 		e_mail_reader_get_group_by_threads (E_MAIL_READER (view)));
@@ -1082,23 +1095,26 @@ build_histogram (GtkWidget *widget, CamelFolder *folder)
 
 static void
 mail_notebook_view_set_folder (EMailReader *reader,
-                               CamelFolder *folder,
-                               const gchar *folder_uri)
+                               CamelFolder *folder)
 {
 	EMailNotebookViewPrivate *priv;
 	GtkWidget *new_view;
+	gchar *folder_uri;
 #if HAVE_CLUTTER
 	EMailTab *tab;
 	ClutterActor *clone;
 	ClutterTimeline *timeline;
 #endif
 
-	if (!folder_uri)
+	if (folder == NULL)
 		return;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (reader);
+	priv = E_MAIL_NOTEBOOK_VIEW (reader)->priv;
 
+	folder_uri = e_mail_folder_uri_from_folder (folder);
 	new_view = g_hash_table_lookup (priv->views, folder_uri);
+	g_free (folder_uri);
+
 	if (new_view) {
 		gint curr = emnv_get_page_num (E_MAIL_NOTEBOOK_VIEW (reader), new_view);
 #if HAVE_CLUTTER
@@ -1127,7 +1143,8 @@ mail_notebook_view_set_folder (EMailReader *reader,
 		return;
 	}
 
-	if (folder || folder_uri) {
+	/* FIXME Redundant NULL check. */
+	if (folder != NULL) {
 		gint page;
 #if HAVE_CLUTTER
 		GtkWidget *list;
@@ -1225,8 +1242,10 @@ mail_notebook_view_set_folder (EMailReader *reader,
 		g_object_set_data ((GObject *)list, "actor", priv->actor);
 
 #endif
-		e_mail_reader_set_folder (E_MAIL_READER (priv->current_view), folder, folder_uri);
-		g_hash_table_insert (priv->views, g_strdup (folder_uri), priv->current_view);
+		e_mail_reader_set_folder (E_MAIL_READER (priv->current_view), folder);
+
+		folder_uri = e_mail_folder_uri_from_folder (folder);
+		g_hash_table_insert (priv->views, folder_uri, priv->current_view);
 		g_signal_connect (
 			priv->current_view, "changed",
 			G_CALLBACK (reconnect_changed_event), reader);
@@ -1244,7 +1263,7 @@ mail_notebook_view_show_search_bar (EMailReader *reader)
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (reader);
+	priv = E_MAIL_NOTEBOOK_VIEW (reader)->priv;
 
 	if (priv->current_view == NULL)
 		return;
@@ -1270,7 +1289,7 @@ mail_notebook_view_open_selected_mail (EMailReader *reader)
 {
 	EMailNotebookViewPrivate *priv;
 
-	priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (reader);
+	priv = E_MAIL_NOTEBOOK_VIEW (reader)->priv;
 
 	if (priv->current_view == NULL)
 		return 0;
@@ -1343,7 +1362,8 @@ e_mail_notebook_view_reader_init (EMailReaderInterface *interface)
 static void
 e_mail_notebook_view_init (EMailNotebookView  *view)
 {
-	view->priv = E_MAIL_NOTEBOOK_VIEW_GET_PRIVATE (view);
+	view->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		view, E_TYPE_MAIL_NOTEBOOK_VIEW, EMailNotebookViewPrivate);
 
 	view->priv->inited = FALSE;
 	view->priv->views = g_hash_table_new (g_str_hash, g_str_equal);
