@@ -44,6 +44,7 @@
 #include "mail-config.h"
 #include "mail-ops.h"
 #include "message-list.h"
+#include "e-mail-folder-utils.h"
 #include "e-mail-reader-utils.h"
 
 #define E_SHELL_WINDOW_ACTION_GROUP_MAIL(window) \
@@ -95,22 +96,25 @@ mail_paned_view_save_boolean (EMailView *view,
 {
 	EShellView *shell_view;
 	EMailReader *reader;
+	CamelFolder *folder;
 	GKeyFile *key_file;
-	const gchar *folder_uri;
+	gchar *folder_uri;
 	gchar *group_name;
 
 	shell_view = e_mail_view_get_shell_view (view);
 	key_file = e_shell_view_get_state_key_file (shell_view);
 
 	reader = E_MAIL_READER (view);
-	folder_uri = e_mail_reader_get_folder_uri (reader);
+	folder = e_mail_reader_get_folder (reader);
 
-	if (folder_uri == NULL)
+	if (folder == NULL)
 		return;
 
+	folder_uri = e_mail_folder_uri_from_folder (folder);
 	group_name = g_strdup_printf ("Folder %s", folder_uri);
 	g_key_file_set_boolean (key_file, group_name, key, value);
 	g_free (group_name);
+	g_free (folder_uri);
 
 	e_shell_view_set_state_dirty (shell_view);
 }
@@ -138,24 +142,29 @@ mail_paned_view_message_list_built_cb (EMailView *view,
 	if (message_list->cursor_uid != NULL)
 		;  /* do nothing */
 
-	else if (message_list->folder_uri == NULL)
+	else if (message_list->folder == NULL)
 		;  /* do nothing */
 
 	else if (e_shell_window_get_safe_mode (shell_window))
 		e_shell_window_set_safe_mode (shell_window, FALSE);
 
 	else {
-		const gchar *folder_uri;
+		CamelFolder *folder;
 		const gchar *key;
+		gchar *folder_uri;
 		gchar *group_name;
 		gchar *uid;
 
+		folder = message_list->folder;
+		folder_uri = e_mail_folder_uri_from_folder (folder);
+
 		key = STATE_KEY_SELECTED_MESSAGE;
-		folder_uri = message_list->folder_uri;
 		group_name = g_strdup_printf ("Folder %s", folder_uri);
 		uid = g_key_file_get_string (key_file, group_name, key, NULL);
 		g_free (group_name);
 
+		g_free (folder_uri);
+
 		/* Use selection fallbacks if UID is not found. */
 		message_list_select_uid (message_list, uid, TRUE);
 
@@ -169,22 +178,25 @@ mail_paned_view_message_selected_cb (EMailView *view,
                                      MessageList *message_list)
 {
 	EShellView *shell_view;
+	CamelFolder *folder;
 	GKeyFile *key_file;
-	const gchar *folder_uri;
 	const gchar *key;
+	gchar *folder_uri;
 	gchar *group_name;
 
-	folder_uri = message_list->folder_uri;
+	folder = message_list->folder;
 
 	/* This also gets triggered when selecting a store name on
 	 * the sidebar such as "On This Computer", in which case
-	 * 'folder_uri' will be NULL. */
-	if (folder_uri == NULL)
+	 * 'folder' will be NULL. */
+	if (folder == NULL)
 		return;
 
 	shell_view = e_mail_view_get_shell_view (view);
 	key_file = e_shell_view_get_state_key_file (shell_view);
 
+	folder_uri = e_mail_folder_uri_from_folder (folder);
+
 	key = STATE_KEY_SELECTED_MESSAGE;
 	group_name = g_strdup_printf ("Folder %s", folder_uri);
 
@@ -195,7 +207,7 @@ mail_paned_view_message_selected_cb (EMailView *view,
 	e_shell_view_set_state_dirty (shell_view);
 
 	g_free (group_name);
-
+	g_free (folder_uri);
 }
 
 static void
@@ -456,8 +468,7 @@ mail_paned_view_get_window (EMailReader *reader)
 
 static void
 mail_paned_view_set_folder (EMailReader *reader,
-                            CamelFolder *folder,
-                            const gchar *folder_uri)
+                            CamelFolder *folder)
 {
 	EMailPanedViewPrivate *priv;
 	EMailView *view;
@@ -468,6 +479,7 @@ mail_paned_view_set_folder (EMailReader *reader,
 	EMailReaderInterface *default_interface;
 	GtkWidget *message_list;
 	GKeyFile *key_file;
+	gchar *folder_uri;
 	gchar *group_name;
 	const gchar *key;
 	gboolean value;
@@ -488,12 +500,14 @@ mail_paned_view_set_folder (EMailReader *reader,
 
 	/* Chain up to interface's default set_folder() method. */
 	default_interface = g_type_default_interface_peek (E_TYPE_MAIL_READER);
-	default_interface->set_folder (reader, folder, folder_uri);
+	default_interface->set_folder (reader, folder);
 
 	if (folder == NULL)
 		goto exit;
 
-	mail_refresh_folder (folder, NULL, NULL);
+	/* Only refresh the folder if we're online. */
+	if (e_shell_get_online (shell))
+		mail_refresh_folder (folder, NULL, NULL);
 
 	/* This is a one-time-only callback. */
 	if (MESSAGE_LIST (message_list)->cursor_uid == NULL &&
@@ -505,8 +519,10 @@ mail_paned_view_set_folder (EMailReader *reader,
 
 	/* Restore the folder's preview and threaded state. */
 
+	folder_uri = e_mail_folder_uri_from_folder (folder);
 	key_file = e_shell_view_get_state_key_file (shell_view);
 	group_name = g_strdup_printf ("Folder %s", folder_uri);
+	g_free (folder_uri);
 
 	key = STATE_KEY_GROUP_BY_THREADS;
 	value = g_key_file_get_boolean (key_file, group_name, key, &error);
@@ -577,6 +593,8 @@ mail_paned_view_constructed (GObject *object)
 	EShellBackend *shell_backend;
 	EShellWindow *shell_window;
 	EShellView *shell_view;
+	EShell *shell;
+	EShellSettings *shell_settings;
 	ESearchBar *search_bar;
 	EMailReader *reader;
 	EMailView *view;
@@ -592,6 +610,15 @@ mail_paned_view_constructed (GObject *object)
 	shell_view = e_mail_view_get_shell_view (view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
 	shell_backend = e_shell_view_get_shell_backend (shell_view);
+	shell = e_shell_window_get_shell (shell_window);
+	shell_settings = e_shell_get_shell_settings (shell);
+
+	/* Make headers collapsable and store state of headers in config file */
+	em_format_html_set_headers_collapsable (EM_FORMAT_HTML (priv->formatter), TRUE);
+	g_object_bind_property (shell_settings, "paned-view-headers-state",
+				EM_FORMAT_HTML (priv->formatter), "headers-state",
+				G_BINDING_BIDIRECTIONAL |
+				G_BINDING_SYNC_CREATE);
 
 	web_view = em_format_html_get_web_view (
 		EM_FORMAT_HTML (priv->formatter));
@@ -735,7 +762,6 @@ mail_paned_view_update_view_instance (EMailView *view)
 	GtkOrientation orientation;
 	gboolean outgoing_folder;
 	gboolean show_vertical_view;
-	const gchar *folder_uri;
 	gchar *view_id;
 
 	priv = E_MAIL_PANED_VIEW (view)->priv;
@@ -750,30 +776,28 @@ mail_paned_view_update_view_instance (EMailView *view)
 
 	reader = E_MAIL_READER (view);
 	folder = e_mail_reader_get_folder (reader);
-	folder_uri = e_mail_reader_get_folder_uri (reader);
 
 	/* If no folder is selected, return silently. */
 	if (folder == NULL)
 		return;
 
-	/* If we have a folder, we should also have a URI. */
-	g_return_if_fail (folder_uri != NULL);
-
 	if (priv->view_instance != NULL) {
 		g_object_unref (priv->view_instance);
 		priv->view_instance = NULL;
 	}
 
-	view_id = g_strdup (folder_uri);
+	view_id = e_mail_folder_uri_from_folder (folder);
 	e_filename_make_safe (view_id);
 
 	outgoing_folder =
-		em_utils_folder_is_drafts (folder, folder_uri) ||
-		em_utils_folder_is_outbox (folder, folder_uri) ||
-		em_utils_folder_is_sent (folder, folder_uri);
+		em_utils_folder_is_drafts (folder) ||
+		em_utils_folder_is_outbox (folder) ||
+		em_utils_folder_is_sent (folder);
 
 	if (e_shell_settings_get_boolean (shell_settings, "mail-global-view-setting"))
-		view_instance = e_shell_view_new_view_instance (shell_view, outgoing_folder ? "global_view_sent_setting" : "global_view_setting");
+		view_instance = e_shell_view_new_view_instance (
+			shell_view, outgoing_folder ?
+			"global_view_sent_setting" : "global_view_setting");
 	else
 		view_instance = e_shell_view_new_view_instance (shell_view, view_id);
 
