@@ -70,7 +70,7 @@ e_mail_reader_confirm_delete (EMailReader *reader)
 	CamelFolder *folder;
 	CamelStore *parent_store;
 	GtkWidget *check_button;
-	GtkWidget *content_area;
+	GtkWidget *container;
 	GtkWidget *dialog;
 	GtkWindow *window;
 	const gchar *label;
@@ -104,15 +104,11 @@ e_mail_reader_confirm_delete (EMailReader *reader)
 		window, "mail:ask-delete-vfolder-msg",
 		camel_folder_get_full_name (folder), NULL);
 
-	/* XXX e-error should provide a widget layout and API suitable
-	 *     for packing additional widgets to the right of the alert
-	 *     icon.  But for now, screw it. */
+	container = e_alert_dialog_get_content_area (E_ALERT_DIALOG (dialog));
 
-	label = _("Do not ask me again");
-	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+	label = _("Do not warn me again");
 	check_button = gtk_check_button_new_with_label (label);
-	gtk_box_pack_start (
-		GTK_BOX (content_area), check_button, TRUE, TRUE, 6);
+	gtk_box_pack_start (GTK_BOX (container), check_button, TRUE, TRUE, 6);
 	gtk_widget_show (check_button);
 
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -226,14 +222,12 @@ e_mail_reader_open_selected (EMailReader *reader)
 	GtkWindow *window;
 	GPtrArray *views;
 	GPtrArray *uids;
-	const gchar *folder_uri;
 	guint ii;
 
 	g_return_val_if_fail (E_IS_MAIL_READER (reader), 0);
 
 	backend = e_mail_reader_get_backend (reader);
 	folder = e_mail_reader_get_folder (reader);
-	folder_uri = e_mail_reader_get_folder_uri (reader);
 	uids = e_mail_reader_get_selected_uids (reader);
 	window = e_mail_reader_get_window (reader);
 
@@ -245,9 +239,9 @@ e_mail_reader_open_selected (EMailReader *reader)
 		return 0;
 	}
 
-	if (em_utils_folder_is_drafts (folder, folder_uri) ||
-		em_utils_folder_is_outbox (folder, folder_uri) ||
-		em_utils_folder_is_templates (folder, folder_uri)) {
+	if (em_utils_folder_is_drafts (folder) ||
+		em_utils_folder_is_outbox (folder) ||
+		em_utils_folder_is_templates (folder)) {
 		em_utils_edit_messages (shell, folder, uids, TRUE);
 		return uids->len;
 	}
@@ -259,7 +253,6 @@ e_mail_reader_open_selected (EMailReader *reader)
 		const gchar *uid = uids->pdata[ii];
 		CamelFolder *real_folder;
 		CamelMessageInfo *info;
-		const gchar *real_folder_uri;
 		gchar *real_uid;
 
 		if (!CAMEL_IS_VEE_FOLDER (folder)) {
@@ -274,10 +267,9 @@ e_mail_reader_open_selected (EMailReader *reader)
 		real_folder = camel_vee_folder_get_location (
 			CAMEL_VEE_FOLDER (folder),
 			(CamelVeeMessageInfo *) info, &real_uid);
-		real_folder_uri = camel_folder_get_uri (real_folder);
 
-		if (em_utils_folder_is_drafts (real_folder, real_folder_uri) ||
-			em_utils_folder_is_outbox (real_folder, real_folder_uri)) {
+		if (em_utils_folder_is_drafts (real_folder) ||
+			em_utils_folder_is_outbox (real_folder)) {
 			GPtrArray *edits;
 
 			edits = g_ptr_array_new ();
@@ -297,8 +289,7 @@ e_mail_reader_open_selected (EMailReader *reader)
 		GtkWidget *browser;
 
 		browser = e_mail_browser_new (backend);
-		e_mail_reader_set_folder (
-			E_MAIL_READER (browser), folder, folder_uri);
+		e_mail_reader_set_folder (E_MAIL_READER (browser), folder);
 		e_mail_reader_set_message (E_MAIL_READER (browser), uid);
 		copy_tree_state (reader, E_MAIL_READER (browser));
 		e_mail_reader_set_group_by_threads (
@@ -539,7 +530,6 @@ e_mail_reader_create_filter_from_selected (EMailReader *reader,
 	EMailSession *session;
 	CamelFolder *folder;
 	const gchar *filter_source;
-	const gchar *folder_uri;
 	GPtrArray *uids;
 
 	struct {
@@ -550,15 +540,13 @@ e_mail_reader_create_filter_from_selected (EMailReader *reader,
 
 	g_return_if_fail (E_IS_MAIL_READER (reader));
 
+	folder = e_mail_reader_get_folder (reader);
 	backend = e_mail_reader_get_backend (reader);
 	session = e_mail_backend_get_session (backend);
 
-	folder = e_mail_reader_get_folder (reader);
-	folder_uri = e_mail_reader_get_folder_uri (reader);
-
-	if (em_utils_folder_is_sent (folder, folder_uri))
+	if (em_utils_folder_is_sent (folder))
 		filter_source = E_FILTER_SOURCE_OUTGOING;
-	else if (em_utils_folder_is_outbox (folder, folder_uri))
+	else if (em_utils_folder_is_outbox (folder))
 		filter_source = E_FILTER_SOURCE_OUTGOING;
 	else
 		filter_source = E_FILTER_SOURCE_INCOMING;
@@ -589,17 +577,15 @@ mail_reader_create_vfolder_cb (CamelFolder *folder,
 {
 	struct {
 		EMailSession *session;
-		gchar *uri;
 		gint type;
 	} *vfolder_data = user_data;
 
 	if (message != NULL)
 		vfolder_gui_add_from_message (
 			vfolder_data->session, message,
-			vfolder_data->type, vfolder_data->uri);
+			vfolder_data->type, folder);
 
 	g_object_unref (vfolder_data->session);
-	g_free (vfolder_data->uri);
 	g_free (vfolder_data);
 }
 
@@ -610,12 +596,10 @@ e_mail_reader_create_vfolder_from_selected (EMailReader *reader,
 	EMailBackend *backend;
 	EMailSession *session;
 	CamelFolder *folder;
-	const gchar *folder_uri;
 	GPtrArray *uids;
 
 	struct {
 		EMailSession *session;
-		gchar *uri;
 		gint type;
 	} *vfolder_data;
 
@@ -625,13 +609,11 @@ e_mail_reader_create_vfolder_from_selected (EMailReader *reader,
 	session = e_mail_backend_get_session (backend);
 
 	folder = e_mail_reader_get_folder (reader);
-	folder_uri = e_mail_reader_get_folder_uri (reader);
 	uids = e_mail_reader_get_selected_uids (reader);
 
 	if (uids->len == 1) {
 		vfolder_data = g_malloc (sizeof (*vfolder_data));
 		vfolder_data->session = g_object_ref (session);
-		vfolder_data->uri = g_strdup (folder_uri);
 		vfolder_data->type = vfolder_type;
 
 		mail_get_message (
