@@ -96,17 +96,14 @@ struct _EMailReaderInterface {
 	GtkWindow *	(*get_window)		(EMailReader *reader);
 
 	CamelFolder *	(*get_folder)		(EMailReader *reader);
-	const gchar *	(*get_folder_uri)	(EMailReader *reader);
 	void		(*set_folder)		(EMailReader *reader,
-						 CamelFolder *folder,
-						 const gchar *folder_uri);
+						 CamelFolder *folder);
 	void		(*set_message)		(EMailReader *reader,
 						 const gchar *uid);
 	guint		(*open_selected_mail)	(EMailReader *reader);
 	gboolean	(*enable_show_folder)	(EMailReader *reader);
 
 	/* Signals */
-	void		(*folder_loaded)	(EMailReader *reader);
 	void		(*show_search_bar)	(EMailReader *reader);
 	void		(*update_actions)	(EMailReader *reader,
 						 guint32 state);
@@ -135,12 +132,8 @@ GtkMenu *	e_mail_reader_get_popup_menu	(EMailReader *reader);
 GPtrArray *	e_mail_reader_get_selected_uids	(EMailReader *reader);
 GtkWindow *	e_mail_reader_get_window	(EMailReader *reader);
 CamelFolder *	e_mail_reader_get_folder	(EMailReader *reader);
-const gchar *	e_mail_reader_get_folder_uri	(EMailReader *reader);
 void		e_mail_reader_set_folder	(EMailReader *reader,
-						 CamelFolder *folder,
-						 const gchar *folder_uri);
-void		e_mail_reader_set_folder_uri	(EMailReader *reader,
-						 const gchar *folder_uri);
+						 CamelFolder *folder);
 void		e_mail_reader_set_message	(EMailReader *reader,
 						 const gchar *uid);
 EMailForwardStyle
