@@ -23,6 +23,7 @@
 
 #include <mail/mail-tools.h>
 #include <mail/e-mail-local.h>
+#include <mail/e-mail-folder-utils.h>
 #include <e-util/e-account-utils.h>
 #include <filter/e-filter-rule.h>
 
@@ -51,9 +52,8 @@ struct _AsyncContext {
 	GPtrArray *post_to_uris;
 
 	gchar *folder_uri;
-	gchar *destination;
 	gchar *message_uid;
-	gchar *transport_uri;
+	gchar *transport_uid;
 	gchar *sent_folder_uri;
 };
 
@@ -93,9 +93,8 @@ async_context_free (AsyncContext *context)
 	}
 
 	g_free (context->folder_uri);
-	g_free (context->destination);
 	g_free (context->message_uid);
-	g_free (context->transport_uri);
+	g_free (context->transport_uid);
 	g_free (context->sent_folder_uri);
 
 	g_slice_free (AsyncContext, context);
@@ -401,33 +400,30 @@ mail_session_send_to_thread (GSimpleAsyncResult *simple,
 
 	/* Send the message to all recipients. */
 	if (camel_address_length (context->recipients) > 0) {
-		CamelTransport *transport;
-		CamelProviderFlags flags;
+		CamelProvider *provider;
+		CamelService *service;
+
+		service = camel_session_get_service (
+			CAMEL_SESSION (session), context->transport_uid);
+
+		g_return_if_fail (CAMEL_IS_TRANSPORT (service));
 
 		/* XXX This API does not allow for cancellation. */
-		transport = camel_session_get_transport (
-			CAMEL_SESSION (session),
-			context->transport_uri, &error);
-
-		if (error != NULL) {
-			g_warn_if_fail (transport == NULL);
+		if (!camel_service_connect_sync (service, &error)) {
 			g_simple_async_result_set_from_error (simple, error);
 			g_error_free (error);
 			return;
 		}
 
-		g_return_if_fail (CAMEL_IS_TRANSPORT (transport));
+		provider = camel_service_get_provider (service);
 
-		flags = CAMEL_SERVICE (transport)->provider->flags;
-		if (flags & CAMEL_PROVIDER_DISABLE_SENT_FOLDER)
+		if (provider->flags & CAMEL_PROVIDER_DISABLE_SENT_FOLDER)
 			copy_to_sent = FALSE;
 
 		camel_transport_send_to_sync (
-			transport, context->message,
-			context->from, context->recipients,
-			cancellable, &error);
-
-		g_object_unref (transport);
+			CAMEL_TRANSPORT (service),
+			context->message, context->from,
+			context->recipients, cancellable, &error);
 
 		if (error != NULL) {
 			g_simple_async_result_set_from_error (simple, error);
@@ -619,7 +615,6 @@ exit:
 void
 e_mail_session_send_to (EMailSession *session,
                         CamelMimeMessage *message,
-                        const gchar *destination,
                         gint io_priority,
                         GCancellable *cancellable,
                         CamelFilterGetFolderFunc get_folder_func,
@@ -639,7 +634,7 @@ e_mail_session_send_to (EMailSession *session,
 	struct _camel_header_raw *header;
 	const gchar *string;
 	const gchar *resent_from;
-	gchar *transport_uri = NULL;
+	gchar *transport_uid = NULL;
 	gchar *sent_folder_uri = NULL;
 	GError *error = NULL;
 
@@ -665,7 +660,12 @@ e_mail_session_send_to (EMailSession *session,
 
 	if (account != NULL) {
 		if (account->transport != NULL) {
-			transport_uri = g_strdup (account->transport->url);
+
+			/* XXX Transport UIDs are kludgy right now.  We
+			 *     use the EAccount's regular UID and tack on
+			 *     "-transport".  Will be better soon. */
+			transport_uid = g_strconcat (
+				account->uid, "-transport", NULL);
 
 			/* to reprompt password on sending if needed */
 			account->transport->get_password_canceled = FALSE;
@@ -674,16 +674,13 @@ e_mail_session_send_to (EMailSession *session,
 	}
 
 	string = camel_header_raw_find (&xev, "X-Evolution-Transport", NULL);
-	if (transport_uri == NULL && string != NULL)
-		transport_uri = g_strstrip (g_strdup (string));
+	if (transport_uid == NULL && string != NULL)
+		transport_uid = g_strstrip (g_strdup (string));
 
 	string = camel_header_raw_find (&xev, "X-Evolution-Fcc", NULL);
 	if (sent_folder_uri == NULL && string != NULL)
 		sent_folder_uri = g_strstrip (g_strdup (string));
 
-	if (transport_uri == NULL)
-		transport_uri = g_strdup (destination);
-
 	post_to_uris = g_ptr_array_new ();
 	for (header = xev; header != NULL; header = header->next) {
 		gchar *folder_uri;
@@ -691,7 +688,7 @@ e_mail_session_send_to (EMailSession *session,
 		if (g_strcmp0 (header->name, "X-Evolution-PostTo") != 0)
 			continue;
 
-		folder_uri = g_strstrip (g_strdup (header->name));
+		folder_uri = g_strstrip (g_strdup (header->value));
 		g_ptr_array_add (post_to_uris, folder_uri);
 	}
 
@@ -748,7 +745,6 @@ e_mail_session_send_to (EMailSession *session,
 
 	context = g_slice_new0 (AsyncContext);
 	context->message = g_object_ref (message);
-	context->destination = g_strdup (destination);
 	context->io_priority = io_priority;
 	context->from = from;
 	context->recipients = recipients;
@@ -756,7 +752,7 @@ e_mail_session_send_to (EMailSession *session,
 	context->info = info;
 	context->xev = xev;
 	context->post_to_uris = post_to_uris;
-	context->transport_uri = transport_uri;
+	context->transport_uid = transport_uid;
 	context->sent_folder_uri = sent_folder_uri;
 
 	if (G_IS_CANCELLABLE (cancellable))
@@ -837,45 +833,36 @@ e_mail_session_unsubscribe_folder_sync (EMailSession *session,
                                         GCancellable *cancellable,
                                         GError **error)
 {
-	CamelURL *url;
-	CamelStore *store;
-	CamelProviderURLFlags flags;
+	CamelStore *store = NULL;
+	gchar *folder_name = NULL;
 	const gchar *message;
-	const gchar *path = NULL;
 	gboolean success = FALSE;
 
 	g_return_val_if_fail (E_IS_MAIL_SESSION (session), FALSE);
 	g_return_val_if_fail (folder_uri != NULL, FALSE);
 
+	success = e_mail_folder_uri_parse (
+		CAMEL_SESSION (session), folder_uri,
+		&store, &folder_name, error);
+
+	if (!success)
+		return FALSE;
+
 	message = _("Unsubscribing from folder '%s'");
-	camel_operation_push_message (cancellable, message, folder_uri);
+	camel_operation_push_message (cancellable, message, folder_name);
 
-	store = camel_session_get_store (
-		CAMEL_SESSION (session), folder_uri, error);
-	if (store == NULL)
-		goto exit;
+	/* FIXME This should take our GCancellable. */
+	success =
+		camel_service_connect_sync (
+			CAMEL_SERVICE (store), error) &&
+		camel_store_unsubscribe_folder_sync (
+			store, folder_name, cancellable, error);
 
-	url = camel_url_new (folder_uri, error);
-	if (url == NULL)
-		goto exit;
-
-	flags = CAMEL_SERVICE (store)->provider->url_flags;
-
-	if (flags & CAMEL_URL_FRAGMENT_IS_PATH)
-		path = url->fragment;
-	else if (url->path != NULL && *url->path != '\0')
-		path = url->path + 1;
-
-	g_return_val_if_fail (path != NULL, FALSE);
-
-	success = camel_store_unsubscribe_folder_sync (
-		store, path, cancellable, error);
-
-	camel_url_free (url);
-
-exit:
 	camel_operation_pop_message (cancellable);
 
+	g_object_unref (store);
+	g_free (folder_name);
+
 	return success;
 }
 
