@@ -64,6 +64,10 @@
 #include "mail-send-recv.h"
 #include "mail-tools.h"
 
+#define E_MAIL_SESSION_GET_PRIVATE(obj) \
+	(G_TYPE_INSTANCE_GET_PRIVATE \
+	((obj), E_TYPE_MAIL_SESSION, EMailSessionPrivate))
+
 static guint session_check_junk_notify_id;
 static guint session_gconf_proxy_id;
 
@@ -79,6 +83,7 @@ struct _EMailSessionPrivate {
 struct _AsyncContext {
 	/* arguments */
 	CamelStoreGetFolderFlags flags;
+	gchar *uid;
 	gchar *uri;
 
 	/* results */
@@ -486,6 +491,7 @@ async_context_free (AsyncContext *context)
 	if (context->folder != NULL)
 		g_object_unref (context->folder);
 
+	g_free (context->uid);
 	g_free (context->uri);
 
 	g_slice_free (AsyncContext, context);
@@ -499,9 +505,8 @@ mail_session_make_key (CamelService *service,
 
 	if (service != NULL)
 		key = camel_url_to_string (
-			service->url,
-			CAMEL_URL_HIDE_PASSWORD |
-			CAMEL_URL_HIDE_PARAMS);
+			camel_service_get_camel_url (service),
+			CAMEL_URL_HIDE_PASSWORD | CAMEL_URL_HIDE_PARAMS);
 	else
 		key = g_strdup (item);
 
@@ -552,7 +557,7 @@ mail_session_dispose (GObject *object)
 {
 	EMailSessionPrivate *priv;
 
-	priv = E_MAIL_SESSION (object)->priv;
+	priv = E_MAIL_SESSION_GET_PRIVATE (object);
 
 	if (priv->folder_cache != NULL) {
 		g_object_unref (priv->folder_cache);
@@ -598,19 +603,18 @@ mail_session_get_password (CamelSession *session,
                            guint32 flags,
                            GError **error)
 {
-	gchar *url;
-	gchar *ret = NULL;
 	EAccount *account = NULL;
+	const gchar *uid = NULL;
+	gchar *ret = NULL;
 
-	url = service?camel_url_to_string (service->url, CAMEL_URL_HIDE_ALL):NULL;
+	if (CAMEL_IS_SERVICE (service)) {
+		uid = camel_service_get_uid (service);
+		account = e_get_account_by_uid (uid);
+	}
 
-	if (!strcmp(item, "popb4smtp_uri")) {
+	if (!strcmp(item, "popb4smtp_uid")) {
 		/* not 100% mt safe, but should be ok */
-		if (url
-		    && (account = e_get_account_by_transport_url (url)))
-			ret = g_strdup (account->source->url);
-		else
-			ret = g_strdup (url);
+		ret = g_strdup ((account != NULL) ? account->uid : uid);
 	} else {
 		gchar *key = mail_session_make_key (service, item);
 		EAccountService *config_service = NULL;
@@ -625,29 +629,36 @@ mail_session_get_password (CamelSession *session,
 			g_free (ret);
 			ret = NULL;
 
-			if (url) {
-				if  ((account = e_get_account_by_source_url (url)))
+			if (account != NULL) {
+				if (CAMEL_IS_STORE (service))
 					config_service = account->source;
-				else if ((account = e_get_account_by_transport_url (url)))
+				if (CAMEL_IS_TRANSPORT (service))
 					config_service = account->transport;
 			}
 
 			remember = config_service?config_service->save_passwd:FALSE;
 
-			if (!config_service || (config_service && !config_service->get_password_canceled)) {
+			if (!config_service || (config_service &&
+				!config_service->get_password_canceled)) {
 				guint32 eflags;
 				gchar *title;
 
 				if (flags & CAMEL_SESSION_PASSPHRASE) {
 					if (account)
-						title = g_strdup_printf (_("Enter Passphrase for %s"), account->name);
+						title = g_strdup_printf (
+							_("Enter Passphrase for %s"),
+							account->name);
 					else
-						title = g_strdup (_("Enter Passphrase"));
+						title = g_strdup (
+							_("Enter Passphrase"));
 				} else {
 					if (account)
-						title = g_strdup_printf (_("Enter Password for %s"), account->name);
+						title = g_strdup_printf (
+							_("Enter Password for %s"),
+							account->name);
 					else
-						title = g_strdup (_("Enter Password"));
+						title = g_strdup (
+							_("Enter Password"));
 				}
 				if ((flags & CAMEL_SESSION_PASSWORD_STATIC) != 0)
 					eflags = E_PASSWORDS_REMEMBER_NEVER;
@@ -694,8 +705,6 @@ mail_session_get_password (CamelSession *session,
 		g_free (key);
 	}
 
-	g_free (url);
-
 	if (ret == NULL)
 		g_set_error (
 			error, G_IO_ERROR,
@@ -790,61 +799,6 @@ mail_session_lookup_addressbook (CamelSession *session,
 	return ret;
 }
 
-static gpointer
-mail_session_thread_msg_new (CamelSession *session,
-                             CamelSessionThreadOps *ops,
-                             guint size)
-{
-	CamelSessionThreadMsg *msg;
-	CamelSessionClass *session_class;
-
-	/* TODO This is very temporary, until we have a better way to do
-	 *      the progress reporting, we just borrow a dummy mail-mt
-	 *      thread message and hook it onto out camel thread message. */
-
-	/* Chain up to parent's thread_msg_new() method. */
-	session_class = CAMEL_SESSION_CLASS (e_mail_session_parent_class);
-	msg = session_class->thread_msg_new (session, ops, size);
-
-#if 0
-	/* We create a dummy mail_msg, and then copy its cancellation
-	 * port over to ours, so we get cancellation and progress in
-	 * common with hte existing mail code, for free. */
-	if (msg) {
-		MailMsg *m = mail_msg_new (&ms_thread_info_dummy);
-
-		msg->data = m;
-		e_activity_set_cancellable (
-			m->activity, msg->cancellable);
-	}
-#endif
-
-	return msg;
-}
-
-static void
-mail_session_thread_msg_free (CamelSession *session,
-                              CamelSessionThreadMsg *msg)
-{
-	CamelSessionClass *session_class;
-
-#if 0
-	mail_msg_unref (msg->data);
-#endif
-
-	/* Chain up to parent's thread_msg_free() method. */
-	session_class = CAMEL_SESSION_CLASS (e_mail_session_parent_class);
-	session_class->thread_msg_free (session, msg);
-}
-
-static void
-mail_session_thread_status (CamelSession *session,
-                            CamelSessionThreadMsg *msg,
-                            const gchar *text,
-                            gint pc)
-{
-}
-
 static gboolean
 mail_session_forward_to (CamelSession *session,
                          CamelFolder *folder,
@@ -978,9 +932,6 @@ e_mail_session_class_init (EMailSessionClass *class)
 	session_class->alert_user = mail_session_alert_user;
 	session_class->get_filter_driver = mail_session_get_filter_driver;
 	session_class->lookup_addressbook = mail_session_lookup_addressbook;
-	session_class->thread_msg_new = mail_session_thread_msg_new;
-	session_class->thread_msg_free = mail_session_thread_msg_free;
-	session_class->thread_status = mail_session_thread_status;
 	session_class->forward_to = mail_session_forward_to;
 
 	g_object_class_install_property (
@@ -999,17 +950,12 @@ e_mail_session_init (EMailSession *session)
 {
 	GConfClient *client;
 
-	session->priv = G_TYPE_INSTANCE_GET_PRIVATE (
-		session, E_TYPE_MAIL_SESSION, EMailSessionPrivate);
+	session->priv = E_MAIL_SESSION_GET_PRIVATE (session);
 	session->priv->folder_cache = mail_folder_cache_new ();
 
 	/* Initialize the EAccount setup. */
 	e_account_writable (NULL, E_ACCOUNT_SOURCE_SAVE_PASSWD);
 
-	camel_session_construct (
-		CAMEL_SESSION (session),
-		mail_session_get_data_dir ());
-
 	client = gconf_client_get_default ();
 
 	gconf_client_add_dir (
@@ -1034,7 +980,13 @@ e_mail_session_init (EMailSession *session)
 EMailSession *
 e_mail_session_new (void)
 {
-	return g_object_new (E_TYPE_MAIL_SESSION, NULL);
+	const gchar *user_data_dir;
+
+	user_data_dir = mail_session_get_data_dir ();
+
+	return g_object_new (
+		E_TYPE_MAIL_SESSION,
+		"user-data-dir", user_data_dir, NULL);
 }
 
 MailFolderCache *
@@ -1056,7 +1008,7 @@ mail_session_get_inbox_thread (GSimpleAsyncResult *simple,
 	context = g_simple_async_result_get_op_res_gpointer (simple);
 
 	context->folder = e_mail_session_get_inbox_sync (
-		session, context->uri, cancellable, &error);
+		session, context->uid, cancellable, &error);
 
 	if (error != NULL) {
 		g_simple_async_result_set_from_error (simple, error);
@@ -1066,32 +1018,31 @@ mail_session_get_inbox_thread (GSimpleAsyncResult *simple,
 
 CamelFolder *
 e_mail_session_get_inbox_sync (EMailSession *session,
-                               const gchar *service_uri,
+                               const gchar *service_uid,
                                GCancellable *cancellable,
                                GError **error)
 {
-	CamelStore *store;
-	CamelFolder *folder;
+	CamelService *service;
 
 	g_return_val_if_fail (E_IS_MAIL_SESSION (session), NULL);
-	g_return_val_if_fail (service_uri != NULL, NULL);
+	g_return_val_if_fail (service_uid != NULL, NULL);
 
-	store = camel_session_get_store (
-		CAMEL_SESSION (session), service_uri, error);
+	service = camel_session_get_service (
+		CAMEL_SESSION (session), service_uid);
 
-	if (store == NULL)
+	if (!CAMEL_IS_STORE (service))
 		return NULL;
 
-	folder = camel_store_get_inbox_folder_sync (store, cancellable, error);
+	if (!camel_service_connect_sync (service, error))
+		return NULL;
 
-	g_object_unref (store);
-
-	return folder;
+	return camel_store_get_inbox_folder_sync (
+		CAMEL_STORE (service), cancellable, error);
 }
 
 void
 e_mail_session_get_inbox (EMailSession *session,
-                          const gchar *service_uri,
+                          const gchar *service_uid,
                           gint io_priority,
                           GCancellable *cancellable,
                           GAsyncReadyCallback callback,
@@ -1101,10 +1052,10 @@ e_mail_session_get_inbox (EMailSession *session,
 	AsyncContext *context;
 
 	g_return_if_fail (E_IS_MAIL_SESSION (session));
-	g_return_if_fail (service_uri != NULL);
+	g_return_if_fail (service_uid != NULL);
 
 	context = g_slice_new0 (AsyncContext);
-	context->uri = g_strdup (service_uri);
+	context->uid = g_strdup (service_uid);
 
 	simple = g_simple_async_result_new (
 		G_OBJECT (session), callback,
@@ -1156,7 +1107,7 @@ mail_session_get_trash_thread (GSimpleAsyncResult *simple,
 	context = g_simple_async_result_get_op_res_gpointer (simple);
 
 	context->folder = e_mail_session_get_trash_sync (
-		session, context->uri, cancellable, &error);
+		session, context->uid, cancellable, &error);
 
 	if (error != NULL) {
 		g_simple_async_result_set_from_error (simple, error);
@@ -1166,32 +1117,31 @@ mail_session_get_trash_thread (GSimpleAsyncResult *simple,
 
 CamelFolder *
 e_mail_session_get_trash_sync (EMailSession *session,
-                               const gchar *service_uri,
+                               const gchar *service_uid,
                                GCancellable *cancellable,
                                GError **error)
 {
-	CamelStore *store;
-	CamelFolder *folder;
+	CamelService *service;
 
 	g_return_val_if_fail (E_IS_MAIL_SESSION (session), NULL);
-	g_return_val_if_fail (service_uri != NULL, NULL);
+	g_return_val_if_fail (service_uid != NULL, NULL);
 
-	store = camel_session_get_store (
-		CAMEL_SESSION (session), service_uri, error);
+	service = camel_session_get_service (
+		CAMEL_SESSION (session), service_uid);
 
-	if (store == NULL)
+	if (!CAMEL_IS_STORE (service))
 		return NULL;
 
-	folder = camel_store_get_trash_folder_sync (store, cancellable, error);
+	if (!camel_service_connect_sync (service, error))
+		return NULL;
 
-	g_object_unref (store);
-
-	return folder;
+	return camel_store_get_trash_folder_sync (
+		CAMEL_STORE (service), cancellable, error);
 }
 
 void
 e_mail_session_get_trash (EMailSession *session,
-                          const gchar *service_uri,
+                          const gchar *service_uid,
                           gint io_priority,
                           GCancellable *cancellable,
                           GAsyncReadyCallback callback,
@@ -1201,10 +1151,10 @@ e_mail_session_get_trash (EMailSession *session,
 	AsyncContext *context;
 
 	g_return_if_fail (E_IS_MAIL_SESSION (session));
-	g_return_if_fail (service_uri != NULL);
+	g_return_if_fail (service_uid != NULL);
 
 	context = g_slice_new0 (AsyncContext);
-	context->uri = g_strdup (service_uri);
+	context->uid = g_strdup (service_uid);
 
 	simple = g_simple_async_result_new (
 		G_OBJECT (session), callback,
@@ -1272,90 +1222,33 @@ e_mail_session_uri_to_folder_sync (EMailSession *session,
                                    GCancellable *cancellable,
                                    GError **error)
 {
-	CamelURL *url;
 	CamelStore *store;
-	CamelFolder *folder = NULL;
-	gchar *camel_uri = NULL;
-	gboolean vtrash = FALSE;
-	gboolean vjunk = FALSE;
+	CamelFolder *folder;
+	gchar *folder_name;
+	gboolean success;
 
 	g_return_val_if_fail (E_IS_MAIL_SESSION (session), NULL);
 	g_return_val_if_fail (folder_uri != NULL, NULL);
 
-	url = camel_url_new (folder_uri, NULL);
-	g_return_val_if_fail (url, NULL);
-
-	/* url->path[1] skips the leading "/" */
-	camel_operation_push_message (
-		cancellable, _("Opening folder '%s'"), &url->path[1]);
-
-	/* FIXME vtrash and vjunk are no longer used for these URI's. */
-	if (g_str_has_prefix (folder_uri, "vtrash:")) {
-		folder_uri += 7;
-		vtrash = TRUE;
-	} else if (g_str_has_prefix (folder_uri, "vjunk:")) {
-		folder_uri += 6;
-		vjunk = TRUE;
-	} else if (g_str_has_prefix (folder_uri, "email:")) {
-		/* FIXME Shouldn't the filter:get_folder
-		 *       callback do this itself? */
-		camel_uri = em_uri_to_camel (folder_uri);
-		if (camel_uri == NULL) {
-			g_set_error (
-				error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-				_("Invalid folder: %s"), &url->path[1]);
-			goto exit;
-		}
-		folder_uri = camel_uri;
-	}
-	camel_url_free (url);
-
-	url = camel_url_new (folder_uri, error);
-
-	if (url == NULL) {
-		g_free (camel_uri);
-		goto exit;
-	}
-
-	store = (CamelStore *) camel_session_get_service (
+	success = e_mail_folder_uri_parse (
 		CAMEL_SESSION (session), folder_uri,
-		CAMEL_PROVIDER_STORE, error);
+		&store, &folder_name, error);
 
-	if (store != NULL) {
-		const gchar *name = "";
+	if (!success)
+		return NULL;
 
-		/* If we have a fragment, then the path is actually
-		 * used by the store, so the fragment is the path to
-		 * the folder instead. */
-		if (url->fragment != NULL)
-			name = url->fragment;
-		else if (url->path != NULL && *url->path != '\0')
-			name = url->path + 1;
+	camel_operation_push_message (
+		cancellable, _("Opening folder '%s'"), folder_name);
 
-		if (vtrash)
-			folder = camel_store_get_trash_folder_sync (
-				store, cancellable, error);
-		else if (vjunk)
-			folder = camel_store_get_junk_folder_sync (
-				store, cancellable, error);
-		else
-			folder = camel_store_get_folder_sync (
-				store, name, flags, cancellable, error);
-
-		g_object_unref (store);
-	}
+	folder = camel_store_get_folder_sync (
+		store, folder_name, flags, cancellable, error);
 
 	if (folder != NULL) {
 		MailFolderCache *folder_cache;
-
 		folder_cache = e_mail_session_get_folder_cache (session);
 		mail_folder_cache_note_folder (folder_cache, folder);
 	}
 
-	camel_url_free (url);
-	g_free (camel_uri);
-
-exit:
 	camel_operation_pop_message (cancellable);
 
 	return folder;
