@@ -25,6 +25,7 @@
 #include <glib.h>
 #include <camel/camel.h>
 #include <mail/e-mail-session.h>
+#include <libedataserver/e-account.h>
 
 G_BEGIN_DECLS
 
@@ -33,13 +34,12 @@ void		e_mail_store_init		(EMailSession *session,
 void		e_mail_store_add		(EMailSession *session,
 						 CamelStore *store,
 						 const gchar *display_name);
-CamelStore *	e_mail_store_add_by_uri		(EMailSession *session,
-						 const gchar *uri,
-						 const gchar *display_name);
+CamelStore *	e_mail_store_add_by_account	(EMailSession *session,
+						 EAccount *account);
 void		e_mail_store_remove		(EMailSession *session,
 						 CamelStore *store);
-void		e_mail_store_remove_by_uri	(EMailSession *session,
-						 const gchar *uri);
+void		e_mail_store_remove_by_account	(EMailSession *session,
+						 EAccount *account);
 void		e_mail_store_foreach		(GHFunc func,
 						 gpointer user_data);
 
