@@ -87,7 +87,6 @@ struct _ForwardData {
 	EShell *shell;
 	CamelFolder *folder;
 	GPtrArray *uids;
-	gchar *from_uri;
 	EMailForwardStyle style;
 };
 
@@ -121,8 +120,6 @@ forward_data_free (ForwardData *data)
 	if (data->uids != NULL)
 		em_utils_uids_free (data->uids);
 
-	g_free (data->from_uri);
-
 	g_slice_free (ForwardData, data);
 }
 
@@ -567,7 +564,7 @@ em_utils_composer_send_cb (EMsgComposer *composer,
 	session = e_msg_composer_get_session (context->composer);
 
 	e_mail_session_send_to (
-		E_MAIL_SESSION (session), message, NULL,
+		E_MAIL_SESSION (session), message,
 		G_PRIORITY_DEFAULT, cancellable, NULL, NULL,
 		(GAsyncReadyCallback) composer_send_completed,
 		context);
@@ -876,7 +873,7 @@ em_utils_composer_print_cb (EMsgComposer *composer,
 static EMsgComposer *
 create_new_composer (EShell *shell,
                      const gchar *subject,
-                     const gchar *from_uri)
+                     CamelFolder *folder)
 {
 	EMsgComposer *composer;
 	EComposerHeaderTable *table;
@@ -886,14 +883,23 @@ create_new_composer (EShell *shell,
 
 	table = e_msg_composer_get_header_table (composer);
 
-	if (from_uri != NULL) {
+	if (folder != NULL) {
+		CamelStore *store;
+		const gchar *uid;
+		gchar *folder_uri;
 		GList *list;
 
-		account = e_get_account_by_source_url (from_uri);
+		store = camel_folder_get_parent_store (folder);
+		uid = camel_service_get_uid (CAMEL_SERVICE (store));
+		account = e_get_account_by_uid (uid);
 
-		list = g_list_prepend (NULL, (gpointer) from_uri);
+		folder_uri = e_mail_folder_uri_from_folder (folder);
+
+		list = g_list_prepend (NULL, folder_uri);
 		e_composer_header_table_set_post_to_list (table, list);
 		g_list_free (list);
+
+		g_free (folder_uri);
 	}
 
 	e_composer_header_table_set_account (table, account);
@@ -905,40 +911,42 @@ create_new_composer (EShell *shell,
 /**
  * em_utils_compose_new_message:
  * @shell: an #EShell
+ * @folder: a #CamelFolder, or %NULL
  *
  * Opens a new composer window as a child window of @parent's toplevel
  * window.
  **/
 void
 em_utils_compose_new_message (EShell *shell,
-                              const gchar *from_uri)
+                              CamelFolder *folder)
 {
-	GtkWidget *composer;
+	EMsgComposer *composer;
 
 	g_return_if_fail (E_IS_SHELL (shell));
 
-	composer = (GtkWidget *) create_new_composer (shell, "", from_uri);
-	if (composer == NULL)
-		return;
+	if (folder != NULL)
+		g_return_if_fail (CAMEL_IS_FOLDER (folder));
 
-	composer_set_no_change (E_MSG_COMPOSER (composer));
+	composer = create_new_composer (shell, "", folder);
+	composer_set_no_change (composer);
 
-	gtk_widget_show (composer);
+	gtk_widget_show (GTK_WIDGET (composer));
 }
 
 /**
  * em_utils_compose_new_message_with_mailto:
  * @shell: an #EShell
- * @url: mailto url
+ * @mailto: a mailto URL
+ * @folder: a #CamelFolder, or %NULL
  *
  * Opens a new composer window as a child window of @parent's toplevel
- * window. If @url is non-NULL, the composer fields will be filled in
- * according to the values in the mailto url.
+ * window. If @mailto is non-NULL, the composer fields will be filled in
+ * according to the values in the mailto URL.
  **/
 EMsgComposer *
 em_utils_compose_new_message_with_mailto (EShell *shell,
-                                          const gchar *url,
-                                          const gchar *from_uri)
+                                          const gchar *mailto,
+                                          CamelFolder *folder)
 {
 	EMsgComposer *composer;
 	EComposerHeaderTable *table;
@@ -946,15 +954,26 @@ em_utils_compose_new_message_with_mailto (EShell *shell,
 
 	g_return_val_if_fail (E_IS_SHELL (shell), NULL);
 
-	if (url != NULL)
-		composer = e_msg_composer_new_from_url (shell, url);
+	if (folder != NULL)
+		g_return_val_if_fail (CAMEL_IS_FOLDER (folder), NULL);
+
+	if (mailto != NULL)
+		composer = e_msg_composer_new_from_url (shell, mailto);
 	else
 		composer = e_msg_composer_new (shell);
 
 	table = e_msg_composer_get_header_table (composer);
 
-	if (from_uri
-	    && (account = e_get_account_by_source_url (from_uri)))
+	if (folder != NULL) {
+		CamelStore *store;
+		const gchar *uid;
+
+		store = camel_folder_get_parent_store (folder);
+		uid = camel_service_get_uid (CAMEL_SERVICE (store));
+		account = e_get_account_by_uid (uid);
+	}
+
+	if (account != NULL)
 		e_composer_header_table_set_account_name (table, account->name);
 
 	composer_set_no_change (composer);
@@ -1117,7 +1136,7 @@ edit_message (EShell *shell,
 	EMsgComposer *composer;
 
 	/* Template specific code follows. */
-	if (em_utils_folder_is_templates (folder, NULL)) {
+	if (em_utils_folder_is_templates (folder)) {
 		GConfClient *gconf;
 		GSList *clue_list = NULL;
 
@@ -1138,14 +1157,15 @@ edit_message (EShell *shell,
 
 	composer = e_msg_composer_new_with_message (shell, message, NULL);
 
-	if (message_uid != NULL) {
-		const gchar *folder_uri;
+	if (message_uid != NULL && em_utils_folder_is_drafts (folder)) {
+		gchar *folder_uri;
 
-		folder_uri = camel_folder_get_uri (folder);
+		folder_uri = e_mail_folder_uri_from_folder (folder);
 
-		if (em_utils_folder_is_drafts (folder, folder_uri))
-			e_msg_composer_set_draft_headers (
-				composer, folder_uri, message_uid);
+		e_msg_composer_set_draft_headers (
+			composer, folder_uri, message_uid);
+
+		g_free (folder_uri);
 	}
 
 	composer_set_no_change (composer);
@@ -1372,14 +1392,11 @@ forward_attached (EShell *shell,
                   GPtrArray *uids,
                   GPtrArray *messages,
                   CamelMimePart *part,
-                  gchar *subject,
-                  const gchar *from_uri)
+                  gchar *subject)
 {
 	EMsgComposer *composer;
 
-	composer = create_new_composer (shell, subject, from_uri);
-	if (composer == NULL)
-		return NULL;
+	composer = create_new_composer (shell, subject, folder);
 
 	e_msg_composer_attach (composer, part);
 
@@ -1405,7 +1422,7 @@ forward_attached_cb (CamelFolder *folder,
 	if (part)
 		forward_attached (
 			data->shell, folder, data->uids,
-			messages, part, subject, data->from_uri);
+			messages, part, subject);
 
 	forward_data_free (data);
 }
@@ -1415,12 +1432,11 @@ forward_non_attached (EShell *shell,
                       CamelFolder *folder,
                       GPtrArray *uids,
                       GPtrArray *messages,
-                      EMailForwardStyle style,
-                      const gchar *from_uri)
+                      EMailForwardStyle style)
 {
 	CamelMimeMessage *message;
 	EMsgComposer *composer = NULL;
-	const gchar *folder_uri;
+	gchar *folder_uri;
 	gchar *subject, *text, *forward;
 	gint i;
 	guint32 flags;
@@ -1428,7 +1444,7 @@ forward_non_attached (EShell *shell,
 	if (messages->len == 0)
 		return NULL;
 
-	folder_uri = camel_folder_get_uri (folder);
+	folder_uri = e_mail_folder_uri_from_folder (folder);
 
 	flags = EM_FORMAT_QUOTE_HEADERS | EM_FORMAT_QUOTE_KEEP_SIG;
 	if (style == E_MAIL_FORWARD_STYLE_QUOTED)
@@ -1445,7 +1461,7 @@ forward_non_attached (EShell *shell,
 			message, forward, flags, NULL, NULL, &validity_found);
 
 		if (text) {
-			composer = create_new_composer (shell, subject, from_uri);
+			composer = create_new_composer (shell, subject, folder);
 
 			if (composer) {
 				if (CAMEL_IS_MULTIPART (camel_medium_get_content ((CamelMedium *)message)))
@@ -1470,6 +1486,8 @@ forward_non_attached (EShell *shell,
 		g_free (subject);
 	}
 
+	g_free (folder_uri);
+
 	return composer;
 }
 
@@ -1477,7 +1495,7 @@ forward_non_attached (EShell *shell,
  * em_utils_forward_message:
  * @shell: an #EShell
  * @message: message to be forwarded
- * @from_uri: from folder uri
+ * @folder: a #CamelFolder, or %NULL
  * @style: the forward style to use
  *
  * Forwards a message in the given style.  See em_utils_forward_messages()
@@ -1486,7 +1504,7 @@ forward_non_attached (EShell *shell,
 EMsgComposer *
 em_utils_forward_message (EShell *shell,
                           CamelMimeMessage *message,
-                          const gchar *from_uri,
+                          CamelFolder *folder,
                           EMailForwardStyle style)
 {
 	GPtrArray *messages;
@@ -1507,8 +1525,7 @@ em_utils_forward_message (EShell *shell,
 			subject = mail_tool_generate_forward_subject (message);
 
 			composer = forward_attached (
-				shell, NULL, NULL, messages,
-				part, subject, from_uri);
+				shell, NULL, NULL, messages, part, subject);
 
 			g_object_unref (part);
 			g_free (subject);
@@ -1517,13 +1534,13 @@ em_utils_forward_message (EShell *shell,
 		case E_MAIL_FORWARD_STYLE_INLINE:
 			composer = forward_non_attached (
 				shell, NULL, NULL, messages,
-				E_MAIL_FORWARD_STYLE_INLINE, from_uri);
+				E_MAIL_FORWARD_STYLE_INLINE);
 			break;
 
 		case E_MAIL_FORWARD_STYLE_QUOTED:
 			composer = forward_non_attached (
 				shell, NULL, NULL, messages,
-				E_MAIL_FORWARD_STYLE_QUOTED, from_uri);
+				E_MAIL_FORWARD_STYLE_QUOTED);
 			break;
 	}
 
@@ -1541,8 +1558,7 @@ forward_got_messages_cb (CamelFolder *folder,
 	ForwardData *data = user_data;
 
 	forward_non_attached (
-		data->shell, folder, uids, messages,
-		data->style, data->from_uri);
+		data->shell, folder, uids, messages, data->style);
 
 	forward_data_free (data);
 }
@@ -1574,7 +1590,6 @@ void
 em_utils_forward_messages (EShell *shell,
                            CamelFolder *folder,
                            GPtrArray *uids,
-                           const gchar *from_uri,
                            EMailForwardStyle style)
 {
 	ForwardData *data;
@@ -1584,7 +1599,6 @@ em_utils_forward_messages (EShell *shell,
 	data = g_slice_new0 (ForwardData);
 	data->shell = g_object_ref (shell);
 	data->uids = em_utils_uids_copy (uids);
-	data->from_uri = g_strdup (from_uri);
 	data->style = style;
 
 	switch (style) {
@@ -1802,6 +1816,7 @@ em_utils_send_receipt (EMailSession *session,
 	gchar *hostname;
 	gchar *self_address, *receipt_subject;
 	gchar *ua, *recipient;
+	gchar *transport_uid;
 
 	message_id = camel_medium_get_header (
 		CAMEL_MEDIUM (message), "Message-ID");
@@ -1916,6 +1931,8 @@ em_utils_send_receipt (EMailSession *session,
 	camel_mime_message_set_recipients (receipt, CAMEL_RECIPIENT_TYPE_TO, addr);
 	g_object_unref (addr);
 
+	transport_uid = g_strconcat (account->uid, "-transport", NULL);
+
 	camel_medium_set_header (
 		CAMEL_MEDIUM (receipt),
 		"Return-Path", "<>");
@@ -1926,12 +1943,14 @@ em_utils_send_receipt (EMailSession *session,
 	camel_medium_set_header (
 		CAMEL_MEDIUM (receipt),
 		"X-Evolution-Transport",
-		account->transport->url);
+		transport_uid);
 	camel_medium_set_header (
 		CAMEL_MEDIUM (receipt),
 		"X-Evolution-Fcc",
 		account->sent_folder_uri);
 
+	g_free (transport_uid);
+
 	/* Send the receipt */
 	info = camel_message_info_new (NULL);
 	out_folder = e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_OUTBOX);
@@ -2042,11 +2061,16 @@ reply_get_composer (EShell *shell,
 
 		if (folder) {
 			CamelStore *parent_store;
+			CamelService *service;
+			CamelURL *url;
 
 			parent_store = camel_folder_get_parent_store (folder);
+
+			service = CAMEL_SERVICE (parent_store);
+			url = camel_service_get_camel_url (service);
+
 			store_url = camel_url_to_string (
-				CAMEL_SERVICE (parent_store)->url,
-				CAMEL_URL_HIDE_ALL);
+				url, CAMEL_URL_HIDE_ALL);
 			if (store_url[strlen (store_url) - 1] == '/')
 				store_url[strlen (store_url)-1] = '\0';
 		}
@@ -2741,12 +2765,14 @@ em_utils_reply_to_message (EShell *shell,
 	g_object_unref (message);
 
 	if (folder != NULL) {
-		const gchar *folder_uri;
+		gchar *folder_uri;
 
-		folder_uri = camel_folder_get_uri (folder);
+		folder_uri = e_mail_folder_uri_from_folder (folder);
 
 		e_msg_composer_set_source_headers (
 			composer, folder_uri, uid, flags);
+
+		g_free (folder_uri);
 	}
 
 	composer_set_no_change (composer);
