@@ -20,8 +20,8 @@
  *
  */
 
-#ifndef __EM_CONFIG_H__
-#define __EM_CONFIG_H__
+#ifndef EM_CONFIG_H
+#define EM_CONFIG_H
 
 #include <camel/camel.h>
 #include <gconf/gconf-client.h>
@@ -64,17 +64,14 @@ struct _EMConfigTargetPrefs {
 struct _EMConfigTargetAccount {
 	EConfigTarget target;
 
-	EAccount *account;
-	/* Need also: working account, not just real account, so changes can be propagated around
-	   And some mechamism for controlling the gui if we're running inside an assistant, e.g. enabling 'next' */
+	EAccount *original_account;
+	EAccount *modified_account;
 };
 
 typedef struct _EConfigItem EMConfigItem;
 
-/* The object */
 struct _EMConfig {
 	EConfig config;
-
 	EMConfigPrivate *priv;
 };
 
@@ -82,14 +79,21 @@ struct _EMConfigClass {
 	EConfigClass config_class;
 };
 
-GType em_config_get_type (void);
-
-EMConfig *em_config_new (gint type, const gchar *menuid);
-
-EMConfigTargetFolder *em_config_target_new_folder (EMConfig *emp, CamelFolder *folder, const gchar *uri);
-EMConfigTargetPrefs *em_config_target_new_prefs (EMConfig *emp, GConfClient *gconf);
-EMConfigTargetAccount *em_config_target_new_account (EMConfig *emp, EAccount *account);
+GType		em_config_get_type		(void);
+EMConfig *	em_config_new			(gint type,
+						 const gchar *menuid);
+EMConfigTargetFolder *
+		em_config_target_new_folder	(EMConfig *emp,
+						 CamelFolder *folder,
+						 const gchar *uri);
+EMConfigTargetPrefs *
+		em_config_target_new_prefs	(EMConfig *emp,
+						 GConfClient *gconf);
+EMConfigTargetAccount *
+		em_config_target_new_account	(EMConfig *emp,
+						 EAccount *original_account,
+						 EAccount *modified_account);
 
 G_END_DECLS
 
-#endif /* __EM_CONFIG_H__ */
+#endif /* EM_CONFIG_H */
