@@ -39,10 +39,6 @@
 #include "libedataserver/e-sexp.h"
 #include "e-util/e-alert.h"
 
-#define EM_FILTER_FOLDER_ELEMENT_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), EM_TYPE_FILTER_FOLDER_ELEMENT, EMFilterFolderElementPrivate))
-
 struct _EMFilterFolderElementPrivate {
 	EMailSession *session;
 	gchar *uri;
@@ -122,7 +118,7 @@ filter_folder_element_dispose (GObject *object)
 {
 	EMFilterFolderElementPrivate *priv;
 
-	priv = EM_FILTER_FOLDER_ELEMENT_GET_PRIVATE (object);
+	priv = EM_FILTER_FOLDER_ELEMENT (object)->priv;
 
 	if (priv->session != NULL) {
 		g_object_unref (priv->session);
@@ -138,7 +134,7 @@ filter_folder_element_finalize (GObject *object)
 {
 	EMFilterFolderElementPrivate *priv;
 
-	priv = EM_FILTER_FOLDER_ELEMENT_GET_PRIVATE (object);
+	priv = EM_FILTER_FOLDER_ELEMENT (object)->priv;
 
 	g_free (priv->uri);
 
@@ -185,7 +181,9 @@ em_filter_folder_element_class_init (EMFilterFolderElementClass *class)
 static void
 em_filter_folder_element_init (EMFilterFolderElement *element)
 {
-	element->priv = EM_FILTER_FOLDER_ELEMENT_GET_PRIVATE (element);
+	element->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		element, EM_TYPE_FILTER_FOLDER_ELEMENT,
+		EMFilterFolderElementPrivate);
 }
 
 EFilterElement *
@@ -227,7 +225,7 @@ em_filter_folder_element_set_uri (EMFilterFolderElement *element,
 static gboolean
 validate (EFilterElement *fe, EAlert **alert)
 {
-	EMFilterFolderElement *ff = (EMFilterFolderElement *)fe;
+	EMFilterFolderElement *ff = (EMFilterFolderElement *) fe;
 
 	g_warn_if_fail (alert == NULL || *alert == NULL);
 
@@ -246,25 +244,22 @@ folder_eq (EFilterElement *fe, EFilterElement *cm)
 {
 	return E_FILTER_ELEMENT_CLASS (
 		em_filter_folder_element_parent_class)->eq (fe, cm) &&
-		strcmp (((EMFilterFolderElement *)fe)->priv->uri,
-		((EMFilterFolderElement *)cm)->priv->uri)== 0;
+		strcmp (((EMFilterFolderElement *) fe)->priv->uri,
+		((EMFilterFolderElement *) cm)->priv->uri)== 0;
 }
 
 static xmlNodePtr
 xml_encode (EFilterElement *fe)
 {
 	xmlNodePtr value, work;
-	EMFilterFolderElement *ff = (EMFilterFolderElement *)fe;
+	EMFilterFolderElement *ff = (EMFilterFolderElement *) fe;
 
-	value = xmlNewNode(NULL, (const guchar *)"value");
-	xmlSetProp(value, (const guchar *)"name", (guchar *)fe->name);
-	if (ff->store_camel_uri)
-		xmlSetProp(value, (const guchar *)"type", (const guchar *)"folder-curi");
-	else
-		xmlSetProp(value, (const guchar *)"type", (const guchar *)"folder");
+	value = xmlNewNode(NULL, (xmlChar *) "value");
+	xmlSetProp(value, (xmlChar *) "name", (xmlChar *) fe->name);
+	xmlSetProp(value, (xmlChar *) "type", (xmlChar *) "folder");
 
-	work = xmlNewChild(value, NULL, (const guchar *)"folder", NULL);
-	xmlSetProp(work, (const guchar *)"uri", (const guchar *)ff->priv->uri);
+	work = xmlNewChild(value, NULL, (xmlChar *) "folder", NULL);
+	xmlSetProp(work, (xmlChar *) "uri", (xmlChar *) ff->priv->uri);
 
 	return value;
 }
@@ -272,27 +267,18 @@ xml_encode (EFilterElement *fe)
 static gint
 xml_decode (EFilterElement *fe, xmlNodePtr node)
 {
-	EMFilterFolderElement *ff = (EMFilterFolderElement *)fe;
+	EMFilterFolderElement *ff = (EMFilterFolderElement *) fe;
 	xmlNodePtr n;
-	xmlChar *type;
 
 	xmlFree (fe->name);
-	fe->name = (gchar *)xmlGetProp(node, (const guchar *)"name");
-
-	type = xmlGetProp (node, (const guchar *)"type");
-	if (type) {
-		ff->store_camel_uri = g_str_equal ((const gchar *)type, "folder-curi");
-		xmlFree (type);
-	} else {
-		ff->store_camel_uri = FALSE;
-	}
+	fe->name = (gchar *) xmlGetProp(node, (xmlChar *) "name");
 
 	n = node->children;
 	while (n) {
-		if (!strcmp((gchar *)n->name, "folder")) {
+		if (!strcmp((gchar *) n->name, "folder")) {
 			gchar *uri;
 
-			uri = (gchar *)xmlGetProp(n, (const guchar *)"uri");
+			uri = (gchar *) xmlGetProp(n, (xmlChar *) "uri");
 			g_free (ff->priv->uri);
 			ff->priv->uri = g_strdup (uri);
 			xmlFree (uri);
@@ -305,18 +291,16 @@ xml_decode (EFilterElement *fe, xmlNodePtr node)
 }
 
 static void
-folder_selected (EMFolderSelectionButton *button, EMFilterFolderElement *ff)
+folder_selected (EMFolderSelectionButton *button,
+                 EMFilterFolderElement *ff)
 {
 	GtkWidget *toplevel;
 	const gchar *uri;
 
 	uri = em_folder_selection_button_get_selection (button);
-	g_free (ff->priv->uri);
 
-	if (ff->store_camel_uri)
-		ff->priv->uri = g_strdup (uri);
-	else
-		ff->priv->uri = uri != NULL ? em_uri_from_camel (uri) : NULL;
+	g_free (ff->priv->uri);
+	ff->priv->uri = g_strdup (uri);
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (button));
 	gtk_window_present (GTK_WINDOW (toplevel));
@@ -325,29 +309,21 @@ folder_selected (EMFolderSelectionButton *button, EMFilterFolderElement *ff)
 static GtkWidget *
 get_widget (EFilterElement *fe)
 {
-	EMFilterFolderElement *ff = (EMFilterFolderElement *)fe;
+	EMFilterFolderElement *ff = (EMFilterFolderElement *) fe;
 	EMailSession *session;
 	GtkWidget *button;
-	gchar *uri;
 
 	session = em_filter_folder_element_get_session (ff);
 
-	if (ff->store_camel_uri)
-		uri = ff->priv->uri;
-	else
-		uri = em_uri_to_camel (ff->priv->uri);
-
 	button = em_folder_selection_button_new (
 		session, _("Select Folder"), NULL);
-
 	em_folder_selection_button_set_selection (
-		EM_FOLDER_SELECTION_BUTTON (button), uri);
-
-	if (!ff->store_camel_uri)
-		g_free (uri);
-
+		EM_FOLDER_SELECTION_BUTTON (button), ff->priv->uri);
 	gtk_widget_show (button);
-	g_signal_connect(button, "selected", G_CALLBACK(folder_selected), ff);
+
+	g_signal_connect (
+		button, "selected",
+		G_CALLBACK (folder_selected), ff);
 
 	return button;
 }
@@ -361,7 +337,7 @@ build_code (EFilterElement *fe, GString *out, EFilterPart *ff)
 static void
 format_sexp (EFilterElement *fe, GString *out)
 {
-	EMFilterFolderElement *ff = (EMFilterFolderElement *)fe;
+	EMFilterFolderElement *ff = (EMFilterFolderElement *) fe;
 
 	e_sexp_encode_string (out, ff->priv->uri);
 }
@@ -370,11 +346,11 @@ static void
 emff_copy_value (EFilterElement *de, EFilterElement *se)
 {
 	if (EM_IS_FILTER_FOLDER_ELEMENT (se)) {
-		((EMFilterFolderElement *)de)->store_camel_uri =
-			((EMFilterFolderElement *)se)->store_camel_uri;
-		em_filter_folder_element_set_uri ((
-			EMFilterFolderElement *) de,
-			((EMFilterFolderElement *) se)->priv->uri);
-	} else
-		E_FILTER_ELEMENT_CLASS (em_filter_folder_element_parent_class)->copy_value (de, se);
+		em_filter_folder_element_set_uri (
+			EM_FILTER_FOLDER_ELEMENT (de),
+			EM_FILTER_FOLDER_ELEMENT (se)->priv->uri);
+	} else {
+		E_FILTER_ELEMENT_CLASS (
+		em_filter_folder_element_parent_class)->copy_value (de, se);
+	}
 }
