@@ -25,6 +25,7 @@
 #define EM_FOLDER_SELECTION_BUTTON_H
 
 #include <gtk/gtk.h>
+#include <mail/e-mail-session.h>
 
 /* Standard GObject macros */
 #define EM_TYPE_FOLDER_SELECTION_BUTTON \
@@ -66,28 +67,24 @@ struct _EMFolderSelectionButtonClass {
 
 GType		em_folder_selection_button_get_type (void);
 GtkWidget *	em_folder_selection_button_new
-					(const gchar *title,
+					(EMailSession *session,
+					 const gchar *title,
 					 const gchar *caption);
 const gchar *	em_folder_selection_button_get_caption
 					(EMFolderSelectionButton *button);
 void		em_folder_selection_button_set_caption
 					(EMFolderSelectionButton *button,
 					 const gchar *caption);
-gboolean	em_folder_selection_button_get_multiselect
-					(EMFolderSelectionButton *button);
-void		em_folder_selection_button_set_multiselect
-					(EMFolderSelectionButton *button,
-					 gboolean multiselect);
 const gchar *	em_folder_selection_button_get_selection
 					(EMFolderSelectionButton *button);
 void		em_folder_selection_button_set_selection
 					(EMFolderSelectionButton *button,
 					 const gchar *uri);
-GList *		em_folder_selection_button_get_selection_mult
-					(EMFolderSelectionButton *button);
-void		em_folder_selection_button_set_selection_mult
+void		em_folder_selection_button_set_session
 					(EMFolderSelectionButton *button,
-					 GList *uris);
+					 EMailSession *session);
+EMailSession *	em_folder_selection_button_get_session
+					(EMFolderSelectionButton *button);
 const gchar *	em_folder_selection_button_get_title
 					(EMFolderSelectionButton *button);
 void		em_folder_selection_button_set_title
