@@ -25,13 +25,13 @@
 #include <glib/gi18n.h>
 #include <e-util/e-util.h>
 
+#include "e-mail-session.h"
 #include "em-folder-tree.h"
 #include "em-folder-selector.h"
 #include "em-folder-utils.h"
 
 #define d(x)
 
-extern CamelSession *session;
 static gpointer parent_class;
 
 static void
@@ -48,7 +48,7 @@ folder_selector_finalize (GObject *object)
 }
 
 static void
-folder_selector_destroy (GtkObject *object)
+folder_selector_dispose (GObject *object)
 {
 	EMFolderSelector *emfs = EM_FOLDER_SELECTOR (object);
 	GtkTreeModel *model;
@@ -59,23 +59,20 @@ folder_selector_destroy (GtkObject *object)
 		emfs->created_id = 0;
 	}
 
-	/* Chain up to parent's destroy() method. */
-	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+	/* Chain up to parent's dispose() method. */
+	G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
 static void
 folder_selector_class_init (EMFolderSelectorClass *class)
 {
 	GObjectClass *object_class;
-	GtkObjectClass *gtk_object_class;
 
 	parent_class = g_type_class_peek_parent (class);
 
 	object_class = G_OBJECT_CLASS (class);
 	object_class->finalize = folder_selector_finalize;
-
-	gtk_object_class = GTK_OBJECT_CLASS (class);
-	gtk_object_class->destroy = folder_selector_destroy;
+	object_class->dispose = folder_selector_dispose;
 }
 
 static void
@@ -119,7 +116,9 @@ emfs_response (GtkWidget *dialog, gint response, EMFolderSelector *emfs)
 
 	g_object_set_data ((GObject *)emfs->emft, "select", GUINT_TO_POINTER (1));
 
-	em_folder_utils_create_folder (NULL, emfs->emft, GTK_WINDOW (dialog));
+	em_folder_utils_create_folder (
+		GTK_WINDOW (dialog), emfs->emft,
+		em_folder_tree_get_session (emfs->emft), NULL);
 
 	g_signal_stop_emission_by_name (emfs, "response");
 }
@@ -134,24 +133,32 @@ emfs_create_name_changed (GtkEntry *entry, EMFolderSelector *emfs)
 	if (gtk_entry_get_text_length (emfs->name_entry) > 0)
 		text = gtk_entry_get_text (emfs->name_entry);
 
-	path = em_folder_tree_get_selected_uri(emfs->emft);
+	path = em_folder_tree_get_selected_uri (emfs->emft);
 	active = text && path && !strchr (text, '/');
-	g_free(path);
+	g_free (path);
 
 	gtk_dialog_set_response_sensitive ((GtkDialog *) emfs, GTK_RESPONSE_OK, active);
 }
 
 static void
-folder_selected_cb (EMFolderTree *emft, const gchar *path, const gchar *uri, guint32 flags, EMFolderSelector *emfs)
+folder_selected_cb (EMFolderTree *emft,
+                    CamelStore *store,
+                    const gchar *folder_name,
+                    CamelFolderInfoFlags flags,
+                    EMFolderSelector *emfs)
 {
 	if (emfs->name_entry)
 		emfs_create_name_changed (emfs->name_entry, emfs);
 	else
-		gtk_dialog_set_response_sensitive (GTK_DIALOG (emfs), GTK_RESPONSE_OK, TRUE);
+		gtk_dialog_set_response_sensitive (
+			GTK_DIALOG (emfs), GTK_RESPONSE_OK, TRUE);
 }
 
 static void
-folder_activated_cb (EMFolderTree *emft, const gchar *path, const gchar *uri, EMFolderSelector *emfs)
+folder_activated_cb (EMFolderTree *emft,
+                     CamelStore *store,
+                     const gchar *folder_name,
+                     EMFolderSelector *emfs)
 {
 	gtk_dialog_response ((GtkDialog *) emfs, GTK_RESPONSE_OK);
 }
@@ -235,11 +242,11 @@ emfs_create_name_activate (GtkEntry *entry, EMFolderSelector *emfs)
 		const gchar *text;
 
 		text = gtk_entry_get_text (emfs->name_entry);
-		path = em_folder_tree_get_selected_uri(emfs->emft);
+		path = em_folder_tree_get_selected_uri (emfs->emft);
 
 		if (text && path && !strchr (text, '/'))
 			g_signal_emit_by_name (emfs, "response", GTK_RESPONSE_OK);
-		g_free(path);
+		g_free (path);
 	}
 }
 
@@ -262,7 +269,7 @@ em_folder_selector_create_new (GtkWindow *parent,
 		EM_TYPE_FOLDER_SELECTOR,
 		"transient-for", parent, NULL);
 	em_folder_selector_construct (emfs, emft, flags, title, text, _("C_reate"));
-	em_folder_tree_set_excluded(emft, EMFT_EXCLUDE_NOINFERIORS);
+	em_folder_tree_set_excluded (emft, EMFT_EXCLUDE_NOINFERIORS);
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	w = gtk_label_new_with_mnemonic (_("Folder _name:"));
@@ -310,7 +317,7 @@ em_folder_selector_get_selected_uri (EMFolderSelector *emfs)
 		CamelURL *url;
 		gchar *newpath;
 
-		provider = camel_provider_get(uri, NULL);
+		provider = camel_provider_get (uri, NULL);
 
 		name = gtk_entry_get_text (emfs->name_entry);
 
@@ -326,10 +333,10 @@ em_folder_selector_get_selected_uri (EMFolderSelector *emfs)
 			gchar *path;
 
 			path = g_strdup_printf("%s/%s", (url->path == NULL || strcmp(url->path, "/") == 0) ? "":url->path, name);
-			camel_url_set_path(url, path);
+			camel_url_set_path (url, path);
 			if (path[0] == '/') {
-				newpath = g_strdup(path+1);
-				g_free(path);
+				newpath = g_strdup (path+1);
+				g_free (path);
 			} else
 				newpath = path;
 		}
@@ -369,13 +376,13 @@ em_folder_selector_get_selected_path (EMFolderSelector *emfs)
 		return emfs->selected_path;
 	}
 
-	if ((uri = em_folder_tree_get_selected_uri(emfs->emft)) == NULL) {
+	if ((uri = em_folder_tree_get_selected_uri (emfs->emft)) == NULL) {
 		d(printf ("no selected folder?\n"));
 		return NULL;
 	}
-	g_free(uri);
+	g_free (uri);
 
-	path = em_folder_tree_get_selected_path(emfs->emft);
+	path = em_folder_tree_get_selected_path (emfs->emft);
 	if (emfs->name_entry) {
 		const gchar *name;
 		gchar *newpath;
@@ -383,10 +390,10 @@ em_folder_selector_get_selected_path (EMFolderSelector *emfs)
 		name = gtk_entry_get_text (emfs->name_entry);
 		newpath = g_strdup_printf ("%s/%s", path?path:"", name);
 
-		g_free(path);
+		g_free (path);
 		emfs->selected_path = g_strdup (newpath);
 	} else {
-		g_free(emfs->selected_path);
+		g_free (emfs->selected_path);
 		emfs->selected_path = path?path:g_strdup("");
 	}
 
