@@ -62,6 +62,7 @@
 #include "em-folder-properties.h"
 #include "em-event.h"
 
+#include "e-mail-folder-utils.h"
 #include "e-mail-local.h"
 #include "e-mail-session.h"
 #include "e-mail-store.h"
@@ -71,7 +72,7 @@
 struct _selected_uri {
 	gchar *key;		/* store:path or account/path */
 	gchar *uri;
-	CamelStore *store;
+	CamelService *service;
 	gchar *path;
 };
 
@@ -370,8 +371,8 @@ static void
 folder_tree_free_select_uri (struct _selected_uri *u)
 {
 	g_free (u->uri);
-	if (u->store)
-		g_object_unref (u->store);
+	if (u->service)
+		g_object_unref (u->service);
 	g_free (u->key);
 	g_free (u->path);
 	g_free (u);
@@ -473,8 +474,7 @@ folder_tree_expand_node (const gchar *key,
 
 	if ((account = e_get_account_by_uid (uid)) && account->enabled) {
 		store = (CamelStore *) camel_session_get_service (
-			CAMEL_SESSION (session), account->source->url,
-			CAMEL_PROVIDER_STORE, NULL);
+			CAMEL_SESSION (session), account->uid);
 
 		if (store == NULL)
 			return;
@@ -673,11 +673,11 @@ folder_tree_selection_changed_cb (EMFolderTree *folder_tree,
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	GList *list;
-	guint32 flags = 0;
+	CamelStore *store = NULL;
+	CamelFolderInfoFlags flags = 0;
 	guint unread = 0;
 	guint old_unread = 0;
-	gchar *full_name = NULL;
-	gchar *uri = NULL;
+	gchar *folder_name = NULL;
 
 	list = gtk_tree_selection_get_selected_rows (selection, &model);
 
@@ -688,10 +688,11 @@ folder_tree_selection_changed_cb (EMFolderTree *folder_tree,
 
 	gtk_tree_model_get (
 		model, &iter,
-		COL_STRING_FULL_NAME, &full_name,
-		COL_STRING_URI, &uri, COL_UINT_FLAGS, &flags,
-		COL_UINT_UNREAD, &unread, COL_UINT_UNREAD_LAST_SEL,
-		&old_unread, -1);
+		COL_POINTER_CAMEL_STORE, &store,
+		COL_STRING_FULL_NAME, &folder_name,
+		COL_UINT_FLAGS, &flags,
+		COL_UINT_UNREAD, &unread,
+		COL_UINT_UNREAD_LAST_SEL, &old_unread, -1);
 
 	/* Sync unread counts to distinguish new incoming mail. */
 	if (unread != old_unread)
@@ -701,10 +702,10 @@ folder_tree_selection_changed_cb (EMFolderTree *folder_tree,
 
 exit:
 	g_signal_emit (
-		folder_tree, signals[FOLDER_SELECTED], 0, full_name, uri, flags);
+		folder_tree, signals[FOLDER_SELECTED], 0,
+		store, folder_name, flags);
 
-	g_free (full_name);
-	g_free (uri);
+	g_free (folder_name);
 
 	g_list_foreach (list, (GFunc) gtk_tree_path_free, NULL);
 	g_list_free (list);
@@ -973,9 +974,10 @@ folder_tree_row_activated (GtkTreeView *tree_view,
 {
 	EMFolderTreePrivate *priv;
 	GtkTreeModel *model;
-	gchar *full_name, *uri;
+	gchar *folder_name;
 	GtkTreeIter iter;
-	guint32 flags;
+	CamelStore *store;
+	CamelFolderInfoFlags flags;
 
 	priv = EM_FOLDER_TREE (tree_view)->priv;
 
@@ -988,19 +990,22 @@ folder_tree_row_activated (GtkTreeView *tree_view,
 		return;
 
 	gtk_tree_model_get (
-		model, &iter, COL_STRING_FULL_NAME, &full_name,
-		COL_STRING_URI, &uri, COL_UINT_FLAGS, &flags, -1);
+		model, &iter,
+		COL_POINTER_CAMEL_STORE, &store,
+		COL_STRING_FULL_NAME, &folder_name,
+		COL_UINT_FLAGS, &flags, -1);
 
 	folder_tree_clear_selected_list (EM_FOLDER_TREE (tree_view));
 
 	g_signal_emit (
-		tree_view, signals[FOLDER_SELECTED], 0, full_name, uri, flags);
+		tree_view, signals[FOLDER_SELECTED], 0,
+		store, folder_name, flags);
 
 	g_signal_emit (
-		tree_view, signals[FOLDER_ACTIVATED], 0, full_name, uri);
+		tree_view, signals[FOLDER_ACTIVATED], 0,
+		store, folder_name);
 
-	g_free (full_name);
-	g_free (uri);
+	g_free (folder_name);
 }
 
 static gboolean
@@ -1133,9 +1138,9 @@ folder_tree_class_init (EMFolderTreeClass *class)
 		G_SIGNAL_RUN_FIRST,
 		G_STRUCT_OFFSET (EMFolderTreeClass, folder_selected),
 		NULL, NULL,
-		e_marshal_VOID__STRING_STRING_UINT,
+		e_marshal_VOID__OBJECT_STRING_UINT,
 		G_TYPE_NONE, 3,
-		G_TYPE_STRING,
+		CAMEL_TYPE_STORE,
 		G_TYPE_STRING,
 		G_TYPE_UINT);
 
@@ -1145,9 +1150,9 @@ folder_tree_class_init (EMFolderTreeClass *class)
 		G_SIGNAL_RUN_FIRST,
 		G_STRUCT_OFFSET (EMFolderTreeClass, folder_activated),
 		NULL, NULL,
-		e_marshal_VOID__STRING_STRING,
+		e_marshal_VOID__OBJECT_STRING,
 		G_TYPE_NONE, 2,
-		G_TYPE_STRING,
+		CAMEL_TYPE_STORE,
 		G_TYPE_STRING);
 
 	signals[POPUP_EVENT] = g_signal_new (
@@ -1821,7 +1826,8 @@ tree_drag_data_get (GtkWidget *widget,
 	CamelStore *store;
 	GtkTreeIter iter;
 
-	if (!priv->drag_row || !(src_path = gtk_tree_row_reference_get_path (priv->drag_row)))
+	if (!priv->drag_row || !(src_path =
+		gtk_tree_row_reference_get_path (priv->drag_row)))
 		return;
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (folder_tree));
@@ -2711,7 +2717,6 @@ em_folder_tree_set_selected_list (EMFolderTree *folder_tree,
 {
 	EMFolderTreePrivate *priv = folder_tree->priv;
 	EMailSession *session;
-	gint id = 0;
 
 	session = em_folder_tree_get_session (folder_tree);
 
@@ -2720,61 +2725,51 @@ em_folder_tree_set_selected_list (EMFolderTree *folder_tree,
 		folder_tree_clear_selected_list (folder_tree);
 
 	for (;list;list = list->next) {
-		struct _selected_uri *u = g_malloc0 (sizeof (*u));
-		CamelURL *url;
+		CamelStore *store;
+		struct _selected_uri *u;
+		const gchar *folder_uri;
+		const gchar *uid;
+		gchar *folder_name;
+		gchar *expand_key;
+		gchar *end;
+		gboolean success;
 
-		u->uri = g_strdup (list->data);
-		u->store = (CamelStore *) camel_session_get_service (
-			CAMEL_SESSION (session), u->uri,
-			CAMEL_PROVIDER_STORE, NULL);
+		/* This makes sure all our parents up to the root are
+		 * expanded. */
 
-		url = camel_url_new (u->uri, NULL);
-		if (u->store == NULL || url == NULL) {
-			if (!expand_only) {
-				u->key = g_strdup_printf("dummy-%d:%s", id++, u->uri);
-				g_hash_table_insert (priv->select_uris_table, u->key, u);
-				priv->select_uris = g_slist_append (priv->select_uris, u);
-			}
-		} else {
-			const gchar *path;
-			gchar *expand_key, *end;
-			EAccount *account;
+		folder_uri = list->data;
 
-			if (((CamelService *)u->store)->provider->url_flags & CAMEL_URL_FRAGMENT_IS_PATH)
-				path = url->fragment;
-			else
-				path = url->path && url->path[0]=='/' ? url->path+1:url->path;
-			if (path == NULL)
-				path = "";
+		success = e_mail_folder_uri_parse (
+			CAMEL_SESSION (session), folder_uri,
+			&store, &folder_name, NULL);
 
-			/* This makes sure all our parents up to the root are
-			 * expanded.  FIXME: Why does the expanded state store
-			 * this made up path rather than the euri? */
-			if ((account = e_get_account_by_source_url (u->uri)))
-				expand_key = g_strdup_printf ("%s/%s", account->uid, path);
-			else if (CAMEL_IS_VEE_STORE (u->store))
-				expand_key = g_strdup_printf ("vfolder/%s", path);
-			else
-				expand_key = g_strdup_printf ("local/%s", path);
+		if (!success)
+			continue;
 
-			if (!expand_only) {
-				u->key = g_strdup (expand_key);
+		uid = camel_service_get_uid (CAMEL_SERVICE (store));
+		expand_key = g_strdup_printf ("%s/%s", uid, folder_name);
+		g_free (folder_name);
 
-				g_hash_table_insert (priv->select_uris_table, u->key, u);
-				priv->select_uris = g_slist_append (priv->select_uris, u);
-			}
+		u = g_malloc0 (sizeof (*u));
+		u->uri = g_strdup (folder_uri);
+		u->service = CAMEL_SERVICE (store);  /* takes ownership */
+		u->key = g_strdup (expand_key);
 
-			end = strrchr (expand_key, '/');
-			do {
-				folder_tree_expand_node (expand_key, folder_tree);
-				*end = 0;
-				end = strrchr (expand_key, '/');
-			} while (end);
-			g_free (expand_key);
+		if (!expand_only) {
+			g_hash_table_insert (
+				priv->select_uris_table, u->key, u);
+			priv->select_uris =
+				g_slist_append (priv->select_uris, u);
 		}
 
-		if (url)
-			camel_url_free (url);
+		end = strrchr (expand_key, '/');
+		do {
+			folder_tree_expand_node (expand_key, folder_tree);
+			*end = 0;
+			end = strrchr (expand_key, '/');
+		} while (end);
+
+		g_free (expand_key);
 	}
 }
 
@@ -3089,8 +3084,10 @@ em_folder_tree_get_selected_folder (EMFolderTree *folder_tree)
 	selection = gtk_tree_view_get_selection (tree_view);
 
 	if (gtk_tree_selection_get_selected (selection, &model, &iter))
-		gtk_tree_model_get (model, &iter, COL_POINTER_CAMEL_STORE, &store,
-				    COL_STRING_FULL_NAME, &full_name, -1);
+		gtk_tree_model_get (
+			model, &iter,
+			COL_POINTER_CAMEL_STORE, &store,
+			COL_STRING_FULL_NAME, &full_name, -1);
 
 	/* FIXME camel_store_get_folder_sync() may block. */
 	if (store && full_name)
@@ -3103,16 +3100,15 @@ em_folder_tree_get_selected_folder (EMFolderTree *folder_tree)
 	return folder;
 }
 
-CamelFolderInfo *
-em_folder_tree_get_selected_folder_info (EMFolderTree *folder_tree)
+EAccount *
+em_folder_tree_get_selected_account (EMFolderTree *folder_tree)
 {
 	GtkTreeView *tree_view;
 	GtkTreeSelection *selection;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	gchar *full_name = NULL, *name = NULL, *uri = NULL;
 	CamelStore *store = NULL;
-	CamelFolderInfo *fi = NULL;
+	const gchar *uid = NULL;
 
 	g_return_val_if_fail (EM_IS_FOLDER_TREE (folder_tree), NULL);
 
@@ -3120,27 +3116,14 @@ em_folder_tree_get_selected_folder_info (EMFolderTree *folder_tree)
 	selection = gtk_tree_view_get_selection (tree_view);
 
 	if (gtk_tree_selection_get_selected (selection, &model, &iter))
-		gtk_tree_model_get (model, &iter, COL_POINTER_CAMEL_STORE, &store,
-				    COL_STRING_FULL_NAME, &full_name,
-				    COL_STRING_DISPLAY_NAME, &name,
-				    COL_STRING_URI, &uri, -1);
+		gtk_tree_model_get (
+			model, &iter,
+			COL_POINTER_CAMEL_STORE, &store, -1);
 
-	fi = camel_folder_info_new ();
-	fi->full_name = g_strdup (full_name);
-	fi->uri = g_strdup (uri);
-	fi->name = g_strdup (name);
+	if (CAMEL_IS_STORE (store))
+		uid = camel_service_get_uid (CAMEL_SERVICE (store));
 
-	if (!fi->full_name)
-		goto done;
-
-	g_free (fi->name);
-	if (!g_ascii_strcasecmp (fi->full_name, "INBOX"))
-		fi->name = g_strdup (_("Inbox"));
-	else
-		fi->name = g_strdup (name);
-
-done:
-	return fi;
+	return (uid != NULL) ? e_get_account_by_uid (uid) : NULL;
 }
 
 void
