@@ -78,12 +78,12 @@ struct _EMFolderTreeClass {
 
 	/* signals */
 	void		(*folder_activated)	(EMFolderTree *folder_tree,
-						 const gchar *full_name,
-						 const gchar *uri);
+						 CamelStore *store,
+						 const gchar *folder_name);
 	void		(*folder_selected)	(EMFolderTree *folder_tree,
-						 const gchar *full_name,
-						 const gchar *uri,
-						 guint32 flags);
+						 CamelStore *store,
+						 const gchar *folder_name,
+						 CamelFolderInfoFlags flags);
 	void		(*popup_event)		(EMFolderTree *folder_tree);
 	void		(*hidden_key_event)	(EMFolderTree *emft, GdkEvent *event);
 };
@@ -120,8 +120,7 @@ gchar *		em_folder_tree_get_selected_uri	(EMFolderTree *folder_tree);
 gchar *		em_folder_tree_get_selected_path (EMFolderTree *folder_tree);
 CamelFolder *	em_folder_tree_get_selected_folder
 						(EMFolderTree *folder_tree);
-CamelFolderInfo *
-		em_folder_tree_get_selected_folder_info
+EAccount *	em_folder_tree_get_selected_account
 						(EMFolderTree *folder_tree);
 gboolean	em_folder_tree_create_folder	(EMFolderTree *folder_tree,
 						 const gchar *full_name,
