@@ -69,6 +69,11 @@ typedef enum {
 	EM_FORMAT_HTML_STATE_RENDERING
 } EMFormatHTMLState;
 
+typedef enum {
+	EM_FORMAT_HTML_HEADERS_STATE_EXPANDED = 0, /* Default value */
+	EM_FORMAT_HTML_HEADERS_STATE_COLLAPSED
+} EMFormatHTMLHeadersState;
+
 typedef enum {
 	EM_FORMAT_HTML_COLOR_BODY,	/* header area background */
 	EM_FORMAT_HTML_COLOR_CITATION,	/* citation font color */
@@ -128,7 +133,10 @@ struct _EMFormatHTMLJob {
 /* Pending object (classid: url) */
 typedef struct _EMFormatHTMLPObject EMFormatHTMLPObject;
 
-typedef gboolean (*EMFormatHTMLPObjectFunc)(EMFormatHTML *md, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *pobject);
+typedef gboolean
+		(*EMFormatHTMLPObjectFunc)	(EMFormatHTML *md,
+						 GtkHTMLEmbedded *eb,
+						 EMFormatHTMLPObject *pobject);
 
 /**
  * struct _EMFormatHTMLPObject - Pending object.
@@ -157,11 +165,16 @@ struct _EMFormatHTMLPObject {
 };
 
 #define EM_FORMAT_HTML_HEADER_NOCOLUMNS (EM_FORMAT_HEADER_LAST)
-#define EM_FORMAT_HTML_HEADER_HTML (EM_FORMAT_HEADER_LAST<<1) /* header already in html format */
-#define EM_FORMAT_HTML_HEADER_NODEC (EM_FORMAT_HEADER_LAST<<2) /* header already in html format */
+
+/* header already in html format */
+#define EM_FORMAT_HTML_HEADER_HTML (EM_FORMAT_HEADER_LAST<<1)
+#define EM_FORMAT_HTML_HEADER_NODEC (EM_FORMAT_HEADER_LAST<<2)
+
 #define EM_FORMAT_HTML_HEADER_LAST (EM_FORMAT_HEADER_LAST<<8)
 
-#define EM_FORMAT_HTML_VPAD "<table cellspacing=0 cellpadding=3><tr><td><a name=\"padding\"></a></td></tr></table>\n"
+#define EM_FORMAT_HTML_VPAD \
+	"<table cellspacing=0 cellpadding=3><tr><td>" \
+	"<a name=\"padding\"></a></td></tr></table>\n"
 
 /**
  * struct _EMFormatHTML - HTML formatter object.
@@ -277,6 +290,13 @@ void		em_format_html_job_queue	(EMFormatHTML *efh,
 gboolean	em_format_html_get_show_real_date (EMFormatHTML *efh);
 void		em_format_html_set_show_real_date (EMFormatHTML *efh,
 						 gboolean show_real_date);
+EMFormatHTMLHeadersState
+		em_format_html_get_headers_state (EMFormatHTML *efh);
+void		em_format_html_set_headers_state (EMFormatHTML *efh,
+						  EMFormatHTMLHeadersState state);
+gboolean	em_format_html_get_headers_collapsable (EMFormatHTML *efh);
+void		em_format_html_set_headers_collapsable (EMFormatHTML *efh,
+							gboolean collapsable);
 
 gchar *		em_format_html_format_cert_infos (CamelCipherCertInfo *first_cinfo);
 
