@@ -33,10 +33,6 @@
 
 #include "em-folder-utils.h"
 
-#define EM_SUBSCRIPTION_EDITOR_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), EM_TYPE_SUBSCRIPTION_EDITOR, EMSubscriptionEditorPrivate))
-
 #define FOLDER_CAN_SELECT(folder_info) \
 	((folder_info) != NULL && \
 	((folder_info)->flags & CAMEL_FOLDER_NOSELECT) == 0)
@@ -182,7 +178,7 @@ subscription_editor_populate (EMSubscriptionEditor *editor,
 			tree_store, &iter,
 			COL_CASEFOLDED, NULL,  /* not needed */
 			COL_FOLDER_ICON, icon_name,
-			COL_FOLDER_NAME, folder_info->name,
+			COL_FOLDER_NAME, folder_info->display_name,
 			COL_FOLDER_INFO, folder_info, -1);
 
 		if (FOLDER_SUBSCRIBED (folder_info)) {
@@ -798,7 +794,7 @@ subscription_editor_add_account (EMSubscriptionEditor *editor,
                                  EAccount *account)
 {
 	StoreData *data;
-	CamelStore *store;
+	CamelService *service;
 	CamelSession *session;
 	GtkListStore *list_store;
 	GtkTreeStore *tree_store;
@@ -808,16 +804,14 @@ subscription_editor_add_account (EMSubscriptionEditor *editor,
 	GtkComboBoxText *combo_box;
 	GtkWidget *container;
 	GtkWidget *widget;
-	const gchar *url;
 
 	combo_box = GTK_COMBO_BOX_TEXT (editor->priv->combo_box);
 	gtk_combo_box_text_append_text (combo_box, account->name);
 
 	session = em_subscription_editor_get_session (editor);
-	url = e_account_get_string (account, E_ACCOUNT_SOURCE_URL);
+	service = camel_session_get_service (session, account->uid);
 
-	store = (CamelStore *) camel_session_get_service (
-		session, url, CAMEL_PROVIDER_STORE, NULL);
+	g_return_if_fail (CAMEL_IS_STORE (service));
 
 	tree_store = gtk_tree_store_new (
 		N_COLUMNS,
@@ -895,7 +889,7 @@ subscription_editor_add_account (EMSubscriptionEditor *editor,
 
 	data = g_slice_new0 (StoreData);
 	data->account = g_object_ref (account);
-	data->store = g_object_ref (store);
+	data->store = g_object_ref (service);
 	data->tree_view = g_object_ref (widget);
 	data->list_store = GTK_TREE_MODEL (list_store);
 	data->tree_store = GTK_TREE_MODEL (tree_store);
@@ -980,7 +974,7 @@ subscription_editor_dispose (GObject *object)
 {
 	EMSubscriptionEditorPrivate *priv;
 
-	priv = EM_SUBSCRIPTION_EDITOR_GET_PRIVATE (object);
+	priv = EM_SUBSCRIPTION_EDITOR (object)->priv;
 
 	if (priv->session != NULL) {
 		g_object_unref (priv->session);
@@ -1008,7 +1002,7 @@ subscription_editor_finalize (GObject *object)
 {
 	EMSubscriptionEditorPrivate *priv;
 
-	priv = EM_SUBSCRIPTION_EDITOR_GET_PRIVATE (object);
+	priv = EM_SUBSCRIPTION_EDITOR (object)->priv;
 
 	g_ptr_array_free (priv->stores, TRUE);
 
@@ -1099,7 +1093,9 @@ em_subscription_editor_init (EMSubscriptionEditor *editor)
 	GtkWidget *box;
 	const gchar *tooltip;
 
-	editor->priv = EM_SUBSCRIPTION_EDITOR_GET_PRIVATE (editor);
+	editor->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		editor, EM_TYPE_SUBSCRIPTION_EDITOR,
+		EMSubscriptionEditorPrivate);
 	editor->priv->stores = g_ptr_array_new_with_free_func (
 		(GDestroyNotify) store_data_free);
 
