@@ -70,6 +70,7 @@
 #include "em-utils.h"
 #include "em-composer-utils.h"
 #include "em-format-quote.h"
+#include "e-mail-folder-utils.h"
 #include "e-mail-local.h"
 #include "e-mail-session.h"
 
@@ -128,7 +129,8 @@ em_utils_prompt_user (GtkWindow *parent,
                       const gchar *tag,
                       ...)
 {
-	GtkWidget *mbox, *check = NULL;
+	GtkWidget *dialog;
+	GtkWidget *check = NULL;
 	GtkWidget *container;
 	va_list ap;
 	gint button;
@@ -146,24 +148,27 @@ em_utils_prompt_user (GtkWindow *parent,
 	alert = e_alert_new_valist (tag, ap);
 	va_end (ap);
 
-	mbox = e_alert_dialog_new (parent, alert);
+	dialog = e_alert_dialog_new (parent, alert);
 	g_object_unref (alert);
 
+	container = e_alert_dialog_get_content_area (E_ALERT_DIALOG (dialog));
+
 	if (promptkey) {
-		check = gtk_check_button_new_with_mnemonic (_("_Do not show this message again"));
-		container = gtk_dialog_get_content_area (GTK_DIALOG (mbox));
-		gtk_box_pack_start (GTK_BOX (container), check, FALSE, FALSE, 0);
+		check = gtk_check_button_new_with_mnemonic (
+			_("_Do not show this message again"));
+		gtk_box_pack_start (
+			GTK_BOX (container), check, FALSE, FALSE, 0);
 		gtk_widget_show (check);
 	}
 
-	button = gtk_dialog_run ((GtkDialog *) mbox);
+	button = gtk_dialog_run (GTK_DIALOG (dialog));
 	if (promptkey)
 		gconf_client_set_bool (
 			client, promptkey,
 			!gtk_toggle_button_get_active (
 			GTK_TOGGLE_BUTTON (check)), NULL);
 
-	gtk_widget_destroy (mbox);
+	gtk_widget_destroy (dialog);
 
 	g_object_unref (client);
 
@@ -226,7 +231,7 @@ em_utils_check_user_can_send_mail (void)
 
 	account_list = e_get_account_list ();
 
-	if (e_list_length ((EList *) account_list) == 0)
+	if (e_list_length (E_LIST (account_list)) == 0)
 		return FALSE;
 
 	if (!(account = e_get_default_account ()))
@@ -766,25 +771,27 @@ em_utils_selection_get_message (GtkSelectionData *selection_data,
 /**
  * em_utils_selection_set_uidlist:
  * @selection_data: selection data
- * @uri:
+ * @folder:
  * @uids:
  *
  * Sets a "x-uid-list" format selection data.
- *
- * FIXME: be nice if this could take a folder argument rather than uri
  **/
 void
 em_utils_selection_set_uidlist (GtkSelectionData *selection_data,
-                                const gchar *uri,
+                                CamelFolder *folder,
                                 GPtrArray *uids)
 {
 	GByteArray *array = g_byte_array_new ();
 	GdkAtom target;
+	gchar *folder_uri;
 	gint i;
 
 	/* format: "uri\0uid1\0uid2\0uid3\0...\0uidn\0" */
 
-	g_byte_array_append (array, (guchar *)uri, strlen (uri)+1);
+	folder_uri = e_mail_folder_uri_from_folder (folder);
+
+	g_byte_array_append (
+		array, (guchar *) folder_uri, strlen (folder_uri) + 1);
 
 	for (i=0; i<uids->len; i++)
 		g_byte_array_append (array, uids->pdata[i], strlen (uids->pdata[i])+1);
@@ -793,6 +800,8 @@ em_utils_selection_set_uidlist (GtkSelectionData *selection_data,
 	gtk_selection_data_set (
 		selection_data, target, 8, array->data, array->len);
 	g_byte_array_free (array, TRUE);
+
+	g_free (folder_uri);
 }
 
 /**
@@ -902,7 +911,7 @@ em_utils_selection_set_urilist (GtkSelectionData *data,
 		/* Drop filename for messages from a mailbox */
 		file = g_strdup_printf (
 			_("Messages from %s"),
-			camel_folder_get_name (folder));
+			camel_folder_get_display_name (folder));
 	}
 
 	e_filename_make_safe (file);
@@ -985,25 +994,27 @@ em_utils_selection_get_urilist (GtkSelectionData *selection_data,
 	g_strfreev (uris);
 }
 
-/** em_utils_folder_is_templates:
- * @folder: folder
- * @uri: uri for this folder, if known
+/**
+ * em_utils_folder_is_templates:
+ * @folder: a #CamelFolder
  *
  * Decides if @folder is a Templates folder.
  *
- * Returns %TRUE if this is a Drafts folder or %FALSE otherwise.
+ * Returns %TRUE if this is a Templates folder or %FALSE otherwise.
  **/
 
 gboolean
-em_utils_folder_is_templates (CamelFolder *folder, const gchar *uri)
+em_utils_folder_is_templates (CamelFolder *folder)
 {
 	CamelFolder *local_templates_folder;
-	CamelStore *parent_store;
-	EAccountList *accounts;
-	EAccount *account;
-	EIterator *iter;
-	gint is = FALSE;
-	gchar *templates_uri;
+	CamelSession *session;
+	CamelStore *store;
+	EAccountList *account_list;
+	EIterator *iterator;
+	gchar *folder_uri;
+	gboolean is_templates = FALSE;
+
+	g_return_val_if_fail (CAMEL_IS_FOLDER (folder), FALSE);
 
 	local_templates_folder =
 		e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_TEMPLATES);
@@ -1011,53 +1022,54 @@ em_utils_folder_is_templates (CamelFolder *folder, const gchar *uri)
 	if (folder == local_templates_folder)
 		return TRUE;
 
-	if (folder == NULL || uri == NULL)
-		return FALSE;
+	folder_uri = e_mail_folder_uri_from_folder (folder);
 
-	parent_store = camel_folder_get_parent_store (folder);
+	store = camel_folder_get_parent_store (folder);
+	session = camel_service_get_session (CAMEL_SERVICE (store));
 
-	accounts = e_get_account_list ();
-	iter = e_list_get_iterator ((EList *)accounts);
-	while (e_iterator_is_valid (iter)) {
-		account = (EAccount *)e_iterator_get (iter);
+	account_list = e_get_account_list ();
+	iterator = e_list_get_iterator (E_LIST (account_list));
 
-		if (account->templates_folder_uri) {
-			templates_uri = em_uri_to_camel (account->templates_folder_uri);
-			if (camel_store_folder_uri_equal (parent_store, templates_uri, uri)) {
-				g_free (templates_uri);
-				is = TRUE;
-				break;
-			}
-			g_free (templates_uri);
-		}
+	while (!is_templates && e_iterator_is_valid (iterator)) {
+		EAccount *account;
 
-		e_iterator_next (iter);
+		/* XXX EIterator misuses const. */
+		account = (EAccount *) e_iterator_get (iterator);
+
+		if (account->templates_folder_uri != NULL)
+			is_templates = e_mail_folder_uri_equal (
+				session, folder_uri,
+				account->templates_folder_uri);
+
+		e_iterator_next (iterator);
 	}
 
-	g_object_unref (iter);
+	g_object_unref (iterator);
+	g_free (folder_uri);
 
-	return is;
+	return is_templates;
 }
 
 /**
  * em_utils_folder_is_drafts:
- * @folder: folder
- * @uri: uri for this folder, if known
+ * @folder: a #CamelFolder
  *
  * Decides if @folder is a Drafts folder.
  *
  * Returns %TRUE if this is a Drafts folder or %FALSE otherwise.
  **/
 gboolean
-em_utils_folder_is_drafts (CamelFolder *folder, const gchar *uri)
+em_utils_folder_is_drafts (CamelFolder *folder)
 {
 	CamelFolder *local_drafts_folder;
-	CamelStore *parent_store;
-	EAccountList *accounts;
-	EAccount *account;
-	EIterator *iter;
-	gint is = FALSE;
-	gchar *drafts_uri;
+	CamelSession *session;
+	CamelStore *store;
+	EAccountList *account_list;
+	EIterator *iterator;
+	gchar *folder_uri;
+	gboolean is_drafts = FALSE;
+
+	g_return_val_if_fail (CAMEL_IS_FOLDER (folder), FALSE);
 
 	local_drafts_folder =
 		e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_DRAFTS);
@@ -1065,116 +1077,108 @@ em_utils_folder_is_drafts (CamelFolder *folder, const gchar *uri)
 	if (folder == local_drafts_folder)
 		return TRUE;
 
-	if (folder == NULL || uri == NULL)
-		return FALSE;
+	folder_uri = e_mail_folder_uri_from_folder (folder);
 
-	parent_store = camel_folder_get_parent_store (folder);
+	store = camel_folder_get_parent_store (folder);
+	session = camel_service_get_session (CAMEL_SERVICE (store));
 
-	accounts = e_get_account_list ();
-	iter = e_list_get_iterator ((EList *)accounts);
-	while (e_iterator_is_valid (iter)) {
-		account = (EAccount *)e_iterator_get (iter);
+	account_list = e_get_account_list ();
+	iterator = e_list_get_iterator (E_LIST (account_list));
 
-		if (account->drafts_folder_uri) {
-			drafts_uri = em_uri_to_camel (account->drafts_folder_uri);
-			if (camel_store_folder_uri_equal (parent_store, drafts_uri, uri)) {
-				g_free (drafts_uri);
-				is = TRUE;
-				break;
-			}
-			g_free (drafts_uri);
-		}
+	while (!is_drafts && e_iterator_is_valid (iterator)) {
+		EAccount *account;
 
-		e_iterator_next (iter);
+		/* XXX EIterator misuses const. */
+		account = (EAccount *) e_iterator_get (iterator);
+
+		if (account->drafts_folder_uri != NULL)
+			is_drafts = e_mail_folder_uri_equal (
+				session, folder_uri,
+				account->drafts_folder_uri);
+
+		e_iterator_next (iterator);
 	}
 
-	g_object_unref (iter);
+	g_object_unref (iterator);
+	g_free (folder_uri);
 
-	return is;
+	return is_drafts;
 }
 
 /**
  * em_utils_folder_is_sent:
- * @folder: folder
- * @uri: uri for this folder, if known
+ * @folder: a #CamelFolder
  *
- * Decides if @folder is a Sent folder
+ * Decides if @folder is a Sent folder.
  *
  * Returns %TRUE if this is a Sent folder or %FALSE otherwise.
  **/
 gboolean
-em_utils_folder_is_sent (CamelFolder *folder, const gchar *uri)
+em_utils_folder_is_sent (CamelFolder *folder)
 {
 	CamelFolder *local_sent_folder;
-	CamelStore *parent_store;
-	EAccountList *accounts;
-	EAccount *account;
-	EIterator *iter;
-	gint is = FALSE;
-	gchar *sent_uri;
+	CamelSession *session;
+	CamelStore *store;
+	EAccountList *account_list;
+	EIterator *iterator;
+	gchar *folder_uri;
+	gboolean is_sent = FALSE;
 
-	local_sent_folder = e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_SENT);
+	g_return_val_if_fail (CAMEL_IS_FOLDER (folder), FALSE);
+
+	local_sent_folder =
+		e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_SENT);
 
 	if (folder == local_sent_folder)
 		return TRUE;
 
-	if (folder == NULL || uri == NULL)
-		return FALSE;
+	folder_uri = e_mail_folder_uri_from_folder (folder);
 
-	parent_store = camel_folder_get_parent_store (folder);
+	store = camel_folder_get_parent_store (folder);
+	session = camel_service_get_session (CAMEL_SERVICE (store));
 
-	accounts = e_get_account_list ();
-	iter = e_list_get_iterator ((EList *)accounts);
-	while (e_iterator_is_valid (iter)) {
-		account = (EAccount *)e_iterator_get (iter);
+	account_list = e_get_account_list ();
+	iterator = e_list_get_iterator (E_LIST (account_list));
 
-		if (account->sent_folder_uri) {
-			sent_uri = em_uri_to_camel (account->sent_folder_uri);
-			if (camel_store_folder_uri_equal (parent_store, sent_uri, uri)) {
-				g_free (sent_uri);
-				is = TRUE;
-				break;
-			}
-			g_free (sent_uri);
-		}
+	while (!is_sent && e_iterator_is_valid (iterator)) {
+		EAccount *account;
 
-		e_iterator_next (iter);
+		/* XXX EIterator misuses const. */
+		account = (EAccount *) e_iterator_get (iterator);
+
+		if (account->sent_folder_uri != NULL)
+			is_sent = e_mail_folder_uri_equal (
+				session, folder_uri,
+				account->sent_folder_uri);
+
+		e_iterator_next (iterator);
 	}
 
-	g_object_unref (iter);
+	g_object_unref (iterator);
+	g_free (folder_uri);
 
-	return is;
+	return is_sent;
 }
 
 /**
  * em_utils_folder_is_outbox:
- * @folder: folder
- * @uri: uri for this folder, if known
+ * @folder: a #CamelFolder
  *
- * Decides if @folder is an Outbox folder
+ * Decides if @folder is an Outbox folder.
  *
  * Returns %TRUE if this is an Outbox folder or %FALSE otherwise.
  **/
 gboolean
-em_utils_folder_is_outbox (CamelFolder *folder, const gchar *uri)
+em_utils_folder_is_outbox (CamelFolder *folder)
 {
 	CamelFolder *local_outbox_folder;
-	const gchar *local_outbox_folder_uri;
+
+	g_return_val_if_fail (CAMEL_IS_FOLDER (folder), FALSE);
 
 	local_outbox_folder =
 		e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_OUTBOX);
-	local_outbox_folder_uri =
-		e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_OUTBOX);
 
-	if (folder == local_outbox_folder)
-		return TRUE;
-
-	if (uri == NULL)
-		return FALSE;
-
-	return camel_store_folder_uri_equal (
-		camel_folder_get_parent_store (local_outbox_folder),
-		local_outbox_folder_uri, uri);
+	return (folder == local_outbox_folder);
 }
 
 /* ********************************************************************** */
@@ -1321,7 +1325,8 @@ em_utils_message_to_html (CamelMimeMessage *message,
 		GConfClient *gconf;
 		gchar *charset;
 
-		/* FIXME: we should be getting this from the current view, not the global setting. */
+		/* FIXME We should be getting this from the
+		 *       current view, not the global setting. */
 		gconf = gconf_client_get_default ();
 		charset = gconf_client_get_string (
 			gconf, "/apps/evolution/mail/display/charset", NULL);
@@ -1384,9 +1389,9 @@ em_utils_empty_trash (GtkWidget *parent,
                       EMailSession *session)
 {
 	CamelProvider *provider;
-	EAccountList *accounts;
+	EAccountList *account_list;
 	EAccount *account;
-	EIterator *iter;
+	EIterator *iterator;
 
 	g_return_if_fail (E_IS_MAIL_SESSION (session));
 
@@ -1395,10 +1400,11 @@ em_utils_empty_trash (GtkWidget *parent,
 		"mail:ask-empty-trash", NULL))
 		return;
 
-	accounts = e_get_account_list ();
-	iter = e_list_get_iterator ((EList *) accounts);
-	while (e_iterator_is_valid (iter)) {
-		account = (EAccount *) e_iterator_get (iter);
+	account_list = e_get_account_list ();
+	iterator = e_list_get_iterator (E_LIST (account_list));
+
+	while (e_iterator_is_valid (iterator)) {
+		account = (EAccount *) e_iterator_get (iterator);
 
 		/* make sure this is a valid source */
 		if (account->enabled && account->source->url) {
@@ -1411,10 +1417,10 @@ em_utils_empty_trash (GtkWidget *parent,
 			}
 		}
 
-		e_iterator_next (iter);
+		e_iterator_next (iterator);
 	}
 
-	g_object_unref (iter);
+	g_object_unref (iterator);
 
 	/* Now empty the local trash folder */
 	mail_empty_trash (session, NULL, NULL, NULL);
@@ -1445,148 +1451,6 @@ em_utils_folder_name_from_uri (const gchar *uri)
 	return folder_name;
 }
 
-/* email: uri's are based on the account, with special cases for local
- * stores, vfolder and local mail.
- * e.g.
- *  imap account imap://user@host/ -> email://accountid@accountid.host/
- *  vfolder      vfolder:/storage/path#folder -> email://vfolder@local/folder
- *  local        local:/storage/path#folder   -> email://local@local/folder
- */
-
-gchar *em_uri_from_camel (const gchar *curi)
-{
-	CamelURL *curl;
-	EAccount *account;
-	const gchar *uid, *path;
-	gchar *euri, *tmp;
-	CamelProvider *provider;
-
-	/* Easiest solution to code that shouldnt be calling us */
-	if (!strncmp(curi, "email:", 6))
-		return g_strdup (curi);
-
-	provider = camel_provider_get (curi, NULL);
-	if (provider == NULL) {
-		d(printf("em uri from camel failed '%s'\n", curi));
-		return g_strdup (curi);
-	}
-
-	curl = camel_url_new (curi, NULL);
-	if (curl == NULL)
-		return g_strdup (curi);
-
-	if (strcmp(curl->protocol, "vfolder") == 0)
-		uid = "vfolder@local";
-	else if ((account = e_get_account_by_source_url (curi)) == NULL)
-		uid = "local@local";
-	else
-		uid = account->uid;
-	path = (provider->url_flags & CAMEL_URL_FRAGMENT_IS_PATH)?curl->fragment:curl->path;
-	if (path) {
-		if (path[0] == '/')
-			path++;
-
-		tmp = camel_url_encode(path, ";?");
-		euri = g_strdup_printf("email://%s/%s", uid, tmp);
-		g_free (tmp);
-	} else {
-		euri = g_strdup_printf("email://%s/", uid);
-	}
-
-	d(printf("em uri from camel '%s' -> '%s'\n", curi, euri));
-
-	camel_url_free (curl);
-
-	return euri;
-}
-
-gchar *em_uri_to_camel (const gchar *euri)
-{
-	EAccountList *accounts;
-	const EAccount *account;
-	EAccountService *service;
-	CamelProvider *provider;
-	CamelURL *eurl, *curl;
-	gchar *uid, *curi;
-
-	if (strncmp(euri, "email:", 6) != 0) {
-		d(printf("em uri to camel not euri '%s'\n", euri));
-		return g_strdup (euri);
-	}
-
-	eurl = camel_url_new (euri, NULL);
-	if (eurl == NULL)
-		return g_strdup (euri);
-
-	g_return_val_if_fail (eurl->host != NULL, g_strdup (euri));
-
-	if (eurl->user != NULL) {
-		/* Sigh, shoul'dve used mbox@local for mailboxes, not local@local */
-		if (strcmp(eurl->host, "local") == 0
-		    && (strcmp(eurl->user, "local") == 0 || strcmp(eurl->user, "vfolder") == 0)) {
-			gchar *base;
-
-			if (strcmp(eurl->user, "vfolder") == 0)
-				curl = camel_url_new("vfolder:", NULL);
-			else
-				curl = camel_url_new("maildir:", NULL);
-
-			base = g_strdup_printf("%s/mail/%s", e_get_user_data_dir(), eurl->user);
-#ifdef G_OS_WIN32
-			/* Turn backslashes into slashes to avoid URI encoding */
-			{
-				gchar *p = base;
-				while ((p = strchr (p, '\\')))
-					*p++ = '/';
-			}
-#endif
-			camel_url_set_path (curl, base);
-			g_free (base);
-			camel_url_set_fragment (curl, eurl->path[0]=='/'?eurl->path+1:eurl->path);
-			curi = camel_url_to_string (curl, 0);
-			camel_url_free (curl);
-			camel_url_free (eurl);
-
-			d(printf("em uri to camel local '%s' -> '%s'\n", euri, curi));
-			return curi;
-		}
-
-		uid = g_strdup_printf("%s@%s", eurl->user, eurl->host);
-	} else {
-		uid = g_strdup (eurl->host);
-	}
-
-	accounts = e_get_account_list ();
-	account = e_account_list_find (accounts, E_ACCOUNT_FIND_UID, uid);
-	g_free (uid);
-
-	if (account == NULL) {
-		camel_url_free (eurl);
-		d(printf("em uri to camel no account '%s' -> '%s'\n", euri, euri));
-		return g_strdup (euri);
-	}
-
-	service = account->source;
-	provider = camel_provider_get (service->url, NULL);
-	if (provider == NULL)
-		return g_strdup (euri);
-
-	curl = camel_url_new (service->url, NULL);
-	if (provider->url_flags & CAMEL_URL_FRAGMENT_IS_PATH)
-		camel_url_set_fragment (curl, eurl->path[0]=='/'?eurl->path+1:eurl->path);
-	else
-		camel_url_set_path (curl, eurl->path);
-
-	curi = camel_url_to_string (curl, 0);
-
-	camel_url_free (eurl);
-	camel_url_free (curl);
-
-	d(printf("em uri to camel '%s' -> '%s'\n", euri, curi));
-
-	return curi;
-}
-
 /* ********************************************************************** */
 
 /* runs sync, in main thread */
@@ -1770,7 +1634,8 @@ search_address_in_addressbooks (const gchar *address,
 
 	query = e_book_query_field_test (E_CONTACT_EMAIL, E_BOOK_QUERY_IS, address);
 
-	for (g = e_source_list_peek_groups (emu_books_source_list); g; g = g_slist_next (g)) {
+	for (g = e_source_list_peek_groups (emu_books_source_list);
+			g; g = g_slist_next (g)) {
 		ESourceGroup *group = g->data;
 
 		if (!group)
@@ -1875,7 +1740,8 @@ search_address_in_addressbooks (const gchar *address,
 				g_list_free (contacts);
 			}
 		} else if (book) {
-			stop = stop || (err && g_error_matches (err, E_BOOK_ERROR, E_BOOK_ERROR_CANCELLED));
+			stop = stop || (err && g_error_matches (
+				err, E_BOOK_ERROR, E_BOOK_ERROR_CANCELLED));
 			if (err && !stop) {
 				gchar *source_uid = g_strdup (e_source_peek_uid (source));
 
@@ -1897,7 +1763,9 @@ search_address_in_addressbooks (const gchar *address,
 		if (stop && !cached_book && book) {
 			g_object_unref (book);
 		} else if (!stop && book && !cached_book) {
-			g_hash_table_insert (emu_books_hash, g_strdup (e_source_peek_uid (source)), book);
+			g_hash_table_insert (
+				emu_books_hash, g_strdup (
+				e_source_peek_uid (source)), book);
 		}
 	}
 
@@ -2140,26 +2008,24 @@ emu_free_mail_cache (void)
 void
 em_utils_clear_get_password_canceled_accounts_flag (void)
 {
-	EAccountList *accounts;
+	EAccountList *account_list;
+	EIterator *iterator;
 
-	accounts = e_get_account_list ();
-	if (accounts) {
-		EIterator *iter;
+	account_list = e_get_account_list ();
 
-		for (iter = e_list_get_iterator ((EList *) accounts);
-		     e_iterator_is_valid (iter);
-		     e_iterator_next (iter)) {
-			EAccount *account = (EAccount *) e_iterator_get (iter);
+	for (iterator = e_list_get_iterator (E_LIST (account_list));
+	     e_iterator_is_valid (iterator);
+	     e_iterator_next (iterator)) {
+		EAccount *account = (EAccount *) e_iterator_get (iterator);
 
-			if (account && account->source)
-				account->source->get_password_canceled = FALSE;
+		if (account && account->source)
+			account->source->get_password_canceled = FALSE;
 
-			if (account && account->transport)
-				account->transport->get_password_canceled = FALSE;
-		}
-
-		g_object_unref (iter);
+		if (account && account->transport)
+			account->transport->get_password_canceled = FALSE;
 	}
+
+	g_object_unref (iterator);
 }
 
 gchar *
@@ -2196,31 +2062,23 @@ em_utils_url_unescape_amp (const gchar *url)
 static EAccount *
 guess_account_from_folder (CamelFolder *folder)
 {
-	CamelService *service;
-	CamelStore *parent_store;
-	EAccount *account;
-	gchar *source_url;
+	CamelStore *store;
+	const gchar *uid;
 
-	parent_store = camel_folder_get_parent_store (folder);
-	service = CAMEL_SERVICE (parent_store);
+	store = camel_folder_get_parent_store (folder);
+	uid = camel_service_get_uid (CAMEL_SERVICE (store));
 
-	source_url = camel_url_to_string (service->url, CAMEL_URL_HIDE_ALL);
-	account = e_get_account_by_source_url (source_url);
-	g_free (source_url);
-
-	return account;
+	return e_get_account_by_uid (uid);
 }
 
 static EAccount *
 guess_account_from_message (CamelMimeMessage *message)
 {
-	const gchar *source_url;
+	const gchar *uid;
 
-	source_url = camel_mime_message_get_source (message);
-	if (source_url == NULL)
-		return NULL;
+	uid = camel_mime_message_get_source (message);
 
-	return e_get_account_by_source_url (source_url);
+	return (uid != NULL) ? e_get_account_by_uid (uid) : NULL;
 }
 
 GHashTable *
@@ -2228,17 +2086,18 @@ em_utils_generate_account_hash (void)
 {
 	GHashTable *account_hash;
 	EAccount *account, *def;
-	EAccountList *accounts;
-	EIterator *iter;
+	EAccountList *account_list;
+	EIterator *iterator;
 
-	accounts = e_get_account_list ();
+	account_list = e_get_account_list ();
 	account_hash = g_hash_table_new (camel_strcase_hash, camel_strcase_equal);
 
 	def = e_get_default_account ();
 
-	iter = e_list_get_iterator ((EList *) accounts);
-	while (e_iterator_is_valid (iter)) {
-		account = (EAccount *) e_iterator_get (iter);
+	iterator = e_list_get_iterator (E_LIST (account_list));
+
+	while (e_iterator_is_valid (iterator)) {
+		account = (EAccount *) e_iterator_get (iterator);
 
 		if (account->id->address) {
 			EAccount *acnt;
@@ -2262,10 +2121,10 @@ em_utils_generate_account_hash (void)
 					(gpointer) account);
 		}
 
-		e_iterator_next (iter);
+		e_iterator_next (iterator);
 	}
 
-	g_object_unref (iter);
+	g_object_unref (iterator);
 
 	/* The default account has to be there if none of the enabled accounts are present */
 	if (g_hash_table_size (account_hash) == 0 && def && def->id->address)
@@ -2308,7 +2167,7 @@ em_utils_guess_account_with_recipients (CamelMimeMessage *message,
 	EAccount *account = NULL;
 	EAccountList *account_list;
 	GHashTable *recipients;
-	EIterator *iter;
+	EIterator *iterator;
 	CamelInternetAddress *addr;
 	const gchar *type;
 	const gchar *key;
@@ -2366,10 +2225,11 @@ second_preference:
 	 * address appears in the list to To: or Cc: recipients. */
 
 	account_list = e_get_account_list ();
-	iter = e_list_get_iterator (E_LIST (account_list));
-	while (e_iterator_is_valid (iter)) {
-		account = (EAccount *) e_iterator_get (iter);
-		e_iterator_next (iter);
+	iterator = e_list_get_iterator (E_LIST (account_list));
+
+	while (e_iterator_is_valid (iterator)) {
+		account = (EAccount *) e_iterator_get (iterator);
+		e_iterator_next (iterator);
 
 		if (account == NULL || !account->enabled)
 			continue;
@@ -2378,11 +2238,11 @@ second_preference:
 			continue;
 
 		if (g_hash_table_lookup (recipients, key) != NULL) {
-			g_object_unref (iter);
+			g_object_unref (iterator);
 			goto exit;
 		}
 	}
-	g_object_unref (iter);
+	g_object_unref (iterator);
 
 	/* Last Preference: Defer to em_utils_guess_account(). */
 	account = em_utils_guess_account (message, folder);
@@ -2423,168 +2283,14 @@ emu_restore_folder_tree_state (EMFolderTree *folder_tree)
 	g_key_file_free (key_file);
 }
 
-/* checks whether uri points to a local mbox file and returns TRUE if yes. */
+/* Returns TRUE if CamelURL points to a local mbox file. */
 gboolean
-em_utils_is_local_delivery_mbox_file (const gchar *uri)
+em_utils_is_local_delivery_mbox_file (CamelURL *url)
 {
-	g_return_val_if_fail (uri != NULL, FALSE);
+	g_return_val_if_fail (url != NULL, FALSE);
 
-	if (g_str_has_prefix (uri, "mbox:///")) {
-		CamelURL *curl;
-
-		curl = camel_url_new (uri, NULL);
-		if (curl) {
-			if (curl->path
-			    && g_file_test (curl->path, G_FILE_TEST_EXISTS)
-			    && !g_file_test (curl->path, G_FILE_TEST_IS_DIR)) {
-				camel_url_free (curl);
-				return TRUE;
-			}
-			camel_url_free (curl);
-		}
-	}
-
-	return FALSE;
-}
-
-static struct {
-	gchar tag;
-	guint32 mozflag;
-	guint32 flag;
-} status_flags[] = {
-	{ 'F', MSG_FLAG_MARKED, CAMEL_MESSAGE_FLAGGED },
-	{ 'A', MSG_FLAG_REPLIED, CAMEL_MESSAGE_ANSWERED },
-	{ 'D', MSG_FLAG_EXPUNGED, CAMEL_MESSAGE_DELETED },
-	{ 'R', MSG_FLAG_READ, CAMEL_MESSAGE_SEEN },
-};
-
-static guint32
-decode_status (const gchar *status)
-{
-	const gchar *p;
-	guint32 flags = 0;
-	gint i;
-
-	p = status;
-	while ((*p++)) {
-		for (i = 0; i < G_N_ELEMENTS (status_flags); i++)
-			if (status_flags[i].tag == *p)
-				flags |= status_flags[i].flag;
-	}
-
-	return flags;
-}
-
-static guint32
-decode_mozilla_status (const gchar *tmp)
-{
-	unsigned long status = strtoul (tmp, NULL, 16);
-	guint32 flags = 0;
-	gint i;
-
-	for (i = 0; i < G_N_ELEMENTS (status_flags); i++)
-		if (status_flags[i].mozflag & status)
-			flags |= status_flags[i].flag;
-	return flags;
-}
-
-void
-em_utils_import_mbox	(EMailSession *mail_session, 
-			 const gchar *folder_uri, 
-			 const gchar *mbox_path, 
-			 GCancellable *cancellable, 
-			 GError **error)
-{
-	CamelFolder *folder;
-	CamelMimeParser *mp = NULL;
-	struct stat st;
-	gint fd;
-	CamelMessageInfo *info;
-
-	if (g_stat (mbox_path, &st) == -1) {
-		g_warning("cannot find source file to import '%s': %s", mbox_path, g_strerror(errno));
-		return;
-	}
-
-	if (folder_uri == NULL || folder_uri[0] == 0)
-		folder = e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_INBOX);
-	else
-		folder = e_mail_session_uri_to_folder_sync (
-			mail_session, folder_uri, CAMEL_STORE_FOLDER_CREATE,
-			cancellable, error);
-
-	if (folder == NULL)
-		return;
-
-	if (S_ISREG (st.st_mode)) {
-		fd = g_open (mbox_path, O_RDONLY|O_BINARY, 0);
-		if (fd == -1) {
-			g_warning("cannot find source file to import '%s': %s", mbox_path, g_strerror(errno));
-			goto fail1;
-		}
-
-		mp = camel_mime_parser_new ();
-		camel_mime_parser_scan_from (mp, TRUE);
-		if (camel_mime_parser_init_with_fd (mp, fd) == -1) {
-			/* will never happen - 0 is unconditionally returned */
-			goto fail2;
-		}
-
-		camel_operation_push_message (
-			cancellable, _("Importing '%s'"),
-			camel_folder_get_full_name (folder));
-		camel_folder_freeze (folder);
-		while (camel_mime_parser_step (mp, NULL, NULL) == CAMEL_MIME_PARSER_STATE_FROM) {
-			CamelMimeMessage *msg;
-			const gchar *tmp;
-			gint pc = 0;
-			guint32 flags = 0;
-
-			if (st.st_size > 0)
-				pc = (gint)(100.0 * ((double)camel_mime_parser_tell (mp) / (double)st.st_size));
-			camel_operation_progress (cancellable, pc);
-
-			msg = camel_mime_message_new ();
-			if (!camel_mime_part_construct_from_parser_sync (
-				(CamelMimePart *)msg, mp, NULL, NULL)) {
-				/* set exception? */
-				g_object_unref (msg);
-				break;
-			}
-
-			info = camel_message_info_new (NULL);
-
-			tmp = camel_medium_get_header((CamelMedium *)msg, "X-Mozilla-Status");
-			if (tmp)
-				flags |= decode_mozilla_status (tmp);
-			tmp = camel_medium_get_header((CamelMedium *)msg, "Status");
-			if (tmp)
-				flags |= decode_status (tmp);
-			tmp = camel_medium_get_header((CamelMedium *)msg, "X-Status");
-			if (tmp)
-				flags |= decode_status (tmp);
-
-			camel_message_info_set_flags (info, flags, ~0);
-			camel_folder_append_message_sync (
-				folder, msg, info, NULL,
-				cancellable, error);
-			camel_message_info_free (info);
-			g_object_unref (msg);
-
-			if (error && *error != NULL)
-				break;
-
-			camel_mime_parser_step (mp, NULL, NULL);
-		}
-		/* FIXME Not passing a GCancellable or GError here. */
-		camel_folder_synchronize_sync (folder, FALSE, NULL, NULL);
-		camel_folder_thaw (folder);
-		camel_operation_pop_message (cancellable);
-	fail2:
-		g_object_unref (mp);
-	}
-fail1:
-	/* FIXME Not passing a GCancellable or GError here. */
-	camel_folder_synchronize_sync (folder, FALSE, NULL, NULL);
-	g_object_unref (folder);
+	return g_str_equal (url->protocol, "mbox") &&
+		(url->path != NULL) &&
+		g_file_test (url->path, G_FILE_TEST_EXISTS) &&
+		!g_file_test (url->path, G_FILE_TEST_IS_DIR);
 }
