@@ -69,13 +69,12 @@ struct _filter_mail_msg {
 struct _fetch_mail_msg {
 	struct _filter_mail_msg fmsg;
 
+	CamelStore *store;
 	GCancellable *cancellable;	/* we have our own cancellation
 					 * struct, the other should be empty */
 	gint keep;		/* keep on server? */
 
-	gchar *source_uri;
-
-	void (*done)(const gchar *source, gpointer data);
+	void (*done)(gpointer data);
 	gpointer data;
 };
 
@@ -199,27 +198,6 @@ mail_filter_folder (EMailSession *session,
 
 /* ********************************************************************** */
 
-/* Temporary workaround for various issues. Gone before 0.11 */
-static gchar *
-uid_cachename_hack (CamelStore *store)
-{
-	CamelURL *url = CAMEL_SERVICE (store)->url;
-	gchar *encoded_url, *filename;
-	const gchar *data_dir;
-
-	encoded_url = g_strdup_printf ("%s%s%s@%s", url->user,
-				       url->authmech ? ";auth=" : "",
-				       url->authmech ? url->authmech : "",
-				       url->host);
-	e_filename_make_safe (encoded_url);
-
-	data_dir = mail_session_get_data_dir ();
-	filename = g_build_filename (data_dir, "pop", encoded_url, "uid-cache", NULL);
-	g_free (encoded_url);
-
-	return filename;
-}
-
 static gchar *
 fetch_mail_desc (struct _fetch_mail_msg *m)
 {
@@ -232,103 +210,93 @@ fetch_mail_exec (struct _fetch_mail_msg *m,
                  GError **error)
 {
 	struct _filter_mail_msg *fm = (struct _filter_mail_msg *)m;
+	CamelFolder *folder;
+	const gchar *uid;
 	gint i;
 
-	fm->destination = e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_LOCAL_INBOX);
+	fm->destination = e_mail_local_get_folder (
+		E_MAIL_LOCAL_FOLDER_LOCAL_INBOX);
 	if (fm->destination == NULL)
 		goto fail;
 	g_object_ref (fm->destination);
 
-	/* FIXME: this should support keep_on_server too, which would then perform a spool
-	   access thingy, right?  problem is matching raw messages to uid's etc. */
-	if (em_utils_is_local_delivery_mbox_file (m->source_uri)) {
-		gchar *path = mail_tool_do_movemail (m->source_uri, error);
+	uid = camel_service_get_uid (CAMEL_SERVICE (m->store));
 
-		if (path && (!error || !*error)) {
-			camel_folder_freeze (fm->destination);
-			camel_filter_driver_set_default_folder (
-				fm->driver, fm->destination);
-			camel_filter_driver_filter_mbox (
-				fm->driver, path, m->source_uri,
-				cancellable, error);
-			camel_folder_thaw (fm->destination);
+	folder = fm->source_folder =
+		e_mail_session_get_inbox_sync (
+			fm->session, uid, cancellable, error);
 
-			if (!error || !*error)
-				g_unlink (path);
-		}
-		g_free (path);
-	} else {
-		CamelFolder *folder;
+	if (folder != NULL) {
+		/* This handles 'keep on server' stuff, if we have any new
+		 * uid's to copy across, we need to copy them to a new array
+		 * 'cause of the way fetch_mail_free works. */
+		CamelUIDCache *cache = NULL;
+		CamelStore *parent_store;
+		CamelService *service;
+		const gchar *data_dir;
+		gchar *cachename;
 
-		folder = fm->source_folder =
-			e_mail_session_get_inbox_sync (
-				fm->session, m->source_uri,
-				cancellable, error);
+		parent_store = camel_folder_get_parent_store (folder);
 
-		if (folder) {
-			/* this handles 'keep on server' stuff, if we have any new uid's to copy
-			   across, we need to copy them to a new array 'cause of the way fetch_mail_free works */
-			CamelUIDCache *cache = NULL;
-			CamelStore *parent_store;
-			gchar *cachename;
+		service = CAMEL_SERVICE (parent_store);
+		data_dir = camel_service_get_user_data_dir (service);
 
-			parent_store = camel_folder_get_parent_store (folder);
-			cachename = uid_cachename_hack (parent_store);
-			cache = camel_uid_cache_new (cachename);
-			g_free (cachename);
+		cachename = g_build_filename (data_dir, "uid-cache", NULL);
+		cache = camel_uid_cache_new (cachename);
+		g_free (cachename);
 
-			if (cache) {
-				GPtrArray *folder_uids, *cache_uids, *uids;
+		if (cache) {
+			GPtrArray *folder_uids, *cache_uids, *uids;
 
-				folder_uids = camel_folder_get_uids (folder);
-				cache_uids = camel_uid_cache_get_new_uids (cache, folder_uids);
-				if (cache_uids) {
-					/* need to copy this, sigh */
-					fm->source_uids = uids = g_ptr_array_new ();
-					g_ptr_array_set_size (uids, cache_uids->len);
-					for (i = 0; i < cache_uids->len; i++)
-						uids->pdata[i] = g_strdup (cache_uids->pdata[i]);
-					camel_uid_cache_free_uids (cache_uids);
+			folder_uids = camel_folder_get_uids (folder);
+			cache_uids = camel_uid_cache_get_new_uids (cache, folder_uids);
+			if (cache_uids) {
+				/* need to copy this, sigh */
+				fm->source_uids = uids = g_ptr_array_new ();
+				g_ptr_array_set_size (uids, cache_uids->len);
+				for (i = 0; i < cache_uids->len; i++)
+					uids->pdata[i] = g_strdup (cache_uids->pdata[i]);
+				camel_uid_cache_free_uids (cache_uids);
 
-					fm->cache = cache;
-					em_filter_folder_element_exec (fm, cancellable, error);
-
-					/* need to uncancel so writes/etc. don't fail */
-					if (g_cancellable_is_cancelled (m->cancellable))
-						g_cancellable_reset (m->cancellable);
-
-					/* save the cache of uids that we've just downloaded */
-					camel_uid_cache_save (cache);
-				}
-
-				if (fm->delete && (!error || !*error)) {
-					/* not keep on server - just delete all the actual messages on the server */
-					for (i=0;i<folder_uids->len;i++) {
-						d(printf("force delete uid '%s'\n", (gchar *)folder_uids->pdata[i]));
-						camel_folder_delete_message (folder, folder_uids->pdata[i]);
-					}
-				}
-
-				if ((fm->delete || cache_uids) && (!error || !*error)) {
-					/* expunge messages (downloaded so far) */
-					/* FIXME Not passing a GCancellable or GError here. */
-					camel_folder_synchronize_sync (
-						folder, fm->delete, NULL, NULL);
-				}
-
-				camel_uid_cache_destroy (cache);
-				camel_folder_free_uids (folder, folder_uids);
-			} else {
+				fm->cache = cache;
 				em_filter_folder_element_exec (fm, cancellable, error);
+
+				/* need to uncancel so writes/etc. don't fail */
+				if (g_cancellable_is_cancelled (m->cancellable))
+					g_cancellable_reset (m->cancellable);
+
+				/* save the cache of uids that we've just downloaded */
+				camel_uid_cache_save (cache);
 			}
 
-			/* we unref the source folder here since we
-			   may now block in finalize (we try to
-			   disconnect cleanly) */
-			g_object_unref (fm->source_folder);
-			fm->source_folder = NULL;
+			if (fm->delete && (!error || !*error)) {
+				/* not keep on server - just delete all the actual messages on the server */
+				for (i=0;i<folder_uids->len;i++) {
+					d(printf("force delete uid '%s'\n", (gchar *)folder_uids->pdata[i]));
+					camel_folder_delete_message (folder, folder_uids->pdata[i]);
+				}
+			}
+
+			if ((fm->delete || cache_uids) && (!error || !*error)) {
+				/* expunge messages (downloaded so far) */
+				/* FIXME Not passing a GCancellable or GError here. */
+				camel_folder_synchronize_sync (
+					folder, fm->delete, NULL, NULL);
+			}
+
+			camel_uid_cache_destroy (cache);
+			camel_folder_free_uids (folder, folder_uids);
+		} else {
+			em_filter_folder_element_exec (fm, cancellable, error);
 		}
+
+		/* we unref the source folder here since we
+		   may now block in finalize (we try to
+		   disconnect cleanly) */
+		g_object_unref (fm->source_folder);
+		fm->source_folder = NULL;
 	}
+
 fail:
 	/* we unref this here as it may have more work to do (syncing
 	   folders and whatnot) before we are really done */
@@ -343,13 +311,14 @@ static void
 fetch_mail_done (struct _fetch_mail_msg *m)
 {
 	if (m->done)
-		m->done (m->source_uri, m->data);
+		m->done (m->data);
 }
 
 static void
 fetch_mail_free (struct _fetch_mail_msg *m)
 {
-	g_free (m->source_uri);
+	if (m->store != NULL)
+		g_object_unref (m->store);
 
 	if (m->cancellable != NULL)
 		g_object_unref (m->cancellable);
@@ -367,8 +336,7 @@ static MailMsgInfo fetch_mail_info = {
 
 /* ouch, a 'do everything' interface ... */
 void
-mail_fetch_mail (EMailSession *session,
-                 const gchar *source,
+mail_fetch_mail (CamelStore *store,
                  gint keep,
                  const gchar *type,
                  GCancellable *cancellable,
@@ -376,16 +344,21 @@ mail_fetch_mail (EMailSession *session,
                  gpointer get_data,
                  CamelFilterStatusFunc *status,
                  gpointer status_data,
-                 void (*done)(const gchar *source, gpointer data),
+                 void (*done)(gpointer data),
                  gpointer data)
 {
 	struct _fetch_mail_msg *m;
 	struct _filter_mail_msg *fm;
+	CamelSession *session;
+
+	g_return_if_fail (CAMEL_IS_STORE (store));
+
+	session = camel_service_get_session (CAMEL_SERVICE (store));
 
 	m = mail_msg_new (&fetch_mail_info);
 	fm = (struct _filter_mail_msg *)m;
 	fm->session = g_object_ref (session);
-	m->source_uri = g_strdup (source);
+	m->store = g_object_ref (store);
 	fm->delete = !keep;
 	fm->cache = NULL;
 	if (cancellable)
@@ -393,8 +366,7 @@ mail_fetch_mail (EMailSession *session,
 	m->done = done;
 	m->data = data;
 
-	fm->driver = camel_session_get_filter_driver (
-		CAMEL_SESSION (session), type, NULL);
+	fm->driver = camel_session_get_filter_driver (session, type, NULL);
 	camel_filter_driver_set_folder_func (fm->driver, get_folder, get_data);
 	if (status)
 		camel_filter_driver_set_status_func (fm->driver, status, status_data);
@@ -445,7 +417,7 @@ struct _send_queue_msg {
 
 	EMailSession *session;
 	CamelFolder *queue;
-	gchar *destination;
+	CamelTransport *transport;
 
 	CamelFilterDriver *driver;
 
@@ -453,7 +425,7 @@ struct _send_queue_msg {
 	CamelFilterStatusFunc *status;
 	gpointer status_data;
 
-	void (*done)(const gchar *destination, gpointer data);
+	void (*done)(gpointer data);
 	gpointer data;
 };
 
@@ -464,7 +436,7 @@ static void
 mail_send_message (struct _send_queue_msg *m,
                    CamelFolder *queue,
                    const gchar *uid,
-                   const gchar *destination,
+                   CamelTransport *transport,
                    CamelFilterDriver *driver,
                    GCancellable *cancellable,
                    GError **error)
@@ -473,8 +445,8 @@ mail_send_message (struct _send_queue_msg *m,
 	const CamelInternetAddress *iaddr;
 	CamelAddress *from, *recipients;
 	CamelMessageInfo *info = NULL;
-	CamelTransport *xport = NULL;
-	gchar *transport_url = NULL;
+	CamelProvider *provider;
+	gchar *transport_uid = NULL;
 	gchar *sent_folder_uri = NULL;
 	const gchar *resent_from, *tmp;
 	CamelFolder *folder = NULL;
@@ -502,8 +474,20 @@ mail_send_message (struct _send_queue_msg *m,
 		if ((account = e_get_account_by_uid (name))
 		    /* 'old' x-evolution-account stored the name, how silly */
 		    || (account = e_get_account_by_name (name))) {
-			if (account->transport && account->transport->url)
-				transport_url = g_strdup (account->transport->url);
+			if (account->transport) {
+				CamelService *service;
+				gchar *transport_uid;
+
+				transport_uid = g_strconcat (
+					account->uid, "-transport", NULL);
+				service = camel_session_get_service (
+					CAMEL_SESSION (m->session),
+					transport_uid);
+				g_free (transport_uid);
+
+				if (CAMEL_IS_TRANSPORT (service))
+					transport = CAMEL_TRANSPORT (service);
+			}
 
 			sent_folder_uri = g_strdup (account->sent_folder_uri);
 		}
@@ -514,20 +498,27 @@ mail_send_message (struct _send_queue_msg *m,
 		/* default back to these headers */
 		tmp = camel_header_raw_find(&xev, "X-Evolution-Transport", NULL);
 		if (tmp)
-			transport_url = g_strstrip (g_strdup (tmp));
+			transport_uid = g_strstrip (g_strdup (tmp));
 
 		tmp = camel_header_raw_find(&xev, "X-Evolution-Fcc", NULL);
 		if (tmp)
 			sent_folder_uri = g_strstrip (g_strdup (tmp));
 	}
 
-	if (transport_url || destination) {
-		gchar *escaped = escape_percent_sign (transport_url ? transport_url : destination);
+	if (transport != NULL) {
+		CamelURL *url;
+		gchar *url_string;
+		gchar *escaped;
 
-		/* let the dialog know the right account it is using; percentage is ignored */
+		url = camel_service_get_camel_url (CAMEL_SERVICE (transport));
+		url_string = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
+		escaped = escape_percent_sign (url_string);
+
+		/* Let the dialog know the right account it is using. */
 		report_status (m, CAMEL_FILTER_STATUS_ACTION, 0, escaped);
 
 		g_free (escaped);
+		g_free (url_string);
 	}
 
 	/* Check for email sending */
@@ -550,15 +541,13 @@ mail_send_message (struct _send_queue_msg *m,
 	}
 
 	if (camel_address_length (recipients) > 0) {
-		xport = camel_session_get_transport (
-			CAMEL_SESSION (m->session),
-			transport_url ? transport_url :
-			destination, error);
-		if (xport == NULL)
+		if (!camel_service_connect_sync (
+			CAMEL_SERVICE (transport), error))
 			goto exit;
 
 		if (!camel_transport_send_to_sync (
-			xport, message, from, recipients, cancellable, error))
+			transport, message, from,
+			recipients, cancellable, error))
 			goto exit;
 	}
 
@@ -609,8 +598,10 @@ mail_send_message (struct _send_queue_msg *m,
 		}
 	}
 
-	if (xport == NULL
-	    || !( ((CamelService *)xport)->provider->flags & CAMEL_PROVIDER_DISABLE_SENT_FOLDER)) {
+	provider = camel_service_get_provider (CAMEL_SERVICE (transport));
+
+	if (provider == NULL
+	    || !(provider->flags & CAMEL_PROVIDER_DISABLE_SENT_FOLDER)) {
 		GError *local_error = NULL;
 
 		if (sent_folder_uri) {
@@ -706,10 +697,8 @@ exit:
 		camel_message_info_free (info);
 	g_object_unref (recipients);
 	g_object_unref (from);
-	if (xport)
-		g_object_unref (xport);
 	g_free (sent_folder_uri);
-	g_free (transport_url);
+	g_free (transport_uid);
 	camel_header_raw_clear (&xev);
 	g_string_free (err, TRUE);
 	g_object_unref (message);
@@ -789,7 +778,7 @@ send_queue_exec (struct _send_queue_msg *m,
 			cancellable, (i+1) * 100 / send_uids->len);
 
 		mail_send_message (
-			m, m->queue, send_uids->pdata[i], m->destination,
+			m, m->queue, send_uids->pdata[i], m->transport,
 			m->driver, cancellable, &local_error);
 		if (local_error != NULL) {
 			if (!g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
@@ -857,7 +846,7 @@ static void
 send_queue_done (struct _send_queue_msg *m)
 {
 	if (m->done)
-		m->done (m->destination, m->data);
+		m->done (m->data);
 }
 
 static gchar *
@@ -873,8 +862,9 @@ send_queue_free (struct _send_queue_msg *m)
 		g_object_unref (m->session);
 	if (m->driver != NULL)
 		g_object_unref (m->driver);
+	if (m->transport != NULL)
+		g_object_unref (m->transport);
 	g_object_unref (m->queue);
-	g_free (m->destination);
 }
 
 static MailMsgInfo send_queue_info = {
@@ -889,14 +879,14 @@ static MailMsgInfo send_queue_info = {
 void
 mail_send_queue (EMailSession *session,
                  CamelFolder *queue,
-                 const gchar *destination,
+                 CamelTransport *transport,
                  const gchar *type,
                  GCancellable *cancellable,
                  CamelFilterGetFolderFunc get_folder,
                  gpointer get_data,
                  CamelFilterStatusFunc *status,
                  gpointer status_data,
-                 void (*done)(const gchar *destination, gpointer data),
+                 void (*done)(gpointer data),
                  gpointer data)
 {
 	struct _send_queue_msg *m;
@@ -904,7 +894,7 @@ mail_send_queue (EMailSession *session,
 	m = mail_msg_new (&send_queue_info);
 	m->session = g_object_ref (session);
 	m->queue = g_object_ref (queue);
-	m->destination = g_strdup (destination);
+	m->transport = g_object_ref (transport);
 	if (G_IS_CANCELLABLE (cancellable))
 		e_activity_set_cancellable (m->base.activity, cancellable);
 	m->status = status;
@@ -1292,7 +1282,9 @@ struct _get_quota_msg {
 static gchar *
 get_quota_desc (struct _get_quota_msg *m)
 {
-	return g_strdup_printf (_("Retrieving quota information for folder '%s'"), camel_folder_get_name (m->folder));
+	return g_strdup_printf (
+		_("Retrieving quota information for folder '%s'"),
+		camel_folder_get_display_name (m->folder));
 }
 
 static void
@@ -1352,83 +1344,6 @@ mail_get_folder_quota (CamelFolder *folder,
 	return id;
 }
 
-/* ** GET STORE ******************************************************* */
-
-struct _get_store_msg {
-	MailMsg base;
-
-	EMailSession *session;
-	gchar *uri;
-	CamelStore *store;
-	void (*done) (gchar *uri, CamelStore *store, gpointer data);
-	gpointer data;
-};
-
-static gchar *
-get_store_desc (struct _get_store_msg *m)
-{
-	return g_strdup_printf (_("Opening store '%s'"), m->uri);
-}
-
-static void
-get_store_exec (struct _get_store_msg *m,
-                GCancellable *cancellable,
-                GError **error)
-{
-	/*camel_session_get_store connects us, which we don't want to do on startup. */
-
-	m->store = (CamelStore *) camel_session_get_service (
-		CAMEL_SESSION (m->session), m->uri,
-		CAMEL_PROVIDER_STORE, error);
-}
-
-static void
-get_store_done (struct _get_store_msg *m)
-{
-	if (m->done)
-		m->done (m->uri, m->store, m->data);
-}
-
-static void
-get_store_free (struct _get_store_msg *m)
-{
-	g_object_unref (m->session);
-	g_free (m->uri);
-	if (m->store)
-		g_object_unref (m->store);
-}
-
-static MailMsgInfo get_store_info = {
-	sizeof (struct _get_store_msg),
-	(MailMsgDescFunc) get_store_desc,
-	(MailMsgExecFunc) get_store_exec,
-	(MailMsgDoneFunc) get_store_done,
-	(MailMsgFreeFunc) get_store_free
-};
-
-gint
-mail_get_store (EMailSession *session,
-                const gchar *uri,
-                GCancellable *cancellable,
-                void (*done) (gchar *uri, CamelStore *store, gpointer data),
-                gpointer data)
-{
-	struct _get_store_msg *m;
-	gint id;
-
-	m = mail_msg_new (&get_store_info);
-	if (G_IS_CANCELLABLE (cancellable))
-		e_activity_set_cancellable (m->base.activity, cancellable);
-	m->session = g_object_ref (session);
-	m->uri = g_strdup (uri);
-	m->data = data;
-	m->done = done;
-
-	id = m->base.seq;
-	mail_msg_unordered_push (m);
-	return id;
-}
-
 /* ** REMOVE FOLDER ******************************************************* */
 
 struct _remove_folder_msg {
@@ -1671,9 +1586,12 @@ struct _sync_store_msg {
 static gchar *
 sync_store_desc (struct _sync_store_msg *m)
 {
+	CamelURL *url;
 	gchar *uri, *res;
 
-	uri = camel_url_to_string (((CamelService *)m->store)->url, CAMEL_URL_HIDE_ALL);
+	url = camel_service_get_camel_url (CAMEL_SERVICE (m->store));
+	uri = camel_url_to_string (url, CAMEL_URL_HIDE_ALL);
+
 	res = g_strdup_printf (m->expunge
 			      ?_("Expunging and storing account '%s'")
 			      :_("Storing account '%s'"),
@@ -1772,32 +1690,16 @@ mail_refresh_folder (CamelFolder *folder, void (*done) (CamelFolder *folder, gpo
 /* ******************************************************************************** */
 
 static gboolean
-folder_is_from_source_url (CamelFolder *folder, const gchar *source_url)
+folder_is_from_source_uid (CamelFolder *folder,
+                           const gchar *source_uid)
 {
 	CamelStore *store;
-	CamelService *service;
-	CamelURL *url;
-	gboolean res = FALSE;
-
-	g_return_val_if_fail (folder != NULL, FALSE);
-	g_return_val_if_fail (source_url != NULL, FALSE);
+	const gchar *uid;
 
 	store = camel_folder_get_parent_store (folder);
-	g_return_val_if_fail (store != NULL, FALSE);
+	uid = camel_service_get_uid (CAMEL_SERVICE (store));
 
-	service = CAMEL_SERVICE (store);
-	g_return_val_if_fail (service != NULL, FALSE);
-	g_return_val_if_fail (service->provider != NULL, FALSE);
-	g_return_val_if_fail (service->provider->url_equal != NULL, FALSE);
-
-	url = camel_url_new (source_url, NULL);
-	g_return_val_if_fail (url != NULL, FALSE);
-
-	res = service->provider->url_equal (service->url, url);
-
-	camel_url_free (url);
-
-	return res;
+	return (g_strcmp0 (uid, source_uid) == 0);
 }
 
 /* This is because pop3 accounts are hidden under local Inbox, thus whenever an expunge
@@ -1865,7 +1767,8 @@ expunge_pop3_stores (CamelFolder *expunging, EMailSession *session, GCancellable
 		if (account->enabled && account->source && account->source->url && g_str_has_prefix (account->source->url, "pop://")) {
 			gboolean any_found = FALSE;
 
-			folder = e_mail_session_get_inbox_sync (session, account->source->url, cancellable, error);
+			folder = e_mail_session_get_inbox_sync (
+				session, account->uid, cancellable, error);
 			if (!folder || (error && *error))
 				continue;
 
@@ -1873,8 +1776,11 @@ expunge_pop3_stores (CamelFolder *expunging, EMailSession *session, GCancellable
 			if (uids) {
 				for (i = 0; i < uids->len; i++) {
 					/* ensure the ID is from this account, as it's generated by evolution */
-					const gchar *source_url = g_hash_table_lookup (expunging_uids, uids->pdata[i]);
-					if (source_url && folder_is_from_source_url (folder, source_url)) {
+					const gchar *source_uid;
+
+					source_uid = g_hash_table_lookup (
+						expunging_uids, uids->pdata[i]);
+					if (folder_is_from_source_uid (folder, source_uid)) {
 						any_found = TRUE;
 						camel_folder_delete_message (folder, uids->pdata[i]);
 					}
@@ -1909,15 +1815,10 @@ expunge_folder_exec (struct _sync_folder_msg *m,
 	gboolean is_local_inbox_or_trash = m->folder == e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_INBOX);
 
 	if (!is_local_inbox_or_trash && e_mail_local_get_store () == camel_folder_get_parent_store (m->folder)) {
-		const gchar *data_dir;
 		CamelFolder *trash;
-		gchar *uri;
 
-		data_dir = mail_session_get_data_dir ();
-		uri = g_strdup_printf ("maildir:%s/local", data_dir);
 		trash = e_mail_session_get_trash_sync (
-			m->session, uri, cancellable, error);
-		g_free (uri);
+			m->session, "local", cancellable, error);
 
 		is_local_inbox_or_trash = m->folder == trash;
 
@@ -1980,20 +1881,12 @@ empty_trash_exec (struct _empty_trash_msg *m,
                   GError **error)
 {
 	CamelFolder *trash;
-	const gchar *data_dir;
-	gchar *uri;
+	const gchar *uid;
 
-	if (m->account) {
-		trash = e_mail_session_get_trash_sync (
-			m->session, m->account->source->url,
-			cancellable, error);
-	} else {
-		data_dir = mail_session_get_data_dir ();
-		uri = g_strdup_printf ("maildir:%s/local", data_dir);
-		trash = e_mail_session_get_trash_sync (
-			m->session, uri, cancellable, error);
-		g_free (uri);
-	}
+	uid = (m->account != NULL) ? m->account->uid : "local";
+
+	trash = e_mail_session_get_trash_sync (
+		m->session, uid, cancellable, error);
 
 	if (trash) {
 		/* do this before expunge, to know which messages will be expunged */
@@ -2488,11 +2381,10 @@ struct _check_msg {
 	MailMsg base;
 
 	EMailSession *session;
-	gchar *url;
-	CamelProviderType type;
+	gchar *service_uid;
 	GList *authtypes;
 
-	void (*done)(const gchar *url, CamelProviderType type, GList *types, gpointer data);
+	void (*done)(GList *types, gpointer data);
 	gpointer data;
 };
 
@@ -2510,7 +2402,7 @@ check_service_exec (struct _check_msg *m,
 	CamelService *service;
 
 	service = camel_session_get_service (
-		CAMEL_SESSION (m->session), m->url, m->type, error);
+		CAMEL_SESSION (m->session), m->service_uid);
 	if (!service)
 		return;
 
@@ -2523,14 +2415,14 @@ static void
 check_service_done (struct _check_msg *m)
 {
 	if (m->done)
-		m->done (m->url, m->type, m->authtypes, m->data);
+		m->done (m->authtypes, m->data);
 }
 
 static void
 check_service_free (struct _check_msg *m)
 {
 	g_object_unref (m->session);
-	g_free (m->url);
+	g_free (m->service_uid);
 	g_list_free (m->authtypes);
 }
 
@@ -2544,9 +2436,8 @@ static MailMsgInfo check_service_info = {
 
 gint
 mail_check_service (EMailSession *session,
-                    const gchar *url,
-                    CamelProviderType type,
-                    void (*done)(const gchar *url, CamelProviderType type, GList *authtypes, gpointer data),
+                    const gchar *service_uid,
+                    void (*done)(GList *authtypes, gpointer data),
                     gpointer data)
 {
 	struct _check_msg *m;
@@ -2554,8 +2445,7 @@ mail_check_service (EMailSession *session,
 
 	m = mail_msg_new (&check_service_info);
 	m->session = g_object_ref (session);
-	m->url = g_strdup (url);
-	m->type = type;
+	m->service_uid = g_strdup (service_uid);
 	m->done = done;
 	m->data = data;
 
