@@ -26,15 +26,9 @@
 #include <glib.h>
 #include <camel/camel.h>
 
-/* Get the "inbox" for a url (uses global session) */
-CamelFolder *mail_tool_get_inbox (const gchar *url, CamelException *ex);
-
-/* Get the "trash" for a url (uses global session) */
-CamelFolder *mail_tool_get_trash (const gchar *url, gint connect, CamelException *ex);
-
 /* Does a camel_movemail into the local movemail folder
  * and returns the path to the new movemail folder that was created. which shoudl be freed later */
-gchar *mail_tool_do_movemail (const gchar *source_url, CamelException *ex);
+gchar *mail_tool_do_movemail (CamelStore *store, GError **error);
 
 struct _camel_header_raw *mail_tool_remove_xevolution_headers (CamelMimeMessage *message);
 void mail_tool_restore_xevolution_headers (CamelMimeMessage *message, struct _camel_header_raw *);
@@ -45,13 +39,4 @@ gchar *mail_tool_generate_forward_subject (CamelMimeMessage *msg);
 /* Make a message into an attachment */
 CamelMimePart *mail_tool_make_message_attachment (CamelMimeMessage *message);
 
-/* Parse the ui into a real CamelFolder any way we know how. */
-CamelFolder *mail_tool_uri_to_folder (const gchar *uri, guint32 flags, CamelException *ex);
-
-GHashTable *mail_lookup_url_table (CamelMimeMessage *mime_message);
-
-CamelFolder *mail_tools_x_evolution_message_parse (gchar *in, guint inlen, GPtrArray **uids);
-
-gchar *mail_tools_folder_to_url (CamelFolder *folder);
-
 #endif
