@@ -35,6 +35,7 @@
 
 #include "e-mail-backend.h"
 #include "e-mail-session.h"
+#include "e-mail-folder-utils.h"
 #include "em-folder-tree-model.h"
 #include "em-utils.h"
 #include "em-vfolder-context.h"
@@ -202,46 +203,39 @@ struct _adduri_msg {
 static gchar *
 vfolder_adduri_desc (struct _adduri_msg *m)
 {
-	gchar *euri, *desc = NULL;
+	EAccount *account;
+	CamelStore *store;
+	CamelSession *session;
+	const gchar *store_name;
+	const gchar *uid;
+	gchar *folder_name;
+	gchar *description;
+	gboolean success;
 
-	/* Yuck yuck.  Lookup the account name and use that to describe the path */
-	/* We really need to normalise this across all of camel and evolution :-/ */
-	euri = em_uri_from_camel (m->uri);
-	if (euri) {
-		CamelURL *url = camel_url_new (euri, NULL);
+	session = CAMEL_SESSION (m->session);
 
-		if (url) {
-			const gchar *loc = NULL;
+	success = e_mail_folder_uri_parse (
+		session, m->uri, &store, &folder_name, NULL);
 
-			if (url->host && !strcmp(url->host, "local")
-			    && url->user && !strcmp(url->user, "local")) {
-				loc = _("On This Computer");
-			} else {
-				gchar *uid;
-				const EAccount *account;
+	if (!success)
+		return NULL;
 
-				if (url->user == NULL)
-					uid = g_strdup (url->host);
-				else
-					uid = g_strdup_printf("%s@%s", url->user, url->host);
+	uid = camel_service_get_uid (CAMEL_SERVICE (store));
+	account = e_get_account_by_uid (uid);
 
-				account = e_get_account_by_uid (uid);
-				g_free (uid);
-				if (account != NULL)
-					loc = account->name;
-			}
+	if (account != NULL)
+		store_name = account->name;
+	else
+		store_name = _("On This Computer");
 
-			if (loc && url->path)
-				desc = g_strdup_printf(_("Updating Search Folders for '%s:%s'"), loc, url->path);
-			camel_url_free (url);
-		}
-		g_free (euri);
-	}
+	description = g_strdup_printf (
+		_("Updating Search Folders for '%s' : %s"),
+		store_name, folder_name);
 
-	if (desc == NULL)
-		desc = g_strdup_printf(_("Updating Search Folders for '%s'"), m->uri);
+	g_object_unref (store);
+	g_free (folder_name);
 
-	return desc;
+	return description;
 }
 
 static void
@@ -333,67 +327,64 @@ vfolder_adduri (EMailSession *session,
 /* ********************************************************************** */
 
 static GList *
-mv_find_folder (GList *l, CamelStore *store, const gchar *uri)
+mv_find_folder (GList *l, EMailSession *session, const gchar *uri)
 {
+	CamelSession *camel_session = CAMEL_SESSION (session);
+
 	while (l) {
-		if (camel_store_folder_uri_equal (store, l->data, uri))
+		if (e_mail_folder_uri_equal (camel_session, l->data, uri))
 			break;
 		l = l->next;
 	}
 	return l;
 }
 
-/* uri is a camel uri */
 static gint
-uri_is_ignore (CamelStore *store, const gchar *uri)
+uri_is_ignore (EMailSession *session, const gchar *uri)
 {
 	EAccountList *accounts;
 	EAccount *account;
 	EIterator *iter;
+	CamelSession *camel_session;
 	const gchar *local_drafts_uri;
 	const gchar *local_outbox_uri;
 	const gchar *local_sent_uri;
 	gint found = FALSE;
 
-	local_drafts_uri = e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_DRAFTS);
-	local_outbox_uri = e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_OUTBOX);
-	local_sent_uri = e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_SENT);
+	local_drafts_uri =
+		e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_DRAFTS);
+	local_outbox_uri =
+		e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_OUTBOX);
+	local_sent_uri =
+		e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_SENT);
 
-	d(printf("checking '%s' against:\n  %s\n  %s\n  %s\n", uri,
-		local_outbox_uri,
-		local_sent_uri,
-		local_drafts_uri));
+	camel_session = CAMEL_SESSION (session);
 
-	found = camel_store_folder_uri_equal (store, local_outbox_uri, uri)
-		|| camel_store_folder_uri_equal (store, local_sent_uri, uri)
-		|| camel_store_folder_uri_equal (store, local_drafts_uri, uri);
+	if (e_mail_folder_uri_equal (camel_session, local_outbox_uri, uri))
+		return TRUE;
 
-	if (found)
-		return found;
+	if (e_mail_folder_uri_equal (camel_session, local_sent_uri, uri))
+		return TRUE;
+
+	if (e_mail_folder_uri_equal (camel_session, local_drafts_uri, uri))
+		return TRUE;
 
 	accounts = e_get_account_list ();
-	iter = e_list_get_iterator ((EList *) accounts);
-	while (e_iterator_is_valid (iter)) {
-		gchar *curi;
+	iter = e_list_get_iterator (E_LIST (accounts));
 
+	while (!found && e_iterator_is_valid (iter)) {
+		/* XXX EIterator misuses const. */
 		account = (EAccount *) e_iterator_get (iter);
 
-		d(printf("checking sent_folder_uri '%s' == '%s'\n",
-			 account->sent_folder_uri ? account->sent_folder_uri : "empty", uri));
+		if (!found && account->sent_folder_uri != NULL)
+			found = e_mail_folder_uri_equal (
+				camel_session, uri,
+				account->sent_folder_uri);
 
-		if (account->sent_folder_uri) {
-			curi = em_uri_to_camel (account->sent_folder_uri);
-			found = camel_store_folder_uri_equal (store, uri, curi);
-			g_free (curi);
-		}
-		if (!found && account->drafts_folder_uri) {
-			curi = em_uri_to_camel (account->drafts_folder_uri);
-			found = camel_store_folder_uri_equal (store, uri, curi);
-			g_free (curi);
-		}
-
-		if (found)
-			break;
+		if (!found && account->drafts_folder_uri != NULL)
+			found = e_mail_folder_uri_equal (
+				camel_session, uri,
+				account->drafts_folder_uri);
 
 		e_iterator_next (iter);
 	}
@@ -405,98 +396,81 @@ uri_is_ignore (CamelStore *store, const gchar *uri)
 
 /* so special we never use it */
 static gint
-uri_is_spethal (CamelStore *store, const gchar *uri)
+folder_is_spethal (CamelStore *store,
+                   const gchar *folder_name)
 {
-	CamelURL *url;
-	gint res;
+	/* This is a bit of a hack, but really the only way it can be done
+	 * at the moment. */
 
-	/* This is a bit of a hack, but really the only way it can be done at the moment. */
+	if (store->flags & CAMEL_STORE_VTRASH)
+		if (g_strcmp0 (folder_name, CAMEL_VTRASH_NAME) == 0)
+			return TRUE;
 
-	if ((store->flags & (CAMEL_STORE_VTRASH|CAMEL_STORE_VJUNK)) == 0)
-		return FALSE;
+	if (store->flags & CAMEL_STORE_VJUNK)
+		if (g_strcmp0 (folder_name, CAMEL_VJUNK_NAME) == 0)
+			return TRUE;
 
-	url = camel_url_new (uri, NULL);
-	if (url == NULL)
-		return TRUE;
-
-	/* don't use strcasecmp here */
-	if (url->fragment) {
-		res = (((store->flags & CAMEL_STORE_VTRASH)
-			&& strcmp (url->fragment, CAMEL_VTRASH_NAME) == 0)
-		       || ((store->flags & CAMEL_STORE_VJUNK)
-			   && strcmp (url->fragment, CAMEL_VJUNK_NAME) == 0));
-	} else {
-		res = url->path
-			&& (((store->flags & CAMEL_STORE_VTRASH)
-			     && strcmp(url->path, "/" CAMEL_VTRASH_NAME) == 0)
-			    || ((store->flags & CAMEL_STORE_VJUNK)
-				&& strcmp(url->path, "/" CAMEL_VJUNK_NAME) == 0));
-	}
-
-	camel_url_free (url);
-
-	return res;
+	return FALSE;
 }
 
 /**
- * mail_vfolder_add_uri:
+ * mail_vfolder_add_folder:
  * @session: an #EMailSession
- * @store: a #CamelStore containing the uri
- * @curi: an email uri to be added/removed
- * @remove: Whether the uri should be removed or added
+ * @store: a #CamelStore
+ * @folder: a folder name
+ * @remove: whether the folder should be removed or added
  *
- * Called when a new uri becomes (un)available.  If @store is not a
- * CamelVeeStore, the uri is added/removed from the list of cached source
- * folders.  Then each vfolder rule is checked to see if the specified uri
+ * Called when a new folder becomes (un)available.  If @store is not a
+ * CamelVeeStore, the folder is added/removed from the list of cached source
+ * folders.  Then each vfolder rule is checked to see if the specified folder
  * matches a source of the rule.  It builds a list of vfolders that use (or
- * would use) the specified uri as a source.  It then adds (or removes) this uri
- * to (from) those vfolders via camel_vee_folder_add/remove_folder() but does
- * not modify the actual filters or write changes to disk.
+ * would use) the specified folder as a source.  It then adds (or removes)
+ * this folder to (from) those vfolders via camel_vee_folder_add/
+ * remove_folder() but does not modify the actual filters or write changes
+ * to disk.
  *
  * NOTE: This function must be called from the main thread.
  */
 static void
-mail_vfolder_add_uri (EMailSession *session,
-                      CamelStore *store,
-                      const gchar *curi,
-                      gint remove)
+mail_vfolder_add_folder (EMailSession *session,
+                         CamelStore *store,
+                         const gchar *folder_name,
+                         gint remove)
 {
 	EFilterRule *rule;
 	const gchar *source;
 	CamelVeeFolder *vf;
+	CamelProvider *provider;
 	GList *folders = NULL, *link;
 	gint remote;
 	gint is_ignore;
 	gchar *uri;
 
-	remote = (((CamelService *)store)->provider->flags &
-		CAMEL_PROVIDER_IS_REMOTE) != 0;
+	provider = camel_service_get_provider (CAMEL_SERVICE (store));
+	remote = (provider->flags & CAMEL_PROVIDER_IS_REMOTE) != 0;
 
-	uri = em_uri_from_camel (curi);
-	if (uri_is_spethal (store, curi)) {
-		g_free (uri);
+	if (folder_is_spethal (store, folder_name))
 		return;
-	}
 
 	g_return_if_fail (mail_in_main_thread ());
 
-	is_ignore = uri_is_ignore (store, curi);
+	uri = e_mail_folder_uri_build (store, folder_name);
+
+	is_ignore = uri_is_ignore (session, uri);
 
 	G_LOCK (vfolder);
 
-/*	d(printf("%s uri to check: %s\n", remove?"Removing":"Adding", uri)); */
-
 	/* maintain the source folders lists for changed rules later on */
 	if (CAMEL_IS_VEE_STORE (store)) {
 		is_ignore = TRUE;
 	} else if (remove) {
 		if (remote) {
-			if ((link = mv_find_folder (source_folders_remote, store, curi)) != NULL) {
+			if ((link = mv_find_folder (source_folders_remote, session, uri)) != NULL) {
 				g_free (link->data);
 				source_folders_remote = g_list_remove_link (source_folders_remote, link);
 			}
 		} else {
-			if ((link = mv_find_folder (source_folders_local, store, curi)) != NULL) {
+			if ((link = mv_find_folder (source_folders_local, session, uri)) != NULL) {
 				g_free (link->data);
 				source_folders_local = g_list_remove_link (source_folders_local, link);
 			}
@@ -504,11 +478,11 @@ mail_vfolder_add_uri (EMailSession *session,
 	} else if (!is_ignore) {
 		/* we ignore drafts/sent/outbox here */
 		if (remote) {
-			if (mv_find_folder (source_folders_remote, store, curi) == NULL)
-				source_folders_remote = g_list_prepend (source_folders_remote, g_strdup (curi));
+			if (mv_find_folder (source_folders_remote, session, uri) == NULL)
+				source_folders_remote = g_list_prepend (source_folders_remote, g_strdup (uri));
 		} else {
-			if (mv_find_folder (source_folders_local, store, curi) == NULL)
-				source_folders_local = g_list_prepend (source_folders_local, g_strdup (curi));
+			if (mv_find_folder (source_folders_local, session, uri) == NULL)
+				source_folders_local = g_list_prepend (source_folders_local, g_strdup (uri));
 		}
 	}
 
@@ -527,19 +501,19 @@ mail_vfolder_add_uri (EMailSession *session,
 		 * they must be explictly listed as a source. */
 		if (rule->source
 		    && !is_ignore
-		    && ((((EMVFolderRule *)rule)->with == EM_VFOLDER_RULE_WITH_LOCAL && !remote)
-			|| (((EMVFolderRule *)rule)->with == EM_VFOLDER_RULE_WITH_REMOTE_ACTIVE && remote)
-			|| (((EMVFolderRule *)rule)->with == EM_VFOLDER_RULE_WITH_LOCAL_REMOTE_ACTIVE)))
+		    && ((((EMVFolderRule *)rule)->with ==
+				EM_VFOLDER_RULE_WITH_LOCAL && !remote)
+			|| (((EMVFolderRule *)rule)->with ==
+				EM_VFOLDER_RULE_WITH_REMOTE_ACTIVE && remote)
+			|| (((EMVFolderRule *)rule)->with ==
+				EM_VFOLDER_RULE_WITH_LOCAL_REMOTE_ACTIVE)))
 			found = TRUE;
 
 		source = NULL;
 		while (!found && (source = em_vfolder_rule_next_source (
 				(EMVFolderRule *)rule, source))) {
-			gchar *csource;
-			csource = em_uri_to_camel (source);
-			found = camel_store_folder_uri_equal (store, curi, csource);
-			d(printf(found?" '%s' == '%s'?\n":" '%s' != '%s'\n", curi, csource));
-			g_free (csource);
+			found = e_mail_folder_uri_equal (
+				CAMEL_SESSION (session), uri, source);
 		}
 
 		if (found) {
@@ -557,70 +531,36 @@ done:
 	G_UNLOCK (vfolder);
 
 	if (folders != NULL)
-		vfolder_adduri (session, curi, folders, remove);
+		vfolder_adduri (session, uri, folders, remove);
 
 	g_free (uri);
 }
 
 /**
- * mail_vfolder_uri_available:
- * @session: an #EMailSession
- * @store: a #CamelStore containing the uri
- * @uri: uri of a folder that became available
- *
- * Adds @uri to the list of folders searched if any vfolder source matches the
- * uri.  This function has a transient effect and does not permanently modify
- * the vfolder filter rules on disk.
- */
-static void
-mail_vfolder_notify_uri_available (EMailSession *session,
-                                   CamelStore *store,
-                                   const gchar *uri)
-{
-	mail_vfolder_add_uri (session, store, uri, FALSE);
-}
-
-/**
- * mail_vfolder_uri_available:
- * @session: an #EMailSession
- * @store: a #CamelStore containing the uri
- * @uri: uri of a folder that became unavailable
- *
- * Removes @uri from the list of folders searched if any vfolder source matches the
- * uri.  This function has a transient effect and does not permanently modify
- * the vfolder filter rules on disk.
- */
-static void
-mail_vfolder_notify_uri_unavailable (EMailSession *session,
-                                     CamelStore *store,
-                                     const gchar *uri)
-{
-	mail_vfolder_add_uri (session, store, uri, TRUE);
-}
-
-/**
- * mail_vfolder_delete_uri:
+ * mail_vfolder_delete_folder:
  * @backend: an #EMailBackend
- * @store: a #CamelStore containing the uri
- * @curi: an email uri that has been deleted
+ * @store: a #CamelStore
+ * @folder_name: a folder name
  *
- * Looks through all vfolder rules to see if @curi is listed as a source for any
- * vfolder rules.  If the uri is found in the source for any rule, it is removed
- * and the user is alerted to the fact that the vfolder rules have been updated.
- * The new vfolder rules are written to disk.
+ * Looks through all vfolder rules to see if @folder_name is listed as a
+ * source for any vfolder rules.  If the folder is found in the source for
+ * any rule, it is removed and the user is alerted to the fact that the
+ * vfolder rules have been updated.  The new vfolder rules are written
+ * to disk.
  *
- * XXX: It doesn't appear that the changes to the vfolder rules are sent down to
- * the camel level, however. So the actual vfolders will not change behavior
- * until evolution is restarted (?)
+ * XXX: It doesn't appear that the changes to the vfolder rules are sent
+ * down to the camel level, however. So the actual vfolders will not change
+ * behavior until evolution is restarted (?)
  *
  * NOTE: This function must be called from the main thread.
  */
 static void
-mail_vfolder_delete_uri (EMailBackend *backend,
-                         CamelStore *store,
-                         const gchar *curi)
+mail_vfolder_delete_folder (EMailBackend *backend,
+                            CamelStore *store,
+                            const gchar *folder_name)
 {
 	EFilterRule *rule;
+	EMailSession *session;
 	const gchar *source;
 	CamelVeeFolder *vf;
 	GString *changed;
@@ -630,17 +570,18 @@ mail_vfolder_delete_uri (EMailBackend *backend,
 
 	g_return_if_fail (E_IS_MAIL_BACKEND (backend));
 	g_return_if_fail (CAMEL_IS_STORE (store));
-	g_return_if_fail (curi != NULL);
+	g_return_if_fail (folder_name != NULL);
 
-	if (uri_is_spethal (store, curi))
+	if (folder_is_spethal (store, folder_name))
 		return;
 
-	uri = em_uri_from_camel (curi);
-
 	d(printf ("Deleting uri to check: %s\n", uri));
 
 	g_return_if_fail (mail_in_main_thread ());
 
+	session = e_mail_backend_get_session (backend);
+	uri = e_mail_folder_uri_build (store, folder_name);
+
 	changed_count = 0;
 	changed = g_string_new ("");
 
@@ -660,11 +601,9 @@ mail_vfolder_delete_uri (EMailBackend *backend,
 
 		source = NULL;
 		while ((source = em_vfolder_rule_next_source ((EMVFolderRule *) rule, source))) {
-			gchar *csource = em_uri_to_camel (source);
-
 			/* Remove all sources that match, ignore changed events though
 			   because the adduri call above does the work async */
-			if (camel_store_folder_uri_equal (store, curi, csource)) {
+			if (e_mail_folder_uri_equal (CAMEL_SESSION (session), uri, source)) {
 				vf = g_hash_table_lookup (vfolder_hash, rule->name);
 				if (!vf) {
 					g_warning ("vf is NULL for %s\n", rule->name);
@@ -688,17 +627,16 @@ mail_vfolder_delete_uri (EMailBackend *backend,
 				changed_count++;
 				source = NULL;
 			}
-			g_free (csource);
 		}
 	}
 
 done:
-	if ((link = mv_find_folder (source_folders_remote, store, curi)) != NULL) {
+	if ((link = mv_find_folder (source_folders_remote, session, uri)) != NULL) {
 		g_free (link->data);
 		source_folders_remote = g_list_remove_link (source_folders_remote, link);
 	}
 
-	if ((link = mv_find_folder (source_folders_local, store, curi)) != NULL) {
+	if ((link = mv_find_folder (source_folders_local, session, uri)) != NULL) {
 		g_free (link->data);
 		source_folders_local = g_list_remove_link (source_folders_local, link);
 	}
@@ -737,23 +675,35 @@ done:
 
 /* called when a uri is renamed in a store */
 static void
-mail_vfolder_rename_uri (CamelStore *store, const gchar *cfrom, const gchar *cto)
+mail_vfolder_rename_folder (CamelStore *store,
+                            const gchar *old_folder_name,
+                            const gchar *new_folder_name)
 {
 	EFilterRule *rule;
 	const gchar *source;
 	CamelVeeFolder *vf;
+	CamelSession *session;
 	gint changed = 0;
-	gchar *from, *to;
+	gchar *old_uri;
+	gchar *new_uri;
 
 	d(printf("vfolder rename uri: %s to %s\n", cfrom, cto));
 
-	if (context == NULL || uri_is_spethal (store, cfrom) || uri_is_spethal (store, cto))
+	if (context == NULL)
+		return;
+
+	if (folder_is_spethal (store, old_folder_name))
+		return;
+
+	if (folder_is_spethal (store, new_folder_name))
 		return;
 
 	g_return_if_fail (mail_in_main_thread ());
 
-	from = em_uri_from_camel (cfrom);
-	to = em_uri_from_camel (cto);
+	session = camel_service_get_session (CAMEL_SERVICE (store));
+
+	old_uri = e_mail_folder_uri_build (store, old_folder_name);
+	new_uri = e_mail_folder_uri_build (store, new_folder_name);
 
 	G_LOCK (vfolder);
 
@@ -762,11 +712,9 @@ mail_vfolder_rename_uri (CamelStore *store, const gchar *cfrom, const gchar *cto
 	while ((rule = e_rule_context_next_rule ((ERuleContext *)context, rule, NULL))) {
 		source = NULL;
 		while ((source = em_vfolder_rule_next_source ((EMVFolderRule *)rule, source))) {
-			gchar *csource = em_uri_to_camel (source);
-
 			/* Remove all sources that match, ignore changed events though
 			   because the adduri call above does the work async */
-			if (camel_store_folder_uri_equal (store, cfrom, csource)) {
+			if (e_mail_folder_uri_equal (session, old_uri, source)) {
 				vf = g_hash_table_lookup (vfolder_hash, rule->name);
 				if (!vf) {
 					g_warning ("vf is NULL for %s\n", rule->name);
@@ -777,12 +725,11 @@ mail_vfolder_rename_uri (CamelStore *store, const gchar *cfrom, const gchar *cto
 					G_SIGNAL_MATCH_DATA, 0, 0, NULL,
 					rule_changed, vf);
 				em_vfolder_rule_remove_source ((EMVFolderRule *)rule, source);
-				em_vfolder_rule_add_source ((EMVFolderRule *)rule, to);
+				em_vfolder_rule_add_source ((EMVFolderRule *)rule, new_uri);
 				g_signal_connect(rule, "changed", G_CALLBACK(rule_changed), vf);
 				changed++;
 				source = NULL;
 			}
-			g_free (csource);
 		}
 	}
 
@@ -799,8 +746,8 @@ mail_vfolder_rename_uri (CamelStore *store, const gchar *cfrom, const gchar *cto
 		g_free (user);
 	}
 
-	g_free (from);
-	g_free (to);
+	g_free (old_uri);
+	g_free (new_uri);
 }
 
 GList *
@@ -833,16 +780,17 @@ rule_add_sources (EMailSession *session,
 	folder_cache = e_mail_session_get_folder_cache (session);
 
 	while (l) {
-		gchar *curi = em_uri_to_camel (l->data);
+		const gchar *uri = l->data;
 
 		if (mail_folder_cache_get_folder_from_uri (
-			folder_cache, curi, &newfolder)) {
+			folder_cache, uri, &newfolder)) {
 			if (newfolder)
-				sources_folder = g_list_append (sources_folder, newfolder);
+				sources_folder = g_list_append (
+					sources_folder, newfolder);
 			else
-				sources_uri = g_list_append (sources_uri, g_strdup (curi));
+				sources_uri = g_list_append (
+					sources_uri, g_strdup (uri));
 		}
-		g_free (curi);
 		l = l->next;
 	}
 
@@ -993,14 +941,18 @@ store_folder_deleted_cb (CamelStore *store,
 			0, 0, NULL, context_rule_removed, context);
 		e_rule_context_remove_rule ((ERuleContext *)context, rule);
 		g_object_unref (rule);
-		g_signal_connect(context, "rule_removed", G_CALLBACK(context_rule_removed), context);
+		g_signal_connect (
+			context, "rule_removed",
+			G_CALLBACK (context_rule_removed), context);
 
 		config_dir = mail_session_get_config_dir ();
 		user = g_build_filename (config_dir, "vfolders.xml", NULL);
 		e_rule_context_save ((ERuleContext *)context, user);
 		g_free (user);
 	} else {
-		g_warning("Cannot find rule for deleted vfolder '%s'", info->name);
+		g_warning (
+			"Cannot find rule for deleted vfolder '%s'",
+			info->display_name);
 	}
 
 	G_UNLOCK (vfolder);
@@ -1058,38 +1010,38 @@ store_folder_renamed_cb (CamelStore *store,
 static void
 folder_available_cb (MailFolderCache *cache,
                      CamelStore *store,
-                     const gchar *uri,
+                     const gchar *folder_name,
                      EMailSession *session)
 {
-	mail_vfolder_notify_uri_available (session, store, uri);
+	mail_vfolder_add_folder (session, store, folder_name, FALSE);
 }
 
 static void
 folder_unavailable_cb (MailFolderCache *cache,
                        CamelStore *store,
-                       const gchar *uri,
+                       const gchar *folder_name,
                        EMailSession *session)
 {
-	mail_vfolder_notify_uri_unavailable (session, store, uri);
+	mail_vfolder_add_folder (session, store, folder_name, TRUE);
 }
 
 static void
 folder_deleted_cb (MailFolderCache *cache,
                    CamelStore *store,
-                   const gchar *uri,
+                   const gchar *folder_name,
                    EMailBackend *backend)
 {
-	mail_vfolder_delete_uri (backend, store, uri);
+	mail_vfolder_delete_folder (backend, store, folder_name);
 }
 
 static void
 folder_renamed_cb (MailFolderCache *cache,
                    CamelStore *store,
-                   const gchar *olduri,
-                   const gchar *newuri,
+                   const gchar *old_folder_name,
+                   const gchar *new_folder_name,
                    gpointer user_data)
 {
-	mail_vfolder_rename_uri (store, olduri, newuri);
+	mail_vfolder_rename_folder (store, old_folder_name, new_folder_name);
 }
 
 void
@@ -1098,6 +1050,7 @@ vfolder_load_storage (EMailBackend *backend)
 	/* lock for loading storage, it is safe to call it more than once */
 	G_LOCK_DEFINE_STATIC (vfolder_hash);
 
+	CamelService *service;
 	const gchar *key;
 	const gchar *data_dir;
 	const gchar *config_dir;
@@ -1128,23 +1081,28 @@ vfolder_load_storage (EMailBackend *backend)
 
 	/* first, create the vfolder store, and set it up */
 	storeuri = g_strdup_printf("vfolder:%s/vfolder", data_dir);
-	vfolder_store = camel_session_get_store (
-		CAMEL_SESSION (session), storeuri, NULL);
-	if (vfolder_store == NULL) {
+	service = camel_session_add_service (
+		CAMEL_SESSION (session), "vfolder",
+		storeuri, CAMEL_PROVIDER_STORE, NULL);
+	if (service != NULL)
+		camel_service_connect_sync (service, NULL);
+	else {
 		g_warning("Cannot open vfolder store - no vfolders available");
 		return;
 	}
 
+	g_return_if_fail (CAMEL_IS_STORE (service));
+
+	vfolder_store = CAMEL_STORE (service);
+
 	g_signal_connect (
-		vfolder_store, "folder-deleted",
+		service, "folder-deleted",
 		G_CALLBACK (store_folder_deleted_cb), backend);
 
 	g_signal_connect (
-		vfolder_store, "folder-renamed",
+		service, "folder-renamed",
 		G_CALLBACK (store_folder_renamed_cb), NULL);
 
-	d(printf("got store '%s' = %p\n", storeuri, vfolder_store));
-
 	/* load our rules */
 	user = g_build_filename (config_dir, "vfolders.xml", NULL);
 	context = em_vfolder_context_new (session);
@@ -1161,7 +1119,7 @@ vfolder_load_storage (EMailBackend *backend)
 	g_signal_connect(context, "rule_removed", G_CALLBACK(context_rule_removed), context);
 
 	/* load store to mail component */
-	e_mail_store_add_by_uri (session, storeuri, _("Search Folders"));
+	e_mail_store_add (session, vfolder_store, _("Search Folders"));
 
 	/* and setup the rules we have */
 	rule = NULL;
@@ -1402,8 +1360,6 @@ vfolder_gui_add_rule (EMVFolderRule *rule)
 	GtkDialog *gd;
 	GtkWidget *container;
 
-	g_return_if_fail (EM_IS_VFOLDER_RULE (rule));
-
 	w = e_filter_rule_get_widget ((EFilterRule *)rule, (ERuleContext *)context);
 
 	gd = (GtkDialog *)gtk_dialog_new_with_buttons (
@@ -1432,15 +1388,16 @@ vfolder_gui_add_rule (EMVFolderRule *rule)
 
 void
 vfolder_gui_add_from_message (EMailSession *session,
-                              CamelMimeMessage *msg,
+                              CamelMimeMessage *message,
                               gint flags,
-                              const gchar *source)
+                              CamelFolder *folder)
 {
 	EMVFolderRule *rule;
 
-	g_return_if_fail (msg != NULL);
+	g_return_if_fail (CAMEL_IS_MIME_MESSAGE (message));
 
-	rule = (EMVFolderRule*)em_vfolder_rule_from_message (context, msg, flags, source);
+	rule = (EMVFolderRule*) em_vfolder_rule_from_message (
+		context, message, flags, folder);
 	vfolder_gui_add_rule (rule);
 }
 
@@ -1448,13 +1405,14 @@ void
 vfolder_gui_add_from_address (EMailSession *session,
                               CamelInternetAddress *addr,
                               gint flags,
-                              const gchar *source)
+                              CamelFolder *folder)
 {
 	EMVFolderRule *rule;
 
 	g_return_if_fail (addr != NULL);
 
-	rule = (EMVFolderRule*)em_vfolder_rule_from_address (context, addr, flags, source);
+	rule = (EMVFolderRule*)em_vfolder_rule_from_address (
+		context, addr, flags, folder);
 	vfolder_gui_add_rule (rule);
 }
 
