@@ -36,6 +36,7 @@
 #include "e-mail-shell-view.h"
 
 #include "e-mail-browser.h"
+#include "e-mail-folder-utils.h"
 #include "e-mail-reader.h"
 #include "e-mail-session.h"
 #include "e-mail-store.h"
@@ -78,7 +79,8 @@ mail_shell_backend_init_importers (void)
 
 	importer = mbox_importer_peek ();
 	e_import_class_add_importer (import_class, importer, NULL, NULL);
-	mbox_importer_set_preview_funcs (mbox_create_preview_cb, mbox_fill_preview_cb);
+	mbox_importer_set_preview_funcs (
+		mbox_create_preview_cb, mbox_fill_preview_cb);
 
 	importer = elm_importer_peek ();
 	e_import_class_add_importer (import_class, importer, NULL, NULL);
@@ -95,7 +97,7 @@ mail_shell_backend_mail_icon_cb (EShellWindow *shell_window,
 
 	action = e_shell_window_get_shell_view_action (
 		shell_window, BACKEND_NAME);
-	g_object_set (action, "icon-name", icon_name, NULL);
+	gtk_action_set_icon_name (action, icon_name);
 }
 
 static void
@@ -138,7 +140,7 @@ action_mail_folder_new_cb (GtkAction *action,
 
 exit:
 	em_folder_utils_create_folder (
-		NULL, folder_tree, mail_session, GTK_WINDOW (shell_window));
+		GTK_WINDOW (shell_window), folder_tree, mail_session, NULL);
 }
 
 static void
@@ -146,12 +148,14 @@ action_mail_message_new_cb (GtkAction *action,
                             EShellWindow *shell_window)
 {
 	EMailShellSidebar *mail_shell_sidebar;
+	EShellBackend *shell_backend;
 	EShellSidebar *shell_sidebar;
 	EShellView *shell_view;
 	EShell *shell;
 	EMFolderTree *folder_tree;
+	CamelFolder *folder = NULL;
 	const gchar *view_name;
-	gchar *uri = NULL;
+	gchar *folder_uri = NULL;
 
 	shell = e_shell_window_get_shell (shell_window);
 
@@ -164,16 +168,40 @@ action_mail_message_new_cb (GtkAction *action,
 		goto exit;
 
 	shell_view = e_shell_window_get_shell_view (shell_window, view_name);
+	shell_backend = e_shell_view_get_shell_backend (shell_view);
 	shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
 
 	mail_shell_sidebar = E_MAIL_SHELL_SIDEBAR (shell_sidebar);
 	folder_tree = e_mail_shell_sidebar_get_folder_tree (mail_shell_sidebar);
-	uri = em_folder_tree_get_selected_uri (folder_tree);
+	folder_uri = em_folder_tree_get_selected_uri (folder_tree);
+
+	if (folder_uri != NULL) {
+		EMailBackend *backend;
+		EMailSession *session;
+		CamelStore *store;
+		gchar *folder_name;
+		gboolean success;
+
+		backend = E_MAIL_BACKEND (shell_backend);
+		session = e_mail_backend_get_session (backend);
+
+		success = e_mail_folder_uri_parse (
+			CAMEL_SESSION (session), folder_uri,
+			&store, &folder_name, NULL);
+
+		/* FIXME This blocks and is not cancellable. */
+		if (success) {
+			folder = camel_store_get_folder_sync (
+				store, folder_name, 0, NULL, NULL);
+			g_object_unref (store);
+			g_free (folder_name);
+		}
+
+		g_free (folder_uri);
+	}
 
 exit:
-	em_utils_compose_new_message (shell, uri);
-
-	g_free (uri);
+	em_utils_compose_new_message (shell, folder);
 }
 
 static GtkActionEntry item_entries[] = {
@@ -243,122 +271,19 @@ exit:
 	return TRUE;
 }
 
-static void
-mail_shell_backend_handle_email_uri_cb (gchar *folder_uri,
-                                        CamelFolder *folder,
-                                        gpointer user_data)
-{
-	EShellBackend *shell_backend = user_data;
-	EShellSettings *shell_settings;
-	EMailBackend *backend;
-	CamelURL *url = user_data;
-	EShell *shell;
-	const gchar *forward;
-	const gchar *reply;
-	const gchar *uid;
-
-	backend = E_MAIL_BACKEND (shell_backend);
-	shell = e_shell_backend_get_shell (shell_backend);
-	shell_settings = e_shell_get_shell_settings (shell);
-
-	if (folder == NULL) {
-		g_warning ("Could not open folder '%s'", folder_uri);
-		goto exit;
-	}
-
-	forward = camel_url_get_param (url, "forward");
-	reply = camel_url_get_param (url, "reply");
-	uid = camel_url_get_param (url, "uid");
-
-	if (reply != NULL) {
-		EMailReplyType reply_type;
-		EMailReplyStyle reply_style;
-
-		if (g_strcmp0 (reply, "all") == 0)
-			reply_type = E_MAIL_REPLY_TO_ALL;
-		else if (g_strcmp0 (reply, "list") == 0)
-			reply_type = E_MAIL_REPLY_TO_LIST;
-		else
-			reply_type = E_MAIL_REPLY_TO_SENDER;
-
-		reply_style = e_shell_settings_get_int (
-			shell_settings, "mail-reply-style");
-
-		em_utils_reply_to_message (
-			shell, folder, uid, NULL,
-			reply_type, reply_style, NULL);
-
-	} else if (forward != NULL) {
-		EMailForwardStyle forward_style;
-		GPtrArray *uids;
-
-		uids = g_ptr_array_new ();
-		g_ptr_array_add (uids, g_strdup (uid));
-
-		if (g_strcmp0 (forward, "attached") == 0)
-			forward_style = E_MAIL_FORWARD_STYLE_ATTACHED;
-		else if (g_strcmp0 (forward, "inline") == 0)
-			forward_style = E_MAIL_FORWARD_STYLE_INLINE;
-		else if (g_strcmp0 (forward, "quoted") == 0)
-			forward_style = E_MAIL_FORWARD_STYLE_QUOTED;
-		else
-			forward_style = e_shell_settings_get_int (
-				shell_settings, "mail-forward-style");
-
-		em_utils_forward_messages (
-			shell, folder, uids, folder_uri, forward_style);
-
-	} else {
-		GtkWidget *browser;
-
-		/* FIXME Should pass in the shell module. */
-		browser = e_mail_browser_new (backend);
-		e_mail_reader_set_folder (
-			E_MAIL_READER (browser), folder, folder_uri);
-		e_mail_reader_set_message (E_MAIL_READER (browser), uid);
-		gtk_widget_show (browser);
-	}
-
-exit:
-	camel_url_free (url);
-}
-
 static gboolean
 mail_shell_backend_handle_uri_cb (EShell *shell,
                                   const gchar *uri,
                                   EMailShellBackend *mail_shell_backend)
 {
-	EMailBackend *backend;
-	EMailSession *session;
-	gboolean handled = TRUE;
-
-	backend = E_MAIL_BACKEND (mail_shell_backend);
-	session = e_mail_backend_get_session (backend);
+	gboolean handled = FALSE;
 
 	if (g_str_has_prefix (uri, "mailto:")) {
 		if (em_utils_check_user_can_send_mail ())
 			em_utils_compose_new_message_with_mailto (
 				shell, uri, NULL);
-
-	} else if (g_str_has_prefix (uri, "email:")) {
-		CamelURL *url;
-
-		url = camel_url_new (uri, NULL);
-		if (camel_url_get_param (url, "uid") != NULL) {
-			gchar *curi = em_uri_to_camel (uri);
-
-			mail_get_folder (
-				session, curi, 0,
-				mail_shell_backend_handle_email_uri_cb,
-				mail_shell_backend, mail_msg_unordered_push);
-			g_free (curi);
-
-		} else {
-			g_warning ("Email URI's must include a uid parameter");
-			camel_url_free (url);
-		}
-	} else
-		handled = FALSE;
+		handled = TRUE;
+	}
 
 	return handled;
 }
@@ -417,11 +342,6 @@ mail_shell_backend_window_created_cb (EShell *shell,
 	}
 
 	if (E_IS_MSG_COMPOSER (window)) {
-		/* Start the mail backend if it isn't already.  This
-		 * may be necessary when opening a new composer window
-		 * from a shell view other than mail. */
-		e_shell_backend_start (shell_backend);
-
 		/* Integrate the new composer into the mail module. */
 		em_configure_new_composer (E_MSG_COMPOSER (window));
 		return;
