@@ -26,36 +26,125 @@
 
 #include "e-util/e-util-private.h"
 
+typedef struct _AsyncContext AsyncContext;
+
+struct _AsyncContext {
+	EActivity *activity;
+	EMailReader *reader;
+	EShellView *shell_view;
+};
+
+static void
+async_context_free (AsyncContext *context)
+{
+	if (context->activity != NULL)
+		g_object_unref (context->activity);
+
+	if (context->reader != NULL)
+		g_object_unref (context->reader);
+
+	if (context->shell_view != NULL)
+		g_object_unref (context->shell_view);
+
+	g_slice_free (AsyncContext, context);
+}
+
+static void
+mail_shell_view_got_folder_cb (CamelStore *store,
+                               GAsyncResult *result,
+                               AsyncContext *context)
+{
+	EAlertSink *alert_sink;
+	CamelFolder *folder;
+	GError *error = NULL;
+
+	alert_sink = e_activity_get_alert_sink (context->activity);
+
+	folder = camel_store_get_folder_finish (store, result, &error);
+
+	/* Ignore cancellations. */
+	if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
+		g_warn_if_fail (folder == NULL);
+		async_context_free (context);
+		g_error_free (error);
+		return;
+
+	} else if (error != NULL) {
+		g_warn_if_fail (folder == NULL);
+		e_alert_submit (
+			alert_sink, "folder-open",
+			error->message, NULL);
+		async_context_free (context);
+		g_error_free (error);
+		return;
+	}
+
+	e_mail_reader_set_folder (context->reader, folder);
+	e_shell_view_update_actions (context->shell_view);
+
+	g_object_unref (folder);
+
+	async_context_free (context);
+}
+
 static void
 mail_shell_view_folder_tree_selected_cb (EMailShellView *mail_shell_view,
-                                         const gchar *full_name,
-                                         const gchar *uri,
-                                         guint32 flags,
+                                         CamelStore *store,
+                                         const gchar *folder_name,
+                                         CamelFolderInfoFlags flags,
                                          EMFolderTree *folder_tree)
 {
 	EMailShellContent *mail_shell_content;
+	EShellBackend *shell_backend;
 	EShellView *shell_view;
 	EMailReader *reader;
 	EMailView *mail_view;
-	gboolean folder_selected;
+	GCancellable *cancellable;
+	EAlertSink *alert_sink;
+	AsyncContext *context;
 
 	shell_view = E_SHELL_VIEW (mail_shell_view);
+	shell_backend = e_shell_view_get_shell_backend (shell_view);
 
 	mail_shell_content = mail_shell_view->priv->mail_shell_content;
 	mail_view = e_mail_shell_content_get_mail_view (mail_shell_content);
 
 	reader = E_MAIL_READER (mail_view);
 
-	folder_selected =
-		!(flags & CAMEL_FOLDER_NOSELECT) &&
-		full_name != NULL;
+	/* Cancel any unfinished open folder operations. */
+	if (mail_shell_view->priv->opening_folder != NULL) {
+		g_cancellable_cancel (mail_shell_view->priv->opening_folder);
+		mail_shell_view->priv->opening_folder = NULL;
+	}
 
-	if (folder_selected)
-		e_mail_reader_set_folder_uri (reader, uri);
-	else
-		e_mail_reader_set_folder (reader, NULL, NULL);
+	/* If we are to clear the message list, do so immediately. */
+	if ((flags & CAMEL_FOLDER_NOSELECT) || folder_name == NULL) {
+		e_mail_reader_set_folder (reader, NULL);
+		e_shell_view_update_actions (shell_view);
+		return;
+	}
 
-	e_shell_view_update_actions (shell_view);
+	g_warn_if_fail (CAMEL_IS_STORE (store));
+
+	/* Open the selected folder asynchronously. */
+
+	context = g_slice_new0 (AsyncContext);
+	context->activity = e_activity_new ();
+	context->reader = g_object_ref (reader);
+	context->shell_view = g_object_ref (shell_view);
+
+	alert_sink = E_ALERT_SINK (mail_shell_content);
+	e_activity_set_alert_sink (context->activity, alert_sink);
+
+	cancellable = camel_operation_new ();
+	e_activity_set_cancellable (context->activity, cancellable);
+	mail_shell_view->priv->opening_folder = cancellable;
+
+	e_shell_backend_add_activity (shell_backend, context->activity);
+
+	camel_store_get_folder (
+		store, folder_name, 0, G_PRIORITY_DEFAULT, cancellable,
+		(GAsyncReadyCallback) mail_shell_view_got_folder_cb, context);
 }
 
 static gboolean
@@ -116,7 +205,8 @@ mail_shell_view_folder_tree_selection_done_cb (EMailShellView *mail_shell_view,
 	GtkWidget *message_list;
 	EMailReader *reader;
 	EMailView *mail_view;
-	const gchar *list_uri;
+	CamelFolder *folder;
+	gchar *list_uri;
 	gchar *tree_uri;
 
 	mail_shell_content = mail_shell_view->priv->mail_shell_content;
@@ -128,11 +218,12 @@ mail_shell_view_folder_tree_selection_done_cb (EMailShellView *mail_shell_view,
 	reader = E_MAIL_READER (mail_view);
 	message_list = e_mail_reader_get_message_list (reader);
 
-	/* Don't use e_mail_reader_get_folder_uri() here.  The fact that
-	 * the method gets the folder URI from the message list is supposed
-	 * to be a hidden implementation detail, and we want to explicitly
-	 * get the folder URI from the message list here. */
-	list_uri = MESSAGE_LIST (message_list)->folder_uri;
+	/* Don't use e_mail_reader_get_folder() here.  The fact that the
+	 * method gets the folder from the message list is supposed to be
+	 * a hidden implementation detail, and we want to explicitly get
+	 * the folder URI from the message list here. */
+	folder = MESSAGE_LIST (message_list)->folder;
+	list_uri = e_mail_folder_uri_from_folder (folder);
 	tree_uri = em_folder_tree_get_selected_uri (folder_tree);
 
 	/* If the folder tree and message list disagree on the current
@@ -140,6 +231,7 @@ mail_shell_view_folder_tree_selection_done_cb (EMailShellView *mail_shell_view,
 	if (g_strcmp0 (tree_uri, list_uri) != 0)
 		em_folder_tree_set_selected (folder_tree, list_uri, FALSE);
 
+	g_free (list_uri);
 	g_free (tree_uri);
 
 	/* Disconnect from the "selection-done" signal. */
@@ -748,6 +840,12 @@ e_mail_shell_view_private_dispose (EMailShellView *mail_shell_view)
 	for (ii = 0; ii < MAIL_NUM_SEARCH_RULES; ii++)
 		DISPOSE (priv->search_rules[ii]);
 
+	if (priv->opening_folder != NULL) {
+		g_cancellable_cancel (priv->opening_folder);
+		g_object_unref (priv->opening_folder);
+		priv->opening_folder = NULL;
+	}
+
 	if (priv->search_account_all != NULL) {
 		g_object_unref (priv->search_account_all);
 		priv->search_account_all = NULL;
@@ -780,7 +878,7 @@ e_mail_shell_view_restore_state (EMailShellView *mail_shell_view)
 	CamelFolder *folder;
 	CamelVeeFolder *vee_folder;
 	const gchar *old_state_group;
-	const gchar *folder_uri;
+	gchar *folder_uri;
 	gchar *new_state_group;
 
 	/* XXX Move this to EMailShellContent. */
@@ -793,9 +891,8 @@ e_mail_shell_view_restore_state (EMailShellView *mail_shell_view)
 
 	reader = E_MAIL_READER (mail_view);
 	folder = e_mail_reader_get_folder (reader);
-	folder_uri = e_mail_reader_get_folder_uri (reader);
 
-	if (folder_uri == NULL)
+	if (folder == NULL)
 		return;
 
 	/* Do not restore state if we're running a "Current Account"
@@ -810,8 +907,10 @@ e_mail_shell_view_restore_state (EMailShellView *mail_shell_view)
 	if (vee_folder != NULL && folder == CAMEL_FOLDER (vee_folder))
 		return;
 
+	folder_uri = e_mail_folder_uri_from_folder (folder);
 	new_state_group = g_strdup_printf ("Folder %s", folder_uri);
 	old_state_group = e_shell_searchbar_get_state_group (searchbar);
+	g_free (folder_uri);
 
 	/* Avoid loading search state unnecessarily. */
 	if (g_strcmp0 (new_state_group, old_state_group) != 0) {
@@ -857,7 +956,6 @@ e_mail_shell_view_create_filter_from_selected (EMailShellView *mail_shell_view,
 	EMailView *mail_view;
 	CamelFolder *folder;
 	const gchar *filter_source;
-	const gchar *folder_uri;
 	GPtrArray *uids;
 
 	struct {
@@ -879,12 +977,11 @@ e_mail_shell_view_create_filter_from_selected (EMailShellView *mail_shell_view,
 
 	reader = E_MAIL_READER (mail_view);
 	folder = e_mail_reader_get_folder (reader);
-	folder_uri = e_mail_reader_get_folder_uri (reader);
 	uids = e_mail_reader_get_selected_uids (reader);
 
-	if (em_utils_folder_is_sent (folder, folder_uri))
+	if (em_utils_folder_is_sent (folder))
 		filter_source = E_FILTER_SOURCE_OUTGOING;
-	else if (em_utils_folder_is_outbox (folder, folder_uri))
+	else if (em_utils_folder_is_outbox (folder))
 		filter_source = E_FILTER_SOURCE_OUTGOING;
 	else
 		filter_source = E_FILTER_SOURCE_INCOMING;
@@ -913,17 +1010,15 @@ mail_shell_view_create_vfolder_cb (CamelFolder *folder,
 {
 	struct {
 		EMailSession *session;
-		gchar *uri;
 		gint type;
 	} *vfolder_data = user_data;
 
 	if (message != NULL)
 		vfolder_gui_add_from_message (
 			vfolder_data->session, message,
-			vfolder_data->type, vfolder_data->uri);
+			vfolder_data->type, folder);
 
 	g_object_unref (vfolder_data->session);
-	g_free (vfolder_data->uri);
 	g_free (vfolder_data);
 }
 
@@ -939,12 +1034,10 @@ e_mail_shell_view_create_vfolder_from_selected (EMailShellView *mail_shell_view,
 	EMailReader *reader;
 	EMailView *mail_view;
 	CamelFolder *folder;
-	const gchar *folder_uri;
 	GPtrArray *uids;
 
 	struct {
 		EMailSession *session;
-		gchar *uri;
 		gint type;
 	} *vfolder_data;
 
@@ -961,13 +1054,11 @@ e_mail_shell_view_create_vfolder_from_selected (EMailShellView *mail_shell_view,
 
 	reader = E_MAIL_READER (mail_view);
 	folder = e_mail_reader_get_folder (reader);
-	folder_uri = e_mail_reader_get_folder_uri (reader);
 	uids = e_mail_reader_get_selected_uids (reader);
 
 	if (uids->len == 1) {
 		vfolder_data = g_malloc (sizeof (*vfolder_data));
 		vfolder_data->session = g_object_ref (session);
-		vfolder_data->uri = g_strdup (folder_uri);
 		vfolder_data->type = vfolder_type;
 
 		mail_get_message (
@@ -994,7 +1085,6 @@ e_mail_shell_view_update_sidebar (EMailShellView *mail_shell_view)
 	GString *buffer;
 	const gchar *display_name;
 	const gchar *folder_name;
-	const gchar *folder_uri;
 	gchar *title;
 	guint32 num_deleted;
 	guint32 num_junked;
@@ -1012,7 +1102,6 @@ e_mail_shell_view_update_sidebar (EMailShellView *mail_shell_view)
 
 	reader = E_MAIL_READER (mail_view);
 	folder = e_mail_reader_get_folder (reader);
-	folder_uri = e_mail_reader_get_folder_uri (reader);
 
 	local_store = e_mail_local_get_store ();
 
@@ -1032,7 +1121,7 @@ e_mail_shell_view_update_sidebar (EMailShellView *mail_shell_view)
 		return;
 	}
 
-	folder_name = camel_folder_get_name (folder);
+	folder_name = camel_folder_get_display_name (folder);
 	parent_store = camel_folder_get_parent_store (folder);
 
 	num_deleted = folder->summary->deleted_count;
@@ -1074,19 +1163,19 @@ e_mail_shell_view_update_sidebar (EMailShellView *mail_shell_view)
 				num_junked), num_junked);
 
 	/* "Drafts" folder */
-	} else if (em_utils_folder_is_drafts (folder, folder_uri)) {
+	} else if (em_utils_folder_is_drafts (folder)) {
 		g_string_append_printf (
 			buffer, ngettext ("%d draft", "%d drafts",
 			num_visible), num_visible);
 
 	/* "Outbox" folder */
-	} else if (em_utils_folder_is_outbox (folder, folder_uri)) {
+	} else if (em_utils_folder_is_outbox (folder)) {
 		g_string_append_printf (
 			buffer, ngettext ("%d unsent", "%d unsent",
 			num_visible), num_visible);
 
 	/* "Sent" folder */
-	} else if (em_utils_folder_is_sent (folder, folder_uri)) {
+	} else if (em_utils_folder_is_sent (folder)) {
 		g_string_append_printf (
 			buffer, ngettext ("%d sent", "%d sent",
 			num_visible), num_visible);
@@ -1171,18 +1260,12 @@ e_mail_shell_view_send_receive (EMailShellView *mail_shell_view,
 	} else {
 		/* allow only receive on individual accounts */
 		EAccount *account;
-		const gchar *source_url = NULL;
 
 		account = e_get_account_by_uid (account_uid);
 		g_return_if_fail (account != NULL);
 
 		if (account->enabled && account->source != NULL)
-			source_url = account->source->url;
-
-		if (source_url != NULL && *source_url != '\0')
-			mail_receive_uri (
-				session, source_url,
-				account->source->keep_on_server);
+			mail_receive_account (session, account);
 	}
 }
 
@@ -1537,7 +1620,7 @@ e_mail_shell_view_update_send_receive_menus (EMailShellView *mail_shell_view)
 
 	g_return_if_fail (E_IS_MAIL_SHELL_VIEW (mail_shell_view));
 
-	priv = E_MAIL_SHELL_VIEW_GET_PRIVATE (mail_shell_view);
+	priv = mail_shell_view->priv;
 
 	shell_view = E_SHELL_VIEW (mail_shell_view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
