@@ -42,10 +42,6 @@
 #include "shell/e-shell.h"
 #include "capplet/settings/mail-capplet-shell.h"
 
-#define EM_ACCOUNT_PREFS_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), EM_TYPE_ACCOUNT_PREFS, EMAccountPrefsPrivate))
-
 struct _EMAccountPrefsPrivate {
 	EMailSession *session;
 	gpointer assistant; /* weak pointer */
@@ -71,8 +67,7 @@ account_prefs_enable_account_cb (EAccountTreeView *tree_view,
 	account = e_account_tree_view_get_selected (tree_view);
 	g_return_if_fail (account != NULL);
 
-	e_mail_store_add_by_uri (
-		prefs->priv->session, account->source->url, account->name);
+	e_mail_store_add_by_account (prefs->priv->session, account);
 }
 
 static void
@@ -90,8 +85,10 @@ account_prefs_disable_account_cb (EAccountTreeView *tree_view,
 	account_list = e_account_tree_view_get_account_list (tree_view);
 	g_return_if_fail (account_list != NULL);
 
-	if (!e_account_list_account_has_proxies (account_list, account))
+	if (!e_account_list_account_has_proxies (account_list, account)) {
+		e_mail_store_remove_by_account (prefs->priv->session, account);
 		return;
+	}
 
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (tree_view));
 	parent = gtk_widget_is_toplevel (parent) ? parent : NULL;
@@ -106,8 +103,7 @@ account_prefs_disable_account_cb (EAccountTreeView *tree_view,
 
 	e_account_list_remove_account_proxies (account_list, account);
 
-	e_mail_store_remove_by_uri (
-		prefs->priv->session, account->source->url);
+	e_mail_store_remove_by_account (prefs->priv->session, account);
 }
 
 static void
@@ -160,7 +156,7 @@ account_prefs_dispose (GObject *object)
 {
 	EMAccountPrefsPrivate *priv;
 
-	priv = EM_ACCOUNT_PREFS_GET_PRIVATE (object);
+	priv = EM_ACCOUNT_PREFS (object)->priv;
 
 	if (priv->session != NULL) {
 		g_object_unref (priv->session);
@@ -190,7 +186,7 @@ account_prefs_add_account (EAccountManager *manager)
 	EMAccountEditor *emae;
 	gpointer parent;
 
-	priv = EM_ACCOUNT_PREFS_GET_PRIVATE (manager);
+	priv = EM_ACCOUNT_PREFS (manager)->priv;
 
 	if (priv->assistant != NULL) {
 		gtk_window_present (GTK_WINDOW (priv->assistant));
@@ -237,7 +233,7 @@ account_prefs_edit_account (EAccountManager *manager)
 	EAccount *account;
 	gpointer parent;
 
-	priv = EM_ACCOUNT_PREFS_GET_PRIVATE (manager);
+	priv = EM_ACCOUNT_PREFS (manager)->priv;
 
 	if (priv->editor != NULL) {
 		gtk_window_present (GTK_WINDOW (priv->editor));
@@ -284,7 +280,7 @@ account_prefs_delete_account (EAccountManager *manager)
 	gpointer parent;
 	gint response;
 
-	priv = EM_ACCOUNT_PREFS_GET_PRIVATE (manager);
+	priv = EM_ACCOUNT_PREFS (manager)->priv;
 
 	account_list = e_account_manager_get_account_list (manager);
 	tree_view = e_account_manager_get_tree_view (manager);
@@ -312,9 +308,8 @@ account_prefs_delete_account (EAccountManager *manager)
 	}
 
 	/* Remove the account from the folder tree. */
-	if (account->enabled && account->source && account->source->url)
-		e_mail_store_remove_by_uri (
-			priv->session, account->source->url);
+	if (account->enabled)
+		e_mail_store_remove_by_account (priv->session, account);
 
 	/* Remove all the proxies the account has created. */
 	if (has_proxies)
@@ -362,7 +357,8 @@ em_account_prefs_init (EMAccountPrefs *prefs)
 	EAccountManager *manager;
 	EAccountTreeView *tree_view;
 
-	prefs->priv = EM_ACCOUNT_PREFS_GET_PRIVATE (prefs);
+	prefs->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		prefs, EM_TYPE_ACCOUNT_PREFS, EMAccountPrefsPrivate);
 
 	manager = E_ACCOUNT_MANAGER (prefs);
 	tree_view = e_account_manager_get_tree_view (manager);
