@@ -155,18 +155,6 @@ em_composer_prefs_init (EMComposerPrefs *prefs)
 {
 }
 
-void
-em_composer_prefs_new_signature (GtkWindow *parent,
-                                 gboolean html_mode)
-{
-	GtkWidget *editor;
-
-	editor = e_signature_editor_new ();
-	gtkhtml_editor_set_html_mode (GTKHTML_EDITOR (editor), html_mode);
-	gtk_window_set_transient_for (GTK_WINDOW (editor), parent);
-	gtk_widget_show (editor);
-}
-
 static void
 spell_language_toggled_cb (GtkCellRendererToggle *renderer,
                            const gchar *path_string,
@@ -563,18 +551,6 @@ em_composer_prefs_construct (EMComposerPrefs *prefs,
 			widget, "prefer-html",
 			G_BINDING_SYNC_CREATE);
 
-#if 0  /* XXX Lockdown keys have moved to gsettings-desktop-schemas,
-	*     so disable lockdown integration until we're ready for
-	*     GSettings. */
-#ifndef G_OS_WIN32
-	g_object_bind_property (
-		shell_settings, "disable-command-line",
-		widget, "allow-scripts",
-		G_BINDING_SYNC_CREATE |
-		G_BINDING_INVERT_BOOLEAN);
-#endif
-#endif
-
 	signature_tree_view = e_signature_manager_get_tree_view (
 		E_SIGNATURE_MANAGER (widget));
 
@@ -584,18 +560,6 @@ em_composer_prefs_construct (EMComposerPrefs *prefs,
 	gtk_container_add (GTK_CONTAINER (container), widget);
 	gtk_widget_show (widget);
 
-#if 0  /* XXX Lockdown keys have moved to gsettings-desktop-schemas,
-	*     so disable lockdown integration until we're ready for
-	*     GSettings. */
-#ifndef G_OS_WIN32
-	g_object_bind_property (
-		shell_settings, "disable-command-line",
-		widget, "allow-scripts",
-		G_BINDING_SYNC_CREATE |
-		G_BINDING_INVERT_BOOLEAN);
-#endif
-#endif
-
 	g_object_bind_property (
 		signature_tree_view, "selected",
 		widget, "signature",
