@@ -256,7 +256,6 @@ action_plugin_manager_cb (GtkAction *action,
 	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 640, 400);
-	g_object_set (dialog, "has_separator", FALSE, NULL);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
 
 	hbox = gtk_hbox_new (FALSE, 12);
@@ -502,8 +501,8 @@ plugin_manager_constructed (GObject *object)
 
 	g_object_unref (action);
 
-	if (G_OBJECT_CLASS (e_plugin_manager_parent_class)->constructed)
-		G_OBJECT_CLASS (e_plugin_manager_parent_class)->constructed (object);
+	/* Chain up to parent's constructed() method. */
+	G_OBJECT_CLASS (e_plugin_manager_parent_class)->constructed (object);
 }
 
 static void
