@@ -576,7 +576,8 @@ dbx_import_file (DbxImporter *m)
 	gint i;
 	gint missing = 0;
 	m->status_what = NULL;
-	filename = g_filename_from_uri (((EImportTargetURI *)m->target)->uri_src, NULL, NULL);
+	filename = g_filename_from_uri (
+		((EImportTargetURI *)m->target)->uri_src, NULL, NULL);
 
 	/* Destination folder, was set in our widget */
 	m->parent_uri = g_strdup (((EImportTargetURI *)m->target)->uri_dest);
@@ -600,7 +601,8 @@ dbx_import_file (DbxImporter *m)
 
 	camel_folder_freeze (folder);
 
-	filename = g_filename_from_uri (((EImportTargetURI *)m->target)->uri_src, NULL, NULL);
+	filename = g_filename_from_uri (
+		((EImportTargetURI *)m->target)->uri_src, NULL, NULL);
 	m->dbx_fd = g_open (filename, O_RDONLY, 0);
 	g_free (filename);
 
@@ -811,13 +813,5 @@ org_gnome_evolution_readdbx_cancel (EImport *ei,
 gint
 e_plugin_lib_enable (EPlugin *ep, gint enable)
 {
-	if (enable) {
-		bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
-		bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-		g_message ("DBX Plugin enabled");
-	} else {
-		g_message ("DBX Plugin disabled");
-	}
-
 	return 0;
 }
