@@ -37,10 +37,6 @@
 #include "e-shell.h"
 #include "e-shell-view.h"
 
-#define E_SHELL_BACKEND_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_SHELL_BACKEND, EShellBackendPrivate))
-
 struct _EShellBackendPrivate {
 
 	/* We keep a reference to corresponding EShellView subclass
@@ -171,7 +167,7 @@ shell_backend_dispose (GObject *object)
 {
 	EShellBackendPrivate *priv;
 
-	priv = E_SHELL_BACKEND_GET_PRIVATE (object);
+	priv = E_SHELL_BACKEND (object)->priv;
 
 	if (priv->shell_view_class != NULL) {
 		g_type_class_unref (priv->shell_view_class);
@@ -187,7 +183,7 @@ shell_backend_finalize (GObject *object)
 {
 	EShellBackendPrivate *priv;
 
-	priv = E_SHELL_BACKEND_GET_PRIVATE (object);
+	priv = E_SHELL_BACKEND (object)->priv;
 
 	g_warn_if_fail (g_queue_is_empty (priv->activities));
 	g_queue_free (priv->activities);
@@ -294,7 +290,8 @@ e_shell_backend_class_init (EShellBackendClass *class)
 static void
 e_shell_backend_init (EShellBackend *shell_backend)
 {
-	shell_backend->priv = E_SHELL_BACKEND_GET_PRIVATE (shell_backend);
+	shell_backend->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		shell_backend, E_TYPE_SHELL_BACKEND, EShellBackendPrivate);
 	shell_backend->priv->activities = g_queue_new ();
 }
 
@@ -511,6 +508,21 @@ e_shell_backend_start (EShellBackend *shell_backend)
 	shell_backend->priv->started = TRUE;
 }
 
+/**
+ * e_shell_backend_is_started:
+ * @shell_backend: an #EShellBackend
+ *
+ * Returns whether was shelll_backend already started, by
+ * calling e_shell_backend_start().
+ **/
+gboolean
+e_shell_backend_is_started (EShellBackend *shell_backend)
+{
+	g_return_val_if_fail (E_IS_SHELL_BACKEND (shell_backend), FALSE);
+
+	return shell_backend->priv->started;
+}
+
 /**
  * e_shell_backend_migrate:
  * @shell_backend: an #EShellBackend
