@@ -37,10 +37,6 @@
 
 #include "e-shell-window-actions.h"
 
-#define E_SHELL_SEARCHBAR_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_SHELL_SEARCHBAR, EShellSearchbarPrivate))
-
 #define SEARCH_OPTION_ADVANCED		(-1)
 
 /* Default "state key file" group: [Search Bar] */
@@ -250,11 +246,11 @@ shell_searchbar_update_search_widgets (EShellSearchbar *searchbar)
 		style = gtk_widget_get_style (widget);
 		color = &style->mid[GTK_STATE_SELECTED];
 
-		gtk_widget_modify_base (widget, GTK_STATE_NORMAL, color);
+		gtk_widget_modify_bg (widget, GTK_STATE_NORMAL, color);
 		gtk_widget_modify_text (widget, GTK_STATE_NORMAL, NULL);
 	} else {
 		/* Text color will be updated when we move the focus. */
-		gtk_widget_modify_base (widget, GTK_STATE_NORMAL, NULL);
+		gtk_widget_modify_bg (widget, GTK_STATE_NORMAL, NULL);
 	}
 
 	action = E_SHELL_WINDOW_ACTION_SEARCH_CLEAR (shell_window);
@@ -631,7 +627,7 @@ shell_searchbar_dispose (GObject *object)
 {
 	EShellSearchbarPrivate *priv;
 
-	priv = E_SHELL_SEARCHBAR_GET_PRIVATE (object);
+	priv = E_SHELL_SEARCHBAR (object)->priv;
 
 	if (priv->shell_view != NULL) {
 		g_object_remove_weak_pointer (
@@ -913,7 +909,8 @@ e_shell_searchbar_init (EShellSearchbar *searchbar)
 	GtkLabel *label;
 	GtkWidget *widget;
 
-	searchbar->priv = E_SHELL_SEARCHBAR_GET_PRIVATE (searchbar);
+	searchbar->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		searchbar, E_TYPE_SHELL_SEARCHBAR, EShellSearchbarPrivate);
 
 	gtk_box_set_spacing (GTK_BOX (searchbar), 24);
 
