@@ -29,10 +29,6 @@
 
 #include "e-util/gconf-bridge.h"
 
-#define E_SHELL_SETTINGS_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_SHELL_SETTINGS, EShellSettingsPrivate))
-
 struct _EShellSettingsPrivate {
 	GArray *value_array;
 	guint debug	: 1;
@@ -60,16 +56,19 @@ shell_settings_pspec_for_key (const gchar *property_name,
 
 	entry = gconf_client_get_entry (client, gconf_key, NULL, TRUE, &error);
 	if (error != NULL) {
+		g_warning ("%s", error->message);
+		g_error_free (error);
 		return NULL;
 	}
 
 	schema_name = gconf_entry_get_schema_name (entry);
-	if (schema_name == NULL) {
-		return NULL;
-	}
+	g_return_val_if_fail (schema_name != NULL, NULL);
 
 	schema = gconf_client_get_schema (client, schema_name, &error);
 	if (error != NULL) {
+		g_warning ("%s", error->message);
+		gconf_entry_unref (entry);
+		g_error_free (error);
 		return NULL;
 	}
 
@@ -157,6 +156,7 @@ shell_settings_pspec_for_key (const gchar *property_name,
 
 	gconf_value_free (default_value);
 	gconf_schema_free (schema);
+	gconf_entry_unref (entry);
 
 	return pspec;
 
@@ -176,7 +176,7 @@ shell_settings_set_property (GObject *object,
 	EShellSettingsPrivate *priv;
 	GValue *dest_value;
 
-	priv = E_SHELL_SETTINGS_GET_PRIVATE (object);
+	priv = E_SHELL_SETTINGS (object)->priv;
 
 	dest_value = &g_array_index (
 		priv->value_array, GValue, property_id - 1);
@@ -204,7 +204,7 @@ shell_settings_get_property (GObject *object,
 	EShellSettingsPrivate *priv;
 	GValue *src_value;
 
-	priv = E_SHELL_SETTINGS_GET_PRIVATE (object);
+	priv = E_SHELL_SETTINGS (object)->priv;
 
 	src_value = &g_array_index (
 		priv->value_array, GValue, property_id - 1);
@@ -218,7 +218,7 @@ shell_settings_finalize (GObject *object)
 	EShellSettingsPrivate *priv;
 	guint ii;
 
-	priv = E_SHELL_SETTINGS_GET_PRIVATE (object);
+	priv = E_SHELL_SETTINGS (object)->priv;
 
 	for (ii = 0; ii < priv->value_array->len; ii++)
 		g_value_unset (&g_array_index (priv->value_array, GValue, ii));
@@ -256,7 +256,8 @@ shell_settings_init (EShellSettings *shell_settings,
 	value_array = g_array_new (FALSE, TRUE, sizeof (GValue));
 	g_array_set_size (value_array, property_count);
 
-	shell_settings->priv = E_SHELL_SETTINGS_GET_PRIVATE (shell_settings);
+	shell_settings->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		shell_settings, E_TYPE_SHELL_SETTINGS, EShellSettingsPrivate);
 	shell_settings->priv->value_array = value_array;
 
 	g_object_freeze_notify (G_OBJECT (shell_settings));
