@@ -22,13 +22,12 @@
 #include "e-shell-window-private.h"
 #include "e-preferences-window.h"
 
-#include <e-util/e-util-private.h>
 #include <e-util/e-dialog-utils.h>
-#include <e-util/e-alert-dialog.h>
 #include <e-util/e-print.h>
 #include <gal-define-views-dialog.h>
 
 #include <libedataserverui/e-passwords.h>
+#include <libedataserverui/e-categories-editor.h>
 
 #define EVOLUTION_COPYRIGHT \
 	"Copyright \xC2\xA9 1999 - 2008 Novell, Inc. and Others"
@@ -894,6 +893,42 @@ action_page_setup_cb (GtkAction *action,
 	e_print_run_page_setup_dialog (GTK_WINDOW (shell_window));
 }
 
+/**
+ * E_SHELL_WINDOW_ACTION_CATEGORIES
+ * @window: and #EShellWindow
+ *
+ * Activation of this action opens the Categories Editor dialog.
+ *
+ * Main menu item: Edit -> Available categories
+ **/
+static void
+action_categories_cb (GtkAction *action,
+                      EShellWindow *shell_window)
+{
+	GtkWidget *content_area;
+	GtkWidget *dialog;
+	GtkWidget *editor;
+
+	editor = e_categories_editor_new ();
+	e_categories_editor_set_entry_visible (
+		E_CATEGORIES_EDITOR (editor), FALSE);
+
+	dialog = gtk_dialog_new_with_buttons (
+		_("Categories Editor"),
+		GTK_WINDOW (shell_window),
+		GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 12);
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+	gtk_box_pack_start (
+		GTK_BOX (content_area), GTK_WIDGET (editor), TRUE, TRUE, 6);
+	gtk_box_set_spacing (GTK_BOX (content_area), 12);
+
+	gtk_dialog_run (GTK_DIALOG (dialog));
+
+	gtk_widget_destroy (dialog);
+}
+
 /**
  * E_SHELL_WINDOW_ACTION_PREFERENCES:
  * @window: an #EShellWindow
@@ -915,6 +950,7 @@ action_preferences_cb (GtkAction *action,
 
 	shell = e_shell_window_get_shell (shell_window);
 	preferences_window = e_shell_get_preferences_window (shell);
+	e_preferences_window_setup (E_PREFERENCES_WINDOW (preferences_window));
 
 	gtk_window_set_transient_for (
 		GTK_WINDOW (preferences_window),
@@ -931,15 +967,14 @@ action_preferences_cb (GtkAction *action,
 	shell_backend_class = E_SHELL_BACKEND_GET_CLASS (shell_backend);
 
 	if (shell_backend_class->preferences_page != NULL) {
-		if (e_shell_get_express_mode (shell)) {
+		if (e_shell_get_express_mode (shell))
 			e_preferences_window_filter_page (
 				E_PREFERENCES_WINDOW (preferences_window),
 				shell_backend_class->preferences_page);
-		} else {
+		else
 			e_preferences_window_show_page (
 				E_PREFERENCES_WINDOW (preferences_window),
 				shell_backend_class->preferences_page);
-		}
 	}
 }
 
@@ -1153,24 +1188,6 @@ action_search_save_cb (GtkAction *action,
 	e_shell_window_update_search_menu (shell_window);
 }
 
-/**
- * E_SHELL_WINDOW_ACTION_SEND_RECEIVE:
- * @window: an #EShellWindow
- *
- * Activation of this action opens the Send &amp; Receive Mail dialog.
- *
- * Main menu item: File -> Send / Receive
- **/
-static void
-action_send_receive_cb (GtkAction *action,
-                        EShellWindow *shell_window)
-{
-	EShell *shell;
-
-	shell = e_shell_window_get_shell (shell_window);
-	e_shell_send_receive (shell, GTK_WINDOW (shell_window));
-}
-
 /**
  * E_SHELL_WINDOW_ACTION_SHOW_SIDEBAR:
  * @window: an #EShellWindow
@@ -1502,6 +1519,13 @@ static GtkActionEntry shell_entries[] = {
 	  N_("Paste the clipboard"),
 	  NULL },  /* Handled by EFocusTracker */
 
+	{ "categories",
+	  NULL,
+	  N_("Available Cate_gories"),
+	  NULL,
+	  N_("Manage available categories"),
+	  G_CALLBACK (action_categories_cb) },
+
 	{ "preferences",
 	  GTK_STOCK_PREFERENCES,
 	  NULL,
@@ -1572,13 +1596,6 @@ static GtkActionEntry shell_entries[] = {
 	  N_("Select all text"),
 	  NULL },  /* Handled by EFocusTracker */
 
-	{ "send-receive",
-	  "mail-send-receive",
-	  N_("Send / _Receive"),
-	  "F9",
-	  N_("Send queued items and retrieve new items"),
-	  G_CALLBACK (action_send_receive_cb) },
-
 	{ "submit-bug",
 	  NULL,
 	  N_("Submit _Bug Report..."),
@@ -1934,47 +1951,59 @@ e_shell_window_actions_init (EShellWindow *shell_window)
 
 	gtk_action_set_sensitive (ACTION (SEARCH_QUICK), FALSE);
 
-	g_object_set (ACTION (SEND_RECEIVE), "is-important", TRUE, NULL);
-
-	e_mutual_binding_new (
+	g_object_bind_property (
 		shell_window, "sidebar-visible",
-		ACTION (SHOW_SIDEBAR), "active");
+		ACTION (SHOW_SIDEBAR), "active",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		shell_window, "switcher-visible",
-		ACTION (SHOW_SWITCHER), "active");
+		ACTION (SHOW_SWITCHER), "active",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		shell_window, "taskbar-visible",
-		ACTION (SHOW_TASKBAR), "active");
+		ACTION (SHOW_TASKBAR), "active",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		shell_window, "toolbar-visible",
-		ACTION (SHOW_TOOLBAR), "active");
+		ACTION (SHOW_TOOLBAR), "active",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_binding_new (
+	g_object_bind_property (
 		ACTION (SHOW_SIDEBAR), "active",
-		ACTION (SHOW_SWITCHER), "sensitive");
+		ACTION (SHOW_SWITCHER), "sensitive",
+		G_BINDING_SYNC_CREATE);
 
-	e_binding_new (
+	g_object_bind_property (
 		ACTION (SHOW_SIDEBAR), "active",
-		ACTION (SWITCHER_STYLE_BOTH), "sensitive");
+		ACTION (SWITCHER_STYLE_BOTH), "sensitive",
+		G_BINDING_SYNC_CREATE);
 
-	e_binding_new (
+	g_object_bind_property (
 		ACTION (SHOW_SIDEBAR), "active",
-		ACTION (SWITCHER_STYLE_ICONS), "sensitive");
+		ACTION (SWITCHER_STYLE_ICONS), "sensitive",
+		G_BINDING_SYNC_CREATE);
 
-	e_binding_new (
+	g_object_bind_property (
 		ACTION (SHOW_SIDEBAR), "active",
-		ACTION (SWITCHER_STYLE_TEXT), "sensitive");
+		ACTION (SWITCHER_STYLE_TEXT), "sensitive",
+		G_BINDING_SYNC_CREATE);
 
-	e_binding_new (
+	g_object_bind_property (
 		ACTION (SHOW_SIDEBAR), "active",
-		ACTION (SWITCHER_STYLE_USER), "sensitive");
+		ACTION (SWITCHER_STYLE_USER), "sensitive",
+		G_BINDING_SYNC_CREATE);
 
-	e_binding_new (
+	g_object_bind_property (
 		ACTION (SHOW_SIDEBAR), "active",
-		ACTION (SWITCHER_MENU), "sensitive");
+		ACTION (SWITCHER_MENU), "sensitive",
+		G_BINDING_SYNC_CREATE);
 
 	/* Submitting bug reports requires bug-buddy. */
 	path = g_find_program_in_path ("bug-buddy");
@@ -2266,6 +2295,7 @@ e_shell_window_update_view_menu (EShellWindow *shell_window)
 	/* Unmerge the previous menu. */
 	gtk_ui_manager_remove_ui (ui_manager, merge_id);
 	e_action_group_remove_all_actions (action_group);
+	gtk_ui_manager_ensure_update (ui_manager);
 
 	/* We have a view ID, so forge ahead. */
 	count = gal_view_collection_get_count (view_collection);
@@ -2376,6 +2406,7 @@ e_shell_window_update_search_menu (EShellWindow *shell_window)
 	/* Unmerge the previous menu. */
 	gtk_ui_manager_remove_ui (ui_manager, merge_id);
 	e_action_group_remove_all_actions (action_group);
+	gtk_ui_manager_ensure_update (ui_manager);
 
 	rule = e_rule_context_next_rule (context, NULL, source);
 	while (rule != NULL) {
