@@ -22,10 +22,6 @@
 
 #include <glib/gi18n.h>
 
-#define E_ACTION_COMBO_BOX_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_ACTION_COMBO_BOX, EActionComboBoxPrivate))
-
 enum {
 	COLUMN_ACTION,
 	COLUMN_SORT
@@ -130,6 +126,7 @@ action_combo_box_render_pixbuf (GtkCellLayout *layout,
 		g_object_set (
 			G_OBJECT (renderer),
 			"sensitive", sensitive,
+			"icon-name", NULL,
 			"stock-id", stock_id,
 			"stock-size", GTK_ICON_SIZE_MENU,
 			"visible", visible,
@@ -138,8 +135,9 @@ action_combo_box_render_pixbuf (GtkCellLayout *layout,
 	else
 		g_object_set (
 			G_OBJECT (renderer),
-			"icon-name", icon_name,
 			"sensitive", sensitive,
+			"icon-name", icon_name,
+			"stock-id", NULL,
 			"stock-size", GTK_ICON_SIZE_MENU,
 			"visible", visible,
 			"width", width,
@@ -317,7 +315,7 @@ action_combo_box_get_property (GObject *object,
 static void
 action_combo_box_dispose (GObject *object)
 {
-	EActionComboBoxPrivate *priv = E_ACTION_COMBO_BOX_GET_PRIVATE (object);
+	EActionComboBoxPrivate *priv = E_ACTION_COMBO_BOX (object)->priv;
 
 	if (priv->action != NULL) {
 		g_object_unref (priv->action);
@@ -338,7 +336,7 @@ action_combo_box_dispose (GObject *object)
 static void
 action_combo_box_finalize (GObject *object)
 {
-	EActionComboBoxPrivate *priv = E_ACTION_COMBO_BOX_GET_PRIVATE (object);
+	EActionComboBoxPrivate *priv = E_ACTION_COMBO_BOX (object)->priv;
 
 	g_hash_table_destroy (priv->index);
 
@@ -346,6 +344,38 @@ action_combo_box_finalize (GObject *object)
 	G_OBJECT_CLASS (e_action_combo_box_parent_class)->finalize (object);
 }
 
+static void
+action_combo_box_constructed (GObject *object)
+{
+	GtkComboBox *combo_box;
+	GtkCellRenderer *renderer;
+
+	combo_box = GTK_COMBO_BOX (object);
+
+	/* This needs to happen after constructor properties are set
+	 * so that GtkCellLayout.get_area() returns something valid. */
+
+	renderer = gtk_cell_renderer_pixbuf_new ();
+	gtk_cell_layout_pack_start (
+		GTK_CELL_LAYOUT (combo_box), renderer, FALSE);
+	gtk_cell_layout_set_cell_data_func (
+		GTK_CELL_LAYOUT (combo_box), renderer,
+		(GtkCellLayoutDataFunc) action_combo_box_render_pixbuf,
+		combo_box, NULL);
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (
+		GTK_CELL_LAYOUT (combo_box), renderer, TRUE);
+	gtk_cell_layout_set_cell_data_func (
+		GTK_CELL_LAYOUT (combo_box), renderer,
+		(GtkCellLayoutDataFunc) action_combo_box_render_text,
+		combo_box, NULL);
+
+	gtk_combo_box_set_row_separator_func (
+		combo_box, (GtkTreeViewRowSeparatorFunc)
+		action_combo_box_is_row_separator, NULL, NULL);
+}
+
 static void
 action_combo_box_changed (GtkComboBox *combo_box)
 {
@@ -378,6 +408,7 @@ e_action_combo_box_class_init (EActionComboBoxClass *class)
 	object_class->get_property = action_combo_box_get_property;
 	object_class->dispose = action_combo_box_dispose;
 	object_class->finalize = action_combo_box_finalize;
+	object_class->constructed = action_combo_box_constructed;
 
 	combo_box_class = GTK_COMBO_BOX_CLASS (class);
 	combo_box_class->changed = action_combo_box_changed;
@@ -396,29 +427,8 @@ e_action_combo_box_class_init (EActionComboBoxClass *class)
 static void
 e_action_combo_box_init (EActionComboBox *combo_box)
 {
-	GtkCellRenderer *renderer;
-
-	combo_box->priv = E_ACTION_COMBO_BOX_GET_PRIVATE (combo_box);
-
-	renderer = gtk_cell_renderer_pixbuf_new ();
-	gtk_cell_layout_pack_start (
-		GTK_CELL_LAYOUT (combo_box), renderer, FALSE);
-	gtk_cell_layout_set_cell_data_func (
-		GTK_CELL_LAYOUT (combo_box), renderer,
-		(GtkCellLayoutDataFunc) action_combo_box_render_pixbuf,
-		combo_box, NULL);
-
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (
-		GTK_CELL_LAYOUT (combo_box), renderer, TRUE);
-	gtk_cell_layout_set_cell_data_func (
-		GTK_CELL_LAYOUT (combo_box), renderer,
-		(GtkCellLayoutDataFunc) action_combo_box_render_text,
-		combo_box, NULL);
-
-	gtk_combo_box_set_row_separator_func (
-		GTK_COMBO_BOX (combo_box), (GtkTreeViewRowSeparatorFunc)
-		action_combo_box_is_row_separator, NULL, NULL);
+	combo_box->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		combo_box, E_TYPE_ACTION_COMBO_BOX, EActionComboBoxPrivate);
 
 	combo_box->priv->index = g_hash_table_new_full (
 		g_direct_hash, g_direct_equal,
