@@ -30,7 +30,10 @@
 
 #include "e-selection-model-array.h"
 
-G_DEFINE_TYPE (ESelectionModelArray, e_selection_model_array, e_selection_model_get_type())
+G_DEFINE_TYPE (
+	ESelectionModelArray,
+	e_selection_model_array,
+	E_TYPE_SELECTION_MODEL)
 
 enum {
 	PROP_0,
@@ -39,11 +42,11 @@ enum {
 };
 
 void
-e_selection_model_array_confirm_row_count(ESelectionModelArray *esma)
+e_selection_model_array_confirm_row_count (ESelectionModelArray *esma)
 {
 	if (esma->eba == NULL) {
-		gint row_count = e_selection_model_array_get_row_count(esma);
-		esma->eba = e_bit_array_new(row_count);
+		gint row_count = e_selection_model_array_get_row_count (esma);
+		esma->eba = e_bit_array_new (row_count);
 		esma->selected_row = -1;
 		esma->selected_range_end = -1;
 	}
@@ -69,13 +72,13 @@ es_row_sorted_to_model (ESelectionModelArray *esma, gint sorted_row)
 
 /* FIXME: Should this deal with moving the selection if it's in single mode? */
 void
-e_selection_model_array_delete_rows(ESelectionModelArray *esma, gint row, gint count)
+e_selection_model_array_delete_rows (ESelectionModelArray *esma, gint row, gint count)
 {
 	if (esma->eba) {
-		if (E_SELECTION_MODEL(esma)->mode == GTK_SELECTION_SINGLE)
-			e_bit_array_delete_single_mode(esma->eba, row, count);
+		if (E_SELECTION_MODEL (esma)->mode == GTK_SELECTION_SINGLE)
+			e_bit_array_delete_single_mode (esma->eba, row, count);
 		else
-			e_bit_array_delete(esma->eba, row, count);
+			e_bit_array_delete (esma->eba, row, count);
 
 		if (esma->cursor_row >= row && esma->cursor_row < row + count) {
 			/* we should move the cursor_row, because some lines before us are going to be removed */
@@ -113,34 +116,34 @@ e_selection_model_array_delete_rows(ESelectionModelArray *esma, gint row, gint c
 
 		esma->selected_row = -1;
 		esma->selected_range_end = -1;
-		e_selection_model_selection_changed(E_SELECTION_MODEL(esma));
-		e_selection_model_cursor_changed(E_SELECTION_MODEL(esma), esma->cursor_row, esma->cursor_col);
+		e_selection_model_selection_changed (E_SELECTION_MODEL (esma));
+		e_selection_model_cursor_changed (E_SELECTION_MODEL (esma), esma->cursor_row, esma->cursor_col);
 	}
 }
 
 void
-e_selection_model_array_insert_rows(ESelectionModelArray *esma, gint row, gint count)
+e_selection_model_array_insert_rows (ESelectionModelArray *esma, gint row, gint count)
 {
 	if (esma->eba) {
-		e_bit_array_insert(esma->eba, row, count);
+		e_bit_array_insert (esma->eba, row, count);
 
 		/* just recalculate new position of the previously set cursor row */
 		esma->cursor_row = es_row_sorted_to_model (esma, esma->cursor_row_sorted);
 
 		esma->selected_row = -1;
 		esma->selected_range_end = -1;
-		e_selection_model_selection_changed(E_SELECTION_MODEL(esma));
-		e_selection_model_cursor_changed(E_SELECTION_MODEL(esma), esma->cursor_row, esma->cursor_col);
+		e_selection_model_selection_changed (E_SELECTION_MODEL (esma));
+		e_selection_model_cursor_changed (E_SELECTION_MODEL (esma), esma->cursor_row, esma->cursor_col);
 	}
 }
 
 void
-e_selection_model_array_move_row(ESelectionModelArray *esma, gint old_row, gint new_row)
+e_selection_model_array_move_row (ESelectionModelArray *esma, gint old_row, gint new_row)
 {
-	ESelectionModel *esm = E_SELECTION_MODEL(esma);
+	ESelectionModel *esm = E_SELECTION_MODEL (esma);
 
 	if (esma->eba) {
-		gboolean selected = e_bit_array_value_at(esma->eba, old_row);
+		gboolean selected = e_bit_array_value_at (esma->eba, old_row);
 		gboolean cursor = (esma->cursor_row == old_row);
 		gint old_row_sorted, new_row_sorted;
 
@@ -152,13 +155,13 @@ e_selection_model_array_move_row(ESelectionModelArray *esma, gint old_row, gint
 		else if (new_row_sorted < esma->cursor_row_sorted && esma->cursor_row_sorted < old_row_sorted)
 			esma->cursor_row_sorted++;
 
-		e_bit_array_move_row(esma->eba, old_row, new_row);
+		e_bit_array_move_row (esma->eba, old_row, new_row);
 
 		if (selected) {
 			if (esm->mode == GTK_SELECTION_SINGLE)
 				e_bit_array_select_single_row (esma->eba, new_row);
 			else
-				e_bit_array_change_one_row(esma->eba, new_row, TRUE);
+				e_bit_array_change_one_row (esma->eba, new_row, TRUE);
 		}
 		if (cursor) {
 			esma->cursor_row = new_row;
@@ -168,8 +171,8 @@ e_selection_model_array_move_row(ESelectionModelArray *esma, gint old_row, gint
 
 		esma->selected_row = -1;
 		esma->selected_range_end = -1;
-		e_selection_model_selection_changed(esm);
-		e_selection_model_cursor_changed(esm, esma->cursor_row, esma->cursor_col);
+		e_selection_model_selection_changed (esm);
+		e_selection_model_cursor_changed (esm, esma->cursor_row, esma->cursor_col);
 	}
 }
 
@@ -185,8 +188,8 @@ esma_dispose (GObject *object)
 		esma->eba = NULL;
 	}
 
-	if (G_OBJECT_CLASS (e_selection_model_array_parent_class)->dispose)
-		(* G_OBJECT_CLASS (e_selection_model_array_parent_class)->dispose) (object);
+	/* Chain up to parent's dispose() method. */
+	G_OBJECT_CLASS (e_selection_model_array_parent_class)->dispose (object);
 }
 
 static void
@@ -213,11 +216,11 @@ esma_set_property (GObject *object, guint prop_id, const GValue *value, GParamSp
 
 	switch (prop_id) {
 	case PROP_CURSOR_ROW:
-		e_selection_model_do_something(esm, g_value_get_int (value), esma->cursor_col, 0);
+		e_selection_model_do_something (esm, g_value_get_int (value), esma->cursor_col, 0);
 		break;
 
 	case PROP_CURSOR_COL:
-		e_selection_model_do_something(esm, esma->cursor_row, g_value_get_int(value), 0);
+		e_selection_model_do_something (esm, esma->cursor_row, g_value_get_int (value), 0);
 		break;
 	}
 }
@@ -235,9 +238,9 @@ static gboolean
 esma_is_row_selected (ESelectionModel *selection,
 		      gint             n)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 	if (esma->eba)
-		return e_bit_array_value_at(esma->eba, n);
+		return e_bit_array_value_at (esma->eba, n);
 	else
 		return FALSE;
 }
@@ -256,9 +259,9 @@ esma_foreach (ESelectionModel *selection,
 	      EForeachFunc     callback,
 	      gpointer         closure)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 	if (esma->eba)
-		e_bit_array_foreach(esma->eba, callback, closure);
+		e_bit_array_foreach (esma->eba, callback, closure);
 }
 
 /**
@@ -268,11 +271,11 @@ esma_foreach (ESelectionModel *selection,
  * This routine clears the selection to no rows selected.
  */
 static void
-esma_clear(ESelectionModel *selection)
+esma_clear (ESelectionModel *selection)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 	if (esma->eba) {
-		g_object_unref(esma->eba);
+		g_object_unref (esma->eba);
 		esma->eba = NULL;
 	}
 	esma->cursor_row = -1;
@@ -280,8 +283,8 @@ esma_clear(ESelectionModel *selection)
 	esma->cursor_row_sorted = -1;
 	esma->selected_row = -1;
 	esma->selected_range_end = -1;
-	e_selection_model_selection_changed(E_SELECTION_MODEL(esma));
-	e_selection_model_cursor_changed(E_SELECTION_MODEL(esma), -1, -1);
+	e_selection_model_selection_changed (E_SELECTION_MODEL (esma));
+	e_selection_model_cursor_changed (E_SELECTION_MODEL (esma), -1, -1);
 }
 
 #define PART(x,n) (((x) & (0x01010101 << n)) >> n)
@@ -298,9 +301,9 @@ esma_clear(ESelectionModel *selection)
 static gint
 esma_selected_count (ESelectionModel *selection)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 	if (esma->eba)
-		return e_bit_array_selected_count(esma->eba);
+		return e_bit_array_selected_count (esma->eba);
 	else
 		return 0;
 }
@@ -315,11 +318,11 @@ esma_selected_count (ESelectionModel *selection)
 static void
 esma_select_all (ESelectionModel *selection)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 
-	e_selection_model_array_confirm_row_count(esma);
+	e_selection_model_array_confirm_row_count (esma);
 
-	e_bit_array_select_all(esma->eba);
+	e_bit_array_select_all (esma->eba);
 
 	esma->cursor_col = 0;
 	esma->cursor_row_sorted = 0;
@@ -327,8 +330,8 @@ esma_select_all (ESelectionModel *selection)
 	esma->selection_start_row = esma->cursor_row;
 	esma->selected_row = -1;
 	esma->selected_range_end = -1;
-	e_selection_model_selection_changed(E_SELECTION_MODEL(esma));
-	e_selection_model_cursor_changed(E_SELECTION_MODEL(esma), 0, 0);
+	e_selection_model_selection_changed (E_SELECTION_MODEL (esma));
+	e_selection_model_cursor_changed (E_SELECTION_MODEL (esma), 0, 0);
 }
 
 /**
@@ -341,11 +344,11 @@ esma_select_all (ESelectionModel *selection)
 static void
 esma_invert_selection (ESelectionModel *selection)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 
-	e_selection_model_array_confirm_row_count(esma);
+	e_selection_model_array_confirm_row_count (esma);
 
-	e_bit_array_invert_selection(esma->eba);
+	e_bit_array_invert_selection (esma->eba);
 
 	esma->cursor_col = -1;
 	esma->cursor_row = -1;
@@ -353,24 +356,24 @@ esma_invert_selection (ESelectionModel *selection)
 	esma->selection_start_row = 0;
 	esma->selected_row = -1;
 	esma->selected_range_end = -1;
-	e_selection_model_selection_changed(E_SELECTION_MODEL(esma));
-	e_selection_model_cursor_changed(E_SELECTION_MODEL(esma), -1, -1);
+	e_selection_model_selection_changed (E_SELECTION_MODEL (esma));
+	e_selection_model_cursor_changed (E_SELECTION_MODEL (esma), -1, -1);
 }
 
 static gint
 esma_row_count (ESelectionModel *selection)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
-	e_selection_model_array_confirm_row_count(esma);
-	return e_bit_array_bit_count(esma->eba);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
+	e_selection_model_array_confirm_row_count (esma);
+	return e_bit_array_bit_count (esma->eba);
 }
 
 static void
-esma_change_one_row(ESelectionModel *selection, gint row, gboolean grow)
+esma_change_one_row (ESelectionModel *selection, gint row, gboolean grow)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
-	e_selection_model_array_confirm_row_count(esma);
-	e_bit_array_change_one_row(esma->eba, row, grow);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
+	e_selection_model_array_confirm_row_count (esma);
+	e_bit_array_change_one_row (esma->eba, row, grow);
 }
 
 static void
@@ -378,10 +381,10 @@ esma_change_cursor (ESelectionModel *selection, gint row, gint col)
 {
 	ESelectionModelArray *esma;
 
-	g_return_if_fail(selection != NULL);
-	g_return_if_fail(E_IS_SELECTION_MODEL(selection));
+	g_return_if_fail (selection != NULL);
+	g_return_if_fail (E_IS_SELECTION_MODEL (selection));
 
-	esma = E_SELECTION_MODEL_ARRAY(selection);
+	esma = E_SELECTION_MODEL_ARRAY (selection);
 
 	esma->cursor_row = row;
 	esma->cursor_col = col;
@@ -389,18 +392,18 @@ esma_change_cursor (ESelectionModel *selection, gint row, gint col)
 }
 
 static void
-esma_change_range(ESelectionModel *selection, gint start, gint end, gboolean grow)
+esma_change_range (ESelectionModel *selection, gint start, gint end, gboolean grow)
 {
 	gint i;
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 	if (start != end) {
-		if (selection->sorter && e_sorter_needs_sorting(selection->sorter)) {
+		if (selection->sorter && e_sorter_needs_sorting (selection->sorter)) {
 			for ( i = start; i < end; i++) {
-				e_bit_array_change_one_row(esma->eba, e_sorter_sorted_to_model(selection->sorter, i), grow);
+				e_bit_array_change_one_row (esma->eba, e_sorter_sorted_to_model (selection->sorter, i), grow);
 			}
 		} else {
-			e_selection_model_array_confirm_row_count(esma);
-			e_bit_array_change_range(esma->eba, start, end, grow);
+			e_selection_model_array_confirm_row_count (esma);
+			e_bit_array_change_range (esma->eba, start, end, grow);
 		}
 	}
 }
@@ -408,25 +411,25 @@ esma_change_range(ESelectionModel *selection, gint start, gint end, gboolean gro
 static gint
 esma_cursor_row (ESelectionModel *selection)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 	return esma->cursor_row;
 }
 
 static gint
 esma_cursor_col (ESelectionModel *selection)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 	return esma->cursor_col;
 }
 
 static void
 esma_real_select_single_row (ESelectionModel *selection, gint row)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 
-	e_selection_model_array_confirm_row_count(esma);
+	e_selection_model_array_confirm_row_count (esma);
 
-	e_bit_array_select_single_row(esma->eba, row);
+	e_bit_array_select_single_row (esma->eba, row);
 
 	esma->selection_start_row = row;
 	esma->selected_row = row;
@@ -436,51 +439,51 @@ esma_real_select_single_row (ESelectionModel *selection, gint row)
 static void
 esma_select_single_row (ESelectionModel *selection, gint row)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 	gint selected_row = esma->selected_row;
 	esma_real_select_single_row (selection, row);
 
 	if (selected_row != -1 && esma->eba && selected_row < e_bit_array_bit_count (esma->eba)) {
 		if (selected_row != row) {
-			e_selection_model_selection_row_changed(selection, selected_row);
-			e_selection_model_selection_row_changed(selection, row);
+			e_selection_model_selection_row_changed (selection, selected_row);
+			e_selection_model_selection_row_changed (selection, row);
 		}
 	} else {
-		e_selection_model_selection_changed(selection);
+		e_selection_model_selection_changed (selection);
 	}
 }
 
 static void
 esma_toggle_single_row (ESelectionModel *selection, gint row)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 
-	e_selection_model_array_confirm_row_count(esma);
-	e_bit_array_toggle_single_row(esma->eba, row);
+	e_selection_model_array_confirm_row_count (esma);
+	e_bit_array_toggle_single_row (esma->eba, row);
 
 	esma->selection_start_row = row;
 	esma->selected_row = -1;
 	esma->selected_range_end = -1;
-	e_selection_model_selection_row_changed(E_SELECTION_MODEL(esma), row);
+	e_selection_model_selection_row_changed (E_SELECTION_MODEL (esma), row);
 }
 
 static void
 esma_real_move_selection_end (ESelectionModel *selection, gint row)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 	gint old_start;
 	gint old_end;
 	gint new_start;
 	gint new_end;
-	if (selection->sorter && e_sorter_needs_sorting(selection->sorter)) {
-		old_start = MIN (e_sorter_model_to_sorted(selection->sorter, esma->selection_start_row),
-				 e_sorter_model_to_sorted(selection->sorter, esma->cursor_row));
-		old_end = MAX (e_sorter_model_to_sorted(selection->sorter, esma->selection_start_row),
-			       e_sorter_model_to_sorted(selection->sorter, esma->cursor_row)) + 1;
-		new_start = MIN (e_sorter_model_to_sorted(selection->sorter, esma->selection_start_row),
-				 e_sorter_model_to_sorted(selection->sorter, row));
-		new_end = MAX (e_sorter_model_to_sorted(selection->sorter, esma->selection_start_row),
-			       e_sorter_model_to_sorted(selection->sorter, row)) + 1;
+	if (selection->sorter && e_sorter_needs_sorting (selection->sorter)) {
+		old_start = MIN (e_sorter_model_to_sorted (selection->sorter, esma->selection_start_row),
+				 e_sorter_model_to_sorted (selection->sorter, esma->cursor_row));
+		old_end = MAX (e_sorter_model_to_sorted (selection->sorter, esma->selection_start_row),
+			       e_sorter_model_to_sorted (selection->sorter, esma->cursor_row)) + 1;
+		new_start = MIN (e_sorter_model_to_sorted (selection->sorter, esma->selection_start_row),
+				 e_sorter_model_to_sorted (selection->sorter, row));
+		new_end = MAX (e_sorter_model_to_sorted (selection->sorter, esma->selection_start_row),
+			       e_sorter_model_to_sorted (selection->sorter, row)) + 1;
 	} else {
 		old_start = MIN (esma->selection_start_row, esma->cursor_row);
 		old_end = MAX (esma->selection_start_row, esma->cursor_row) + 1;
@@ -489,13 +492,13 @@ esma_real_move_selection_end (ESelectionModel *selection, gint row)
 	}
 	/* This wouldn't work nearly so smoothly if one end of the selection weren't held in place. */
 	if (old_start < new_start)
-		esma_change_range(selection, old_start, new_start, FALSE);
+		esma_change_range (selection, old_start, new_start, FALSE);
 	if (new_start < old_start)
-		esma_change_range(selection, new_start, old_start, TRUE);
+		esma_change_range (selection, new_start, old_start, TRUE);
 	if (old_end < new_end)
-		esma_change_range(selection, old_end, new_end, TRUE);
+		esma_change_range (selection, old_end, new_end, TRUE);
 	if (new_end < old_end)
-		esma_change_range(selection, new_end, old_end, FALSE);
+		esma_change_range (selection, new_end, old_end, FALSE);
 	esma->selected_row = -1;
 	esma->selected_range_end = -1;
 }
@@ -504,40 +507,40 @@ static void
 esma_move_selection_end (ESelectionModel *selection, gint row)
 {
 	esma_real_move_selection_end (selection, row);
-	e_selection_model_selection_changed(selection);
+	e_selection_model_selection_changed (selection);
 }
 
 static void
 esma_set_selection_end (ESelectionModel *selection, gint row)
 {
-	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY(selection);
+	ESelectionModelArray *esma = E_SELECTION_MODEL_ARRAY (selection);
 	gint selected_range_end = esma->selected_range_end;
-	gint view_row = e_sorter_model_to_sorted(selection->sorter, row);
+	gint view_row = e_sorter_model_to_sorted (selection->sorter, row);
 
-	esma_real_select_single_row(selection, esma->selection_start_row);
+	esma_real_select_single_row (selection, esma->selection_start_row);
 	esma->cursor_row = esma->selection_start_row;
 	esma->cursor_row_sorted = es_row_model_to_sorted (esma, esma->cursor_row);
-	esma_real_move_selection_end(selection, row);
+	esma_real_move_selection_end (selection, row);
 
 	esma->selected_range_end = view_row;
 	if (selected_range_end != -1 && view_row != -1) {
 		if (selected_range_end == view_row - 1 ||
 		    selected_range_end == view_row + 1) {
-			e_selection_model_selection_row_changed(selection, selected_range_end);
-			e_selection_model_selection_row_changed(selection, view_row);
+			e_selection_model_selection_row_changed (selection, selected_range_end);
+			e_selection_model_selection_row_changed (selection, view_row);
 		}
 	}
-	e_selection_model_selection_changed(selection);
+	e_selection_model_selection_changed (selection);
 }
 
 gint
 e_selection_model_array_get_row_count (ESelectionModelArray *esma)
 {
-	g_return_val_if_fail(esma != NULL, 0);
-	g_return_val_if_fail(E_IS_SELECTION_MODEL_ARRAY(esma), 0);
+	g_return_val_if_fail (esma != NULL, 0);
+	g_return_val_if_fail (E_IS_SELECTION_MODEL_ARRAY (esma), 0);
 
-	if (E_SELECTION_MODEL_ARRAY_GET_CLASS(esma)->get_row_count)
-		return E_SELECTION_MODEL_ARRAY_GET_CLASS(esma)->get_row_count (esma);
+	if (E_SELECTION_MODEL_ARRAY_GET_CLASS (esma)->get_row_count)
+		return E_SELECTION_MODEL_ARRAY_GET_CLASS (esma)->get_row_count (esma);
 	else
 		return 0;
 }
@@ -561,8 +564,8 @@ e_selection_model_array_class_init (ESelectionModelArrayClass *klass)
 	GObjectClass *object_class;
 	ESelectionModelClass *esm_class;
 
-	object_class = G_OBJECT_CLASS(klass);
-	esm_class = E_SELECTION_MODEL_CLASS(klass);
+	object_class = G_OBJECT_CLASS (klass);
+	esm_class = E_SELECTION_MODEL_CLASS (klass);
 
 	object_class->dispose = esma_dispose;
 	object_class->get_property = esma_get_property;
