@@ -29,10 +29,6 @@
 #include <e-util/e-signature-utils.h>
 #include <misc/e-web-view.h>
 
-#define E_SIGNATURE_EDITOR_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_SIGNATURE_EDITOR, ESignatureEditorPrivate))
-
 enum {
 	PROP_0,
 	PROP_FOCUS_TRACKER,
@@ -283,7 +279,7 @@ signature_editor_dispose (GObject *object)
 {
 	ESignatureEditorPrivate *priv;
 
-	priv = E_SIGNATURE_EDITOR_GET_PRIVATE (object);
+	priv = E_SIGNATURE_EDITOR (object)->priv;
 
 	if (priv->action_group != NULL) {
 		g_object_unref (priv->action_group);
@@ -314,7 +310,7 @@ signature_editor_finalize (GObject *object)
 {
 	ESignatureEditorPrivate *priv;
 
-	priv = E_SIGNATURE_EDITOR_GET_PRIVATE (object);
+	priv = E_SIGNATURE_EDITOR (object)->priv;
 
 	g_free (priv->original_name);
 
@@ -400,7 +396,8 @@ e_signature_editor_init (ESignatureEditor *editor)
 	GtkWidget *vbox;
 	GError *error = NULL;
 
-	editor->priv = E_SIGNATURE_EDITOR_GET_PRIVATE (editor);
+	editor->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		editor, E_TYPE_SIGNATURE_EDITOR, ESignatureEditorPrivate);
 	vbox = GTKHTML_EDITOR (editor)->vbox;
 
 	gtkhtml_editor = GTKHTML_EDITOR (editor);
