@@ -27,13 +27,9 @@
 #include <glib/gstdio.h>
 #include "e-util/e-signature-utils.h"
 
-#define E_SIGNATURE_PREVIEW_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_SIGNATURE_PREVIEW, ESignaturePreviewPrivate))
-
 enum {
 	PROP_0,
-	PROP_ALLOW_SCRIPTS,
+	PROP_DISABLE_COMMAND_LINE,
 	PROP_SIGNATURE
 };
 
@@ -44,7 +40,7 @@ enum {
 
 struct _ESignaturePreviewPrivate {
 	ESignature *signature;
-	guint allow_scripts : 1;
+	guint disable_command_line : 1;
 };
 
 static guint signals[LAST_SIGNAL];
@@ -61,8 +57,8 @@ signature_preview_set_property (GObject *object,
                                 GParamSpec *pspec)
 {
 	switch (property_id) {
-		case PROP_ALLOW_SCRIPTS:
-			e_signature_preview_set_allow_scripts (
+		case PROP_DISABLE_COMMAND_LINE:
+			e_signature_preview_set_disable_command_line (
 				E_SIGNATURE_PREVIEW (object),
 				g_value_get_boolean (value));
 			return;
@@ -84,15 +80,17 @@ signature_preview_get_property (GObject *object,
                                 GParamSpec *pspec)
 {
 	switch (property_id) {
-		case PROP_ALLOW_SCRIPTS:
+		case PROP_DISABLE_COMMAND_LINE:
 			g_value_set_boolean (
-				value, e_signature_preview_get_allow_scripts (
+				value,
+				e_signature_preview_get_disable_command_line (
 				E_SIGNATURE_PREVIEW (object)));
 			return;
 
 		case PROP_SIGNATURE:
 			g_value_set_object (
-				value, e_signature_preview_get_signature (
+				value,
+				e_signature_preview_get_signature (
 				E_SIGNATURE_PREVIEW (object)));
 			return;
 	}
@@ -105,7 +103,7 @@ signature_preview_dispose (GObject *object)
 {
 	ESignaturePreviewPrivate *priv;
 
-	priv = E_SIGNATURE_PREVIEW_GET_PRIVATE (object);
+	priv = E_SIGNATURE_PREVIEW (object)->priv;
 
 	if (priv->signature != NULL) {
 		g_object_unref (priv->signature);
@@ -116,6 +114,26 @@ signature_preview_dispose (GObject *object)
 	G_OBJECT_CLASS (e_signature_preview_parent_class)->dispose (object);
 }
 
+static void
+signature_preview_constructed (GObject *object)
+{
+#ifndef G_OS_WIN32
+	GSettings *settings;
+
+	settings = g_settings_new ("org.gnome.desktop.lockdown");
+
+	g_settings_bind (
+		settings, "disable-command-line",
+		object, "disable-command-line",
+		G_SETTINGS_BIND_GET);
+
+	g_object_unref (settings);
+#endif
+
+	/* Chain up to parent's constructed() method. */
+	G_OBJECT_CLASS (e_signature_preview_parent_class)->constructed (object);
+}
+
 static void
 signature_preview_refresh (ESignaturePreview *preview)
 {
@@ -136,7 +154,7 @@ signature_preview_refresh (ESignaturePreview *preview)
 	filename = e_signature_get_filename (signature);
 	is_script = e_signature_get_is_script (signature);
 
-	if (is_script && !preview->priv->allow_scripts)
+	if (is_script && preview->priv->disable_command_line)
 		goto clear;
 
 	if (is_script)
@@ -178,17 +196,18 @@ e_signature_preview_class_init (ESignaturePreviewClass *class)
 	object_class->set_property = signature_preview_set_property;
 	object_class->get_property = signature_preview_get_property;
 	object_class->dispose = signature_preview_dispose;
+	object_class->constructed = signature_preview_constructed;
 
 	class->refresh = signature_preview_refresh;
 
 	g_object_class_install_property (
 		object_class,
-		PROP_ALLOW_SCRIPTS,
+		PROP_DISABLE_COMMAND_LINE,
 		g_param_spec_boolean (
-			"allow-scripts",
-			"Allow Scripts",
+			"disable-command-line",
+			"Disable Command Line",
 			NULL,
-			TRUE,
+			FALSE,
 			G_PARAM_READWRITE |
 			G_PARAM_CONSTRUCT));
 
@@ -215,7 +234,8 @@ e_signature_preview_class_init (ESignaturePreviewClass *class)
 static void
 e_signature_preview_init (ESignaturePreview *preview)
 {
-	preview->priv = E_SIGNATURE_PREVIEW_GET_PRIVATE (preview);
+	preview->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		preview, E_TYPE_SIGNATURE_PREVIEW, ESignaturePreviewPrivate);
 }
 
 GtkWidget *
@@ -233,21 +253,22 @@ e_signature_preview_refresh (ESignaturePreview *preview)
 }
 
 gboolean
-e_signature_preview_get_allow_scripts (ESignaturePreview *preview)
+e_signature_preview_get_disable_command_line (ESignaturePreview *preview)
 {
 	g_return_val_if_fail (E_IS_SIGNATURE_PREVIEW (preview), FALSE);
 
-	return preview->priv->allow_scripts;
+	return preview->priv->disable_command_line;
 }
 
 void
-e_signature_preview_set_allow_scripts (ESignaturePreview *preview,
-                                       gboolean allow_scripts)
+e_signature_preview_set_disable_command_line (ESignaturePreview *preview,
+                                              gboolean disable_command_line)
 {
 	g_return_if_fail (E_IS_SIGNATURE_PREVIEW (preview));
 
-	preview->priv->allow_scripts = allow_scripts;
-	g_object_notify (G_OBJECT (preview), "allow-scripts");
+	preview->priv->disable_command_line = disable_command_line;
+
+	g_object_notify (G_OBJECT (preview), "disable-command-line");
 }
 
 ESignature *
