@@ -14,9 +14,6 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
  */
 
 /* This is intended to serve as a common base class for all HTML viewing
@@ -88,6 +85,8 @@ struct _EWebViewClass {
 						 const gchar *status_message);
 	void		(*stop_loading)		(EWebView *web_view);
 	void		(*update_actions)	(EWebView *web_view);
+	gboolean	(*process_mailto)	(EWebView *web_view,
+						 const gchar *mailto_uri);
 };
 
 GType		e_web_view_get_type		(void);
