@@ -68,9 +68,6 @@
 #include "e-cell-combo.h"
 #include "e-cell-text.h"
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
 #define d(x)
 
 /* The height to make the popup list if there aren't any items in it. */
@@ -109,13 +106,13 @@ static gint e_cell_combo_key_press	(GtkWidget	*popup_window,
 static void e_cell_combo_update_cell	(ECellCombo	*ecc);
 static void e_cell_combo_restart_edit	(ECellCombo	*ecc);
 
-G_DEFINE_TYPE (ECellCombo, e_cell_combo, E_CELL_POPUP_TYPE)
+G_DEFINE_TYPE (ECellCombo, e_cell_combo, E_TYPE_CELL_POPUP)
 
 static void
-e_cell_combo_class_init			(ECellComboClass	*klass)
+e_cell_combo_class_init			(ECellComboClass	*class)
 {
-	ECellPopupClass *ecpc = E_CELL_POPUP_CLASS (klass);
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	ECellPopupClass *ecpc = E_CELL_POPUP_CLASS (class);
+	GObjectClass *object_class = G_OBJECT_CLASS (class);
 
 	object_class->dispose = e_cell_combo_dispose;
 
@@ -203,11 +200,9 @@ e_cell_combo_init			(ECellCombo	*ecc)
  * Returns: an ECellCombo object.
  */
 ECell *
-e_cell_combo_new			(void)
+e_cell_combo_new (void)
 {
-	ECellCombo *ecc = g_object_new (E_CELL_COMBO_TYPE, NULL);
-
-	return (ECell*) ecc;
+	return g_object_new (E_TYPE_CELL_COMBO, NULL);
 }
 
 /*
@@ -426,8 +421,8 @@ e_cell_combo_get_popup_pos		(ECellCombo	*ecc,
 	/* The ETable positions don't include the grid lines, I think, so we add 1. */
 	*y += y1 + 1
 		- (gint)gtk_adjustment_get_value (
-			gtk_layout_get_vadjustment (
-			&((GnomeCanvas *)canvas)->layout))
+			gtk_scrollable_get_vadjustment (
+			GTK_SCROLLABLE (&((GnomeCanvas *)canvas)->layout)))
 		+ ((GnomeCanvas *)canvas)->zoom_yofs;
 
 	widget = gtk_scrolled_window_get_vscrollbar (popup);
@@ -447,7 +442,7 @@ e_cell_combo_get_popup_pos		(ECellCombo	*ecc,
 	widget = gtk_scrolled_window_get_vscrollbar (popup);
 	gtk_widget_get_child_requisition (widget, &requisition);
 
-	gtk_widget_size_request (ecc->popup_tree_view, &list_requisition);
+	gtk_widget_get_preferred_size (ecc->popup_tree_view, &list_requisition, NULL);
 	min_height = MIN (list_requisition.height, requisition.height);
 	if (!gtk_tree_model_iter_n_children (gtk_tree_view_get_model (GTK_TREE_VIEW (ecc->popup_tree_view)), NULL))
 		list_requisition.height += E_CELL_COMBO_LIST_EMPTY_HEIGHT;
