@@ -26,28 +26,33 @@
 
 #include <gtk/gtk.h>
 #include <table/e-table-header.h>
+#include <libgnomecanvas/libgnomecanvas.h>
+
+/* Standard GObject macros */
+#define E_TYPE_TABLE_FIELD_CHOOSER \
+	(e_table_field_chooser_get_type ())
+#define E_TABLE_FIELD_CHOOSER(obj) \
+	(G_TYPE_CHECK_INSTANCE_CAST \
+	((obj), E_TYPE_TABLE_FIELD_CHOOSER, ETableFieldChooser))
+#define E_TABLE_FIELD_CHOOSER_CLASS(cls) \
+	(G_TYPE_CHECK_CLASS_CAST \
+	((cls), E_TYPE_TABLE_FIELD_CHOOSER, ETableFieldChooserClass))
+#define E_IS_TABLE_FIELD_CHOOSER(obj) \
+	(G_TYPE_CHECK_INSTANCE_TYPE \
+	((obj), E_TYPE_TABLE_FIELD_CHOOSER))
+#define E_IS_TABLE_FIELD_CHOOSER_CLASS(cls) \
+	(G_TYPE_CHECK_CLASS_TYPE \
+	((cls), E_TYPE_TABLE_FIELD_CHOOSER))
+#define E_TABLE_FIELD_CHOOSER_GET_CLASS(obj) \
+	(G_TYPE_INSTANCE_GET_CLASS \
+	((obj), E_TYPE_TABLE_FIELD_CHOOSER, ETableFieldChooserClass))
 
 G_BEGIN_DECLS
 
-/* ETableFieldChooser - A dialog displaying information about a contact.
- *
- * The following arguments are available:
- *
- * name		type		read/write	description
- * --------------------------------------------------------------------------------
- */
+typedef struct _ETableFieldChooser ETableFieldChooser;
+typedef struct _ETableFieldChooserClass ETableFieldChooserClass;
 
-#define E_TABLE_FIELD_CHOOSER_TYPE			(e_table_field_chooser_get_type ())
-#define E_TABLE_FIELD_CHOOSER(obj)			(G_TYPE_CHECK_INSTANCE_CAST ((obj), E_TABLE_FIELD_CHOOSER_TYPE, ETableFieldChooser))
-#define E_TABLE_FIELD_CHOOSER_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST ((klass), E_TABLE_FIELD_CHOOSER_TYPE, ETableFieldChooserClass))
-#define E_IS_TABLE_FIELD_CHOOSER(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), E_TABLE_FIELD_CHOOSER_TYPE))
-#define E_IS_TABLE_FIELD_CHOOSER_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((obj), E_TABLE_FIELD_CHOOSER_TYPE))
-
-typedef struct _ETableFieldChooser       ETableFieldChooser;
-typedef struct _ETableFieldChooserClass  ETableFieldChooserClass;
-
-struct _ETableFieldChooser
-{
+struct _ETableFieldChooser {
 	GtkVBox parent;
 
 	/* item specific fields */
@@ -62,13 +67,12 @@ struct _ETableFieldChooser
 	ETableHeader *header;
 };
 
-struct _ETableFieldChooserClass
-{
+struct _ETableFieldChooserClass {
 	GtkVBoxClass parent_class;
 };
 
-GtkWidget *e_table_field_chooser_new(void);
-GType      e_table_field_chooser_get_type (void);
+GType		e_table_field_chooser_get_type	(void) G_GNUC_CONST;
+GtkWidget *	e_table_field_chooser_new	(void);
 
 G_END_DECLS
 
