@@ -264,18 +264,9 @@ e_table_model_value_to_string (ETableModel *e_table_model, gint col, gconstpoint
 }
 
 static void
-e_table_model_finalize (GObject *object)
+e_table_model_class_init (ETableModelClass *class)
 {
-	if (G_OBJECT_CLASS (e_table_model_parent_class)->finalize)
-		(* G_OBJECT_CLASS (e_table_model_parent_class)->finalize)(object);
-}
-
-static void
-e_table_model_class_init (ETableModelClass *klass)
-{
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-
-	object_class->finalize = e_table_model_finalize;
+	GObjectClass *object_class = G_OBJECT_CLASS (class);
 
 	e_table_model_signals[MODEL_NO_CHANGE] =
 		g_signal_new ("model_no_change",
@@ -340,31 +331,31 @@ e_table_model_class_init (ETableModelClass *klass)
 			      e_marshal_VOID__INT_INT,
 			      G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
 
-	klass->column_count        = NULL;
-	klass->row_count           = NULL;
-	klass->append_row          = NULL;
+	class->column_count        = NULL;
+	class->row_count           = NULL;
+	class->append_row          = NULL;
 
-	klass->value_at            = NULL;
-	klass->set_value_at        = NULL;
-	klass->is_cell_editable    = NULL;
+	class->value_at            = NULL;
+	class->set_value_at        = NULL;
+	class->is_cell_editable    = NULL;
 
-	klass->has_save_id         = NULL;
-	klass->get_save_id         = NULL;
+	class->has_save_id         = NULL;
+	class->get_save_id         = NULL;
 
-	klass->has_change_pending  = NULL;
+	class->has_change_pending  = NULL;
 
-	klass->duplicate_value     = NULL;
-	klass->free_value          = NULL;
-	klass->initialize_value    = NULL;
-	klass->value_is_empty      = NULL;
-	klass->value_to_string     = NULL;
+	class->duplicate_value     = NULL;
+	class->free_value          = NULL;
+	class->initialize_value    = NULL;
+	class->value_is_empty      = NULL;
+	class->value_to_string     = NULL;
 
-	klass->model_no_change     = NULL;
-	klass->model_changed       = NULL;
-	klass->model_row_changed   = NULL;
-	klass->model_cell_changed  = NULL;
-	klass->model_rows_inserted = NULL;
-	klass->model_rows_deleted  = NULL;
+	class->model_no_change     = NULL;
+	class->model_changed       = NULL;
+	class->model_row_changed   = NULL;
+	class->model_cell_changed  = NULL;
+	class->model_rows_inserted = NULL;
+	class->model_rows_deleted  = NULL;
 }
 
 static void
@@ -393,7 +384,7 @@ e_table_model_pre_change (ETableModel *e_table_model)
 		return;
 
 	d (print_tabs ());
-	d(g_print("Emitting pre_change on model 0x%p, a %s.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->klass->type)));
+	d(g_print("Emitting pre_change on model 0x%p, a %s.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->class->type)));
 	d (depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals[MODEL_PRE_CHANGE], 0);
@@ -423,7 +414,7 @@ e_table_model_no_change (ETableModel *e_table_model)
 		return;
 
 	d (print_tabs ());
-	d(g_print("Emitting model_no_change on model 0x%p, a %s.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->klass->type)));
+	d(g_print("Emitting model_no_change on model 0x%p, a %s.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->class->type)));
 	d (depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals[MODEL_NO_CHANGE], 0);
@@ -453,7 +444,7 @@ e_table_model_changed (ETableModel *e_table_model)
 		return;
 
 	d (print_tabs ());
-	d(g_print("Emitting model_changed on model 0x%p, a %s.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->klass->type)));
+	d(g_print("Emitting model_changed on model 0x%p, a %s.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->class->type)));
 	d (depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals[MODEL_CHANGED], 0);
@@ -480,7 +471,7 @@ e_table_model_row_changed (ETableModel *e_table_model, gint row)
 		return;
 
 	d (print_tabs ());
-	d(g_print("Emitting row_changed on model 0x%p, a %s, row %d.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->klass->type), row));
+	d(g_print("Emitting row_changed on model 0x%p, a %s, row %d.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->class->type), row));
 	d (depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals[MODEL_ROW_CHANGED], 0, row);
@@ -508,7 +499,7 @@ e_table_model_cell_changed (ETableModel *e_table_model, gint col, gint row)
 		return;
 
 	d (print_tabs ());
-	d(g_print("Emitting cell_changed on model 0x%p, a %s, row %d, col %d.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->klass->type), row, col));
+	d(g_print("Emitting cell_changed on model 0x%p, a %s, row %d, col %d.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->class->type), row, col));
 	d (depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals[MODEL_CELL_CHANGED], 0, col, row);
@@ -536,7 +527,7 @@ e_table_model_rows_inserted (ETableModel *e_table_model, gint row, gint count)
 		return;
 
 	d (print_tabs ());
-	d(g_print("Emitting row_inserted on model 0x%p, a %s, row %d.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->klass->type), row));
+	d(g_print("Emitting row_inserted on model 0x%p, a %s, row %d.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->class->type), row));
 	d (depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals[MODEL_ROWS_INSERTED], 0, row, count);
@@ -579,7 +570,7 @@ e_table_model_rows_deleted (ETableModel *e_table_model, gint row, gint count)
 		return;
 
 	d (print_tabs ());
-	d(g_print("Emitting row_deleted on model 0x%p, a %s, row %d.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->klass->type), row));
+	d(g_print("Emitting row_deleted on model 0x%p, a %s, row %d.\n", e_table_model, g_type_name (G_OBJECT(e_table_model)->class->type), row));
 	d (depth++);
 	g_signal_emit (G_OBJECT (e_table_model),
 		       e_table_model_signals[MODEL_ROWS_DELETED], 0, row, count);
