@@ -71,8 +71,16 @@ static AtkObject* eti_ref_at (AtkTable *table, gint row, gint column);
 static void
 item_finalized (gpointer user_data, GObject *gone_item)
 {
-	GalA11yETableItem *a11y = GAL_A11Y_E_TABLE_ITEM (user_data);
-	GalA11yETableItemPrivate *priv = GET_PRIVATE (a11y);
+	GalA11yETableItem *a11y;
+	GalA11yETableItemPrivate *priv;
+
+	/* XXX GalA11yETableItem may already be finalized.
+	 *     Just work around it for now. */
+	if (!GAL_A11Y_IS_E_TABLE_ITEM (user_data))
+		return;
+
+	a11y = GAL_A11Y_E_TABLE_ITEM (user_data);
+	priv = GET_PRIVATE (a11y);
 
 	atk_state_set_add_state (priv->state_set, ATK_STATE_DEFUNCT);
 	atk_object_notify_state_change (ATK_OBJECT (a11y), ATK_STATE_DEFUNCT, TRUE);
@@ -180,7 +188,8 @@ eti_a11y_reset_focus_object (GalA11yETableItem *a11y,
 
 	old_cell = (AtkObject *)g_object_get_data (G_OBJECT (a11y), "gail-focus-object");
 	if (old_cell && GAL_A11Y_IS_E_CELL (old_cell))
-		gal_a11y_e_cell_remove_state (GAL_A11Y_E_CELL (old_cell), ATK_STATE_FOCUSED, FALSE);
+		gal_a11y_e_cell_remove_state (
+			GAL_A11Y_E_CELL (old_cell), ATK_STATE_FOCUSED, FALSE);
 	if (old_cell)
 		g_object_unref (old_cell);
 
@@ -188,7 +197,8 @@ eti_a11y_reset_focus_object (GalA11yETableItem *a11y,
 
 	if (cell != NULL) {
 		g_object_set_data (G_OBJECT (a11y), "gail-focus-object", cell);
-		gal_a11y_e_cell_add_state (GAL_A11Y_E_CELL (cell), ATK_STATE_FOCUSED, FALSE);
+		gal_a11y_e_cell_add_state (
+			GAL_A11Y_E_CELL (cell), ATK_STATE_FOCUSED, FALSE);
 	} else
 		g_object_set_data (G_OBJECT (a11y), "gail-focus-object", NULL);
 
