@@ -55,9 +55,6 @@
 
 #include "e-text.h"
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
 G_DEFINE_TYPE (EText, e_text, GNOME_TYPE_CANVAS_ITEM)
 
 #define BORDER_INDENT 3
@@ -184,7 +181,8 @@ disconnect_im_context (EText *text)
 	if (!text || !text->im_context)
 		return;
 
-	g_signal_handlers_disconnect_matched (text->im_context, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, text);
+	g_signal_handlers_disconnect_matched (
+		text->im_context, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, text);
 	text->im_context_signals_registered = FALSE;
 }
 
@@ -276,8 +274,8 @@ e_text_dispose (GObject *object)
 		text->font_desc = NULL;
 	}
 
-	if (G_OBJECT_CLASS (e_text_parent_class)->dispose)
-		(* G_OBJECT_CLASS (e_text_parent_class)->dispose) (object);
+	/* Chain up to parent's dispose() method. */
+	G_OBJECT_CLASS (e_text_parent_class)->dispose (object);
 }
 
 static void
@@ -362,8 +360,10 @@ reset_layout_attrs (EText *text)
 
 			e_text_model_get_nth_object_bounds (text->model, i, &start_pos, &end_pos);
 
-			attr->start_index = g_utf8_offset_to_pointer (text->text, start_pos) - text->text;
-			attr->end_index = g_utf8_offset_to_pointer (text->text, end_pos) - text->text;
+			attr->start_index = g_utf8_offset_to_pointer (
+				text->text, start_pos) - text->text;
+			attr->end_index = g_utf8_offset_to_pointer (
+				text->text, end_pos) - text->text;
 
 			pango_attr_list_insert (attrs, attr);
 		}
@@ -403,7 +403,8 @@ create_layout (EText *text)
 	if (text->layout)
 		return;
 
-	text->layout = gtk_widget_create_pango_layout (GTK_WIDGET (item->canvas), text->text);
+	text->layout = gtk_widget_create_pango_layout (
+		GTK_WIDGET (item->canvas), text->text);
 	if (text->line_wrap)
 		pango_layout_set_width (
 			text->layout, text->clip_width < 0
@@ -539,8 +540,8 @@ get_bounds (EText *text, gdouble *px1, gdouble *py1, gdouble *px2, gdouble *py2)
 		clip_height = text->clip_height;
 
 	/* Get canvas pixel coordinates for clip rectangle position */
-	text->clip_cwidth = clip_width * item->canvas->pixels_per_unit;
-	text->clip_cheight = clip_height * item->canvas->pixels_per_unit;
+	text->clip_cwidth = clip_width;
+	text->clip_cheight = clip_height;
 
 	text->text_cx = text->cx;
 	text->text_cy = text->cy;
@@ -768,7 +769,7 @@ e_text_set_property (GObject *object,
 		needs_update = 1;
 		break;
 
-        case PROP_FILL_COLOR:
+	case PROP_FILL_COLOR:
 		if (g_value_get_string (value))
 			gdk_color_parse (g_value_get_string (value), &color);
 
@@ -794,7 +795,7 @@ e_text_set_property (GObject *object,
 		needs_update = 1;
 		break;
 
-        case PROP_FILL_COLOR_RGBA:
+	case PROP_FILL_COLOR_RGBA:
 		text->rgba = g_value_get_uint (value);
 		color.red = ((text->rgba >> 24) & 0xff) * 0x101;
 		color.green = ((text->rgba >> 16) & 0xff) * 0x101;
@@ -1006,11 +1007,11 @@ e_text_get_property (GObject *object,
 		break;
 
 	case PROP_TEXT_WIDTH:
-		g_value_set_double (value, text->width / text->item.canvas->pixels_per_unit);
+		g_value_set_double (value, text->width);
 		break;
 
 	case PROP_TEXT_HEIGHT:
-		g_value_set_double (value, text->height / text->item.canvas->pixels_per_unit);
+		g_value_set_double (value, text->height);
 		break;
 
 	case PROP_EDITABLE:
@@ -1045,8 +1046,7 @@ e_text_get_property (GObject *object,
 		g_value_set_double (
 			value, text->clip &&
 			text->clip_height != -1 ?
-			text->clip_height : text->height /
-			text->item.canvas->pixels_per_unit);
+			text->clip_height : text->height);
 		break;
 
 	case PROP_DRAW_BORDERS:
@@ -1127,25 +1127,28 @@ e_text_update (GnomeCanvasItem *item, const cairo_matrix_t *i2c, gint flags)
 
 	if ( text->needs_recalc_bounds
 	     || (flags & GNOME_CANVAS_UPDATE_AFFINE)) {
-                get_bounds (text, &x1, &y1, &x2, &y2);
-                if ( item->x1 != x1 ||
-                     item->x2 != x2 ||
-                     item->y1 != y1 ||
-                     item->y2 != y2 ) {
-                        gnome_canvas_request_redraw (item->canvas, item->x1, item->y1, item->x2, item->y2);
-                        item->x1 = x1;
-                        item->y1 = y1;
-                        item->x2 = x2;
-                        item->y2 = y2;
-                        text->needs_redraw = 1;
-                        item->canvas->need_repick = TRUE;
-                }
-                if (!text->fill_clip_rectangle)
-                        item->canvas->need_repick = TRUE;
+		get_bounds (text, &x1, &y1, &x2, &y2);
+		if ( item->x1 != x1 ||
+		     item->x2 != x2 ||
+		     item->y1 != y1 ||
+		     item->y2 != y2 ) {
+			gnome_canvas_request_redraw (
+				item->canvas, item->x1, item->y1,
+				item->x2, item->y2);
+			item->x1 = x1;
+			item->y1 = y1;
+			item->x2 = x2;
+			item->y2 = y2;
+			text->needs_redraw = 1;
+			item->canvas->need_repick = TRUE;
+		}
+		if (!text->fill_clip_rectangle)
+			item->canvas->need_repick = TRUE;
 		text->needs_recalc_bounds = 0;
 	}
 	if (text->needs_redraw) {
-		gnome_canvas_request_redraw (item->canvas, item->x1, item->y1, item->x2, item->y2);
+		gnome_canvas_request_redraw (
+			item->canvas, item->x1, item->y1, item->x2, item->y2);
 		text->needs_redraw = 0;
 	}
 }
@@ -1175,9 +1178,9 @@ e_text_unrealize (GnomeCanvasItem *item)
 
 	text = E_TEXT (item);
 
-	gdk_cursor_unref (text->i_cursor);
+	g_object_unref (text->i_cursor);
 	text->i_cursor = NULL;
-	gdk_cursor_unref (text->default_cursor);
+	g_object_unref (text->default_cursor);
 	text->default_cursor = NULL;
 
 	if (GNOME_CANVAS_ITEM_CLASS (e_text_parent_class)->unrealize)
@@ -1198,20 +1201,23 @@ _get_tep (EText *text)
 }
 
 static void
-draw_pango_rectangle (GdkDrawable *drawable,
-                      cairo_t *cr,
+draw_pango_rectangle (cairo_t *cr,
                       gint x1,
                       gint y1,
                       PangoRectangle rect)
 {
 	gint width = rect.width / PANGO_SCALE;
 	gint height = rect.height / PANGO_SCALE;
+
 	if (width <= 0)
 		width = 1;
 	if (height <= 0)
 		height = 1;
-	cairo_rectangle (cr, x1 + rect.x / PANGO_SCALE, y1 + rect.y / PANGO_SCALE, width, height);
-        cairo_fill (cr);
+
+	cairo_rectangle (
+		cr, x1 + rect.x / PANGO_SCALE,
+		y1 + rect.y / PANGO_SCALE, width, height);
+	cairo_fill (cr);
 }
 
 static gboolean
@@ -1280,15 +1286,13 @@ show_pango_rectangle (EText *text, PangoRectangle rect)
 
 /* Draw handler for the text item */
 static void
-e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
+e_text_draw (GnomeCanvasItem *item, cairo_t *cr,
 	     gint x, gint y, gint width, gint height)
 {
 	EText *text;
 	gint xpos, ypos;
-	cairo_t *cr;
 	GnomeCanvas *canvas;
 	GtkWidget *widget;
-	GdkWindow *window;
 	GtkStyle *style;
 	GtkStateType state;
 
@@ -1297,17 +1301,17 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 	widget = GTK_WIDGET (canvas);
 	state = gtk_widget_get_state (widget);
 	style = gtk_widget_get_style (widget);
-	window = gtk_widget_get_window (widget);
-        cr = gdk_cairo_create (drawable);
+
+	cairo_save (cr);
 
 	if (text->draw_background || text->draw_button) {
 		gdk_cairo_set_source_color (cr, &style->fg[state]);
 	} else {
-                cairo_set_source_rgba (cr,
-                                       ((text->rgba >> 24) & 0xff) / 255.0,
-                                       ((text->rgba >> 16) & 0xff) / 255.0,
-                                       ((text->rgba >>  8) & 0xff) / 255.0,
-                                       ( text->rgba        & 0xff) / 255.0);
+		cairo_set_source_rgba (cr,
+				       ((text->rgba >> 24) & 0xff) / 255.0,
+				       ((text->rgba >> 16) & 0xff) / 255.0,
+				       ((text->rgba >>  8) & 0xff) / 255.0,
+				       ( text->rgba        & 0xff) / 255.0);
 	}
 
 	if (text->draw_borders || text->draw_background) {
@@ -1323,17 +1327,17 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 
 		if (text->draw_borders) {
 
-			gtk_paint_shadow (style, drawable,
+			gtk_paint_shadow (style, cr,
 					  GTK_STATE_NORMAL, GTK_SHADOW_IN,
-					  NULL, widget, "entry",
+					  widget, "entry",
 					  thisx, thisy, thiswidth, thisheight);
 
 		}
 
 		if (text->draw_background) {
-			gtk_paint_flat_box (style, drawable,
+			gtk_paint_flat_box (style, cr,
 					    state, GTK_SHADOW_NONE,
-					    NULL, widget, "entry_bg",
+					    widget, "entry_bg",
 					    thisx + style->xthickness,
 					    thisy + style->ythickness,
 					    thiswidth - style->xthickness * 2,
@@ -1367,12 +1371,6 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 			guint border_width;
 			gint thisx, thisy, thisheight, thiswidth;
 			gint default_spacing;
-			GdkRectangle area;
-
-			area.x = 0;
-			area.y = 0;
-			area.width = width;
-			area.height = height;
 
 			gtk_widget_get_allocation (widget, &allocation);
 			relief = gtk_button_get_relief (GTK_BUTTON (widget));
@@ -1394,9 +1392,9 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 			if (gtk_widget_has_default (widget) &&
 			    relief == GTK_RELIEF_NORMAL)
 				{
-					gtk_paint_box (style, drawable,
+					gtk_paint_box (style, cr,
 						       GTK_STATE_NORMAL, GTK_SHADOW_IN,
-						       &area, widget, "buttondefault",
+						       widget, "buttondefault",
 						       thisx + xoff, thisy + yoff, thiswidth, thisheight);
 				}
 
@@ -1424,8 +1422,8 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 			if ((relief != GTK_RELIEF_NONE) ||
 			    ((state != GTK_STATE_NORMAL) &&
 			     (state != GTK_STATE_INSENSITIVE)))
-			gtk_paint_box (style, drawable, state,
-				       shadow_type, &area, widget, "button",
+			gtk_paint_box (style, cr, state,
+				       shadow_type, widget, "button",
 				       thisx + xoff, thisy + yoff,
 				       thiswidth, thisheight);
 
@@ -1435,8 +1433,8 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 				thiswidth += 2;
 				thisheight += 2;
 
-				gtk_paint_focus (style, window, state,
-						 &area, widget, "button",
+				gtk_paint_focus (style, cr, state,
+						 widget, "button",
 						 thisx + xoff, thisy + yoff,
 						 thiswidth - 1, thisheight - 1);
 			}
@@ -1454,7 +1452,7 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 		reset_layout (text);
 
 	if (!pango_layout_get_text (text->layout)) {
-		cairo_destroy (cr);
+		cairo_restore (cr);
 		return;
 	}
 
@@ -1464,12 +1462,14 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 	xpos = xpos - x + text->xofs;
 	ypos = ypos - y + text->yofs;
 
+	cairo_save (cr);
+
 	if (text->clip) {
-                cairo_rectangle (cr,
-                                 xpos, ypos,
-                                 text->clip_cwidth - text->xofs,
-                                 text->clip_cheight - text->yofs);
-                cairo_clip (cr);
+		cairo_rectangle (cr,
+				 xpos, ypos,
+				 text->clip_cwidth - text->xofs,
+				 text->clip_cheight - text->yofs);
+		cairo_clip (cr);
 	}
 
 	if (text->editing) {
@@ -1477,16 +1477,19 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 		ypos -= text->yofs_edit;
 	}
 
-        cairo_move_to (cr, xpos, ypos);
-        pango_cairo_show_layout (cr, text->layout);
+	cairo_move_to (cr, xpos, ypos);
+	pango_cairo_show_layout (cr, text->layout);
 
 	if (text->editing) {
 		if (text->selection_start != text->selection_end) {
-			GdkRegion *clip_region = gdk_region_new ();
+			cairo_region_t *clip_region = cairo_region_create ();
 			gint indices[2];
-                        GtkStateType state;
+			GtkStateType state;
 
-                        state = text->has_selection ? GTK_STATE_SELECTED : GTK_STATE_ACTIVE;
+			if (text->has_selection)
+				state = GTK_STATE_SELECTED;
+			else
+				state = GTK_STATE_ACTIVE;
 
 			indices[0] = MIN (text->selection_start, text->selection_end);
 			indices[1] = MAX (text->selection_start, text->selection_end);
@@ -1495,19 +1498,19 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 			indices[0] = g_utf8_offset_to_pointer (text->text, indices[0]) - text->text;
 			indices[1] = g_utf8_offset_to_pointer (text->text, indices[1]) - text->text;
 
-                        clip_region = gdk_pango_layout_get_clip_region (text->layout,
-                                                                        xpos, ypos,
-                                                                        indices, 1);
-                        gdk_cairo_region (cr, clip_region);
-                        cairo_clip (cr);
-			gdk_region_destroy (clip_region);
+			clip_region = gdk_pango_layout_get_clip_region (text->layout,
+									xpos, ypos,
+									indices, 1);
+			gdk_cairo_region (cr, clip_region);
+			cairo_clip (cr);
+			cairo_region_destroy (clip_region);
 
-                        gdk_cairo_set_source_color (cr, &style->base[state]);
-                        cairo_paint (cr);
+			gdk_cairo_set_source_color (cr, &style->base[state]);
+			cairo_paint (cr);
 
-                        gdk_cairo_set_source_color (cr, &style->text[state]);
-                        cairo_move_to (cr, xpos, ypos);
-                        pango_cairo_show_layout (cr, text->layout);
+			gdk_cairo_set_source_color (cr, &style->text[state]);
+			cairo_move_to (cr, xpos, ypos);
+			pango_cairo_show_layout (cr, text->layout);
 		} else {
 			if (text->show_cursor) {
 				PangoRectangle strong_pos, weak_pos;
@@ -1517,17 +1520,18 @@ e_text_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 					text->layout, offs - text->text +
 					text->preedit_len, &strong_pos,
 					&weak_pos);
-				draw_pango_rectangle (drawable, cr, xpos, ypos, strong_pos);
+				draw_pango_rectangle (cr, xpos, ypos, strong_pos);
 				if (strong_pos.x != weak_pos.x ||
 				    strong_pos.y != weak_pos.y ||
 				    strong_pos.width != weak_pos.width ||
 				    strong_pos.height != weak_pos.height)
-					draw_pango_rectangle (drawable, cr, xpos, ypos, weak_pos);
+					draw_pango_rectangle (cr, xpos, ypos, weak_pos);
 			}
 		}
 	}
 
-	cairo_destroy (cr);
+	cairo_restore (cr);
+	cairo_restore (cr);
 }
 
 /* Point handler for the text item */
@@ -1557,10 +1561,6 @@ e_text_point (GnomeCanvasItem *item, gdouble x, gdouble y,
 	else
 		clip_height = text->clip_height;
 
-	/* Get canvas pixel coordinates for clip rectangle position */
-	clip_width = clip_width * item->canvas->pixels_per_unit;
-	clip_height = clip_height * item->canvas->pixels_per_unit;
-
 	if (cx < text->clip_cx ||
 	    cx > text->clip_cx + clip_width ||
 	    cy < text->clip_cy ||
@@ -1604,9 +1604,6 @@ e_text_bounds (GnomeCanvasItem *item,
 			height = text->clip_height;
 	}
 
-	width = width / item->canvas->pixels_per_unit;
-	height = height / item->canvas->pixels_per_unit;
-
 	*x2 = *x1 + width;
 	*y2 = *y1 + height;
 }
@@ -1699,7 +1696,9 @@ _blink_scroll_timeout (gpointer data)
 			e_tep_event.type = GDK_MOTION_NOTIFY;
 			e_tep_event.motion.state = text->last_state;
 			e_tep_event.motion.time = 0;
-			e_tep_event.motion.position = get_position_from_xy (text, text->lastx, text->lasty);
+			e_tep_event.motion.position =
+				get_position_from_xy (
+				text, text->lastx, text->lasty);
 			_get_tep (text);
 			e_text_event_processor_handle_event (text->tep,
 							     &e_tep_event);
@@ -1870,7 +1869,8 @@ e_text_event (GnomeCanvasItem *item, GdkEvent *event)
 		    && (event->key.state & GDK_SHIFT_MASK)
 		    && text->handle_popup ) {
 
-			/* Simulate a GdkEventButton here, so that we can call e_text_do_popup directly */
+			/* Simulate a GdkEventButton here, so that we can
+			 * call e_text_do_popup directly */
 
 			GdkEventButton *button = (GdkEventButton *) gdk_event_new (GDK_BUTTON_PRESS);
 			button->time = event->key.time;
@@ -2472,7 +2472,8 @@ _get_updated_position (EText *text, gboolean direction)
 
 		/* if is_cursor_position is set, cursor can appear in front of character.
 		   i.e. this is a grapheme boundary AND make some sanity checks */
-		if ((new_pos >=0) && (new_pos < n_attrs) && (log_attrs[new_pos].is_cursor_position))
+		if ((new_pos >=0) && (new_pos < n_attrs) &&
+			(log_attrs[new_pos].is_cursor_position))
 			break;
 		else if ((new_pos < 0) || (new_pos >= n_attrs))
 		{
